

(*Title : Biokinetic  data *)

(* : Author : Guillermo Sanchez*)

(* : Summary : 
      Here are included the biokinetic data for some isotopes included in 
ICRP 78. It is a part of Humorap  *)

(* : Context : `Biokdata`*)

(* : Package Version : 1.2*)

(* : Copyright : Copyright 2004, 
  Guillermo Sanchez.guillerm@usal.es or gsl@fab.enusa.es*)

(* : History :  Ver 1.0, April 2003, Ver 1.1, July 2003, Ver 1.2 January 2004*)

(* : Keywords : Compartmental Models, ICRP 66, ICRP78*)

(* : Sources : ICRP 78,The ICRP Database of Dose Coefficients: workers and 
members of the public*)

(* : Mathematica Version : 4.2*)

BeginPackage["Biokmod`Biokdata`", "Biokmod`Humorap3`", "Biokmod`Resptract`", "Biokmod`Master`", "Biokmod`SysModel`"]

CompartNumbers::usage = "CompartNumbers[element] gives for element the number 
of the compartments used in the transfer rate constants."; 

compartMatrix::usage = "compartMatrix[element] gives for element the 
compartmental matrix using the applicable ICRP model. If the element has 
reciclied throw SI mush be used compartMatrixE"; 

compartMatrixE::usage = "compartMatrixE[element] gives for element the 
compartmental matrix using the applicable ICRP model adding the GI Tract"; 

TransferRates::usage = "TransferRates[element] gives for element the transfer 
rate constants for adult workers for biokinetic model defined in ICRP"; 

TransferRatesE::usage = "TransferRatesE[element] gives for element the 
transfer rate constants for adult workers for biokinetic model defined in 
ICRP, including GI tract rates"; 

ElementICRP = {americium, beryllium, barium, caesium, calcium, cobalt, iodine, iron, lead, 
neptunium, plutonium, radium, strontium, uranium, thorium, selenium, tin, silver, 
tungsten, chromium, rhodium, ruthenium, antimony, zinc, molybdenum, protactinium, 
actinium, berkelium, californium, curium, einsteinium, fermium, mendelevium, 
phosphorus, bismuth, arsenic, manganese, gallium, silicon, tantalum, iridium, 
niobium, osmium, platinum, sodium, nickel, scandium, sulfur, dysprosium, europium, 
gadolinium, lutetium, praseodymium, terbium, ytterbium, hafnium, mercuryinorg, 
mercuryorg, tellurium, zirconium, aluminium, astatine, bromine, cadmium, cerium, 
chlorine, copper, erbium, holmium, indium, lanthanum, magnesium, neodymium, palladium, 
polonium, promethium, rubidium, samarium, thulium, titanium, vanadium, yttrium, gold, 
potassium, thallium, rhenium, technetium, germanium}; 

((MessageName[#1, "usage"] = StringJoin[ToString[#1], 
      " is a chemical element included in ICRP Models."]) & ) /@ ElementICRP; 

Unknown::usage = "Unknown or non included isotope. Check that the name of 
isotope are in small letters. Data about non included isotopes can be obtain 
of CD-ROM: The ICRP Database of Dose Coefficients: workers and members of the 
public\[RightGuillemet] Elsevier Science Ltd."; 

BiokdataReport::usage="BiokdataReport[element,intakeway, intaketype, report, int,  ifd (default AMAD5), fra(default F), 
fin1,  t1, lambda, options]";

Options[BiokdataReport] = {CompartNumbers -> "False", TransferRates-> "False"};

Begin["`Private`"]

CompartNumbers[name_Symbol] := (Message[CompartNumbers::unknown, name]; "Unknown 
or non included isotope. Check that the name of isotope are in small 
letters. Non included isotopes data can be obtained of CD-ROM: <<The ICRP 
Database of Dose Coefficients: workers and members of the public\[RightGuillemet] Elsevier 
Science Ltd>>.")

compartMatrix[name_Symbol] := (Message[compartMatrix::unknown, name]; "Unknown
or non included isotope. Check that the name of isotope are in small 
letters. Non included isotopes data can be obtained of CD-ROM: <<The ICRP 
Database of Dose Coefficients: workers and members of the public\[RightGuillemet] Elsevier 
Science Ltd>>."); 

compartMatrixE[name_Symbol] := (Message[compartMatrixE::unknown, name]; "Unknown or 
non included isotope. Check that the name of isotope are in small 
letters. Non included isotopes data can be obtained of CD-ROM: <<The ICRP 
Database of Dose Coefficients: workers and members of the public\[RightGuillemet] Elsevier 
Science Ltd>>."); 

TransferRates[name_Symbol] := (Message[TransferRates::unknown, name]; "Unknow
n or non included isotope. Check that the name of isotope are in small 
letters. Non included isotopes data can be obtained of CD-ROM: <<The ICRP 
Database of Dose Coefficients: workers and members of the public\[RightGuillemet] Elsevier 
Science Ltd>>."); 

TransferRatesE[name_Symbol] := (Message[TransferRatesE::unknown, name]; "Unknown or non included isotope. Check that the name of isotope are in small
letters. Non included isotopes data can be obtained of CD-ROM: <<The ICRP 
Database of Dose Coefficients: workers and members of the public\[RightGuillemet] Elsevier 
Science Ltd>>."); 

CompartNumbers[calcium] ^= TableForm[{{1, "Plasma"}, {2, "ST2"}, {3, "ST1"}, 
     {4, "ST0"}, {5, "CorticalSurf"}, {6, "CorticalVolExch"}, 
     {7, "CorticalVolNonExch"}, {8, "TrabecularSurf"}, 
     {9, "TrabecularVolExch"}, {10, "TrabecularVolNonExch"}, {11, "Bladder"}, 
     {12, "Urine"}, {13, "ULI"}, {14, "LLI"}, {15, "Faeces"}, {16, "SI"}, 
     {17, ST}}]; 

CompartNumbers[barium] ^= TableForm[{{1, "Plasma"}, {2, "ST0"}, {3, "ST1"}, 
     {4, "ST2"}, {5, "Cortical Surface"}, {6, "Cortical Volume Exch"}, 
     {7, "Cortical Volume Nonexch"}, {8, "Trabecular Surface"}, 
     {9, "Trabecular Volume Exch"}, {10, "Trabecular Volume Nonexch"}, 
     {11, "Bladder"}, {12, "Urine"}, {13, "ULI"}, {14, "LLI"}, {15, "FEC"}}]; 

CompartNumbers[radium] ^= TableForm[{{1, "Blood"}, {2, "ST1"}, {3, "ST0"}, 
     {4, "ST2"}, {5, "CorticalSurf"}, {6, "CorticalVolExch"}, 
     {7, "CorticalVolNonExch"}, {8, "TrabecularSurface"}, {9, "ExchTrabVol"}, 
     {10, "NonExchTrabVol"}, {11, "Liver1"}, {12, "Bladder"}, {13, "Urine"}, 
     {14, "ULI"}, {15, "LLI"}, {16, "FEC"}, {17, "SI"}, {18, "ST"}}]; 

CompartNumbers[strontium] ^= TableForm[{{1, "Blood"}, {2, "ST0"}, {3, "ST1"}, 
     {4, "ST2"}, {5, "Trabecular Marrow"}, {6, "Trabecular Volume Exchange"}, 
     {7, "Trabecular Volume NonExchange"}, {8, "Cortical Surface"}, 
     {9, "Cortical Volume Exchange"}, {10, "Cortical Volume NonExchange"}, 
     {11, "Urinary Bladder"}, {12, "URINE"}, {13, "ULI"}, {14, "LLI"}, 
     {15, "FECES"}, {16, "SI"}, {17, "ST"}}]; 

CompartNumbers[uranium] ^= TableForm[{{1, "Plasma"}, {2, "RBC"}, {3, "ST0"}, 
     {4, "ST1"}, {5, "ST2"}, {6, "Liver1"}, {7, "Liver2"}, 
     {8, "UrinaryPath"}, {9, "OtherKidney"}, {10, "TrabecularSurface"}, 
     {11, "ExchTrabVol"}, {12, "NonExchTrabVol"}, {13, "CorticalSurf"}, 
     {14, "CorticalVolExch"}, {15, "CorticalVolNonExch"}, {16, "Bladder"}, 
     {17, "Urine"}, {18, "ULI"}, {19, "LLI"}, {20, "FEC"}, {21, "SI"}, 
     {22, "ST"}}]; 

CompartNumbers[plutonium] ^= TableForm[{{1, "Blood"}, {2, "ST0"}, {3, "ST1"}, 
     {4, "ST2"}, {5, "Liver1"}, {6, "Liver2"}, {7, "Kidneys(Urinary)"}, 
     {8, "Other kidneys"}, {9, "Cort. bone"}, {10, "Cort. Surface"}, 
     {11, "Cort. Vol."}, {12, "Trab. Volum"}, {13, "Trab. Surf."}, 
     {14, "Trab. bone"}, {15, "Gonads"}, {16, "Bladder"}, {17, "URI"}, 
     {18, "ULI"}, {19, "LLI"}, {20, "FEC"}, {21, "SI"}, {22, "ST"}}]; 

CompartNumbers[americium] ^= TableForm[{{1, "Blood"}, {2, "ST0"}, {3, "ST1"}, 
     {4, "ST2"}, {5, "Liver1"}, {6, "Kidneys(Urinary)"}, 
     {7, "Other kidneys"}, {8, "Cort. bone"}, {9, "Cort. Surface"}, 
     {10, "Cort. Vol."}, {11, "Trab. Volum"}, {12, "Trab. Surf."}, 
     {13, "Trab. bone"}, {14, "Gonads"}, {15, "Bladder"}, {16, "URI"}, 
     {17, "ULI"}, {18, "LLI"}, {19, "FEC"}, {20, "SI"}, {21, "ST"}}]; 

CompartNumbers[iodine] ^= TableForm[{{1, "Blood"}, {2, "Thyroid"}, 
     {3, "Rest"}, {4, "Bladder"}, {5, "Urine"}, {6, "ULI"}, {7, "LLI"}, 
     {8, "FEC"}}]; 

CompartNumbers[caesium] ^= TableForm[{{1, "Blood"}, {2, "Systemic A"}, 
     {3, "Systemic B"}, {4, "Bladder"}, {5, "Urine"}, {6, "ULI"}, {7, "LLI"}, 
     {8, "FEC"}}]; 

icrp30Number3 = TableForm[{{1,"Blood"},{2,"Systemic A"},{3,"Systemic B"},{4,
"Systemic C"},{5,"Bladder"},{6,"Urine"},{7,"ULI"},{8,"LLI"},{9,"FEC"}}];

CompartNumbers[cobalt]^= icrp30Number3;
CompartNumbers[selenium] ^= icrp30Number3;
CompartNumbers[tin] ^= icrp30Number3;
CompartNumbers[silver] ^= icrp30Number3;
CompartNumbers[tungsten] ^= icrp30Number3;
CompartNumbers[chromium] ^= icrp30Number3;
CompartNumbers[rhodium] ^= icrp30Number3;
CompartNumbers[ruthenium] ^= icrp30Number3;
CompartNumbers[antimony] ^= icrp30Number3;
CompartNumbers[zinc] ^= icrp30Number3;
CompartNumbers[molybdenum] ^= icrp30Number3;
CompartNumbers[protactinium] ^= icrp30Number3;
CompartNumbers[actinium] ^= icrp30Number3;
CompartNumbers[berkelium] ^= icrp30Number3;
CompartNumbers[einsteinium] ^= icrp30Number3;
CompartNumbers[fermium] ^= icrp30Number3;
CompartNumbers[mendelevium] ^= icrp30Number3;
CompartNumbers[phosphorus] ^= icrp30Number3;

icrp30Number2 = TableForm[{{1,"Blood"},{2,"Systemic A"},{3,"Systemic B"},
{4,"Bladder"},{5,"Urine"},{6,"ULI"},{7,"LLI"},{8,"FEC"}}];

CompartNumbers[beryllium]^= icrp30Number2;
CompartNumbers[bismuth] ^= icrp30Number2;
CompartNumbers[arsenic] ^= icrp30Number2;
CompartNumbers[manganese] ^= icrp30Number2;
CompartNumbers[gallium] ^= icrp30Number2;
CompartNumbers[silicon] ^= icrp30Number2;
CompartNumbers[tantalum] ^= icrp30Number2;
CompartNumbers[iridium] ^= icrp30Number2;
CompartNumbers[niobium] ^= icrp30Number2;
CompartNumbers[osmium] ^= icrp30Number2;
CompartNumbers[platinum] ^= icrp30Number2;
CompartNumbers[sodium] ^= icrp30Number2;
CompartNumbers[nickel] ^= icrp30Number2;
CompartNumbers[scandium] ^= icrp30Number2;
CompartNumbers[sulfur] ^= icrp30Number2;
CompartNumbers[dysprosium] ^= icrp30Number2;
CompartNumbers[europium] ^= icrp30Number2;
CompartNumbers[gadolinium] ^= icrp30Number2;
CompartNumbers[lutetium] ^= icrp30Number2;
CompartNumbers[praseodymium] ^= icrp30Number2;
CompartNumbers[terbium] ^= icrp30Number2;
CompartNumbers[ytterbium] ^= icrp30Number2;
CompartNumbers[hafnium] ^= icrp30Number2;
CompartNumbers[mercuryinorg] ^= icrp30Number2;
CompartNumbers[mercuryorg] ^= icrp30Number2;
CompartNumbers[tellurium] ^= icrp30Number2;
CompartNumbers[zirconium] ^= icrp30Number2;


icrp30Number1 = TableForm[{{1,"Blood"},{2,"Systemic A"},{3,"Bladder"},
{4,"Urine"},{5,"ULI"},{6,"LLI"},{7,"FEC"}}];

CompartNumbers[aluminium] ^= icrp30Number1;
CompartNumbers[astatine] ^= icrp30Number1;
CompartNumbers[bromine] ^= icrp30Number1;
CompartNumbers[cadmium] ^= icrp30Number1;
CompartNumbers[cerium] ^= icrp30Number1;
CompartNumbers[chlorine] ^= icrp30Number1;
CompartNumbers[copper] ^= icrp30Number1;
CompartNumbers[erbium] ^= icrp30Number1;
CompartNumbers[holmium] ^= icrp30Number1;
CompartNumbers[holmium] ^= icrp30Number1;
CompartNumbers[indium] ^= icrp30Number1;
CompartNumbers[lanthanum] ^= icrp30Number1;
CompartNumbers[magnesium] ^= icrp30Number1;
CompartNumbers[neodymium] ^= icrp30Number1;
CompartNumbers[palladium] ^= icrp30Number1;
CompartNumbers[polonium] ^= icrp30Number1;
CompartNumbers[promethium] ^= icrp30Number1;
CompartNumbers[rubidium] ^= icrp30Number1;
CompartNumbers[samarium] ^= icrp30Number1;
CompartNumbers[thulium] ^= icrp30Number1;
CompartNumbers[titanium] ^= icrp30Number1;
CompartNumbers[vanadium] ^= icrp30Number1;
CompartNumbers[yttrium] ^= icrp30Number1;

CompartNumbers[iron] ^= TableForm[{{1, "Plasma"}, {2, "RBC"}, {3, "ST0"}, {4, "ST1"}, 
{5, "Excreta"}, {6, "Liver1"}, {7, "Liver2"}, {8, "RedMarrowTran"}, 
{9, "RedMarrowStorage"}, {10, "Spleen"}, {11, "RedMarrowSynthes"}, 
{12, "UrinaryBladderContents"}, {13, "Urine"}, {14, "UpperLargeIntestine"}, 
{15, LowerLargeIntestine}, {16, Feces}, {17, "SmallIntestine"}, {18, "ST"}}]; 

CompartNumbers[thorium]^= TableForm[{{1, "Plasma"}, {2, "ST0"}, {3, "ST1"}, 
    {4, "ST2"}, {5, "Liver1"}, {6, "Liver2"}, {7, "UrinaryPath"}, 
    {8, "OtherKidney"}, {9, "TrabecularSurface"}, {10, "TrabecularMarrow"}, 
    {11, "TrabecularVolume"}, {12, "CorticalSurface"}, 
    {13, "CorticalMarrow"}, {14, "CorticalVolume"}, {15, "Gonads"}, 
    {16, "Bladder"}, {17, "Urine"}, {18, "ULI"}, {19, "LLI"}, {20, "Feces"}, 
    {21, "SI"}, {22, "ST"}}];

CompartNumbers[neptunium] ^= TableForm[{{1, "Blood"}, {2, "ST0"}, {3, "ST1"}, 
{4, "ST2"}, {5, "Liver1"}, {6, "Liver2"}, {7, "Kidneys Urinary"}, {8, "Other kidneys"}, 
{9, "Cort. bone"}, {10, "Cort. Surface"}, {11, "Cort Vol"}, {12, "Trab. Volum"}, 
{13, "Trab. Surf"}, {14, "Trab. bone"}, {15, "Gonads"}, {16, "Bladder"}, {17, "URI"}, 
{18, "ULI"}, {19, "LLI"}, {20, "FEC"}, {21, "SI"}, {22, "ST"}}];


CompartNumbers[lead] ^= TableForm[{{1, "Plasma"}, {2, "RBC"}, {3, "ST0"}, {4, "ST1"}, 
{5, "ST2"}, {6, "Cortical Surface"}, {7, "Cortical Volume Exch"}, 
{8, "Cortical Volume Nonexch"}, {9, "Trabecular Marrow Surface"}, 
{10, "Trabecular Volume Exch"}, {11, "Trabecular Volume Nonexch"}, {12, "Liver1"}, 
{13, "Liver2"}, {14, "Kidneys (Urinary Path)"}, {15, "Other Kidney Tissue"}, {16, "Sweat"}, {17, "Bladder"}, {18, "Urine"}, {19, "ULI"}, {20, "LLI"}, {21, "FEC"}, {22, "SI"}, 
{23, "ST"}}];

TransferRates[strontium]^={{1,2,7.5},{1,3,1.5},{1,4,3./10^3},{2,1,2.5},
{3,1,1.16/10},{4,1,3.8/10^4},{1,8,1.67},{1,5,2.08},{8,1,5.78/10},
{5, 1, 5.78/10},{10,1,8.21/10^5},{7,1,4.93/10^4},{1,11,1.73},
{1,13,5.25/10},{8,9,1.16/10},{9,8,4.3/10^3},{9,10,4.3/10^3},
{5, 6, 1.16/10},{6,5,4.3/10^3},{6,7,4.3/10^3},{11,12,12},
{13,14,Subscript[k,ULI]},{14,15,Subscript[k,LLI]}};

compartMatrix[strontium]^=CompartMatrix[15,TransferRates[strontium]];

TransferRatesE[strontium] ^= {{1, 2, 7.5}, {1, 3, 1.5}, {1, 4, 3./10^3}, 
    {2, 1, 2.5}, {3, 1, 1.16/10}, {4, 1, 3.8/10^4}, {1, 8, 1.67}, 
    {1, 5, 2.08}, {8, 1, 5.78/10}, {5, 1, 5.78/10}, {10, 1, 8.21/10^5}, 
    {7, 1, 4.93/10^4}, {1, 11, 1.73}, {1, 13, 5.25/10}, 
    {13, 14, Subscript[k, ULI]}, {14, 15, Subscript[k, LLI]}, 
    {8, 9, 1.16/10}, {9, 8, 4.3/10^3}, {9, 10, 4.3/10^3}, {5, 6, 1.16/10}, 
    {6, 5, 4.3/10^3}, {6, 7, 4.3/10^3}, {11, 12, 12}, 
    {16, 1, Subscript[f, B]*Subscript[k, SI]}, {16, 13, Subscript[k, SI]}, 
    {17, 16, Subscript[k, ST]}}; 

compartMatrixE[strontium] ^= CompartMatrix[17, TransferRatesE[strontium]]; 

TransferRatesE[radium] ^= {{1, 2, 7}, {1, 3, 22.68}, {1, 4, 0.07}, 
    {1, 12, 0.606}, {1, 14, 21.79}, {1, 8, 9.72}, {1, 5, 7.78}, 
    {5, 1, 0.578}, {5, 6, 0.116}, {6, 5, 0.0185}, {6, 7, 0.0046}, 
    {1, 11, 0.35}, {8, 1, 0.578}, {8, 9, 0.116}, {9, 8, 0.0185}, 
    {9, 10, 0.00046}, {10, 1, 0.000493}, {7, 1, 0.0000821}, {11, 1, 0.0139}, 
    {2, 1, 0.693}, {3, 1, 7.56}, {4, 1, 0.00038}, {12, 13, 12}, 
    {14, 15, Subscript[k, ULI]}, {15, 16, 1}, {17, 14, Subscript[k, SI]}, 
    {18, 17, Subscript[k, ST]}, {17, 1, Subscript[f, B]*Subscript[k, SI]}}; 

compartMatrixE[radium] ^= CompartMatrix[18, TransferRatesE[radium]]; 

TransferRates[barium] ^= {{1, 2, 23.}, {1, 3, 7.}, {1, 4, 0.14}, 
    {2, 1, 7.67}, {3, 1, 0.693}, {4, 1, 0.00038}, {1, 5, 7.78}, 
    {5, 1, 0.578}, {5, 6, 0.116}, {6, 5, 0.0097}, {6, 7, 0.0042}, 
    {7, 1, 0.0000821}, {1, 8, 9.72}, {8, 1, 0.578}, {8, 9, 0.116}, 
    {9, 8, 0.0097}, {9, 10, 0.0042}, {10, 1, 0.000493}, {1, 11, 2.24}, 
    {1, 13, 20.16}, {13, 14, Subscript[k, ULI]}, {14, 15, Subscript[k, LLI]}, 
    {11, 12, 12}}; 

compartMatrix[barium] ^= CompartMatrix[15, TransferRates[barium]]; 

TransferRates[calcium] ^= {{1, 2, 0.00075}, {1, 3, 1.5}, {1, 4, 8.7}, 
    {1, 5, 1.67}, {1, 8, 2.08}, {1, 11, 0.6}, {1, 13, 0.45}, {2, 1, 0.00038}, 
    {3, 1, 0.1733}, {4, 1, 2.9}, {5, 1, 0.578}, {7, 1, 0.0000821}, 
    {8, 1, 0.578}, {10, 1, 0.000493}, {5, 6, 0.116}, {6, 5, 0.002773}, 
    {6, 7, 0.004159}, {8, 9, 0.116}, {9, 8, 0.002733}, {9, 10, 0.004159}, 
    {13, 14, Subscript[k, ULI]}, {11, 12, 12}, {14, 15, Subscript[k, LLI]}}; 

compartMatrix[calcium] ^= CompartMatrix[15, TransferRates[calcium]]; 

TransferRates[iodine] ^= {{1, 2, 0.3*(Log[2]/0.25)}, 
    {1, 4, 0.7*(Log[2]/0.25)}, {2, 3, Log[2]/80}, {3, 6, (Log[2]/12)*0.2}, 
    {3, 1, (Log[2]/12)*0.8}, {4, 5, 12}, {6, 7, Subscript[k, ULI]}, 
    {7, 8, Subscript[k, LLI]}}; 

compartMatrix[iodine] ^= CompartMatrix[8, TransferRates[iodine]]; 

TransferRates[caesium] ^= {{1, 2, 0.27726}, {1, 3, 2.49533}, {2, 4, 0.2768}, 
    {2, 6, 0.0692}, {3, 4, 0.00504}, {3, 6, 0.00126}, {4, 5, 12}, 
    {6, 7, Subscript[k, ULI]}, {7, 8, Subscript[k, LLI]}}; 

compartMatrix[caesium] ^= CompartMatrix[8, TransferRates[caesium]]; 

TransferRates[uranium] ^= {{1, 3, 10.5}, {1, 2, 0.245}, {1, 16, 15.43}, 
    {1, 8, 2.94}, {1, 9, 0.0122}, {1, 18, 0.122}, {1, 6, 0.367}, 
    {1, 4, 1.63}, {1, 5, 0.0735}, {1, 10, 2.04}, {1, 13, 1.63}, {3, 1, 8.32}, 
    {2, 1, 0.347}, {8, 16, 0.099}, {9, 1, 0.00038}, {6, 1, 0.092}, 
    {6, 7, 0.00693}, {4, 1, 0.0347}, {5, 1, 0.000019}, {13, 1, 0.0693}, 
    {13, 14, 0.0693}, {7, 1, 0.00019}, {11, 12, 0.00578}, {12, 1, 0.000493}, 
    {15, 1, 0.0000821}, {14, 13, 0.0173}, {14, 15, 0.00578}, {10, 1, 0.0693}, 
    {11, 10, 0.0173}, {10, 11, 0.0693}, {16, 17, 12}, 
    {18, 19, Subscript[k, ULI]}, {19, 20, Subscript[k, LLI]}}; 

compartMatrix[uranium] ^= CompartMatrix[20, TransferRates[uranium]]; 

TransferRatesE[uranium] ^= {{1, 3, 10.5}, {1, 2, 0.245}, {1, 16, 15.43}, 
    {1, 8, 2.94}, {1, 9, 0.0122}, {1, 18, 0.122}, {1, 6, 0.367}, 
    {1, 4, 1.63}, {1, 5, 0.0735}, {1, 10, 2.04}, {1, 13, 1.63}, {3, 1, 8.32}, 
    {2, 1, 0.347}, {8, 16, 0.099}, {9, 1, 0.00038}, {6, 1, 0.092}, 
    {6, 7, 0.00693}, {4, 1, 0.0347}, {5, 1, 0.000019}, {13, 1, 0.0693}, 
    {13, 14, 0.0693}, {7, 1, 0.00019}, {11, 12, 0.00578}, {12, 1, 0.000493}, 
    {15, 1, 0.0000821}, {14, 13, 0.0173}, {14, 15, 0.00578}, {10, 1, 0.0693}, 
    {11, 10, 0.0173}, {10, 11, 0.0693}, {16, 17, 12}, 
    {18, 19, Subscript[k, ULI]}, {19, 20, Subscript[k, LLI]}, 
    {21, 1, Subscript[f, B]*Subscript[k, SI]}, {21, 18, Subscript[k, SI]}, 
    {22, 21, Subscript[k, ST]}}; 

compartMatrixE[uranium] ^= CompartMatrix[22, TransferRatesE[uranium]]; 

TransferRatesE[americium] ^= {{1, 9, 3.49}, {1, 6, 0.466}, {1, 5, 11.6}, 
    {1, 7, 0.116}, {1, 2, 10}, {1, 3, 1.67}, {1, 4, 0.466}, {1, 14, 0.0082}, 
    {1, 12, 3.49}, {1, 17, 0.303}, {1, 15, 1.63}, {2, 1, 1.386}, 
    {3, 1, 0.0139}, {4, 1, 0.000019}, {5, 1, 0.00185}, {5, 20, 0.000049}, 
    {6, 15, 0.099}, {7, 1, 0.00139}, {8, 1, 0.0076}, {9, 8, 0.0000821}, 
    {9, 10, 0.0000411}, {10, 8, 0.0000821}, {11, 13, 0.000493}, 
    {12, 13, 0.000493}, {12, 11, 0.000247}, {13, 1, 1.0076}, 
    {14, 1, 0.00019}, {15, 16, 12}, {17, 18, Subscript[k, ULI]}, 
    {18, 19, Subscript[k, LLI]}, {20, 1, f1*(Subscript[k, SI]/(1 - f1))}, 
    {20, 17, Subscript[k, SI]}, {21, 20, Subscript[k, ST]}}; 

compartMatrixE[americium] ^= CompartMatrix[21, TransferRatesE[americium]]; 

TransferRatesE[plutonium] ^= {{1, 2, 0.2773}, {1, 3, 0.0806}, {1, 4, 0.0129}, 
    {1, 13, 0.1941}, {1, 10, 0.1294}, {1, 8, 0.00323}, {1, 5, 0.1941}, 
    {1, 15, 0.00023}, {1, 18, 0.0129}, {1, 7, 0.00647}, {1, 16, 0.0129}, 
    {2, 1, 0.693}, {3, 16, 0.000475}, {3, 1, 0.000475}, {4, 1, 0.000019}, 
    {5, 6, 0.00177}, {5, 21, 0.000133}, {6, 1, 0.000211}, {7, 16, 0.01386}, 
    {8, 1, 0.00139}, {9, 1, 0.0076}, {14, 1, 0.0076}, {10, 9, 0.0000821}, 
    {10, 11, 0.0000411}, {11, 9, 0.0000821}, {12, 14, 0.000493}, 
    {13, 14, 0.000493}, {13, 12, 0.000247}, {15, 1, 0.00019}, {16, 17, 12}, 
    {18, 19, Subscript[k, ULI]}, {19, 20, Subscript[k, LLI]}, 
    {21, 1, f1*(Subscript[k, SI]/(1 - f1))}, {21, 18, Subscript[k, SI]}, 
    {22, 21, Subscript[k, ST]}}; 

compartMatrixE[plutonium] ^= CompartMatrix[22, TransferRatesE[plutonium]]; 

TransferRatesE[iron] ^= {{1, 11, 6.0`}, {1, 8, 2`}, {1, 6, 1.5`}, {1, 3, 1.4`}, 
{1, 12, 0.02`}, {2, 8, 0.00833`}, {2, 14, 0.00013`}, {11, 2, 0.70`}, {8, 1, 0.33`}, 
{8, 9, 0.0247`}, {8, 7, 0.00495`}, {8, 10, 0.00791`}, {8, 4, 0.0316`}, {6, 1, 0.01`}, 
{6, 17, 0.00045`}, {3, 1, 0.91`}, {9, 8, 0.0018`}, {7,8, 0.0018`}, {10, 8, 0.0018`}, 
{4, 8, 0.0018`}, {4, 5, 0.000563`}, { 12, 13, 12}, {14, 15, Subscript[k, ULI]}, 
{15, 16, Subscript[k, LLI]}, {17, 1, f1*(Subscript[k, SI]/(1 - f1))}, 
{17, 14, Subscript[k, SI]}, {18, 17, Subscript[k, ST]}};

compartMatrixE[iron] ^= CompartMatrix[18, TransferRatesE[iron]]; 

TransferRatesE[thorium] ^= {{1, 16, 0.1067}, {1, 18, 0.0097}, {1, 9, 0.6793}, {1, 12, 0.6793}, 
    {1, 5, 0.097}, {1, 7, 0.0679}, {1, 8, 0.0194}, {1, 2, 0.832}, 
    {1, 3, 0.243}, {1, 4, 0.0388}, {1, 15, 0.00068}, {10, 1, 0.0076}, 
    {13, 1, 0.0076}, {9, 11, 0.000247}, {9, 10, 0.000493}, 
    {12, 14, 0.0000411}, {12, 13, 0.0000821}, {11, 10, 0.000493}, 
    {14, 13, 0.0000821}, {5, 1, 0.000475}, {5, 21, 0.000475}, 
    {5, 6, 0.00095}, {6, 1, 0.000211}, {7, 16, 0.0462}, {8, 1, 0.00038}, 
    {15, 1, 0.00019}, {2, 1, 0.462}, {3, 1, 0.00095}, {4, 1, 0.000019}, 
    {16, 17, 12}, {18, 19, Subscript[k,ULI]}, {19, 20, Subscript[k,LLI]}, 
    {21, 18, Subscript[k,SI]},{22, 21, Subscript[k,ST]}, 
    {21, 1, f1*(Subscript[k,SI]/(1-f1))}};

compartMatrixE[thorium]^= CompartMatrix[22, TransferRatesE[thorium]]; 

TransferRatesE[neptunium] ^= {{1, 2, 0.832}, {1, 3, 0.1611}, {1, 4, 0.0388}, {1, 13, 0.4804}, 
    {1, 10, 0.393}, {1, 8, 0.0097}, {1, 5, 0.1941}, {1, 15, 0.00068}, {1, 18, 0.01359}, 
    {1, 7, 0.0291}, {1, 16, 0.6211}, {2, 1, 0.6931}, {3, 1, 0.00693}, {4, 1, 0.000019}, 
    {5, 6, 0.00177}, {5, 21, 0.000133}, {6, 1, 0.0019}, {7, 16, 0.0495}, {8, 1, 0.00139}, 
    {9, 1, 0.0076}, {14, 1, 0.0076}, {10, 9, 0.0000821}, {10, 11, 0.0000411}, {11, 9, 0.0000821}, 
    {12, 14, 0.000493}, {13, 14, 0.000493}, {13, 12, 0.000247}, {15, 1, 0.00019}, {16, 17, 12}, 
    {18, 19, Subscript[k, ULI]}, {19, 20, Subscript[k, LLI]}, 
    {21, 1, f1*(Subscript[k, SI]/(1 - f1))}, {21, 18, Subscript[k, SI]}, 
    {22, 21, Subscript[k, ST]}}; 

compartMatrixE[neptunium] ^= CompartMatrix[22, TransferRatesE[neptunium]];

TransferRates[cobalt] ^= {{1, 2, 0.4158883083359672}, {1, 3, 0.13862943611198905}, {1, 4, 0.13862943611198905}, 
  {1, 5, 0.5941261547656673}, {1, 7, 0.09902102579427789}, {2, 5, Log[2]/7}, {3, 5, Log[2]/70}, 
  {4, 5, (3*Log[2])/2800}, {2, 7, Log[2]/42}, {3, 7, Log[2]/420}, {4, 7, Log[2]/5600}, 
  {5, 6, 12}, {7, 8, Subscript[k, ULI]}, {8, 9, Subscript[k, LLI]}}; 
     

compartMatrix[cobalt] ^= CompartMatrix[9, TransferRates[cobalt]]; 

TransferRatesE[lead] ^= {{1, 2, 28.00}, {1, 17, 
  1.750}, {1, 19, 0.7}, {1, 9, 
    4.86}, {1, 6, 3.89}, {1, 12, 4.9}, {1, 14, 2.45}, {1, 15, 0.0245}, {1, 3, 
      22.16}, {1, 4, 0.7}, {1, 5, 0.14}, {1, 16, 0.42}, {2, 1, 0.139}, {6, 1, 
    0.5}, {9, 1, 0.5}, {6, 7, 0.5}, {9, 10, 0.5}, {7, 6, 0.0185}, {
    10, 9, 0.0185}, {7, 8, 0.0046}, {10, 11, 0.0046}, {11, 1, 
    0.000493}, {8, 1, 0.00008210}, {12, 1, 0.03120}, {12, 22, 
    0.03210}, {12, 13, 0.006930}, {13, 1, 0.0019}, {14, 17, 
    0.139}, {15, 1, 0.0019}, {
    3, 1, 7.39}, {4, 1, 0.00416}, {4, 21, 0.00277}, {5, 1,
     0.00038}, {17, 18, 12}, {19, 20, Subscript[k, ULI]}, {20, 21, 
    Subscript[k, LLI]}, {22, 1, Subscript[f, B]*Subscript[k, SI]}, {22, 19,
     Subscript[k, SI]}, {23, 22, Subscript[k, ST]}};

compartMatrixE[lead] ^= CompartMatrix[23, TransferRatesE[lead]];

(*Added in version 1.2*)

icrp30Model1[{fu_,ff_,ti_List,fi_List,TB_}]:=
Module[{a,fR,h,n,i,k1},a=Log[2]/ti;fR=1-Plus@@fi;
n=Length[ti];
h=Flatten[{{fi,fR*fu,fR*ff}*(Log[2]/TB),{fu*a,ff*a},
{12,Subscript[k,ULI],Subscript[k,LLI]}}];
k1=Flatten[{Table[{1,1+i},{i,n+1}],{{1,n+4}},Table[{1+i,2+n},{i,n}],
Table[{1+i,2+n+2},{i,n}],{{n+2,n+3}},{{n+4,n+5}},{{n+5,n+6}}},1];
Transpose[Append[Transpose[k1],h]]];

(* Elements with three systemic comparments *)
(*ICRP 78*)

TransferRatesE[curium] ^= {{1, 9, 3.49}, {1, 6, 0.466}, {1, 5, 11.6}, 
    {1, 7, 0.116}, {1, 2, 10}, {1, 3, 1.67}, {1, 4, 0.466}, {1, 14, 0.0082}, 
    {1, 12, 3.49}, {1, 17, 0.303}, {1, 15, 1.63}, {2, 1, 1.386}, 
    {3, 1, 0.0139}, {4, 1, 0.000019}, {5, 1, 0.00185}, {5, 20, 0.000049}, 
    {6, 15, 0.099}, {7, 1, 0.00139}, {8, 1, 0.0076}, {9, 8, 0.0000821}, 
    {9, 10, 0.0000411}, {10, 8, 0.0000821}, {11, 13, 0.000493}, 
    {12, 13, 0.000493}, {12, 11, 0.000247}, {13, 1, 1.0076}, 
    {14, 1, 0.00019}, {15, 16, 12}, {17, 18, Subscript[k, ULI]}, 
    {18, 19, Subscript[k, LLI]}, {20, 1, f1*(Subscript[k, SI]/(1 - f1))}, 
    {20, 17, Subscript[k, SI]}, {21, 20, Subscript[k, ST]}}; 

compartMatrixE[curium] ^= CompartMatrix[21, TransferRatesE[curium]]; 

Californium = {0.5, 0.5, {18250, 7300, Infinity},  {0.65, 0.25 ,0.00035} , 0.25};

(*ICRP 30*)
{Selenium, Tin, Silver, Cobalt, Tungsten, Chromium, Rhodium, Ruthenium, Antimony, 
    Zinc, Molybdenum, Protactinium, Actinium, Berkelium,
    Einsteinium, Fermium, Mendelevium, Phosphorus} = 
   {{2/3, 1/3, {3, 30, 200}, {0.1, 0.4, 0.5}, 0.25}, {0.5, 0.5, {4, 25, 400}, 
     {0.1, 0.1, 0.3}, 0.25}, {1/21, 20/21, {3.5, 50, 500}, {0.1, 0.8, 0.1}, 0.25}, 
    {6/7, 1/7, {6, 60, 800}, {0.3, 0.1, 0.1}, 0.5}, {0.5, 0.5, {5, 100, 1000}, 
     {0.0225, 0.01, 0.0175}, 0.25}, {0.5, 0.5, {6, 80, 1000}, {0.4, 0.25, 0.05}, 
     0.5}, {0.5, 0.5, {8, 35, 1000}, {0.35, 0.3, 0.2}, 0.3}, 
    {0.8, 0.2, {8, 35, 1000}, {0.35, 0.3, 0.2}, 0.3}, 
    {0.8, 0.2, {5, 100, 5000}, {0.68, 0.08, 0.04}, 0.25}, 
    {0.2, 0.8, {20, 400, 10000}, {0.24, 0.755, 0.005}, 0.25}, 
    {8/9, 1/9, {1, 50, 10000}, {0.09, 0.81, 0.1}, 0.25}, 
    {0.5, 0.5, {10, 60, 36525}, {0.109, 0.061, 0.4}, 0.25}, 
    {0.5, 0.5, {14625, 36510, Infinity}, {0.45, 0.45, 0.00035}, 0.25}, 
    {0.5, 0.5, {14610, 36525, Infinity}, {0.45, 0.45, 0.00035}, 0.25}, 
    {0.5, 0.5, {14610, 36525, Infinity}, {0.45, 0.45, 0.00035}, 0.25}, 
    {0.5, 0.5, {14610, 36525, Infinity}, {0.45, 0.45, 0.00035}, 0.25}, 
    {0.5, 0.5, {14610, 36525, Infinity}, {0.45, 0.45, 0.00035}, 0.25}, 
    {0.9, 0.1, {2, 19, Infinity}, {0.15, 0.4, 0.3}, 0.5}}; 
    
TransferRates[selenium]^=Chop[icrp30Model1[Selenium], 10^-6];
compartMatrix[selenium]^=CompartMatrix[9,TransferRates[selenium]];

TransferRates[tin]^=Chop[icrp30Model1[Tin], 10^-6];
compartMatrix[tin]^=CompartMatrix[9,TransferRates[tin]];

TransferRates[silver]^=Chop[icrp30Model1[Silver], 10^-6];
compartMatrix[silver]^=CompartMatrix[9,TransferRates[silver]];

TransferRates[tungsten]^=Chop[icrp30Model1[Tungsten], 10^-6];
compartMatrix[tungsten]^=CompartMatrix[9,TransferRates[tungsten]];

TransferRates[chromium]^=Chop[icrp30Model1[Chromium], 10^-6];
compartMatrix[chromium]^=CompartMatrix[9,TransferRates[chromium]];

TransferRates[rhodium]^=Chop[icrp30Model1[Rhodium], 10^-6];
compartMatrix[rhodium]^=CompartMatrix[9,TransferRates[rhodium]];

TransferRates[ruthenium]^=Chop[icrp30Model1[Ruthenium], 10^-6];
compartMatrix[ruthenium]^=CompartMatrix[9,TransferRates[ruthenium]];


TransferRates[antimony]^=Chop[icrp30Model1[Antimony], 10^-6];
compartMatrix[antimony]^=CompartMatrix[9,TransferRates[antimony]];

TransferRates[zinc]^=Chop[icrp30Model1[Zinc], 10^-6];
compartMatrix[zinc]^=CompartMatrix[9,TransferRates[zinc]];

TransferRates[molybdenum]^=Chop[icrp30Model1[Molybdenum], 10^-6];
compartMatrix[molybdenum]^=CompartMatrix[9,TransferRates[molybdenum]];

TransferRates[protactinium]^=Chop[icrp30Model1[Protactinium], 10^-6];
compartMatrix[protactinium]^=CompartMatrix[9,TransferRates[protactinium]];

TransferRates[actinium]^=Chop[icrp30Model1[Actinium], 10^-6];
compartMatrix[actinium]^=CompartMatrix[9,TransferRates[actinium]];

TransferRates[berkelium]^=Chop[icrp30Model1[Berkelium], 10^-6];
compartMatrix[berkelium]^=CompartMatrix[9,TransferRates[berkelium]];

TransferRates[californium]^=Chop[icrp30Model1[Californium], 10^-6];
compartMatrix[californium]^=CompartMatrix[9,TransferRates[californium]];

TransferRates[einsteinium]^=Chop[icrp30Model1[Einsteinium], 10^-6];
compartMatrix[einsteinium]^=CompartMatrix[9,TransferRates[einsteinium]];

TransferRates[fermium]^=Chop[icrp30Model1[Fermium], 10^-6];
compartMatrix[fermium]^=CompartMatrix[9,TransferRates[fermium]];

TransferRates[mendelevium]^=Chop[icrp30Model1[Mendelevium], 10^-6];
compartMatrix[mendelevium]^=CompartMatrix[9,TransferRates[mendelevium]];

TransferRates[phosphorus]^=Chop[icrp30Model1[Phosphorus], 10^-6];
compartMatrix[phosphorus]^=CompartMatrix[9,TransferRates[phosphorus]];

{Beryllium, Bismuth, Arsenic, Manganese, Gallium, Silicon, Tantalum, Iridium, Niobium, Osmium, 
Platinum, Sodium, Nickel, Scandium, Sulfur, Dysprosium, Europium, Gadolinium, Lutetium, 
Praseodymium, Terbium, Ytterbium, Hafnium, Mercuryinorg, Mercuryorg, Tellurium, Zirconium} = 
  {{1/2,1/2,{15,1500},{4/25,11/25},1/4},{1/2, 1/2, {3/5, 5}, {21/50, 7/25}, 1/100}, {1/2, 1/2, {1, 10}, {13/50, 39/100}, 1/4}, 
   {1/2, 1/2, {4, 40}, {3/10, 7/10}, 1/4}, {1/2, 1/2, {1, 50}, {3/10, 7/10}, 1/4}, 
   {1/2, 1/2, {5, 100}, {2/5, 3/5}, 1/4}, {1/2, 1/2, {4, 100}, {7/20, 13/20}, 1/4}, 
  {1/2, 1/2, {8, 200}, {4/25, 16/25}, 1/4}, 
   {5/6, 1/6, {6, 200}, {1/2, 1/2}, 1/4}, {1/2, 1/2, {8, 200}, {4/25, 16/25}, 1/4}, 
   {1/2, 1/2, {8, 200}, {19/25, 1/25}, 1/4}, {100/101, 1/101, {10, 500}, {997/1000, 3/1000}, 1/4}, 
   {20/21, 1/21, {1/5, 1200}, {1/50, 3/10}, 1/4}, {1/2, 1/2, {5, 1500}, {1/10, 9/10}, 1/4}, 
   {9/10, 1/10, {20, 2000}, {3/20, 1/20}, 1/4}, {1/2, 1/2, {10, 3500}, {1/50, 7/10}, 1/4}, 
   {1/2, 1/2, {10, 3500}, {3/50, 4/5}, 1/4}, {1/2, 1/2, {10, 3500}, {3/100, 3/4}, 1/4}, 
   {1/2, 1/2, {10, 3500}, {1/200, 31/50}, 1/4}, {1/2, 1/2, {10, 3500}, {1/20, 17/20}, 1/4}, 
   {1/2, 1/2, {10, 3500}, {1/20, 3/4}, 1/4}, {1/2, 1/2, {10, 3500}, {1/50, 107/200}, 1/4}, 
   {1/2, 1/2, {7, 8000}, {1/2, 1/2}, 1/4}, {1/2, 1/2, {40, 10000}, {19/20, 1/20}, 1/4}, 
   {1/2, 1/2, {80, 10000}, {19/20, 1/20}, 1/4}, {4/5, 1/5, {20, 10000}, {1/4, 1/4}, 4/5}, 
   {5/6, 1/6, {7, 10000}, {1/2, 1/2}, 1/4}};

TransferRates[beryllium]^=icrp30Model1[Beryllium];
compartMatrix[beryllium]^=CompartMatrix[8,TransferRates[beryllium]];

TransferRates[bismuth]^=Chop[icrp30Model1[Bismuth], 10^-6];
compartMatrix[bismuth]^=CompartMatrix[8,TransferRates[bismuth]];

TransferRates[arsenic]^=Chop[icrp30Model1[Arsenic], 10^-6];
compartMatrix[arsenic]^=CompartMatrix[8,TransferRates[arsenic]];

TransferRates[manganese]^=Chop[icrp30Model1[Manganese], 10^-6];
compartMatrix[manganese]^=CompartMatrix[8,TransferRates[manganese]];

TransferRates[gallium]^=Chop[icrp30Model1[Gallium], 10^-6];
compartMatrix[gallium]^=CompartMatrix[8,TransferRates[gallium]];

TransferRates[silicon]^=Chop[icrp30Model1[Silicon], 10^-6];
compartMatrix[silicon]^=CompartMatrix[8,TransferRates[silicon]];

TransferRates[tantalum]^=Chop[icrp30Model1[Tantalum], 10^-6];
compartMatrix[tantalum]^=CompartMatrix[8,TransferRates[tantalum]];

TransferRates[iridium]^=Chop[icrp30Model1[Iridium], 10^-6];
compartMatrix[iridium]^=CompartMatrix[8,TransferRates[iridium]];

TransferRates[niobium]^=Chop[icrp30Model1[Niobium], 10^-6];
compartMatrix[niobium]^=CompartMatrix[8,TransferRates[niobium]];

TransferRates[osmium]^=Chop[icrp30Model1[Osmium], 10^-6];
compartMatrix[osmium]^=CompartMatrix[8,TransferRates[osmium]];

TransferRates[platinum]^=Chop[icrp30Model1[Platinum], 10^-6];
compartMatrix[platinum]^=CompartMatrix[8,TransferRates[platinum]];

TransferRates[sodium]^=Chop[icrp30Model1[Sodium], 10^-6];
compartMatrix[sodium]^=CompartMatrix[8,TransferRates[sodium]];

TransferRates[nickel]^=Chop[icrp30Model1[Nickel], 10^-6];
compartMatrix[nickel]^=CompartMatrix[8,TransferRates[nickel]];

TransferRates[scandium]^=Chop[icrp30Model1[Scandium], 10^-6];
compartMatrix[scandium]^=CompartMatrix[8,TransferRates[scandium]];

TransferRates[sulfur]^=Chop[icrp30Model1[Sulfur], 10^-6];
compartMatrix[sulfur]^=CompartMatrix[8,TransferRates[sulfur]];

TransferRates[dysprosium]^=Chop[icrp30Model1[Dysprosium], 10^-6];
compartMatrix[dysprosium]^=CompartMatrix[8,TransferRates[dysprosium]];

TransferRates[europium]^=Chop[icrp30Model1[Europium], 10^-6];
compartMatrix[europium]^=CompartMatrix[8,TransferRates[europium]];

TransferRates[gadolinium]^=Chop[icrp30Model1[Gadolinium], 10^-6];
compartMatrix[gadolinium]^=CompartMatrix[8,TransferRates[gadolinium]];

TransferRates[lutetium]^=Chop[icrp30Model1[Lutetium], 10^-6];
compartMatrix[lutetium]^=CompartMatrix[8,TransferRates[lutetium]];

TransferRates[praseodymium]^=Chop[icrp30Model1[Praseodymium], 10^-6];
compartMatrix[praseodymium]^=CompartMatrix[8,TransferRates[praseodymium]];

TransferRates[terbium]^=Chop[icrp30Model1[Terbium], 10^-6];
compartMatrix[terbium]^=CompartMatrix[8,TransferRates[terbium]];

TransferRates[ytterbium]^=Chop[icrp30Model1[Ytterbium], 10^-6];
compartMatrix[ytterbium]^=CompartMatrix[8,TransferRates[ytterbium]];

TransferRates[hafnium]^=Chop[icrp30Model1[Hafnium], 10^-6];
compartMatrix[hafnium]^=CompartMatrix[8,TransferRates[hafnium]];

TransferRates[mercuryinorg]^=Chop[icrp30Model1[Mercuryinorg], 10^-6];
compartMatrix[mercuryinorg]^=CompartMatrix[8,TransferRates[mercuryinorg]];

TransferRates[mercuryorg]^=Chop[icrp30Model1[Mercuryorg], 10^-6];
compartMatrix[mercuryorg]^=CompartMatrix[8,TransferRates[mercuryorg]];

TransferRates[tellurium]^=Chop[icrp30Model1[Tellurium], 10^-6];
compartMatrix[tellurium]^=CompartMatrix[8,TransferRates[tellurium]];

TransferRates[zirconium]^=Chop[icrp30Model1[Zirconium], 10^-6];
compartMatrix[zirconium]^=CompartMatrix[8,TransferRates[zirconium]];

{Aluminium, Astatine, Bromine, Cadmium, Cerium, Chlorine, Copper, Erbium, 
Holmium, Indium, Lanthanum, Magnesium, Neodymium, Palladium, Polonium, 
Promethium, Rubidium, Samarium, Thulium, Titanium, Vanadium, Yttrium} = 
{{1/2, 1/2, {100}, {1}, 1/4}, {1/2, 1/2, {10}, {1}, 1/4}, 
{1/2, 1/2, {10}, {1}, 1/4}, {1/2, 1/2, {36525/4}, {1}, 1/4}, 
{1/10, 9/10, {3500}, {1}, 1/4}, {100/101, 1/101, {10}, {1}, 1/4}, 
{1/2, 1/2, {40}, {1}, 1/4}, {1/2, 1/2, {3500}, {3/4}, 1/4}, 
{1/2, 1/2, {3500}, {17/20}, 1/4}, {1/2, 1/2, {Infinity}, {1}, 1/4}, 
{1/2, 1/2, {3500}, {1}, 1/4}, {1/2, 1/2, {100}, {4/5}, 1/4}, 
{1/2, 1/2, {3500}, {9/10}, 1/4}, {1/2, 1/2, {15}, {7/10}, 1/4}, 
{1/3, 2/3, {50}, {1}, 1/4}, {1/2, 1/2, {3500}, {9/10}, 1/4}, 
{3/4, 1/4, {44}, {1}, 1/4}, {1/2, 1/2, {3500}, {9/10}, 1/4}, 
{1/2, 1/2, {3500}, {79/100}, 1/4}, {1/2, 1/2, {600}, {1}, 1/4}, 
{1/2, 1/2, {10000}, {3/10}, 1/4}, {1/2, 1/2, {Infinity}, {3/4}, 1/4}}; 

TransferRates[aluminium] ^= Chop[icrp30Model1[Aluminium], 10^(-6)]; 
compartMatrix[aluminium] ^= CompartMatrix[7, TransferRates[aluminium]]; 

TransferRates[astatine] ^= Chop[icrp30Model1[Astatine], 10^(-6)]; 
compartMatrix[astatine] ^= CompartMatrix[7, TransferRates[astatine]]; 

TransferRates[bromine] ^= Chop[icrp30Model1[Bromine], 10^(-6)]; 
compartMatrix[bromine] ^= CompartMatrix[7, TransferRates[bromine]]; 

TransferRates[cadmium] ^= Chop[icrp30Model1[Cadmium], 10^(-6)]; 
compartMatrix[cadmium] ^= CompartMatrix[7, TransferRates[cadmium]]; 

TransferRates[cerium] ^= Chop[icrp30Model1[Cerium], 10^(-6)]; 
compartMatrix[cerium] ^= CompartMatrix[7, TransferRates[cerium]]; 

TransferRates[chlorine] ^= Chop[icrp30Model1[Chlorine], 10^(-6)]; 
compartMatrix[chlorine] ^= CompartMatrix[7, TransferRates[chlorine]]; 

TransferRates[copper] ^= Chop[icrp30Model1[Copper], 10^(-6)]; 
compartMatrix[copper] ^= CompartMatrix[7, TransferRates[copper]]; 

TransferRates[erbium] ^= Chop[icrp30Model1[Erbium], 10^(-6)]; 
compartMatrix[erbium] ^= CompartMatrix[7, TransferRates[erbium]]; 

TransferRates[holmium] ^= Chop[icrp30Model1[Holmium], 10^(-6)]; 
compartMatrix[holmium] ^= CompartMatrix[7, TransferRates[holmium]]; 

TransferRates[indium] ^= Chop[icrp30Model1[Indium], 10^(-6)]; 
compartMatrix[indium] ^= CompartMatrix[7, TransferRates[indium]]; 

TransferRates[lanthanum] ^= Chop[icrp30Model1[Lanthanum], 10^(-6)]; 
compartMatrix[lanthanum] ^= CompartMatrix[7, TransferRates[lanthanum]]; 

TransferRates[magnesium] ^= Chop[icrp30Model1[Magnesium], 10^(-6)]; 
compartMatrix[magnesium] ^= CompartMatrix[7, TransferRates[magnesium]]; 

TransferRates[neodymium] ^= Chop[icrp30Model1[Neodymium], 10^(-6)]; 
compartMatrix[neodymium] ^= CompartMatrix[7, TransferRates[neodymium]]; 

TransferRates[palladium] ^= Chop[icrp30Model1[Palladium], 10^(-6)]; 
compartMatrix[palladium] ^= CompartMatrix[7, TransferRates[palladium]]; 

TransferRates[polonium] ^= Chop[icrp30Model1[Polonium], 10^(-6)]; 
compartMatrix[polonium] ^= CompartMatrix[7, TransferRates[polonium]]; 

TransferRates[promethium] ^= Chop[icrp30Model1[Promethium], 10^(-6)]; 
compartMatrix[promethium] ^= CompartMatrix[7, TransferRates[promethium]]; 

TransferRates[rubidium] ^= Chop[icrp30Model1[Rubidium], 10^(-6)]; 
compartMatrix[rubidium] ^= CompartMatrix[7, TransferRates[rubidium]]; 

TransferRates[samarium] ^= Chop[icrp30Model1[Samarium], 10^(-6)]; 
compartMatrix[samarium] ^= CompartMatrix[7, TransferRates[samarium]]; 

TransferRates[thulium] ^= Chop[icrp30Model1[Thulium], 10^(-6)]; 
compartMatrix[thulium] ^= CompartMatrix[7, TransferRates[thulium]]; 

TransferRates[titanium] ^= Chop[icrp30Model1[Titanium], 10^(-6)]; 
compartMatrix[titanium] ^= CompartMatrix[7, TransferRates[titanium]]; 

TransferRates[vanadium] ^= Chop[icrp30Model1[Vanadium], 10^(-6)]; 
compartMatrix[vanadium] ^= CompartMatrix[7, TransferRates[vanadium]]; 

TransferRates[yttrium] ^= Chop[icrp30Model1[Yttrium], 10^(-6)]; 
compartMatrix[yttrium] ^= CompartMatrix[7, TransferRates[yttrium]]; 

(*additionals*)
TransferRates[gold] ^=  {{1, 2, Log[2]/3}, {2, 3, 12}, {1, 4, 0}, {4, 5, Subscript[k, ULI]}, 
{5, 6, Subscript[k, LLI]}}; ; 
compartMatrix[gold] ^= CompartMatrix[6, TransferRates[gold]]; 

TransferRates[potassium] ^= {{1, 2, Log[2]/(2*30)}, {2, 3, 12}, {1, 4, Log[2]/(2*30)}, 
{4, 5, Subscript[k, ULI]}, {5, 6, Subscript[k, LLI]}}; 
compartMatrix[potassium] ^= CompartMatrix[6, TransferRates[potassium]]; 

TransferRates[thallium] ^= {{1, 2, Log[2]/(2*10)}, {2, 3, 12}, {1, 4, Log[2]/(2*10)}, 
{4, 5, Subscript[k, ULI]}, {5, 6, Subscript[k, LLI]}}; 
compartMatrix[thallium] ^= CompartMatrix[6, TransferRates[thallium]]; 

Rhenium = {1/2, 1/2, {1/2, 8/5, 37/10, 22}, {1/25, 18/25, 24/125, 6/125}, 1/50};
Technetium = {1/2, 1/2, {1/2, 8/5, 37/10, 22}, {1/25, 18/25, 24/125, 6/125}, 1/50};
Germanium = {{1, 2, 2*Log[2]}, {1, 3, 2*Log[2]}, {2, 4, 50*Log[2]}, {3, 4, Log[2]*(1/2)}, 
{3, 6, Log[2]*(1/2)}, {4, 5, 12}, {6, 7, Subscript[k, ULI]}, {7, 8, Subscript[k, LLI]}}; 

TransferRates[rhenium] ^= icrp30Model1[Rhenium]; 
compartMatrix[rhenium] ^= CompartMatrix[10, TransferRates[rhenium]]; 

TransferRates[technetium] ^= icrp30Model1[Technetium]; 
compartMatrix[technetium] ^= CompartMatrix[10, TransferRates[technetium]]; 

TransferRates[germanium] ^= Germanium; 
compartMatrix[germanium] ^= CompartMatrix[8, TransferRates[germanium]]; 

(*Injection*)

BiokdataReport[element_, intway_, opt1_, opt2_, int_, fin1_, t1_, lambda_, 
options___Rule] /; "Injection" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, 
    If[element === lead || element === thorium || element === neptunium || 
       element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      {BioassayReportE[compartMatrixE[element], int, fin1, t1, lambda, 
        IntakeWay -> "Injection", IntakeType -> opt1, ShowReport -> opt2, 
        options], {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRatesE[element], 
          TableHeadings -> {None, {"From", "to", 
             "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}, 
      {BioassayReport[compartMatrix[element], int, t1, lambda, 
        IntakeWay -> "Injection", IntakeType -> opt1, ShowReport -> opt2, 
        options], {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRates[element], 
          TableHeadings -> {None, {"From", "to", 
             "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}] /; 
     m === {"True", "True"}]; 

BiokdataReport[element_, intway_, opt1_, opt2_, int_, 
     fin1_, t1_, lambda_, options___Rule] /; "Injection" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, 
    If[element === lead || element === thorium || element === neptunium || 
       element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      BioassayReportE[compartMatrixE[element], int, fin1, t1, lambda, 
       IntakeWay -> "Injection", IntakeType -> opt1, ShowReport -> opt2, 
       options], BioassayReport[compartMatrix[element], int, t1, lambda, 
       IntakeWay -> "Injection", IntakeType -> opt1, ShowReport -> opt2, 
       options]] /; m === {"False", "False"}]; 

BiokdataReport[element_, intway_, opt1_, opt2_, int_, ifd_, fra_, 
     fin1_, t1_, lambda_, options___Rule] /; "Injection" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, 
    If[element === lead || element === thorium || element === neptunium || 
       element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      {BioassayReportE[compartMatrixE[element], int, fin1, t1, lambda, 
        IntakeWay -> "Injection", IntakeType -> opt1, ShowReport -> opt2, 
        options], {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRatesE[element], 
          TableHeadings -> {None, {"From", "to", 
             "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}, 
      {BioassayReport[compartMatrix[element], int, t1, lambda, 
        IntakeWay -> "Injection", IntakeType -> opt1, ShowReport -> opt2, 
        options], {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRates[element], 
          TableHeadings -> {None, {"From", "to", 
             "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}] /; 
     m === {"True", "True"}]; 

BiokdataReport[element_, intway_, opt1_, opt2_, int_, ifd_, fra_, 
     fin1_, t1_, lambda_, options___Rule] /; "Injection" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, 
    If[element === lead || element === thorium || element === neptunium || 
       element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      BioassayReportE[compartMatrixE[element], int, fin1, t1, lambda, 
       IntakeWay -> "Injection", IntakeType -> opt1, ShowReport -> opt2, 
       options], BioassayReport[compartMatrix[element], int, t1, lambda, 
       IntakeWay -> "Injection", IntakeType -> opt1, ShowReport -> opt2, 
       options]] /; m === {"False", "False"}]; 

(*Ingestion*)

BiokdataReport[element_, intway_, opt1_, opt2_, int_, fin1_, t1_, lambda_, 
     options___Rule] /; "Ingestion" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, If[element === lead || element === thorium || 
       element === neptunium || element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      {BioassayReportE[compartMatrixE[element], int, fin1, t1, lambda, 
        IntakeWay -> "Ingestion", IntakeType -> opt1, ShowReport -> opt2, options], 
       {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRatesE[element], TableHeadings -> 
           {None, {"From", "to", "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}, 
      {BioassayReport[compartMatrix[element], int, fin1, t1, lambda, 
        IntakeWay -> "Ingestion", IntakeType -> opt1, ShowReport -> opt2, options], 
       {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRates[element], TableHeadings -> 
           {None, {"From", "to", "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}] /; 
     m === {"True", "True"}]; 

BiokdataReport[element_, intway_, opt1_, opt2_, int_, fin1_, t1_, 
lambda_, options___Rule] /; "Ingestion" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, 
    If[element === lead || element === thorium || element === neptunium || 
       element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      BioassayReportE[compartMatrixE[element], int, fin1, t1, lambda, 
       IntakeWay -> "Ingestion", IntakeType -> opt1, ShowReport -> opt2, 
       options], BioassayReport[compartMatrix[element], int, fin1, t1, lambda, 
       IntakeWay -> "Ingestion", IntakeType -> opt1, ShowReport -> opt2, 
       options]] /; m === {"False", "False"}]; 

BiokdataReport[element_, intway_, opt1_, opt2_, int_, ifd_, fra_, 
     fin1_, t1_, lambda_, options___Rule] /; "Ingestion" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, 
    If[element === lead || element === thorium || element === neptunium || 
       element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      {BioassayReportE[compartMatrixE[element], int, fin1, t1, lambda, 
        IntakeWay -> "Ingestion", IntakeType -> opt1, ShowReport -> opt2, 
        options], {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRatesE[element], 
          TableHeadings -> {None, {"From", "to", 
             "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}, 
      {BioassayReport[compartMatrix[element], int, fin1, t1, lambda, 
        IntakeWay -> "Ingestion", IntakeType -> opt1, ShowReport -> opt2, 
        options], {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRates[element], 
          TableHeadings -> {None, {"From", "to", 
             "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}] /; 
     m === {"True", "True"}]; 

BiokdataReport[element_, intway_, opt1_, opt2_, int_, ifd_, fra_, 
     fin1_, t1_, lambda_, options___Rule] /; "Ingestion" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, 
    If[element === lead || element === thorium || element === neptunium || 
       element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      BioassayReportE[compartMatrixE[element], int, fin1, t1, lambda, 
       IntakeWay -> "Ingestion", IntakeType -> opt1, ShowReport -> opt2, 
       options], BioassayReport[compartMatrix[element], int, fin1, t1, lambda, 
       IntakeWay -> "Ingestion", IntakeType -> opt1, ShowReport -> opt2, 
       options]] /; m === {"False", "False"}]; 

(*Inhalation*)

BiokdataReport[element_, intway_, opt1_, opt2_, int_, ifd_, fra_, 
     fin1_, t1_, lambda_, options___Rule] /; "Inhalation" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, 
    If[element === lead || element === thorium || element === neptunium || 
       element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      {BioassayReportE[compartMatrixE[element], int, ifd, fra, fin1, t1, lambda, 
        IntakeWay -> "Inhalation", IntakeType -> opt1, ShowReport -> opt2, 
        options], {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRatesE[element], 
          TableHeadings -> {None, {"From", "to", 
             "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}, 
      {BioassayReport[compartMatrix[element], int, ifd, fra, fin1, t1, lambda, 
        IntakeWay -> "Inhalation", IntakeType -> opt1, ShowReport -> opt2, 
        options], {"Compart numbers" -> CompartNumbers[element]}, 
       {"Transfer Rates" -> TableForm[TransferRates[element], 
          TableHeadings -> {None, {"From", "to", 
             "Tranfer Rates(\!\(days\^\(-1\)\))"}}]}}] /; 
     m === {"True", "True"}]; 

BiokdataReport[element_, intway_, opt1_, opt2_, int_, ifd_, fra_, 
     fin1_, t1_, lambda_, options___Rule] /; "Inhalation" === intway := 
   With[{m = {CompartNumbers, TransferRates} /. Flatten[{options}] /. 
       Options[BiokdataReport]}, 
    If[element === lead || element === thorium || element === neptunium || 
       element === plutonium || element === americium || 
       element === curium || element === iron || element === radium, 
      BioassayReportE[compartMatrixE[element], int,ifd, fra,  fin1, t1, lambda, 
       IntakeWay -> "Inhalation", IntakeType -> opt1, ShowReport -> opt2, 
       options], BioassayReport[compartMatrix[element], int, ifd, fra, fin1, t1, lambda, 
       IntakeWay -> "Inhalation", IntakeType -> opt1, ShowReport -> opt2, 
       options]] /; m === {"False", "False"}]; 


End[]


Protect[CompartNumbers, TransferRates, compartMatrix, TransferRatesE, compartMatrixE, 
BiokdataReport]; 

Print["Biokdata 1.2.2 2004-09-3"]

EndPackage[]































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































































