(* ::Package:: *)

(*The Package*)

(*Title : Doses*)


(* : Author : Guillermo Sanchez*)


(* : Summary : This package provides Mathematica functions for internal doses computation*)


(* : Context : Biokmod`Doses`*)


(* : Package Version : 1.2*)

(* : Copyright : Copyright 2015. Guillermo Sanchez.http://diarium.usal.es/guillermo/*)

(* : History : Version 1.0 April 2008; Version 1.1 July 2011, minor changes in  CommittedDose to fix some problems with Math 8; V1.2 August 2015 a couple of specific functions for enriched uranium  have been added*)


(* : Mathematica Version : 8.0&7.0*)

(* : Limitation : None known.*)

(* : Discussion :*)

BeginPackage["Biokmod`Doses`","Biokmod`Biokdata`","Biokmod`Humorap3`", 
"Biokmod`Resptract`","Biokmod`SysModel`", "Biokmod`Master`"]

CommittedDose::usage = "CommittedDose[intake,us, seecal, options]";

dosefactor::usage = "dosefactor1[us, seecal]";

see::usage = "see[Xaaa] gives the SEE factors, in Sv/Bq for isotope Xaaa 
obtained from DCAL (SEECAL)";

ImportSEE::usage = "ImportSEE[file, ext], where ext is csv, txt or xls";
ExportSEE::usage = "ExportSEE[file, see, element]";

targetCompartments::usage = "Target compartments. The same that are used by 
DCAL (SEECAL)";

Decayconst::usage = "Decayconst[Xaaa] gives the radioactive decay constant,in days^-1, 
of isotope Xaaa being X the symbol of the element and aaa Z+N, ej: U235";

label::usage = "label[element] gives the source compartments for element or RT or GI";

doseslabel::usage = "label";
dosefactor::usage = "label";

elementname = {americium, beryllium, barium, caesium, calcium, cobalt, iodine, iron, lead, 
neptunium, plutonium, radium, strontium, uranium, thorium, selenium, tin, silver, 
tungsten, chromium, rhodium, ruthenium, antimony, zinc, molybdenum, protactinium, 
actinium, berkelium, californium, curium, einsteinium, fermium, mendelevium, 
phosphorus, bismuth, arsenic, manganese, gallium, silicon, tantalum, iridium, 
niobium, osmium, platinum, sodium, nickel, scandium, sulfur, dysprosium, europium, 
gadolinium, lutetium, praseodymium, terbium, ytterbium, hafnium, mercuryinorg, 
mercuryorg, tellurium, zirconium, aluminium, astatine, bromine, cadmium, cerium, 
chlorine, copper, erbium, holmium, indium, lanthanum, magnesium, neodymium, palladium, 
polonium, promethium, rubidium, samarium, thulium, titanium, vanadium, yttrium, gold, 
potassium, thallium, rhenium, technetium, germanium}; 

elementsymbol::usage = "Symbol of elements included in the present version of Doses";

esym::usage = "esym[symbol of element] gives the full name of element";
elname::usage = "elname[element] gives the symbol of element";

isotopesymbol::usage = "Symbol of isotopes whose disintegration constans, in day^-1 and see 
factors are included in the present version of Doses";

Disintegrations::usage = "Disintegrations[element, intakeway, intake, AMAD, type, f1_,
 t1 (in year),  decayconst]";
 
EnrichedU::usage= "EnrichedU[enr, actU] where enr (% wt U235) and act (activity in Bq, by default it assumed 100 Bq) returns the isotopic composition for standard uranium (no reprocessed)" 

DoseEnrichedUranium::usage="DoseEnrichedUranium[totalintake, enriched, amad, fs] assuming an totalintake, in Bq, by inhalation of uranium oxide enriched (% wt U235), of radioactive aerosols of AMAD amad with a fraction fs of type S and the rest type M returns efective dose. The isotopic composition for standard uranium (no reprocessed) is used"

Options[Disintegrations] = {DisintegrationReport -> "Automatic"};

Options[CommittedDose] = {DisintegrationReport -> "True"};



Begin["`Private`"]

targetCompartments ={"Adrenals","UB_Wall","Bone_Sur","Brain","Breasts","St_Wall",
      "SI_Wall","ULI_Wall","LLI_Wall","Kidneys","Liver","ET1-bas","ET2-bas",
      "LN-ET","BBi-bas","BBi-sec","bbe-sec","AI","LN-Th","Muscle","Ovaries",
      "Pancreas","R_Marrow","Skin","Spleen","Testes","Thymus","Thyroid",
      "Uterus"};

doseslabel ={"Testes","Ovarius","Red Marrow","Colon","Lungs","St Wall",
        "Bladder Wall","Mama","Liver","Oesophagus","Thyroid","Skin",
        "Bone Surface","Muscle","Brain","Small intestine","Kidneys",
        "Pancreas","Spleen","Thymus","Uterus","Adrenals",
        "Extrathoracic airways", "Effective, e(50)"};

elementsymbol = {"Am", "Be", "Ba", "Cs", "Ca", "Co", "I", "Fe", "Pb", "Np", 
    "Pu", "Ra", "Sr", "U", "Th", "Se", "Sn", "Ag", "W", "Cr", "Rh", "Ru", 
    "Sb", "Zn", "Mo", "Pa", "Ac", "Bk", "Cf", "Cm", "Es", "Fm", "Md", "P", 
    "Bi", "As", "Mn", "Ga", "Si", "Ta", "Ir", "Nb", "Os", "Pt", "Na", "Ni", 
    "Sc", "S", "Dy", "Eu", "Gd", "Lu", "Pr", "Tb", "Yb", "Hf", "Hg", "Hg", 
    "Te", "Zr", "Al", "At", "Br", "Cd", "Ce", "Cl", "Cu", "Er", "Ho", "In", 
    "La", "Mg", "Nd", "Pd", "Po", "Pm", "Rb", "Sm", "Tm", "Ti", "V", "Y", 
    "Au", "K", "Tl", "Re", "Tc", "Ge"}; 

elem3 = {"Co", "Se", "Sn", "Ag", "W", "Cr", "Rh", "Ru", "Sb", "Zn", "Mo", 
    "Pa", "Ac", "Bk", "Es", "Fm", "Md", "P"}; 

elem2 = {"Cs", "Be", "Bi", "As", "Mn", "Ga", "Si", "Ta", "Ir", "Nb", "Os", 
    "Pt", "Na", "Ni", "Sc", "S", "Dy", "Eu", "Gd", "Lu", "Pr", "Tb", "Yb", 
    "Hf", "Hg", "Hg", "Te", "Zr"}; 

elem1 = {"Al", "At", "Br", "Cd", "Ce", "Cl", "Cu", "Er", "Ho", "In", "La", 
    "Mg", "Nd", "Pd", "Po", "Pm", "Rb", "Sm", "Tm", "Ti", "V"}; 

label["RT"] = {"AI", "bb1", "bb2", "bbseq", "BB1", "BB2", "BBseq", "ET2", 
    "ET1", "ETseq", "LNth", "LNet"}; 

label["GI"] = {"ST", "SI", "B", "ULI", "LLI"}; 

label["U"]={"Soft Tissues","UB_Content","Kydneys","Liver","TrabSurface",
          "CorticalSurf","Trab. Vol.","Cort. Vol"};

label["Pu"] = {"Liver","C_Bone-S","T_Bone-S","UB_Content","Kidneys","Testes",
    "Ovaries","Other","C_Bone-V","R_Marrow","T_Bone-V"};

label["Ra"]={"UB_Cont","T_Bone-S","C_Bone-S","Other ","Liver","T_Bone-V",
      "C_Bone-V"};

label["Th"]={"Liver","C_Bone-S","T_Bone-S","UB_Cont","Kidneys","Testes","Other",
"C_Bone-V","R_Marrow","T_Bone-V"};

label["I"]= {"Thyroid","UB_Content","Other"};

label["Sr"]={"UB_Content", "T_Bone-S", "C_Bone-S", "Other", "T_Bone-V", "C_Bone-V"};
  
Map[(label[#]={"Body_Tis", "UB_Content"})&,elem1];
Map[(label[#]={"Body_Tis", "UB_Content"})&,elem2];
Map[(label[#]={"Other", "Liver", "UB_Content"})&,elem3];

comp1[element_] := If[Cases[elem1, element] == {}, "False", element];
comp2[element_] := If[Cases[elem2, element] == {}, "False", element];
comp3[element_] := If[Cases[elem3, element] == {}, "False", element];

Evaluate[Map[esym,elementsymbol]] = elementname;
Evaluate[Map[elname,elementname]] = elementsymbol;


IodineUsinh[amadx_, typem_, ff1_, t1_, decayconst_] := 
   {Subscript[q, AI][t], Subscript[q, bb1][t], Subscript[q, bb2][t], 
      Subscript[q, bbseq][t], Subscript[q, BB1][t], Subscript[q, BB2][t], 
      Subscript[q, BBseq][t], Subscript[q, ET2][t], Subscript[q, ET1][t], 
      Subscript[q, ETseq][t], Subscript[q, LNth][t], Subscript[q, LNet][t], 
      qST[t], qSI[t]+ 0. t, qB[t], qULI[t], qLLI[t], Subscript[q, 2][t], 
      Subscript[q, 4][t], Subscript[q, 3][t]} /. BiokdataReport[iodine, 
      "Inhalation", "Acute", "Disintegrations", 1, amadx, typem, ff1, t, 
      decayconst] /. t -> t1; 

IodineUsing[ff1_, t1_, decayconst_] := 
   {qST[t], qSI[t] + 0. t, qB[t], qULI[t], qLLI[t], Subscript[q, 2][t], 
      Subscript[q, 4][t], Subscript[q, 3][t]} /. BiokdataReport[iodine, 
      "Ingestion", "Acute", "Disintegrations", 1, ff1, t, 
      decayconst] /. t -> t1; 

IodineUsinj[ff1_, t1_, decayconst_] := 
   {0. t, 0. t, qB[t], qULI[t], qLLI[t], Subscript[q, 2][t], 
      Subscript[q, 4][t], Subscript[q, 3][t]} /. BiokdataReport[iodine, 
      "Injection", "Acute", "Disintegrations", 1, ff1, t, 
      decayconst] /. t -> t1; 

g3usinh[element_, amadx_, typem_, ff1_, t1_, decayct_] := 
   {Subscript[q, AI][t], Subscript[q, bb1][t], Subscript[q, bb2][t], 
      Subscript[q, bbseq][t], Subscript[q, BB1][t], Subscript[q, BB2][t], 
      Subscript[q, BBseq][t], Subscript[q, ET2][t], Subscript[q, ET1][t], 
      Subscript[q, ETseq][t], Subscript[q, LNth][t], Subscript[q, LNet][t], 
      qST[t], qSI[t] + 0. t, qB[t], qULI[t], qLLI[t], Subscript[q, 2][t] + 
       Subscript[q, 3][t] + Subscript[q, 4][t], 0. t, Subscript[q, 5][t]} /. 
     BiokdataReport[element, "Inhalation", "Acute", "Disintegrations", 1, 
      amadx, typem, ff1, t, decayct] /. t -> t1; 

g3using[element_, ff1_, t1_, decayct_] := 
   {qST[t], qSI[t] + 0. t, qB[t], qULI[t], qLLI[t], Subscript[q, 2][t] + 
       Subscript[q, 3][t] + Subscript[q, 4][t], 0. t, Subscript[q, 5][t]} /. 
     BiokdataReport[element, "Ingestion", "Acute", "Disintegrations", 1, 
     ff1, t, decayct] /. t -> t1; 

g3usinj[element_, ff1_, t1_, decayct_] := 
   {0. t, 0. t, qB[t], qULI[t], qLLI[t], Subscript[q, 2][t] + 
       Subscript[q, 3][t] + Subscript[q, 4][t], 0. t, Subscript[q, 5][t]} /. 
     BiokdataReport[element, "Injection", "Acute", "Disintegrations", 1, 
     ff1, t, decayct] /. t -> t1; 

g2usinh[element_, amadx_, typem_, ff1_, t1_, decayct_] := 
   {Subscript[q, AI][t], Subscript[q, bb1][t], Subscript[q, bb2][t], 
      Subscript[q, bbseq][t], Subscript[q, BB1][t], Subscript[q, BB2][t], 
      Subscript[q, BBseq][t], Subscript[q, ET2][t], Subscript[q, ET1][t], 
      Subscript[q, ETseq][t], Subscript[q, LNth][t], Subscript[q, LNet][t], 
      qST[t], qSI[t] + 0. t, qB[t], qULI[t], qLLI[t], Subscript[q, 2][t] + 
       Subscript[q, 3][t], Subscript[q, 4][t]} /. BiokdataReport[element, 
      "Inhalation", "Acute", "Disintegrations", 1, amadx, typem, ff1, t, 
      decayct] /. t -> t1; 

g2using[element_, ff1_, t1_, decayct_] := 
   {qST[t], qSI[t] + 0. t, qB[t], qULI[t], qLLI[t], Subscript[q, 2][t] + 
    Subscript[q, 3][t], Subscript[q, 4][t]} /. BiokdataReport[element, 
    "Ingestion", "Acute", "Disintegrations", 1, ff1, t, decayct] /. t -> t1; 

g2usinj[element_, ff1_, t1_, decayct_] := 
   {0. t, 0. t, qB[t], qULI[t], qLLI[t], Subscript[q, 2][t] + 
    Subscript[q, 3][t], Subscript[q, 4][t]} /. BiokdataReport[element, 
    "Injection", "Acute", "Disintegrations", 1, ff1, t, decayct] /. t -> t1; 

g1usinh[element_, amadx_, typem_, ff1_, t1_, decayct_] := 
   {Subscript[q, AI][t], Subscript[q, bb1][t], Subscript[q, bb2][t], 
      Subscript[q, bbseq][t], Subscript[q, BB1][t], Subscript[q, BB2][t], 
      Subscript[q, BBseq][t], Subscript[q, ET2][t], Subscript[q, ET1][t], 
      Subscript[q, ETseq][t], Subscript[q, LNth][t], Subscript[q, LNet][t], 
      qST[t], qSI[t] + 0. t, qB[t], qULI[t], qLLI[t], Subscript[q, 2][t], 
      Subscript[q, 3][t]} /. BiokdataReport[element, "Inhalation", "Acute", 
      "Disintegrations", 1, amadx, typem, ff1, t, decayct] /. t -> t1; 

g1using[typem_, ff1_, t1_, decayct_] := 
   {qST[t], qSI[t] + 0. t, qB[t], qULI[t], qLLI[t], Subscript[q, 2][t], 
      Subscript[q, 3][t]} /. BiokdataReport[element, "Ingestion", "Acute", 
      "Disintegrations", 1, ff1, t, decayct] /. t -> t1; 

g1usinj[typem_, ff1_, t1_, decayct_] := 
   {0. t, 0. t, qB[t], qULI[t], qLLI[t], Subscript[q, 2][t], 
      Subscript[q, 3][t]} /. BiokdataReport[element, "Injection", "Acute", 
      "Disintegrations", 1, ff1, t, decayct] /. t -> t1; 

Uusinh[amadx_, typem_, ff1_, t1_, decaycont_] := 
   {Subscript[q, AI][t], Subscript[q, bb1][t], Subscript[q, bb2][t], 
      Subscript[q, bbseq][t], Subscript[q, BB1][t], Subscript[q, BB2][t], 
      Subscript[q, BBseq][t], Subscript[q, ET2][t], Subscript[q, ET1][t], 
      Subscript[q, ETseq][t], Subscript[q, LNth][t], Subscript[q, LNet][t], 
      qST[t], qSI[t] + 0. t, qB[t] + Subscript[q, 2][t], qULI[t], qLLI[t], 
      Subscript[q, 3][t] + Subscript[q, 4][t] + Subscript[q, 5][t], 
      Subscript[q, 16][t], Subscript[q, 8][t] + Subscript[q, 9][t], 
      Subscript[q, 6][t] + Subscript[q, 7][t], Subscript[q, 10][t], 
      Subscript[q, 13][t], Subscript[q, 11][t] + Subscript[q, 12][t], 
      Subscript[q, 14][t] + Subscript[q, 15][t]} /. 
     BiokdataReport[uranium, "Inhalation", "Acute", "Disintegrations", 1, 
      amadx, typem, ff1, t, decaycont] /. t -> t1; 

Uusing[ff1_, t1_, decayconst_] := 
   {qST[t], qSI[t] + 0. t, qB[t] + Subscript[q, 2][t], qULI[t], qLLI[t], 
      Subscript[q, 3][t] + Subscript[q, 4][t] + Subscript[q, 5][t], 
      Subscript[q, 16][t], Subscript[q, 8][t] + Subscript[q, 9][t], 
      Subscript[q, 6][t] + Subscript[q, 7][t], Subscript[q, 10][t], 
      Subscript[q, 13][t], Subscript[q, 11][t] + Subscript[q, 12][t], 
      Subscript[q, 14][t] + Subscript[q, 15][t]} /. 
     BiokdataReport[uranium, "Ingestion", "Acute", "Disintegrations", 1, 
      ff1, t, decayconst] /. t -> t1; 

Uusinj[ff1_, t1_, decayconst_] := 
   {0. t, 0. t, qB[t] + Subscript[q, 2][t], qULI[t], qLLI[t], 
      Subscript[q, 3][t] + Subscript[q, 4][t] + Subscript[q, 5][t], 
      Subscript[q, 16][t], Subscript[q, 8][t] + Subscript[q, 9][t], 
      Subscript[q, 6][t] + Subscript[q, 7][t], Subscript[q, 10][t], 
      Subscript[q, 13][t], Subscript[q, 11][t] + Subscript[q, 12][t], 
      Subscript[q, 14][t] + Subscript[q, 15][t]} /. 
     BiokdataReport[uranium, "Injection", "Acute", "Disintegrations", 1, 
      ff1, t, decayconst] /. t -> t1; 


PuUsinh[amadx_, typem_, ff1_, t1_,decayconst_] := 
   {Subscript[q, AI][t], Subscript[q, bb1][t], Subscript[q, bb2][t], 
      Subscript[q, bbseq][t], Subscript[q, BB1][t], Subscript[q, BB2][t], 
      Subscript[q, BBseq][t], Subscript[q, ET2][t], Subscript[q, ET1][t], 
      Subscript[q, ETseq][t], Subscript[q, LNth][t], Subscript[q, LNet][t], 
      qST[t], qSI[t] + 0. t, qB[t], qULI[t], qLLI[t], Subscript[q, 5][t] + 
       Subscript[q, 6][t], Subscript[q, 10][t], Subscript[q, 13][t], 
      Subscript[q, 16][t], Subscript[q, 7][t] + Subscript[q, 8][t], 
      Subscript[q, 15][t], Subscript[q, 15][t], Subscript[q, 2][t] + 
       Subscript[q, 3][t] + Subscript[q, 4][t], Subscript[q, 11][t], 
      Subscript[q, 9][t] + Subscript[q, 14][t], Subscript[q, 12][t]} /. 
     BiokdataReport[plutonium, "Inhalation", "Acute", "Disintegrations", 1, 
      amadx, typem, ff1, t, decayconst] /. t -> t1; 
      
PuUsing[ff1_, t1_,decayconst_] := 
  {qST[t], qSI[t], qB[t], qULI[t], qLLI[t], Subscript[q, 5][t] + 
    Subscript[q, 6][t], Subscript[q, 10][t], Subscript[q, 13][t], 
    Subscript[q, 16][t], Subscript[q, 7][t] + Subscript[q, 8][t], 
    Subscript[q, 15][t], Subscript[q, 15][t], Subscript[q, 2][t] + 
    Subscript[q, 3][t] + Subscript[q, 4][t], Subscript[q, 11][t], 
    Subscript[q, 9][t] + Subscript[q, 14][t], Subscript[q, 12][t]} /. 
    BiokdataReport[plutonium, "Ingestion", "Acute", "Disintegrations", 1, 
    ff1, t, decayconst] /. t -> t1; 

PuUsinj[ff1_, t1_,decayconst_] := 
  {0. t, qSI[t], qB[t], qULI[t], qLLI[t], Subscript[q, 5][t] + 
    Subscript[q, 6][t], Subscript[q, 10][t], Subscript[q, 13][t], 
    Subscript[q, 16][t], Subscript[q, 7][t] + Subscript[q, 8][t], 
    Subscript[q, 15][t], Subscript[q, 15][t], Subscript[q, 2][t] + 
    Subscript[q, 3][t] + Subscript[q, 4][t], Subscript[q, 11][t], 
    Subscript[q, 9][t] + Subscript[q, 14][t], Subscript[q, 12][t]} /. 
    BiokdataReport[plutonium, "Injection", "Acute", "Disintegrations", 1, 
    ff1, t, decayconst] /. t -> t1; 

SrUsinh[amadx_, typem_, ff1_, t1_, decaycont_] := 
   {Subscript[q, AI][t], Subscript[q, bb1][t], 
      Subscript[q, bb2][t], Subscript[q, bbseq][t], 
      Subscript[q, BB1][t], Subscript[q, BB2][t], 
      Subscript[q, BBseq][t], Subscript[q, ET2][t], 
      Subscript[q, ET1][t], Subscript[q, ETseq][t], 
      Subscript[q, LNth][t], Subscript[q, LNet][t], qST[t], 
      qSI[t] + 0.*t, qB[t] , qULI[t], qLLI[t], 
      Subscript[q, 11][t], Subscript[q, 5][t], 
      Subscript[q, 8][t], + Subscript[q, 2][t] + 
       Subscript[q, 3][t] + Subscript[q, 4][t], Subscript[q, 6][t] + 
       Subscript[q, 7][t], Subscript[q, 9][t] + 
       Subscript[q, 10][t]} /. BiokdataReport[strontium, 
      "Inhalation", "Acute", "Disintegrations", 1, amadx, typem, 
      ff1, t, decaycont] /. t -> t1; 

SrUsing[ff1_, t1_, decaycont_] := 
   {qST[t], qSI[t]+ 0. t, qB[t] , qULI[t], qLLI[t], 
      Subscript[q, 11][t], Subscript[q, 5][t], 
      Subscript[q, 8][t], + Subscript[q, 2][t] + 
       Subscript[q, 3][t] + Subscript[q, 4][t], Subscript[q, 6][t] + 
       Subscript[q, 7][t], Subscript[q, 9][t] + 
       Subscript[q, 10][t]} /. BiokdataReport[strontium, 
     "Ingestion", "Acute", "Disintegrations", 1,  ff1, t, decaycont] /. t -> t1; 


SrUsinj[ff1_, t1_, decaycont_] := 
   {0. t, 0. t, qB[t] + Subscript[q, 2][t] , qULI[t], qLLI[t], 
      Subscript[q, 11][t], Subscript[q, 5][t], 
      Subscript[q, 8][t], + Subscript[q, 3][t] + Subscript[q, 4][t], Subscript[q, 6][t] + 
       Subscript[q, 7][t], Subscript[q, 9][t] + 
       Subscript[q, 10][t]} /. BiokdataReport[strontium, 
     "Injection", "Acute", "Disintegrations", 1,  ff1, t, decaycont] /. t -> t1; 

RaUsinh[amadx_, typem_, ff1_, t1_, decaycont_] := 
   {Subscript[q, AI][t], Subscript[q, bb1][t], 
      Subscript[q, bb2][t], Subscript[q, bbseq][t], 
      Subscript[q, BB1][t], Subscript[q, BB2][t], 
      Subscript[q, BBseq][t], Subscript[q, ET2][t], 
      Subscript[q, ET1][t], Subscript[q, ETseq][t], 
      Subscript[q, LNth][t], Subscript[q, LNet][t], qST[t], 
      qSI[t] + 0.*t, qB[t], qULI[t], qLLI[t], 
      Subscript[q, 12][t], Subscript[q, 8][t], 
      Subscript[q, 5][t], Subscript[q, 2][t] + 
       Subscript[q, 3][t] + Subscript[q, 4][t], 
      Subscript[q, 11][t], Subscript[q, 9][t] + 
       Subscript[q, 10][t], Subscript[q, 6][t] + 
       Subscript[q, 7][t]} /. BiokdataReport[radium, 
      "Inhalation", "Acute", "Disintegrations", 1, amadx, typem, 
      ff1, t, decaycont] /. t -> t1; 

RaUsing[ff1_, t1_, decayconst_] := 
   {qST[t], qSI[t] + 0.*t, qB[t], qULI[t], qLLI[t], 
      Subscript[q, 12][t], Subscript[q, 8][t], 
      Subscript[q, 5][t], Subscript[q, 2][t] + 
       Subscript[q, 3][t] + Subscript[q, 4][t], 
      Subscript[q, 11][t], Subscript[q, 9][t] + 
       Subscript[q, 10][t], Subscript[q, 6][t] + 
       Subscript[q, 7][t]} /. BiokdataReport[radium, "Ingestion", 
      "Acute", "Disintegrations", 1, ff1, t, decayconst] /. 
    t -> t1; 

RaUsinj[ff1_, t1_, decayconst_] := 
   {0.*t, 0.*t, qB[t], qULI[t], qLLI[t], Subscript[q, 12][t], 
      Subscript[q, 8][t], Subscript[q, 5][t], 
      Subscript[q, 2][t] + Subscript[q, 3][t] + 
       Subscript[q, 4][t], Subscript[q, 11][t], 
      Subscript[q, 9][t] + Subscript[q, 10][t], 
      Subscript[q, 6][t] + Subscript[q, 7][t]} /. 
     BiokdataReport[radium, "Injection", "Acute", 
      "Disintegrations", 1, ff1, t, decayconst] /. t -> t1; 

ThUsinh[amadx_, typem_, ff1_, t1_, decaycont_] := 
   {Subscript[q, AI][t], Subscript[q, bb1][t], 
      Subscript[q, bb2][t], Subscript[q, bbseq][t], 
      Subscript[q, BB1][t], Subscript[q, BB2][t], 
      Subscript[q, BBseq][t], Subscript[q, ET2][t], 
      Subscript[q, ET1][t], Subscript[q, ETseq][t], 
      Subscript[q, LNth][t], Subscript[q, LNet][t], qST[t], 
      qSI[t] + 0.*t, qB[t], qULI[t], qLLI[t], 
      Subscript[q, 5][t] + Subscript[q, 6][t], 
      Subscript[q, 12][t], Subscript[q, 9][t], 
      Subscript[q, 16][t], Subscript[q, 7][t] + 
       Subscript[q, 8][t], Subscript[q, 15][t], 
      Subscript[q, 2][t] + Subscript[q, 3][t] + 
       Subscript[q, 4][t], Subscript[q, 14][t], 
      Subscript[q, 10][t] + Subscript[q, 13][t], 
      Subscript[q, 11][t]} /. BiokdataReport[thorium, 
      "Inhalation", "Acute", "Disintegrations", 1, amadx, typem, 
      ff1, t, decaycont] /. t -> t1; 

ThUsing[ff1_, t1_, decaycont_] := 
   {qST[t], qSI[t] + 0.*t, qB[t], qULI[t], qLLI[t], 
      Subscript[q, 5][t] + Subscript[q, 6][t], 
      Subscript[q, 12][t], Subscript[q, 9][t], 
      Subscript[q, 16][t], Subscript[q, 7][t] + 
       Subscript[q, 8][t], Subscript[q, 15][t], 
      Subscript[q, 2][t] + Subscript[q, 3][t] + 
       Subscript[q, 4][t], Subscript[q, 14][t], 
      Subscript[q, 10][t] + Subscript[q, 13][t], 
      Subscript[q, 11][t]} /. BiokdataReport[thorium, 
      "Ingestion", "Acute", "Disintegrations", 1,  
      ff1, t, decaycont] /. t -> t1; 


ThUsinj[ff1_, t1_, decaycont_] := 
   {0. t, 0. t, qB[t], qULI[t], qLLI[t], 
      Subscript[q, 5][t] + Subscript[q, 6][t], 
      Subscript[q, 12][t], Subscript[q, 9][t], 
      Subscript[q, 16][t], Subscript[q, 7][t] + 
       Subscript[q, 8][t], Subscript[q, 15][t], 
      Subscript[q, 2][t] + Subscript[q, 3][t] + 
       Subscript[q, 4][t], Subscript[q, 14][t], 
      Subscript[q, 10][t] + Subscript[q, 13][t], 
      Subscript[q, 11][t]} /. BiokdataReport[thorium, 
      "Injection", "Acute", "Disintegrations", 1,  
      ff1, t, decaycont] /. t -> t1; 


DisintegrationLabel[dis_,tafter_]:=
    TableForm[Map[Flatten[#]&,dis],
      TableHeadings->{None,Flatten[{"Compartment",tafter "day"}]}];

Disintegrations[element_,intway_,int_, amadx_,typem_, ff1_,t1_, decay_, 
options___Rule]/;"Inhalation"===intway:= 
With[{m = {DisintegrationReport} /. Flatten[{options}] /. 
Options[Disintegrations]}, 
Module[{ss, us, sol},ss= { amadx,typem, ff1,t1, decay}; 
us =Which["U" == element, Uusinh@@ss, 
    "Pu" == element, PuUsinh@@ss, 
    "Sr" == element, SrUsinh@@ss,
    "Ra" == element, RaUsinh@@ss,
    "Th" == element, ThUsinh@@ss,
    "I" == element, IodineUsinh@@ss,
    element== comp1[element],g1usinh@@Join[{esym[element]},ss],
    element== comp2[element],g2usinh@@Join[{esym[element]},ss], 
    element== comp3[element],g3usinh@@Join[{esym[element]},ss]  ];
    sol={Join[label["RT"],label["GI"], label[element]],int*us}; 
    Transpose[sol]] /; m === {"Automatic"}];

Disintegrations[element_,intway_,int_, amadx_,typem_, ff1_,t1_, decay_, 
options___Rule]/;"Inhalation"===intway:= 
With[{m = {DisintegrationReport} /. Flatten[{options}] /. 
Options[Disintegrations]}, 
Module[{ss, us, sol},ss= { amadx,typem, ff1,t1, decay}; 
us =Which["U" == element, Uusinh@@ss, 
    "Pu" == element, PuUsinh@@ss,
    "Sr" == element, SrUsinh@@ss,
    "Ra" == element, RaUsinh@@ss,
    "Th" == element, ThUsinh@@ss,  
    "I" == element, IodineUsinh@@ss,
    element== comp1[element],g1usinh@@Join[{esym[element]},ss],
    element== comp2[element],g2usinh@@Join[{esym[element]},ss], 
    element== comp3[element],g3usinh@@Join[{esym[element]},ss]  ];
    sol={Join[label["RT"],label["GI"], label[element]],int*us}; 
    DisintegrationLabel[Transpose[sol],t1]] /; m === {"True"}];

Disintegrations[element_,intway_,int_, ff1_,t1_, decay_, 
    options___Rule]/;
    "Ingestion"===intway:= 
    With[{m = {DisintegrationReport} /. Flatten[{options}] /. 
       Options[Disintegrations]}, 
    Module[{ss, us, sol},ss= {ff1,t1, decay}; 
    us =Which["U" == element, Uusing@@ss, 
    "Pu" == element, PuUsing@@ss,
    "Sr" == element, SrUsing@@ss, 
    "Ra" == element, RaUsing@@ss,
    "Th" == element, ThUsing@@ss,    
    "I" == element, IodineUsing@@ss,
    element== comp1[element],g1using@@Join[{esym[element]},ss],
    element== comp2[element],g2using@@Join[{esym[element]},ss], 
    element== comp3[element],g3using@@Join[{esym[element]},ss]  ];
    sol={Join[label["GI"], label[element]],int*us}; 
    Transpose[sol]]/; m === {"Automatic"}]; 

Disintegrations[element_,intway_,int_, ff1_,t1_, decay_, 
    options___Rule]/;
    "Ingestion"===intway:= 
    With[{m = {DisintegrationReport} /. Flatten[{options}] /. 
       Options[Disintegrations]}, 
    Module[{ss, us, sol},ss= {ff1,t1, decay}; 
    us =Which["U" == element, Uusing@@ss, 
    "Pu" == element, PuUsing@@ss, 
    "Sr" == element, SrUsing@@ss, 
    "Ra" == element, RaUsing@@ss,
    "Th" == element, ThUsing@@ss, 
    "I" == element, IodineUsing@@ss,
    element== comp1[element],g1using@@Join[{esym[element]},ss],
    element== comp2[element],g2using@@Join[{esym[element]},ss], 
    element== comp3[element],g3using@@Join[{esym[element]},ss]  ];
    sol={Join[label["GI"], label[element]],int*us}; 
    DisintegrationLabel[Transpose[sol],t1]]/; m === {"True"}]; 

Disintegrations[element_,intway_,int_, ff1_,t1_, decay_, 
    options___Rule]/; "Injection"===intway:= 
   With[{m = {DisintegrationReport} /. Flatten[{options}] /. 
   Options[Disintegrations]}, Module[{ss, us, sol},ss= {ff1,t1, decay}; 
    us =Which["U" == element, Uusinj@@ss, 
    "Pu" == element, PuUsinj@@ss,
    "Sr" == element, SrUsinj@@ss, 
    "Ra" == element, RaUsinj@@ss,
    "Th" == element, ThUsinj@@ss,  
    "I" == element, IodineUsinj@@ss,
    element== comp1[element],g1usinj@@Join[{esym[element]},ss],
    element== comp2[element],g2usinj@@Join[{esym[element]},ss], 
    element== comp3[element],g3usinj@@Join[{esym[element]},ss]  ];
    sol={Join[label["GI"], label[element]],int*us}; 
    Transpose[sol]]/; m === {"Automatic"}] ;

Disintegrations[element_,intway_,int_, ff1_,t1_, decay_, 
    options___Rule]/; "Injection"===intway:= 
   With[{m = {DisintegrationReport} /. Flatten[{options}] /. 
   Options[Disintegrations]}, Module[{ss, us, sol},ss= {ff1,t1, decay}; 
    us =Which["U" == element, Uusinj@@ss, 
    "Pu" == element, PuUsinj@@ss,
    "Sr" == element, SrUsinj@@ss, 
    "Ra" == element, RaUsinj@@ss, 
    "Th" == element, ThUsinj@@ss,  
    "I" == element, IodineUsinj@@ss,
    element== comp1[element],g1usinj@@Join[{esym[element]},ss],
    element== comp2[element],g2usinj@@Join[{esym[element]},ss], 
    element== comp3[element],g3usinj@@Join[{esym[element]},ss] ];
    sol={Join[label["GI"], label[element]],int*us}; 
    DisintegrationLabel[Transpose[sol],t1]]/; m === {"True"}] ;

dosefactor[us_, seecal_]:=
Module[{wtf,wtremainder,wtd, mass,mass1, he,organdoses,list1, list2, 
        list2a, wtesp, wt,  edose, adren,ubwall,bonesur,brain,breasts,stwall,
        siwall,uli,lli,kid,liver,et1bas,et2bas,lnet,BBbas,BBsec,bbsec,ai,lnth,
        muscle,ovaries,pancreas,rmarrow,skin,spleen,testes,thymus,thyroid,
        uterus},wtf={.2,.12,.12,.12,.12,.05,.05,.05,.05,.05,.01,.01};
      wtremainder ={0.045515,0.002275757,0.001040346,0.00050392,0.000162554,
          0.0002926,0.00003251,0.00013,0.000022757567,0.000024383};
      wtd =Join[wtf,wtremainder];
      mass={28000,1400,640,310,100,180,20,80,14,15};
      he={adren,ubwall,bonesur,brain,breasts,stwall,siwall,uli,lli,kid,liver,
            et1bas,et2bas,lnet,BBbas,BBsec,bbsec,ai,lnth,muscle,ovaries,
            pancreas,rmarrow,skin,spleen,testes,thymus,thyroid,uterus} = 
          Dot[seecal,us];
      organdoses={testes,ovaries,rmarrow,
          0.57uli +0.43 lli, .1665 BBbas+.1665 BBsec+.333 bbsec+.333ai+
          .001lnth,stwall,ubwall,breasts ,liver, thymus,thyroid,skin , 
          bonesur,muscle, brain , siwall, kid,pancreas,spleen,thymus,uterus,
          adren,.001et1bas+.998et2bas+.001lnet};
      list1 =Take[organdoses,13];list2 = Take[organdoses,-10];
      wtesp:=(max=Ordering[list2,-1];mass1=Drop[mass,max];
          list2a=mass1/Total[mass1]*0.025;
          Join[wtf,Insert[list2a,0.025,max]]);
      wt = If[Max[list1]>Max[list2],wtd,wtesp];
      edose = Dot[Drop[organdoses,1], wt ];Flatten[{organdoses,edose }] ];


OrganLabel[htdose_]:= 
  TableForm[Transpose[{doseslabel, htdose}], 
    TableHeadings -> {None, {"Organ", "Sv/Bq"}}];     

labeldose[d_,t1_] := 
  Join[{Flatten[{{"Sv/Bq"},t1 "day"}]},Transpose[Join[{doseslabel},d]]];

DisintegrationLabel[dis_,tafter_]:=
    TableForm[Map[Flatten[#]&,dis],
      TableHeadings->{None,Flatten[{"Compartment",tafter "day"}]}];

headtitle1= StyleForm["\nAccumulted disintegration, in Bq, as function of the time\n",
          FontFamily->"Times",FontSize->12,FontWeight->"Bold"];

headtitle2=StyleForm["\nDose accumulated, in Sv, as function of the time\n",
FontFamily->"Times",FontSize->12,FontWeight->"Bold"];

desSR90Inj[ff1_,t1_]:=
    Module[{t,kSr90,kY90,actY90,qGISR,qGISR90,qGIY90,UsSr90,UsY90},
      kSr90=Decayconst["Sr 90"];kY90=Decayconst["Y 90"];
      actY90=(kY90/kSr90)*Catenary[1,2,t,k,k,0]/.{Subscript[k,1]->kSr90,
            Subscript[k,2]->kY90};
      qGISR={0. t,0. t,qB[t],qULI[t],qLLI[t],Subscript[q,11][t],
            Subscript[q,5][t],
            Subscript[q,8][t],(Plus[Subscript[q,2][t]])+Subscript[q,3][t]+
              Subscript[q,4][t],Subscript[q,6][t]+Subscript[q,7][t],
            Subscript[q,9][t]+Subscript[q,10][t]}/.BiokdataReport[strontium,
            "Injection","Acute","CompartmentContent",1,ff1,t,0];
      qGISR90=ExpandAll[qGISR*Exp[(-kSr90)*t]];
      qGIY90=ExpandAll[qGISR*actY90];
      UsSr90=24*3600*Flatten[(qContinuous[1,{#1},t,t1]&)/@qGISR90];
      UsY90=24*3600*Flatten[(qContinuous[1,{#1},t,t1]&)/@qGIY90];
      {UsSr90,UsY90}];

desSR90Ing[ff1_, t1_] := Module[{t, kSr90, kY90, actY90, 
    qGISR, qGISR90, qGIY90, UsSr90, UsY90}, 
   kSr90 = Decayconst["Sr 90"]; kY90 = Decayconst["Y 90"]; 
    actY90 = (kY90/kSr90)*Catenary[1, 2, t, k, k, 0] /. 
      {Subscript[k, 1] -> kSr90, Subscript[k, 2] -> 
        kY90}; qGISR = {qST[t], qSI[t] + 0.*t, qB[t], 
       qULI[t], qLLI[t], Subscript[q, 11][t], 
       Subscript[q, 5][t], Subscript[q, 8][t], 
       (Plus[Subscript[q, 2][t]]) + Subscript[q, 3][t] + 
        Subscript[q, 4][t], Subscript[q, 6][t] + 
        Subscript[q, 7][t], Subscript[q, 9][t] + 
        Subscript[q, 10][t]} /. BiokdataReport[
       strontium, "Ingestion", "Acute", 
       "CompartmentContent", 1, ff1, t, 0]; 
      qGISR90=ExpandAll[qGISR*Exp[(-kSr90)*t]];
      qGIY90=ExpandAll[qGISR*actY90];
      UsSr90=24*3600*Flatten[(qContinuous[1,{#1},t,t1]&)/@qGISR90];
      UsY90=24*3600*Flatten[(qContinuous[1,{#1},t,t1]&)/@qGIY90];
      {UsSr90,UsY90}];


desSR90Inh[amadx_,typem_,ff1_,t1_]:=
    Module[{t,kSr90,kY90,actY90,qINHSR,qINHSR90,qINHY90,UsSr90,UsY90},
      kSr90=Decayconst["Sr 90"];
      kY90=Decayconst["Y 90"];
      actY90=(kY90/kSr90)*Catenary[1,2,t,k,k,0]/.{Subscript[k,1]->kSr90,
            Subscript[k,2]->kY90};
      qINHSR={Subscript[q,AI][t],Subscript[q,bb1][t],Subscript[q,bb2][t],
            Subscript[q,bbseq][t],Subscript[q,BB1][t],Subscript[q,BB2][t],
            Subscript[q,BBseq][t],Subscript[q,ET2][t],Subscript[q,ET1][t],
            Subscript[q,ETseq][t],Subscript[q,LNth][t],Subscript[q,LNet][t],
            qST[t],qSI[t]+0.*t,qB[t],qULI[t],qLLI[t],Subscript[q,11][t],
            Subscript[q,5][t],
            Subscript[q,8][t],(Plus[Subscript[q,2][t]])+Subscript[q,3][t]+
              Subscript[q,4][t],Subscript[q,6][t]+Subscript[q,7][t],
            Subscript[q,9][t]+Subscript[q,10][t]}/.BiokdataReport[strontium,
            "Inhalation","Acute","CompartmentContent",1,amadx,typem,ff1,t,0];
      qINHSR90=ExpandAll[qINHSR*Exp[(-kSr90)*t]];
      qINHY90=ExpandAll[qINHSR*actY90];
      UsSr90=24*3600*Flatten[(qContinuous[1,{#1},t,t1]&)/@qINHSR90];
      UsY90=24*3600*Flatten[(qContinuous[1,{#1},t,t1]&)/@qINHY90];
      {UsSr90,UsY90}];

CommittedDose["Sr 90", "Injection", intake_, ff1_, t1_, 
    options___Rule] := 
   With[{m = {DisintegrationReport} /. 
   Flatten[{options}] /. Options[CommittedDose]}, 
    Block[{UsSr90, UsY90, ht}, {UsSr90, UsY90} = desSR90Inj[ff1, t1]; 
    ht = intake*dosefactor[UsSr90, (Drop[#1, 12] & ) /@ see["Sr 90"]] + 
    dosefactor[UsY90, (Drop[#1, 12] & ) /@ see["Y 90"]]; 
    Transpose[{doseslabel, ht}]] /;m === {"False"}]; 


CommittedDose["Sr 90", "Ingestion", intake_, ff1_, t1_, 
    options___Rule] := 
   With[{m = {DisintegrationReport} /. 
   Flatten[{options}] /. Options[CommittedDose]}, 
    Block[{UsSr90, UsY90, ht}, {UsSr90, UsY90} = desSR90Ing[ff1, t1]; 
    ht = intake*dosefactor[UsSr90, (Drop[#1, 12] & ) /@ see["Sr 90"]] + 
    dosefactor[UsY90, (Drop[#1, 12] & ) /@ see["Y 90"]]; 
    Transpose[{doseslabel, ht}]] /;m === {"False"}]; 

CommittedDose["Sr 90", "Inhalation", intake_, amadx_, 
    typem_, ff1_, t1_, options___Rule] := 
   With[{m = {DisintegrationReport} /. Flatten[{options}] /. Options[CommittedDose]}, 
   Block[{UsSr90, UsY90, ht}, {UsSr90, UsY90} = desSR90Inh[amadx, typem, ff1, t1]; 
   ht = intake*dosefactor[UsSr90, see["Sr 90"]] + dosefactor[UsY90, see["Y 90"]]; 
   Transpose[{doseslabel, ht}]] /; m === {"False"}]; 

CommittedDose[element_,"Inhalation",intake_,amadx_,typem_,ff1_,t2_,decay_,
      seecal_,options___Rule]:=
    With[{m={DisintegrationReport}/.Flatten[{options}]/.Options[
              CommittedDose]},
      Block[{t1,us,ust,ht},t1=If[VectorQ[t2]== True , t2, {t2}];
          us=Disintegrations[element,"Inhalation",1,amadx,typem,ff1,t1,decay];
          ust={Flatten[Transpose[us][[2]]]};
          ht=intake*Map[dosefactor[#,seecal]&,ust];
          Print[headtitle1,
          DisintegrationLabel[us,t1],headtitle2,
          TableForm[labeldose[ht,t1]]]]/;m==={"True"}];

CommittedDose[element_,"Inhalation",intake_,amadx_,typem_,ff1_,t2_,decay_,
      seecal_,options___Rule]:=
    With[{m={DisintegrationReport}/.Flatten[{options}]/.Options[
              CommittedDose]},
      Block[{t1,us,ust,ht},t1=If[VectorQ[t2]== True , t2, {t2}];
          us=Disintegrations[element,"Inhalation",1,amadx,typem,ff1,t1,decay];
          ust={Flatten[Transpose[us][[2]]]};
          ht=intake*Map[dosefactor[#,seecal]&,ust];labeldose[ht,t1]]/;
        m==={"False"}];

CommittedDose[isotope_,"Inhalation",intake_,amadx_,typem_,ff1_,t2_,options___Rule]:=
    With[{m={DisintegrationReport}/.Flatten[{options}]/.Options[
              CommittedDose]},
      Block[{t1,us,ust,ht},t1=If[VectorQ[t2]== True , t2, {t2}];
          us=Disintegrations[StringSplit[isotope][[1]],"Inhalation",1,
          amadx,typem,ff1,t1,Decayconst[isotope]];
          ust={Flatten[Transpose[us][[2]]]};
          ht=intake*Map[dosefactor[#,see[isotope]]&,ust];
          Print[headtitle1,
          DisintegrationLabel[us,t1],headtitle2,
          TableForm[labeldose[ht,t1]]]]/;m==={"True"}];


CommittedDose[isotope_,"Inhalation",intake_,amadx_,typem_,ff1_,t2_,options___Rule]:=
    With[{m={DisintegrationReport}/.Flatten[{options}]/.Options[
              CommittedDose]},
      Block[{t1,us,ust,ht},t1=If[VectorQ[t2]== True , t2, {t2}];
          us=Disintegrations[StringSplit[isotope][[1]],"Inhalation",1,
          amadx,typem,ff1,t1,Decayconst[isotope]];
         ust={Flatten[Transpose[us][[2]]]};
          ht=intake*Map[dosefactor[#,see[isotope]]&,ust];
          labeldose[ht,t1]]/;m==={"False"}];


CommittedDose[element_,"Ingestion",intake_,ff1_,t2_,decay_,seecal_,
    options___Rule]:=
  With[{m={DisintegrationReport}/.Flatten[{options}]/.Options[CommittedDose]},
    Block[{t1,us,ust,ht},t1=If[VectorQ[t2]==True,t2,{t2}];
        us=Disintegrations[element,"Ingestion",1,ff1,t1,decay];
        ust={Flatten[Transpose[us][[2]]]};
        ht=intake*Map[dosefactor[#,seecal]&,ust];
        Print[headtitle1, DisintegrationLabel[us,t1],headtitle2,
          TableForm[labeldose[ht,t1]]]]/;m==={"True"}]

CommittedDose[element_,"Ingestion",intake_,ff1_,t2_,decay_,seecal_,
    options___Rule]:=
  With[{m={DisintegrationReport}/.Flatten[{options}]/.Options[CommittedDose]},
    Block[{t1,us,ust,ht},t1=If[VectorQ[t2]==True,t2,{t2}];
        us=Disintegrations[element,"Ingestion",1,ff1,t1,decay];
        ust={Flatten[Transpose[us][[2]]]};
        ht=intake*Map[dosefactor[#,seecal]&,ust];labeldose[ht,t1]]/;
      m==={"False"}];

CommittedDose[isotope_,"Ingestion",intake_,ff1_,t2_,options___Rule]:=
  With[{m={DisintegrationReport}/.Flatten[{options}]/.Options[CommittedDose]},
    Block[{t1,us,ust,ht},t1=If[VectorQ[t2]==True,t2,{t2}];
        us=
          Disintegrations[StringSplit[isotope][[1]],"Ingestion",1,ff1,t1,
            Decayconst[isotope]];
       ust={Flatten[Transpose[us][[2]]]};
        ht=intake*Map[dosefactor[#,Map[Drop[#,12]&,see[isotope]]]&,ust];
        Print[headtitle1, DisintegrationLabel[us,t1],headtitle2,
          TableForm[labeldose[ht,t1]]]]/;m==={"True"}];

CommittedDose[isotope_,"Ingestion",intake_,ff1_,t2_,
    options___Rule]:=
  With[{m={DisintegrationReport}/.Flatten[{options}]/.Options[CommittedDose]},
    Block[{t1,us,ust,ht},t1=If[VectorQ[t2]==True,t2,{t2}];
        us=Disintegrations[StringSplit[isotope][[1]],"Ingestion",1,ff1,t1,
        Decayconst[isotope]];
      ust={Flatten[Transpose[us][[2]]]};
        ht=intake*Map[dosefactor[#,Map[Drop[#,12]&,see[isotope]]]&,ust];
        labeldose[ht,t1]]/;m==={"False"}];

CommittedDose[element_,"Injection",intake_,ff1_,t2_,decay_,seecal_,
    options___Rule]:=
  With[{m={DisintegrationReport}/.Flatten[{options}]/.Options[CommittedDose]},
    Block[{t1,us,ust,ht},t1=If[VectorQ[t2]==True,t2,{t2}];
        us=Disintegrations[element,"Injection",1,ff1,t1,decay];
     ust={Flatten[Transpose[us][[2]]]};
        ht=intake*Map[dosefactor[#,seecal]&,ust];
        Print[headtitle1, DisintegrationLabel[us,t1],headtitle2,
          TableForm[labeldose[ht,t1]]]]/;m==={"True"}]


CommittedDose[element_,"Injection",intake_,ff1_,t2_,decay_,seecal_,
    options___Rule]:=
  With[{m={DisintegrationReport}/.Flatten[{options}]/.Options[CommittedDose]},
    Block[{t1,us,ust,ht},t1=If[VectorQ[t2]==True,t2,{t2}];
        us=Disintegrations[element,"Injection",1,ff1,t1,decay];
      ust={Flatten[Transpose[us][[2]]]};
        ht=intake*Map[dosefactor[#,seecal]&,ust];labeldose[ht,t1]]/;
      m==={"False"}];

CommittedDose[isotope_,"Injection",intake_,ff1_,t2_,options___Rule]:=
  With[{m={DisintegrationReport}/.Flatten[{options}]/.Options[CommittedDose]},
    Block[{t1,us,ust,ht},t1=If[VectorQ[t2]==True,t2,{t2}];
        us=
          Disintegrations[StringSplit[isotope][[1]],"Injection",1,ff1,t1,
            Decayconst[isotope]];
        ust={Flatten[Transpose[us][[2]]]};
        ht=intake*Map[dosefactor[#,Map[Drop[#,12]&,see[isotope]]]&,ust];
        Print[headtitle1, DisintegrationLabel[us,t1],headtitle2,
          TableForm[labeldose[ht,t1]]]]/;m==={"True"}];

CommittedDose[isotope_,"Injection",intake_,ff1_,t2_,
    options___Rule]:=
  With[{m={DisintegrationReport}/.Flatten[{options}]/.Options[CommittedDose]},
    Block[{t1,us,ust,ht},t1=If[VectorQ[t2]==True,t2,{t2}];
        us=Disintegrations[StringSplit[isotope][[1]],"Injection",1,ff1,t1,
        Decayconst[isotope]];
        ust={Flatten[Transpose[us][[2]]]};
        ht=intake*Map[dosefactor[#,Map[Drop[#,12]&,see[isotope]]]&,ust];
        labeldose[ht,t1]]/;m==={"False"}];


ImportSEE[file_, "csv"]:=
    Module[{a, b},SetDirectory[StringJoin[ToString[$InstallationDirectory], 
    "\\AddOns\\Applications\\Biokmod\\Data"]]; 
      a = ToString[file]<>"."<>"csv";b=Import[a];
      ResetDirectory[];Map[Drop[#,1]&,Drop[b,1]]]

ImportSEE[file_, "xls"]:=
    Module[{a, b},SetDirectory[StringJoin[ToString[$InstallationDirectory], 
    "\\AddOns\\Applications\\Biokmod\\Data"]]; 
      a = ToString[file]<>"."<>"xls";
      b=Import[a];ResetDirectory[];Map[Drop[#,1]&,Drop[b,1]]];

ImportSEE[file_, "txt"] := Module[{a, b, list1}, SetDirectory[StringJoin[
ToString[$InstallationDirectory],"\\AddOns\\Applications\\Biokmod\\Data"]];
    a = StringJoin[ToString[file], ".", "txt"]; 
     b = (Drop[#1, 2] & ) /@ Import[a, "Table", ConversionOptions -> {"NumberPoint" -> ","}]; 
     ; ResetDirectory[];
     list1 = Drop[Drop[(Flatten[#1] & ) /@ Transpose[Partition[b, 32]], 1], {29, 30}]; 
     If[Last[Last[list1]] == 0, (Drop[#1, -1] & ) /@ (ToExpression[list1]/1000.), 
     ToExpression[list1]/1000.]]; 


ExportSEE[file_, see_, element_] := Module[{a, b}, 
SetDirectory[StringJoin[ToString[$InstallationDirectory], 
    "\\AddOns\\Applications\\Biokmod\\Data"]]; 
    a = StringJoin[ToString[file], ".", "csv"]; b = Transpose[
       Join[{Flatten[{{"T/S->"}, targetCompartments}]}, 
        Transpose[Join[{Join[label["RT"], label["GI"], label[element]]}, 
          see]]]];Export[a,b]; ResetDirectory[]];

isotopesymbol={"U 234", "U 235", "U 238", "Pu 239", "Co 60", "Cs 137", 
"I 125", "I 131", "Sr 90", "Sr 89", "Y 90", "Th 232", "Ra 226"};

(*Decayconst["U 232"]= Log[2]/26298*)
(*Decayconst["U 236"]= Log[2]/8546850000*)

Decayconst["U 234"]= Log[2]/89121000;
Decayconst["U 235"]= Log[2]/257136000000;
Decayconst["U 238"]= Log[2]/1632667500000;
Decayconst["Pu 239"]= Log[2]/8802525;
Decayconst["Ra 226"]= Log[2]/(1600*365.25);
Decayconst["Th 232"]= 0;
Decayconst["Co 60"]= Log[2]/(5.27*365.25);
Decayconst["Cs 137"]= Log[2]/(30*365.25);
Decayconst["I 125"]= Log[2]/60.1;
Decayconst["I 131"]= Log[2]/8.0;
Decayconst["Sr 89"]= Log[2]/(50.5);
Decayconst["Sr 90"]= Log[2]/(29.1*365.25);
Decayconst["Y 90"] = Log[2]/(64/24);

see["U 234"] =  ImportSEE[U234ADULT, "csv"];
see["U 238"] =  ImportSEE[U238ADULT, "csv"];
see["U 235"] =  ImportSEE[U235ADULT, "csv"] +  ImportSEE[TH231ADULT, "csv"] ;
see["Pu 239"] =  ImportSEE[PU239ADULT, "csv"];
see["Co 60"] =  ImportSEE[CO60ADULT, "csv"];
see["I 125"] =  ImportSEE[I125ADULT, "csv"];
see["I 131"] =  ImportSEE[I131ADULT, "csv"];
see["Cs 137"] = ImportSEE[Cs137ADULT, "csv"] + 0.95*ImportSEE[BA137MADULT, "csv"];
see["Sr 90"] = ImportSEE[SR90ADULT,"csv"];
see["Sr 89"] = ImportSEE[SR89ADULT,"csv"];
see["Y 90"] = ImportSEE[Y90ADULT,"csv"];
see["Ra 226"] = ImportSEE[RA226ADULT,"csv"];
see["Th 232"] = ImportSEE[TH232ADULT,"csv"];

EnrichedU[enr_, actU_: 100] := 
  Module[{u234, isou}, 
    u234 = 0.002381 + 0.00447884668*enr + 0.00091015*enr^2; 
    isou = {u234*231195520, enr*79989, (100 - enr - u234)*12439}; 
    Transpose[{{"U234", "U235", "U238"}, {u234, enr, 100 - enr - u234}, 
    actU*(isou/Total[isou])}]] /; 0.7 <= enr <= 5; 

(* Added in v1.2*)

EnrichedU[enr_, actU_: 100] := "The enrichment must be 0.70\[LessEqual] enr \[LessEqual] 5, in wt%U235"

DoseEnrichedUranium[totalintake_, enr_, amad_, fs_] := 
 Module[{a234, a235, a238, fm}, {a234, a235, a238} = 
   Transpose[EnrichedU[enr]][[2]]/100; fm = 1 - fs; 
      (fs*(Last[
         Last[CommittedDose["U 234", "Inhalation", totalintake*a234, 
           amad, S, 0.002, 50*365.25, 
           DisintegrationReport -> "False"]]] + Last[Last[
          CommittedDose["U 238", "Inhalation", totalintake*a238, 
           amad, S, 0.002, 50*365.25, DisintegrationReport -> "False"]]] + 
          Last[Last[CommittedDose["U 235", "Inhalation", totalintake*a235, 
           amad, S, 0.002, 50*365.25, DisintegrationReport -> "False"]]]) + 
           fm*(Last[Last[CommittedDose["U 234", "Inhalation", totalintake*a234, 
           amad, M, 0.02, 50*365.25, DisintegrationReport -> "False"]]] + 
          Last[Last[ CommittedDose["U 238", "Inhalation", totalintake*a238, amad, M, 0.02, 50*365.25, 
           DisintegrationReport -> "False"]]] + 
          Last[Last[CommittedDose["U 235", "Inhalation", totalintake*a235, 
           AMAD5, M, 0.02, 50*365.25, DisintegrationReport -> "False"]]]))*1000]
End[]

Print[" Doses 1.2   2015-08-27"]

EndPackage[]



