(* ::Package:: *)

(*The Package*)

(*Title : FitModel, a Mathematica package for fitting and uncertainties evaluation 
with application to Biokinetic Systems*)


(* : Author : Guillermo Sanchez*)


(* : Summary : This package provides Mathematica functions for fitting coefficients*)


(* : Context : Biokmod`Fitmodel`*)


(* : Package Version : 1.3 *)

(* : Copyright : Copyright 2015. Guillermo Sanchez.http : //diarium.usal.es/guillermo*)


(* : Keywords : Fit, Compartmental Model, Physiological Model, Biokinetic, 
Pharmacokinetic, Internal Dosimetry, Radiological Protection*)
 
(*Sources : *)

(* : Warning :*)

(* : Mathematica Version : 5.2, 6, 7 &10*)

(* : Limitation : None known.*)

(* : Discussion :*)

BeginPackage["Biokmod`Fitmodel`","Biokmod`Biokdata`", "Biokmod`Humorap3`", 
"Biokmod`Resptract`", "Biokmod`Master`", "Biokmod`SysModel`", "ErrorBarPlots`"]

X2Fit::usage = "X2FitE[pars, data1, model1, , data2, model2, ...,t]";

X2FitE::usage = "X2FitE[pars, data1, model1, , data2, model2, ...,t]";

MLFit::usage = "MLFit[data1, model1, , data2, model2, ...,t]";

MLFitLog::usage = "MLFitML[data1, model1, , data2, model2, ...,t]";

BioassayFit::usage = "BioassayFit[data1, model1, , data2, model2, ...,t]";

BioassayBestfit::usage = "BioassayBestfit[model, {v1,v1min, v1max}, 
{v2,v2min, v2max}, ...]";

UrineBioassayEvaluation::usage ="UrineBioassayEvaluation[sample, element, lambda, T, amad, fS, fM]"; 

LungBioassayEvaluation::usage ="LungBioassayEvaluation[sample, lambda, T, amad]"; 

LungAccidentalIntake::usage ="LungBioassayEvaluation[sample, intdiario, lambda, T, amad]";

Svu::usage = "Svu[f ,vars, sig] gives the combined standard  variance 
of the estimate f, of the inputs vars = {x1, x2, ...}, 
with standard uncertainties sig = {s1, s2, ...}";

Uin::usage  = "Uin[s, vars, sig, k] gives the expanded uncertainty 
interval Y: {upper Limit uL = y + k u, lower Limit lL = y - k u} 
being  vars = {x1, x2, ...}, with standard uncertainties 
us = {s1, s2, ...} and k the coverage factor";

Begin["`Private`"]

linearfit1[t_] = 0; 
linearfit1[list1_, model1_,  r___, t_] := Module[{a, t1, y1, s1}, 
{t1, y1, s1} = Transpose[list1]; 
Plus@@((model1 /. t -> t1)*(y1/s1^2)) + linearfit1[r, t]];

linearfit2[t_] = 0; 
linearfit2[list1_, model1_,  r___, t_] := Module[{a, t1, y1, s1}, 
{t1, y1, s1} = Transpose[list1]; 
Plus@@((model1 /. t -> t1)^2/s1^2) + linearfit2[r, t]];

MLFit[list1_,model1_,  r___, t_] := Module[{a, b}, 
a = linearfit1[list1, model1,  r, t]; b = linearfit2[list1, model1, 
r, t]; Thread[{"Mean", "s"} -> {a/b, 1/Sqrt[b]}]];


linearfit1a[t_] = 0; 
linearfit1a[list1_, model1_, r___, t_] := Module[{a, t1, y1, s1}, 
{t1, y1, s1} = Transpose[list1]; 
Plus @@ (Log[y1/(model1 /. t -> t1)]/Log[s1]^2) + linearfit1a[r, t]]; 
linearfit2a[t_] = 0; 
linearfit2a[list1_, model1_, r___, t_] := Module[{a, t1, y1, s1}, 
{t1, y1, s1} = Transpose[list1]; 
Plus @@ (1/Log[s1]^2) + linearfit2a[r, t]];

MLFitLog[list1_, model1_, r___, t_] := Module[{a, b}, 
a = linearfit1a[list1, model1, r, t]; 
b = linearfit2a[list1, model1, r, t]; "Mean" -> Exp[a/b]];

fx2[t_] = 0; 
fx2[list1_, model1_, r___, t_] := Module[{a, t1, y1}, 
    {t1, y1} = Transpose[list1]; Plus @@ (((model1 /. t -> t1) - y1)^2) + 
      fx2[r, t]]; 
X2Fit[{(par__)?NumberQ}, list1_, model1_, r___, t_] := 
  fx2[list1, model1, r, t]

fx2e[t_] = 0; 
fx2e[list1_, model1_, r___, t_] := Module[{a, t1, y1, s1}, 
    {t1, y1, s1} = Transpose[list1]; 
     Plus @@ (((model1 /. t -> t1) - y1)^2/s1^2) + fx2e[r, t]]; 

fx2elog[t_] = 0; 
fx2elog[list1_, model1_, r___, t_] := 
Module[{a, t1, y1, s1}, {t1, y1, s1} = Transpose[list1]; 
Plus @@ ((Log[model1 /. t -> t1] - Log[y1])^2/Log[s1]^2) + fx2elog[r, t]]; 

X2FitE[{(par__)?NumberQ}, list1_, model1_, r___, t_] := 
  fx2e[list1, model1, r, t];

anQ[x_] := ArrayQ[x, _, NumericQ];

gg[list_] := Flatten[Cases[list, {(x_)?anQ, y_} -> {x, y}], 1];

BioassayFit[element_, "Inhalation", "Acute", "Automatic", amad_, class_, fn1_, 
    lambda_, samplelung_, sampleuri_, samplefec_, samplewb_] := 
   Module[{lungret, uriexcretion, fecexcretion, wbretention, 
     list1, sol, inp, list2}, 
    {lungret[t_], uriexcretion[t_], fecexcretion[t_], 
       wbretention[t_]} = Chop[{qLungs[t], qDailyUrine[t], 
         qDailyFaecal[t], qWholebody[t]} /. BiokdataReport[
         element, "Inhalation", "Acute", "Automatic", 1, amad, 
         class, fn1, t, lambda]]; 
     list1 = {{samplelung, lungret[t]}, {sampleuri, 
       uriexcretion[t]}, {samplefec, fecexcretion[t]}, {samplewb, 
       wbretention[t]}}; sol = MLFit @@ Flatten[{gg[list1], t}, 
        1]; inp = "Mean" /. sol; 
     list2 = {{samplelung, inp*lungret[t]}, {sampleuri, 
       inp*uriexcretion[t]}, {samplefec, inp*fecexcretion[t]}, 
       {samplewb, inp*wbretention[t]}}; 
     Flatten[{sol, "Ji2" -> fx2e @@ Flatten[{gg[list2], t}, 1]}]]; 

BioassayFit[element_, "Inhalation", "Acute", "MLM", amad_, class_, fn1_, 
    lambda_, samplelung_, sampleuri_, samplefec_, samplewb_] := 
   Module[{lungret, uriexcretion, fecexcretion, wbretention, 
     list1, sol, inp, list2}, 
    {lungret[t_], uriexcretion[t_], fecexcretion[t_], 
       wbretention[t_]} = Chop[{qLungs[t], qDailyUrine[t], 
         qDailyFaecal[t], qWholebody[t]} /. BiokdataReport[
         element, "Inhalation", "Acute", "Automatic", 1, amad, 
         class, fn1, t, lambda]]; 
     list1 = {{samplelung, lungret[t]}, {sampleuri, 
       uriexcretion[t]}, {samplefec, fecexcretion[t]}, {samplewb, 
       wbretention[t]}}; sol = MLFitLog @@ Flatten[{gg[list1], t}, 
        1]; inp = "Mean" /. sol; 
     list2 = {{samplelung, inp*lungret[t]}, {sampleuri, 
       inp*uriexcretion[t]}, {samplefec, inp*fecexcretion[t]}, 
       {samplewb, inp*wbretention[t]}}; 
     Flatten[{sol, "Ji2" -> fx2elog @@ Flatten[{gg[list2], t}, 1]}]]; 

BioassayFit[element_, "Ingestion", "Acute", "Automatic",  fn1_, 
    lambda_, sampleuri_, samplefec_, samplewb_] := 
   Module[{ uriexcretion, fecexcretion, wbretention, 
     list1, sol, inp, list2}, 
    {uriexcretion[t_], fecexcretion[t_], wbretention[t_]} = 
    Chop[{qDailyUrine[t], qDailyFaecal[t], qWholebody[t]} /. BiokdataReport[
         element, "Ingestion", "Acute", "Automatic", 1,  fn1, t, lambda]]; 
     list1 = {{sampleuri, uriexcretion[t]}, {samplefec, fecexcretion[t]}, 
     {samplewb, wbretention[t]}}; sol = MLFit @@ Flatten[{gg[list1], t}, 
        1]; inp = "Mean" /. sol; 
     list2 = {{sampleuri, inp*uriexcretion[t]}, {samplefec, inp*fecexcretion[t]}, 
       {samplewb, inp*wbretention[t]}}; 
       Flatten[{sol, "Ji2" -> fx2e @@ Flatten[{gg[list2], t}, 1]}]]; 

BioassayFit[element_, "Ingestion", "Acute", "MLM",  fn1_, 
    lambda_, sampleuri_, samplefec_, samplewb_] := 
   Module[{uriexcretion, fecexcretion, wbretention, list1, sol, inp, list2}, 
    {uriexcretion[t_], fecexcretion[t_], wbretention[t_]} = Chop[{qDailyUrine[t], 
         qDailyFaecal[t], qWholebody[t]} /. BiokdataReport[
         element, "Ingestion", "Acute", "Automatic", 1, fn1, t, lambda]]; 
     list1 = {{sampleuri, uriexcretion[t]}, {samplefec, fecexcretion[t]}, 
     {samplewb, wbretention[t]}}; sol = MLFitLog @@ Flatten[{gg[list1], t}, 1]; 
     inp = "Mean" /. sol; 
     list2 = {{sampleuri, inp*uriexcretion[t]}, {samplefec, inp*fecexcretion[t]}, 
     {samplewb, inp*wbretention[t]}}; 
       Flatten[{sol, "Ji2" -> fx2elog @@ Flatten[{gg[list2], t}, 1]}]]; 

BioassayFit[element_, "Injection", "Acute", "Automatic",  fn1_, 
    lambda_, sampleuri_, samplefec_, samplewb_] := 
   Module[{ uriexcretion, fecexcretion, wbretention, 
     list1, sol, inp, list2}, 
    {uriexcretion[t_], fecexcretion[t_], wbretention[t_]} = 
    Chop[{qDailyUrine[t], qDailyFaecal[t], qWholebody[t]} /. BiokdataReport[
         element, "Injection", "Acute", "Automatic", 1,  fn1, t, lambda]]; 
     list1 = {{sampleuri, uriexcretion[t]}, {samplefec, fecexcretion[t]}, 
     {samplewb, wbretention[t]}}; sol = MLFit @@ Flatten[{gg[list1], t}, 
        1]; inp = "Mean" /. sol; 
     list2 = {{sampleuri, inp*uriexcretion[t]}, {samplefec, inp*fecexcretion[t]}, 
       {samplewb, inp*wbretention[t]}}; 
       Flatten[{sol, "Ji2" -> fx2e @@ Flatten[{gg[list2], t}, 1]}]]; 

BioassayFit[element_, "Injection", "Acute", "MLM",  fn1_, 
    lambda_, sampleuri_, samplefec_, samplewb_] := 
   Module[{uriexcretion, fecexcretion, wbretention, list1, sol, inp, list2}, 
    {uriexcretion[t_], fecexcretion[t_], wbretention[t_]} = Chop[{qDailyUrine[t], 
         qDailyFaecal[t], qWholebody[t]} /. BiokdataReport[
         element, "Injection", "Acute", "Automatic", 1, fn1, t, lambda]]; 
     list1 = {{sampleuri, uriexcretion[t]}, {samplefec, fecexcretion[t]}, 
     {samplewb, wbretention[t]}}; sol = MLFitLog @@ Flatten[{gg[list1], t}, 1]; 
     inp = "Mean" /. sol; 
     list2 = {{sampleuri, inp*uriexcretion[t]}, {samplefec, inp*fecexcretion[t]}, 
     {samplewb, inp*wbretention[t]}}; 
       Flatten[{sol, "Ji2" -> fx2elog @@ Flatten[{gg[list2], t}, 1]}]]; 

BioassayBestfit[func_, h__] := Module[{var, s, td, ji2, ps}, 
   var = First[Transpose[{h}]]; 
    s = Table[Flatten[{func @@ var, var}], h]; 
    td = Flatten[s, Length[var] - 1]; 
    ji2 = ("Ji2" /. #1 & ) /@ Transpose[td][[2]]; 
    ps = Position[ji2, Min[ji2]]; Extract[td, ps][[1]]];


UrineBioassayEvaluation[sample_, element_, lambda_, T_, amad_, fS_, 
   fM_] := Module[{a, b, c, a1, a2, a3, sampleU, t1, T1, T2, model1, 
    model1c, model2, model2c, fit1, fit2, aj4}, 
      {a1, a2, a3} = Transpose[sample]; 
   sampleU = sample /. {a_, b_, c_} -> {{a, b}, ErrorBar[c]}; 
       model1[t_] = 
    D[qURI[t] /. 
      BiokdataReport[element, "Inhalation", "Acute", 
       "CompartmentContent", 1, amad, S, fS, t, lambda], t]; 
   model1c[t1_, T1_] = qConstant[1, {model1[t], t}, t1, T1]; 
       model2[t_] = 
    D[qURI[t] /. 
      BiokdataReport[element, "Inhalation", "Acute",  "CompartmentContent", 1, amad, M, fM, t, lambda], t]; 

   model2c[t1_, T2_] = qConstant[1, {model2[t], t}, t1, T2]; 
       fit1 = (model1c[#1, T] & ) /@ a1; 
   fit2 = (model2c[#1, T] & ) /@ a1; 
   aj4 = FindMinimum[
     Total[((int*(a*fit1 + (1 - a)*fit2) - a2)/a3)^2], {int, 1, 
      10}, {a, 0, 1}]; 
       {"Ji2" -> aj4[[1]], "Total intake" -> T*aj4[[2, 1, 2]], 
    "Fraction S" -> aj4[[2, 2, 2]], 
    "Fraction M" -> 1 - aj4[[2, 2, 2]], 
         Show[
     Plot[{aj4[[2, 1, 
          2]]*(aj4[[2, 2, 2]]*model1c[t1, T] + (1 - aj4[[2, 2, 2]])*
           model2c[t1, T])}, {t1, 1, Max[a1]}], ErrorListPlot[sampleU, PlotRange -> All, Joined -> True]]}];

LungBioassayEvaluation[sample_, lambda_, T_, amad_] := 
  Module[{a, b, c, a1, a2, a3, sampleU, t1, T1, T2, model1, model1c, 
    model2, model2c, fit1, fit2, aj4}, ({a1, a2, a3} = Transpose[sample]; 
    sampleU = sample /. {a_, b_, c_} -> {{a, b}, ErrorBar[c]}; 
    model1[t_] = Chop[LungsRetention[1, AMADAdultW[amad], S, t, lambda]]; 
    model1c[t1_, T1_] = qConstant[1, {model1[t], t}, t1, T1]; 
    model2[t_] = Chop[LungsRetention[1, AMADAdultW[amad], M, t, lambda]]; ); 
    model2c[t1_, T2_] = qConstant[1, {model2[t], t}, t1, T2]; 
   fit1 = (model1c[#1, T] & ) /@ a1; fit2 = (model2c[#1, T] & ) /@ a1; 
        aj4 = 
    FindMinimum[
     Total[((int*(a*fit1 + (1 - a)*fit2) - a2)/a3)^2], {int, 1, 
      10}, {a, 0, 1}]; {"Ji2" -> aj4[[1]], 
    "Total intake" -> T*aj4[[2, 1, 2]], 
    "Fraction S" -> aj4[[2, 2, 2]], 
          "Fraction M" -> 1 - aj4[[2, 2, 2]], 
    Show[Plot[{aj4[[2, 1, 2]]*(aj4[[2, 2, 2]]*model1c[t1, T] + (1 - aj4[[2, 2, 2]])*
           model2c[t1, T])}, {t1, 1, Max[a1]}], ErrorListPlot[sampleU, PlotRange -> All, Joined -> True]]}]; 



LungAccidentalIntake[sample_, intdiario_, lambda_, T_, amad_] := 
  Module[{a1, a2, a3, a4, fit1, fit2, inp, fs, sol, sol1, sol2, t1, T1, model1, 
    model1c}, {a1, a2, a3} = Transpose[sample]; 
    model1[t_] = Chop[fs*LungsRetention[1, AMADAdultW[amad], S, t, lambda] + 
       (1 - fs)*LungsRetention[1, AMADAdultW[amad], M, t, lambda]]; 
    model1c[t1_, T1_] = qConstant[1, {model1[t], t}, t1, T1]; 
    fit1 = (model1c[T + #1, T] & ) /@ a1; fit2 = (model1[#1] & ) /@ a1; 
    a4 = a2 - intdiario*fit1; sol = FindMinimum[Total[((inp*fit2 - a4)/a3)^2], 
      {inp, 0, 1}, {fs, 0, 1}]; sol1 = Last[Flatten[sol]]; 
    sol2 = MLFit[Transpose[{a1, a4, a3}], model1[t], t] /. sol1; 
    Flatten[{"Ji2" -> sol[[1]], "fS" -> sol[[2,2,2]], sol2, 
      Show[Plot[inp*model1[t1] + intdiario*model1c[t1 + T, T] /. sol[[2]], 
        {t1, 0, Max[a1]}, PlotRange -> {0, All}], ErrorListPlot[sample, 
        PlotRange -> All]]}]]

Svu[s_,vars_List, uncs_List]:= 
  Dot[{uncs^2}, Map[Function[{v}, D[s,v]], vars]^2]

Uin[s_,vars_,sig_,k_]:=
  Module[{a,c,ls,li},a=Svu[s,vars,sig][[1]];c=k*Sqrt[a];ls=s+c;li=s-c;
    {"mean" -> s,"uL" -> ls,"lL"-> li}]


End[]

Protect[MLFit, X2FitE, X2Fit, MLFitLog, Svu, Uin, BioassayFit, BioassayBestfit, UrineBioassayEvaluation, LungBioassayEvaluation,LungAccidentalIntake ]; 


Print["FitModel 1.3 2015-11-17"]
 
EndPackage[]
