(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    674509,      15808]
NotebookOptionsPosition[    650460,      15115]
NotebookOutlinePosition[    652727,      15190]
CellTagsIndexPosition[    652595,      15184]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\
FITTING BIOASSAY DATA AND PERFORMING UNCERTAINTY ANALYSIS WITH BIOKMOD\
\>", "Chapter"],

Cell[TextData[{
 "Author: Guillermo S\[AAcute]nchez:  ",
 ButtonBox["http://diarium.usal.es/guillermo",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://diarium.usal.es/guillermo"], None},
  ButtonNote->"http://diarium.usal.es/guillermo"]
}], "Text",
 CellChangeTimes->{{3.4138027549027195`*^9, 3.4138027549027195`*^9}, {
  3.5920642444364967`*^9, 3.5920642577838144`*^9}}],

Cell["\<\
Last update of this help:  \t 2010-04-09  (Verified in version 10.0:\t\
2015-06-18)\
\>", "Commentary",
 CellChangeTimes->{{3.39928025384801*^9, 3.399280259603493*^9}, {
  3.4228525171714554`*^9, 3.4228525382666454`*^9}, {3.422936332120079*^9, 
  3.422936340401223*^9}, {3.442218589593443*^9, 3.4422185944372244`*^9}, {
  3.479816247027495*^9, 3.4798162579804096`*^9}, {3.513395822423673*^9, 
  3.513395880159526*^9}, {3.5185321133491745`*^9, 3.518532117927387*^9}, {
  3.539699411679064*^9, 3.5396994240699263`*^9}, {3.592064218778194*^9, 
  3.5920642365933695`*^9}, {3.6436101902431326`*^9, 3.6436102024461975`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["$Version"], "Input",
 CellLabel->"In[3]:="],

Cell[BoxData["\<\"10.0 for Microsoft Windows (64-bit) (December 4, \
2014)\"\>"], "Output",
 CellChangeTimes->{
  3.3992752647824697`*^9, 3.422852547121887*^9, 3.4422186266093054`*^9, 
   3.4798162427619514`*^9, 3.513395883425235*^9, 3.513395935395315*^9, 
   3.5185321771628995`*^9, 3.5396990210465636`*^9, 3.5920642874149346`*^9, {
   3.6436099021647296`*^9, 3.643609928086645*^9}},
 CellLabel->"Out[3]="]
}, Open  ]],

Cell["This file includes the calculations made for the article: ", "Text"],

Cell[TextData[{
 StyleBox["FITTING BIOASSAY DATA AND PERFORMING UNCERTAINTY ANALYSIS WITH \
BIOKMOD.",
  FontFamily->"Arial",
  FontSize->10,
  FontWeight->"Bold"],
 StyleBox[" ",
  FontFamily->"Arial",
  FontSize->10],
 "\n",
 StyleBox["Health Physics. 92(1):64-72, January 2007.\n",
  FontFamily->"Arial",
  FontSize->10],
 StyleBox["Sanchez, Guillermo ",
  FontFamily->"Arial",
  FontSize->10,
  FontSlant->"Italic"],
 "\n",
 StyleBox["Resumen en; ",
  FontFamily->"Arial",
  FontSize->10,
  FontColor->RGBColor[0, 0, 0.501961]],
 StyleBox["http://www.health-physics.com/pt/re/healthphys/abstract.00004032-\
200701000-00009.htm",
  FontFamily->"Arial",
  FontSize->10,
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ",
  FontFamily->"Arial",
  FontSize->10,
  FontColor->RGBColor[0, 0, 0.501961]]
}], "DefinitionBox"],

Cell[CellGroupData[{

Cell["Summary", "Subsubsection"],

Cell[TextData[{
 "Here it is described the features included in the computer code BIOKMOD \
related with the ICRP Models. BIOKMOD has been applied to analyze several \
sources of uncertainties in the evaluation of internal exposures using the \
bioassay data: (i) Multiple constant and random intakes in occupational \
exposures taking into account periods without intake (weekends, holidays, \
etc.) are evaluated, and they are compared with the chronic intakes showing \
that the chronic approximation is not always good; (ii) An analytical method \
to evaluate the statistical uncertainties associated with the biokinetic \
model is described; (iii) Non linear techniques are applied to estimate the \
intakes using bioassay data, where not only the quantities intaken are \
assumed unknown but also other non linear parameters (AMAD, f1, etc). The \
methods described are accompanied with examples. Some of the most usual \
features of BIOKMOD can be run directly, using BIOKMODWEB, at the web site: \n\
",
 ButtonBox[" http://www3.enusa.es/webMathematica/Public/biokmod.html",
  BaseStyle->"Hyperlink",
  ButtonData:>{
   " http://www3.enusa.es/webMathematica/Public/biokmod.html", None}]
}], "Commentary"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Inicialization", "SubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Biokmod`Fitmodel`\>\"", "]"}]], "Input",
 CellLabel->"In[1]:="],

Cell[BoxData["\<\"Resptract 1.2  2005-05-16\"\>"], "Print",
 CellChangeTimes->{3.6436099250710144`*^9},
 CellLabel->"During evaluation of In[1]:="],

Cell[BoxData["\<\"SysModel, version 1.5.1   2013-11-12\"\>"], "Print",
 CellChangeTimes->{3.6436099250866394`*^9},
 CellLabel->"During evaluation of In[1]:="],

Cell[BoxData["\<\"Humorap 3.7b1 2015-06-15\"\>"], "Print",
 CellChangeTimes->{3.643609925102277*^9},
 CellLabel->"During evaluation of In[1]:="],

Cell[BoxData["\<\"Biokdata 1.2.2 2004-09-3\"\>"], "Print",
 CellChangeTimes->{3.6436099251647773`*^9},
 CellLabel->"During evaluation of In[1]:="],

Cell[BoxData["\<\"Fitmodel, guillermo@usal.es, version 1.2   \
2010-04-12\"\>"], "Print",
 CellChangeTimes->{3.6436099251647773`*^9},
 CellLabel->"During evaluation of In[1]:="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<ErrorBarPlots`\>\"", "]"}]], "Input", "Deemphasis",
 CellLabel->"In[2]:=",
 CellID->72157237]
}, Closed]],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
 "Biokinetic modeling is widely used in internal dosimetry and to evaluate \
bioassay data.  All current ICRP models, compiled in the ICRP Database of \
Dose Coefficients (ICRP 2001), can be represented by compartmental systems \
with constant coefficients. The conceptual model used by ICRP is represented \
in Fig. 1. It can be summarized as it follows. The human body can be divided \
in three systems: \na) The human respiratory tract model (HRTM).  This model \
is applied for modeling the intake of radioactive aerosols by inhalation. The \
detailed description is given in ICRP 66 (1994). If a person inhales \
instantaneously a quantity I, it is deposited directly in some compartments \
of the HRTM. The fraction deposited in each compartment is called Initial \
Deposition Fraction or IDF. It is a function of Activity Median Aerodynamic \
Diameter (AMAD), which includes size, shape, density, anatomical and \
physiological parameters as well as various conditions of exposure. The IDF \
values may be calculated either following the procedure described in ICRP 66 \
(1994) or obtaining it from the Annex F of ICRP 66 (1994). The general model \
of the HRTM is common to any element except the absorption rates {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "pt"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "p"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "t"], TraditionalForm]]],
 "} which are related to the chemical form of the element. ICRP gives default \
values of absorption rates according to types F, M or S. \nb) The \
gastrointestinal tract (GI).- This is applied for modeling the intake of \
particles in the GI tract following the model provided in ICRP 30 (ICRP 1979) \
. Particles can be introduced in the GI Tract directly by ingestion, or from \
the RT. Deposition is in the stomach (ST). Part or all the flow is \
transferred, through SI, to the blood (B). The rate transfer from SI to B, is \
given by ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", "B"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", "SI"], TraditionalForm]]],
 "/(1 \[Dash] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 ") , where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 " is the fraction of the stable element reaching the blood (or body fluids). \
If ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 " = 1 all flows from the stomach it goes to B. The value of f1 is associated \
to the element and their chemical form  The GI tract model will be replaced \
by the called Human Alimentary Tract Model (HATM), but it is not published \
yet.\nc) Systemic compartments.- . They are specific to an element or groups \
of elements (ICRP 2001). ICRP 78 (1997) establishes three generic groups: (i) \
hydrogen, cobalt, ruthenium, caesium, and californium,  (ii) strontium, \
radium, and uranium and,  (iii) thorium, neptunium, plutonium, americium, and \
curium. For other elements not included in ICRP78, the ICRP 30 model is \
applicable and they have the same generalized compartmental model as group \
(i). For the elements of each group the same model is applied although some \
parameters are specific to the element.  From a mathematical point of view we \
can establish two groups: a) Elements whose biokinetic model does not involve \
recycling, this includes the group (i) and the elements where ICRP 30 is \
still applicable, and b) elements whose biokinetic models involve recycling, \
this includes group (ii) and (iii).\nA few computer codes have been developed \
to estimate intake and calculate internal dose using biassay data. The main \
characteristics of most of then are summarized by Ansoborlo et al (2003).   \
BIOKMOD. has the following features to our knowledge are not included in any \
other.\na) It gives analytical and numerical solutions (other codes only give \
the  numerical). Even the solutions can be given as function of some \
parameters. The accumulated disintegrations in a compartment or region can be \
computed exactly by analytical integration, what is more precise than the \
method of the mean resident time (Loevinger et al. 1988) often applied for \
other codes.\nc) Apart from acute, chronic and multi-inputs, it can \
practically be used for any kind of continuous inputs (exponentials, \
periodic, etc.), even for random inputs. \nd)  The intakes can be estimated \
fitting bioassay data where not only the intake quantities but also other \
parameters (AMAD, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 ", etc.) can be assumed unknown. \ne)  Analytical expressions instead of \
simulation can be used for sensitivity and uncertainty analysis.\nf) The user \
himself can build compartmental models in a very easy way generating \
automatically the system of differential equations and their solutions \
[Sanchez 2005]."
}], "Text"],

Cell["\<\
We have applied BIOKMOD to the evaluation of internal exposures using \
bioassay data. In particular we will refer to the random intakes in \
occupational exposures and their implication in the bioassays, the \
application of analytical methods to evaluate the uncertainties associated \
with the biokinetic model parameters, and the use of non linear regression \
techniques to the bioassay data fitting. The methods described are \
accompanied with examples.\
\>", "Text"],

Cell[TextData[{
 "BIOKMOD is a tool box developed using Mathematica (Wofram Research, Inc. \
Champaign, IL) It includes several Mathematica packages (or subprograms). To \
run BIOKMOD with all capability it is necessary Mathematica, however, some of \
the most usual features of BIOKMOD can be run directly at: ",
 ButtonBox["http://www3.enusa.es/webMathematica/Public/biokmod.html",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www3.enusa.es/webMathematica/Public/biokmod.html"], None}],
 ". It is possible thanks to an interface, called, BiokmodWeb, which we have \
developed using webMathematica (Wofram Research, Inc)  and Java (by Sun \
Microsystems, Inc.). "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Solving ICRP models", "Section"],

Cell[CellGroupData[{

Cell["General description", "Subsection"],

Cell["\<\
All current ICRP models, compiled in ICRP Database of Dose Coefficients (ICRP \
2001), can be represented by compartmental systems with constant \
coefficients. The conceptual model used by ICRP is represented in figure 1. \
It can be summarized as it follows. The human body can be divided in three \
systems: \
\>", "Text"],

Cell[TextData[{
 "a) The human respiratory tract model (HRTM).- It is applied for modeling \
the intake of radioactive aerosols by inhalation. The detailed description is \
given in ICRP 66. If a person intakes by inhalation instantaneously a \
quantity ",
 Cell[BoxData[
  FormBox["I", TraditionalForm]]],
 ", it is deposited directly in some compartments of the HRTM. The fraction \
deposited in each compartment is called Initial Deposition Factor or IDF. It \
is a function of Activity Median Aerodynamic Diameter (AMAD), which includes \
size, shape, density, anatomical and physiological parameters as well as \
various conditions of exposure. The IDF values may be calculated either \
following the procedure described in ICRP 66 (1994) or obtaining from the \
Annex F of ICRP 66 (1994). AMAD value can be written and then the program \
computes the IDF. Another option is to directly write the IDF values for AI, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["bb", 
    RowBox[{"fast", "+", "seq"}]], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["bb", "slow"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["BB", 
    RowBox[{"fast", "+", "seq"}]], TraditionalForm]]],
 " , ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["BB", "slow"], TraditionalForm]]],
 ", ET1, and ET2.  The general model of the RT is common to any element \
except the absorption rates {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "pt"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "p"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "t"], TraditionalForm]]],
 "} that are related with the chemical form of the element. ICRP gives \
default values of absorption rates according to types F, M or S. In BIOKMOD \
F, M or S can be chosen and the program will apply default values for \
absorption rates. Another option is to directly write the absorption rate \
parameters. "
}], "Text"],

Cell[TextData[{
 "b) The gastro intestinal tract (GI).- ",
 "This is applied for modeling the intake of particles in the GI tract \
following the model provided in ICRP 30 (ICRP 1979) . Particles can be \
introduced in the GI Tract directly by ingestion, or from the RT. Deposition \
is in the stomach (ST). Part or all the flow is transferred, through SI, to \
the blood (B). The rate transfer from SI to B, is given by ",
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", "B"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", "SI"], TraditionalForm]]],
 "/(1 \[Dash] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 ") , where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 " is the fraction of the stable element reaching the blood (or body fluids). \
If ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 " = 1 all flow from SI goes to B. The value of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 " is associated to the element and their chemical form.  In BIOKMOD ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 " must be introduced or a value by default (from ICRP 2001 and ICRP 1997) \
will be applied according with the element and the absorption rate previously \
chosen."
}], "Text"],

Cell["\<\
c) Systemic compartments.- . They are specific to an element or groups of \
elements (ICRP 2001). ICRP 78 (1997) establishes three generic groups: (i) \
hydrogen, cobalt, ruthenium, caesium, and californium,  (ii) strontium, \
radium, and uranium and,  (iii) thorium, neptunium, plutonium, americium, and \
curium. For other elements not included in ICRP78, the ICRP 30 model is \
applicable and they have the same generalized compartmental model as group \
(i). For the elements of each group the same model is applied although some \
parameters are specific to the element.  From a mathematical point of view we \
can establish two groups: a) Elements whose biokinetic model does not involve \
recycling, this includes the group (i) and the elements where ICRP 30 is \
still applicable, and b) elements whose biokinetic models involve recycling, \
this includes group (ii) and (iii).\
\>", "Text"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@000>LD0@0006`000001@00C0000=l6003G0@00
>Yd00<@9002ieP009cP00215CDH000405>L00487000<0000000000000000000000@0000300100@00
l0000000000000000000003R1020Z@<0AP0002`0000P0000ADe6:`500@0L00004000008@`=/10000
H000060000160000G00005000015CDH[8T0400`0000000007T0900`000000000940100`000000000
<4020100000400000020?b501`0<0000000000A0000<0000000001P0000<0000000001T0000<0000
oooo01@0000<00003@000180000<00000P00024000080000500000`0000=0000<00000`0000?0020
AP0002P0000L0000AdA9@`8000081@00D0000=l6003<0@00000004H0000X0000700004M4BD<20000
``H001`1003O1P00D040000000160000D00004@00015CDH[:T0002@0000H00000020?`0008000020
0020?`00080000202T00`1`0000@0000ooooo`4000331Q`1700d024000080000HP0000`000010000
900002@00000080m000000000000080m00000000000200009`0001P00001000000000?ooo`000000
9@0000`0000100009@0000`000080020EP00030000321P006`400=l6001@0@001@0002Q/^14XK?PD
j6gh5>Q]^14XK;PA9@0000`0000700209@0000`000000020900002@0000008110000000000000811
00000000000200008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000000004H0000D0000
200004M4BD<300008@0000P0000N000060000<D6000N0@00g@H004h1001B0000L0400080003coooo
0000000000000000T040000000000000@@1b06T0H@1/000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000001TMP080000000000000000
00000000000000003@000000001XgA<0KZ`0<?RG_@3/gA<030000<F`033/gA<0n9Nm00`0003Zk00`
k=dC0?RG_@060000g=hC0>CO4`06kP0`K=lC0040003IRm5g003GM`l10014g1<0c;?AMjNcdGM70000
K=lC0000002000000@000000000Dg1<0A`000<CN4`1W1=Ag0000000000010000dG@0<<fg0C000000
00000;X400000000IPD:l`0000000000IPD:lkX@0CghUkd0loooo`00001TMP08000002D0000<0000
0P0002D0000<00003@00P2D0000<00000P000180000<00000@000580001`0@000`000??oool00000
Q0<008@3002@0@000000000@00110780J@1Q06`00000000000000000000000000000000000000000
00000000000000000000000000000000002BO?oooolb1i9lZ`JBO>/6TW`00000F2;;0Oooool00000
000000Rj8`?di1<047_E<00000000000000003Cb4`000001O`?oo`00ool00000P00008P0001hh1<0
>RC`MgCOY08U0000F2;;0@002P1H8//1S>0C0;/Sl7L00000H1@QnQT0/06/h1<0CR?`Mf0D8OX20000
9@00028B2SX00040000:0=3P4`11inmgH1@QnR8B2SXU0000003_Mb8B2SZ0Ukd000000?3P4`0Hm1H0
05X0020`lgLTha<00000082G_@3767GcJAH1<<0@0Ek8gAP32@0006Af00P000009@0000`000030000
E00008@000351P007P400=<6001=0@000@000000nT400?Y1a@H004d100090000C000000000000000
00000?ooooooooooH00004L0B@0P0200M01b0640H`1d00002P0000@000040000100000@000040000
1`0000L0000400009@0000`000020000:00000`0000300009@0000`0000=00208P0000`0003ooooo
8@0000P0000I000030000?ooo`0H000030000000000N0000600001P0000<0000k0<000l2000R0000
30000?oooolH000030000000000I000030000?ooo`0U000030000000080U0000300000d008160000
:00001`00017A4U30P0000P5001`0000KPH00?<000000000AP00050000140000ADe6:bY0000T0000
60000000P3l000200000P000P3l000200000P0Y00<0L000040000?ooool100002@Ea06@1P@0Q0000
20000680000<00000@0002@0000T00000020?@00000000000020?@00000000000P0002D0000<0000
0@0002D0000<00002000P5H0000`000020D00700001]1P00lP0000D00028D0P7R50H3lQV60o8IPP7
R5081bD0000<00001`00P2D0000<00000000P2@0000T00000020@@00000000000020@@0000000000
0P0004H0002D0000R00004E=AR/8@002B00003`000024<3K00000901000000000020?`0004400000
10000000044004100020?`00@4024<3K000000000?l8@043;000020000024<3K1000001000091G40
2@Gb06d6lP1]1W400041PAE00@0@000010000000000X000030000040000T000090000000P3d00000
00000000P3d0000000000080001O0000>0000040000h0000000003P0000000000181010000000000
0000000000000000000002D0000<00000@0002L0000H00000`00000000000000000002D0000<0000
0`0001<0000<00000P0005/0001@30001PD006h0001_1P00m0000840002;0P001@0000D000050000
1@0000D0000500001@0000D0000500001@0000D0000500001@0000D0000500001@0000D000050000
1@0000D0000500001@0000D0000500001@0000D0000500001@0000D0000500001@0000D000050000
1@0000D0000500001@0000D0000500001@0000D0000500001@0000D0000500001@0000D000050000
1@0000D0000500001@0000D0000500001@0000D0000500001@0000D0000500001@0000D000050000
1@0000P0000500001@0000D0000500001@0000D0000500001@0000D0000500001@0000D000050000
1@0000D0000500001@0000D0000500001@0000D0000500001@0000D0000500001@0000D000050000
1@0000D0000500001@0000D0000500001@0000D0000500001@0000D0000500001@0000D000050000
1@0000D0000500001@0000P0000500001@0000D0000500001@0000D0000500001@0000D000050000
1@0000D0000500001@0000D000050000b6H@1dQV40M8IP07b6H01lQV40LHIQ0726H@1`QV00LHIP07
66H@1mQU40MHIA07F6D01mQU00OHIA07:6D@1aQU40LHI@07:6D01bQU40OXI107J6@@1fQT00OXI007
j6@@1cQT40LXI107:6@01cQT00LhI107n6<@1gQS40MhH`07n6<01oQS40M8Ha07>6<@1cQS00M8H`07
B6<@1`QS40N8HQ07R6801`QS00L8Ha07F68@1dQR40M8HP07F6801eQR40LHHQ07V64@1iQQ00LHHP07
668@1fQQ40MHHA07F6401fQQ00MXHA07:64@1jQP40NXH007:6401bQQ40MhH107J60@1fQP00MhH007
N60@1cQP40NhGa07^5l01cQP00LhH107R5l@1gQO40MhG`07R5l01hQO40M8Ga07b5h@1lQN00M8G`07
B5l@1iQN40N8GQ07R5h01iQN00NHGQ07F5h@1mQM40OHG@07F5h01eQN40NXGA07V5d@1iQM00NXG@07
Z5d@1fQM40OXG107j5`01fQM00MXGA07^5`@1jQL40NXG007^5`01kQL40MhG107n5/@1oQK00MhG007
N5`@1lQK40NhFa07^5/01lQK00O8Fa07R5/@1`QK40L8F`07R5/01hQK40OHFQ07b5X@1lQJ00OHFP07
f5X@1iQJ40LHFQ0765X01iQJ00NHFQ07j5T@1mQI40OHF@07j5T01nQI40NXFA07:5T@1bQI00NXF@07
Z5T@1oQH40OXF107j5P01oQH00OhF107^5P@1cQH40LhF007^5P01kQH40L8F107n5L@1oQG00L8F007
25P@1lQG40M8Ea07B5L01lQG00O8Ea0765L@1`QG40L8E`0765L01aQG40OHEQ07F5H@1eQF00OHEP07
f5H@1bQF40LHEQ0765H01bQF00LXEQ07j5D@1fQE40MXE@07j5D01nQE40LhEA07:5D@1bQE00LhE@07
>5D@1oQD40MhE107N5@01oQD00OhE107B5@@1cQD40LhE007B5@01dQD40L8E107R5<@1hQC00L8E007
25@@1eQC40M8Da07B5<01eQC00MHDa0765<@1iQB40NHDP0765<01aQC40MXDQ07F58@1eQB00MXDP07
J58@1bQB40NXDA07Z5401bQB00LXDQ07N54@1fQA40MXD@07N5401gQA40LhDA07^50@1kQ@00LhD@07
>54@1i1@20N@D1P7P50H1h1@20N@D0P7T5181i1@b0N0D<P7P5181i1@B0N@D?P7T508281@20R0D?P7
T53h1i1@>0R@D;P8P52h281@>0R@D3P8T53X291@n0R0D?P8P53X291@j0R@D2P9T52X2H1@Z0V0D2P9
T50X2I1@f0V@D>P9P53X2H1@f0V@D=P9T50H2Y1@V0Z0D9P:P50H2Y1@60Z@D<P:T53H2X1@f0Z0D<P:
T5382Y1@20^@D8P;P5282h1@20^@D0P;T52h2i1@b0^0D<P;P52h2i1@^0^@D?P;T51h381@N0b0D?P;
T53h2i1@Z0b@D;P<P52h381@Z0b@D:P<T53X391@J0f0D6P=P53X391@j0b@D9P=T52X3H1@Z0f0D9P=
T52H3I1@f0f@D5P>P51H3X1@f0f@D=P=T5283Y1@V0j0D9P>P5283Y1@R0j@D<P>T50H3hQ@40nhD10?
^50P3h1@80n0D<P>T5383^Q@40ohD10?n50P3nQ@80oXD10?:54@3jQA40nXDB0?:54P3bQA40oHDA0?
j54@3nQA80oHDB0?f54@3aQB40nHDQ0?V58P3aQB80lHDQ0?b58@3mQB40oHDR0?b58P3lQB40l8Da0?
R5<@3hQC80l8Db0?25<@3kQC40o8Da0?b5<P3kQC80nhDa0?n5<@3gQD40mhE20?n5<P3oQC40nXE10?
^5@@3kQD80nXE20?Z5@@3nQD40mXEA0?J5DP3nQD80oXE10?V5D@3jQE40nXEB0?V5DP3iQE40oHEA0?
F5H@3eQF80oHEB0?f5D@3hQF40nHEQ0?V5HP3hQF80n8EQ0?b5H@3dQG40m8Eb0?b5HP3lQF40mhEa0?
R5L@3hQG80mhEb0?N5L@3kQG40lhF10?>5PP3kQG80nhEa0?J5P@3gQH40mhF20?J5PP3fQH40nXF10?
:5T@3bQI80nXF20?Z5P@3eQI40mXFA0?J5TP3eQI80mHFA0?V5T@3aQJ40lHFR0?V5TP3iQI40m8FQ0?
F5X@3eQJ80m8FR0?B5X@3hQJ40l8Fa0?25/P3hQJ80n8FQ0?>5/@3dQK40m8Fb0?>5/P3cQK40mhFa0?
n5/@3oQK80mhFb0?N5/@3bQL40lhG10?>5`P3bQL80lXG10?J5`@3nQL40oXG20?J5`P3fQL40lHGA0?
:5d@3bQM80lHGB0?65d@3eQM40oHGA0?f5dP3eQM80mHGA0?25h@3aQN40lHGR0?25hP3`QN40m8GQ0?
b5h@3lQN80m8GR0?B5h@3oQN40l8Ga0?25lP3oQN80ohGQ0?>5l@3kQO40nhGb0?>5lP3cQO40oXGa0?
n5l@3oQO80oXGb0?j5l@3bQP40nXH10?Z60P3bQP80lXH10?f60@3nQP40oXH20?f60P3mQP40lHHA0?
V64@3iQQ80lHHB0?664@3lQQ40oHHA0?f64P3lQQ80o8HA0?268@3hQR40n8HR0?268P3`QR40nhHQ0?
b68@3lQR80nhHR0?^68@3oQR40mhHa0?N6<P3oQR80ohHQ0?Z6<@3kQS40nhHb0?Z6<P3jQS40oXHa0?
J6@@3fQT80oXHb0?j6<@3iQT40nXI10?Z6@P3iQT80nHI10?f6@@3eQU40mHIB0?f6@P3mQT40n8IA0?
V6D@3iQU80n8IB0?R6D@3lQU40m8IQ0?B6HP3lQU80o8IA0?N6H@3hQV40n8IR0?N6HP3gQV40nhIQ0?
b6H@3l1V60o0IZP>d6JX3]1V80nhIR0?^6H@3l1VN0k0IVP>d6IX3]1VN0k0IWP>`6Hh3/1V^0g@I[P=
d6Hh3/1V>0k0IXP=`6Ih3M1VN0g@IXP=`6J83L1VB0g0I/P<d6K83=1VB0g0ITP=`6JH3<1VR0c@IXP<
d6JH3<1VV0c0IUP<`6KH2m1Vf0_@IUP<`6IH3<1VZ0_0IYP;d6JH2m1VZ0_0IZP;`6IX2l1Vj0[@I^P:
d6IX2l1VJ0_0I[P:`6JX2]1VZ0[@I[P:`6Jh2/1VN0[0I_P9d6Kh2M1VN0[0IWP:`6K82L1V^0W@I[P9
d6K82L1Vb0W0IXP9`6H82M1V20W@IXP9`6J82L1Vf0S0I/P8d6K82=1Vf0S0I]P8`6JH2<1V60S@IQP8
d6JH2<1VV0S0I^P7`6KH1m1Vf0O@I^P7`6KX1l1VZ0O0IRP7d6HX1m1VZ0O0IZP74`0000`000010000
9@0000`0000000209@0000`000070020900002@00000081100000000000008110000000000020000
:00000`0000100008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000000004H0000D0000
200004M4BD<30000AP0002P0000L0000AdA9@`80002B1P00^0000<@6002U0@00000004H0001@0000
A00004E=AR/Z@000900001P00000080o0000P0000800080o0000P000080:@03070000100003ooooo
0@0009<6^@0`0>/0:00000`0000300008@0000P0001R000030000040000T000090000000P3d00000
00000000P3d0000000000080000W0000600000<000000000oooo0000000U0000300000<0000U0000
300000P0081F0000<0000986002h0000``H00:@100050000:6V82bQY>1XXK3PJ:6b82bQYR0/U0000
300000L0080U000030000000080T000090000000P440000000000000P44000000000008000160000
U00008P00015CDH[24020TP0000l00000Q30f`00002@0@0000000000P3l00011000000@000000011
0010@000P3l004100Q30f`000000003o24030b`0000P00000Q30f`@00000@000T`Ji09<6Y0731Z@1
``Ji00010H4E@0<0400000@000020000:00000`000030000900002@00000080m000000000000080m
0000000000020000G`0003P000030000>0000000000h00000000000B0@0@00000000000000000000
00000000000U0000300000<0000W0000600000400000000000000000000U000030000040000C0000
30000080001K0000@0L00906002f0000a@H00:H1001;0000O@4000D0000500001@0000D000050000
1@0000P0000500001@0000D0000500001@0000D0000500001@0000D0000500001@0000D000050000
1@0000D0000500001@0000D0000500001@0000D0000500001@0000D0000500001@0000D000050000
1@0000D0000500001@0000D0000500001@0000D000050000200000D0000500001@0000D000050000
1@0000D0000500001@0000D0000500001@0000D0000500001@0000D0000500001@0000D000050000
1@0000D0000500001@0000D0000500001@0000D0000500001@0002Q/T0^XJi0;Z6^02bQ/P0/XK90;
N6^@2fQ[T0]XJh0;N6^02gQ[T0/hJi0;^6Z@2kQZP0/hJh0;>6^@2hQZT0]hJY0;N6Z02hQZP0^8JY0;
B6Z@2lQYT0_8JH0;B6Z02dQZT0^HJI0;R6V@2hQYP0^HJH0;V6V@2eQYT0/XJI0;<6V82c1Yf0/PJMP;
86V02eQYP0]HJI0;<6T8331Y60`PJAP<86T8331Y20``JDP<<6W8321Yb0`PJDP<<6U8331Yn0``J@P=
86T83B1Yn0``JOP<<6Th3C1Y^0dPJKP=86Th3C1Y>0d`JNP=<6Wh3B1Yn0dPJNP=<6WX3C1Y:0h`JJP>
86VX3R1Y:0h`JBP><6WH3S1Yj0hPJNP>86WH3S1Yf0h`JAP?<6VH3b1YV0lPJAP?<6TH3c1Yb0l`JMP?
86WH3b1Yb0l`JLP?<6T8431YR10PJHP@86T8431Y210`JKP@<6W8421Yb10PJKP@<6Vh431Yn10`JGPA
86Uh4B1Yn10`JOP@<6VX4C1Y^14PJKPA86VX4C1YZ14`JNPA<6UX4R1YJ18PJNPA<6WX4C1YV18`JJPB
86VX4R1YV18`JIPB<6WH4S1YF1<PJEPC86WH4S1Yf18`JHPC<6VH4b1YV1<PJHPC<6V84c1Yb1<`JDPD
86U8521Yb1<`JLPC<6Uh531YR1@PJHPD86Uh531YN1@`JKPD<6Th5B1Y>1DPJKPD<6Vh531YJ1D`JGPE
86Uh5B1YJ1D`JFPE<6VX5C1Y:1HPJBPF86VX5C1YZ1D`JEPF<6UX5R1YJ1HPJEPF<6UH5S1YV1H`JAPG
86TH5b1YV1H`JIPF<6U85c1YF1LPJEPG86U85c1YB1L`JHPG<6T8621Y21PPJHPG<6V85c1Y>1P`JDPH
86U8621Y>1P`JCPH<6Uh631Yn1PPJOPH86Uh631YN1P`JBPI<6Th6B1Y>1TPJBPI<6TX6C1YJ1T`JNPI
86WX6B1YJ1T`JFPI<6TH6S1Y:1XPJBPJ86TH6S1Y61Y8JC0Jb6T`6/QY@1Y8JD0JB6T`6_QY<1X8JS0J
26Y06_QY@1[hJC0J>6X`6[QZ<1ZhJT0J>6Y06SQZ<1[XJS0Jn6X`6_QZ@1[XJT0Jj6X`6RQ[<1ZXJc0J
Z6]06RQ[@1XXJc0Jf6/`6^Q[<1[XJd0Jf6]06]Q[<1XHK30J:6``6R1/>1XPK<PI<6c86C1/@1XHK40J
66``6R1/V1TPK8PI<6b86C1/V1TPK9PI86aH6B1/f1P`K=PH<6aH6B1/F1TPK:PH86bH631/V1P`K:PH
86bX621/J1PPK>PG<6cX5c1/J1PPK6PH86bh5b1/Z1L`K:PG<6bh5b1/^1LPK7PG86ch5S1/n1H`K7PG
86ah5b1/b1HPK;PF<6bh5S1/b1HPK<PF86b85R1/21H`K0PF<6b85R1/R1HPK=PE86c85C1/b1D`K=PE
86cH5B1/V1DPK1PE<6`H5C1/V1DPK9PE86cX521/f1@`K=PD<6cX521/j1@PK:PD86`X531/:1@`K:PD
86bX521/n1<PK>PC<6cX4c1/n1<PK?PC86bh4b1/>1<`K3PC<6bh4b1/^1<PK0PC86ch4S1/n18`K0PC
86`84b1/b18PK4PB<6a84S1/b18PK<PB86`H4R1/218`K0PB<6`H4R1/618PK=PA86aH4C1/F14`K=PA
86cH4B1/:14PK1PA<6`H4C1/:14PK2PA86cX421/J10`K6P@<6cX421/j10PK3P@86`X431/:10`K3P@
86`h421/n0lPK7P?<6ah3c1/n0lPK?P?86a83b1/>0l`K3P?<6a83b1/B0lPK0P?86b83S1/R0h`K0P?
86`83b1/F0hPK4P><6a83S1/F0hPK5P>86`H3R1/V0d`K9P=<6`H3R1/60hPK6P=86aH3C1/F0d`K6P=
86aX3B1/:0dPK:P<<6bX331/:0dPK2P=86ah321/J0``K6P<<6ah321/N0`PK3P<86bh2c1/^0/`K3P<
86`h31<0000<00000@0002D0000<00000000P2D0000<00001`00P2@0000T00000020@@0000000000
0020@@00000000000P0002P0000<00000`000280000<0000ooooodH0000L0000400004E=AR/4@000
3000000000160000500000P00017A4U30`0004H0000X0000700004M4BD<20000]PD00841001H1P00
X`40000000160000D00004@00015CDH[:T0002@0000H00000020?`00080000200020?`0008000020
2T00`1`0000@0000ooooo`40002g1H81X00P02P0000<00000@00024000080000HP0000`000010000
900002@00000080m000000000000080m00000000000200009`0001P00001000000000?ooo`000000
9@0000`0000100009@0000`000080020EP000300002f1@00P@4005L6002R0@001@0006QK61QXFaPJ
J6DH6VQU61QXFaPH9@0000`0000700209@0000`000000020900002@0000008110000000000000811
0000000000020000AP0008`000200000ADe6:`Q010900000=000008@`=/00000eP0000000000080o
0P000080000000110P00000000024<3K000000000?l8@0D3;000020000024<3K10000010002g1H81
]`FR0EL6XP5G1X810041PAE01@0@0000100000@0000j0000300000P0000T000090000000P3d00000
00000000P3d0000000000080001O0000>00000<0000h0000000003P0000000000201010000000000
0000000000000000000002D0000<00000`0002D0000<00001@00P5H0000/0000ZPD007D1001S1P00
[P4000@0001XFaPHJ5/H6VQU61YXIAPH9@0000`0000700209@0000`000000020900002@000000811
00000000000008110000000000020000:00000`000030000>P0000`0000:00008P0000`0003ooooo
AP0001`0000@0000ADe6:`A0000<0000000004H0000D0000200004M4BD<30000AP0002P0000L0000
AdA9@`80002T1P00V@400:h6002e0@00000004H0000H0@00304004E=AR/Z@000900001P00000080o
0000P0000800080o0000P0000808@0H2/0000:@000024<3K00000?h@00000000ZjZZ?`80003o0000
0P000000044200000P000000001T00000Q30f`00000100000P0005IEED0000000000000000000211
0020?`000000000000000000000X00000Q30f`<000008000ZjZZ?`00P<00000000000:^ZZ[l00830
0061@`8@`=/000000000o`Q01`<T00006000008@`=/2000004000:X6VP6Y1[<10041PAE01`0@0000
100000H0000X000030000040000Q000020000680000<00000@0002@0000T00000020?@0000000000
0020?@00000000000P0005l0000h00000@0003P000000000>000000000004P404000000000000000
00000000000000009@0000`0000100009`0001P00003000000000000000000009@0000`000030000
4`0000`000020000>`0000P0000K000040000:=Z002I6@00=P000100002SJP00VAT005P0000d0000
00000000003oooooooooo`H0002SJYlIWFZT6IMZXaVBJZ<ISFZM6HiZV1Tf0000400008iZ002G6@00
F00003@00000000000000?oooooooooo1P0008iZTQVDJXdIVFZ>6ImZSQVTJY@IXfZI6Cd000080000
6`000100002QJP00a1T003H0000@0000XFX00<@I001H0000=000000000000000ooooooooool60000
XF[:6IaZcQVFJ/hIT6[=6HaZb1V<J/8I=P000100002<JP00`QT005P0000d000000000000003ooooo
ooooo`H0002=J[`ITVZh6IQZ^AVNJ[TIXVZn6J5Za1Tm0000200001/0000@0000X6X00>lI000f0000
40000:1Z003_6@00F00003@00000000000000?oooooooooo1P0009mZmAVJJ_TIU6[h6HiZn1V:J_<I
RV[]6CH0000@0000RVX00>dI001H0000=000000000000000ooooooooool60000Rf[W6I1ZhaVFJ^<I
W6[T6J1ZjAVPJ^lI?@0000P0000K0000400009iZ000I6P00=P000100002NJP006AX005P0000d0000
00000000003oooooooooo`H0002MJQlJV6XT6Y9Z8aZ<JR<JR6XM6XUZ5aXf0000400008UZ000G6P00
F00003@00000000000000?oooooooooo1P0008UZ4QZ>JPdJU6X>6YYZ3QZOJQ@JWVXI6Sd000080000
6`000100002LJP00A1X003H0000@0000W6X004@J001H0000=000000000000000ooooooooool60000
W6Y:6YMZCQZAJThJRfY=6XIZB1Z7JT8J=P0001000027JP00@QX005P0000d000000000000003ooooo
ooooo`H00028JS`JSFXh6Y=Z>1ZHJSTJWFXn6YaZA1Xm0000200001/0000@0000VfX006lJ000f0000
400009]Z001_6P00F00003@00000000000000?oooooooooo1P0009YZMAZEJWTJSfYh6XUZN1Z5JW<J
QFY]6SH0000@0000QFX006dJ001H0000=000000000000000ooooooooool60000QVYW6X]ZHaZAJV<J
UfYT6Y]ZJAZKJVlJ?@0000P0000K0000400009UZ002I6P00=P000100002IJP00VAX005P0000d0000
00000000003oooooooooo`H0002HJYlJTfZT6XeZXaZ7JZ8JPfZM6XAZUaXf0000400008AZ002G6P00
F00003@00000000000000?oooooooooo1P0008AZTQZ9JXdJSfZ>6YEZSQZIJY@JVFZI6Sd000080000
6`000100002GJP00a1X003H0000@0000UfX00<@J001H0000=000000000000000ooooooooool60000
Uf[:6Y5ZcQZ<J/hJQV[=6X5Zb1Z2J/8J=P0001000022JP00`QX005P0000d000000000000003ooooo
ooooo`H00022J[`JR6Zh6XiZ^1ZCJ[TJV6Zn6YMZa1Xm0000200001/0000@0000^6X00:XJ001I0000
9000000000000000ooooooooool20000R6XX6f=ZYaXm0000200003`000080000?`0001P0002T1P00
U`400:d6002d0@004`0000`0000100009@0000`0000000209@0000`000070020900002@000000811
00000000000008110000000000020000:00000`0000100008P0000`0003oooooAP0001`0000@0000
ADe6:`A0000<0000000004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`8000271@00
[`400<0500370@00000004H0001@0000A00004E=AR/Z@000900001P00000080o0000P0000800080o
0000P000080:@03070000100003ooooo0@0008P5/04g01H0:00000`0000300008@0000P0001R0000
30000040000T000090000000P3d0000000000000P3d0000000000080000W0000600000<000000000
oooo0000000U0000300000<0000U0000300000P0081F0000<00008L5002_0@00_`D00<H100050000
N5Sh6WQHF1cXFePLj5_h6WQHn1XU0000300000L0080U000030000000080T000090000000P4400000
00000000P44000000000008000160000S00008000015CDH[24080T00000d00000Q30f`00003F0000
00000000P3l200000P000000044200000000008@`=/00000ooooo`Q02@</00008000008@`=/40000
040008P5/0681LH1_`G60Kl5/0400@615D09010000040000200003X0000<0000200002@0000T0000
0020?@00000000000020?@00000000000P0005l0000h00000@0003P000000000>000000000008040
40000000003oool000000000000000009@0000`0000100009@0000`000050020EP0002`0001k1@00
X`400</5003B0@00100007QHn1YhF5PLj5]H7>QKn1XU0000300000L0080U000030000000080T0000
90000000P440000000000000P440000000000080000X000030000040000j0000300000X0000R0000
30000?oooom60000700001000015CDH[140000`000000000AP0001@000080000AdA9@`<0000Q0000
200001h0000H0000S0D00;41002l1@00aP400580001`0@000@000?3oool0000000000000002@0@00
0000000002110780J@1Q06`000000000000000000000000000000000000000000000000000000000
0000000000000000000000D000050000flX2<0X<00010000n7dC00D000000;@12oc:<54B2]`?0000
DA8:g>Qm4`1^[00`58jd0Fan4`0<0000aK00<6an4`0DS[@130000>[/031/OQ<058jd0@H0000H]k@1
I84C00K^031DfDL0T040000000400000E01Q06P0K`1]0640Y7`C00UA5E/400006P000000000<0000
2P0000D000020000000003<00000000000000040001?4@Y`cKL1<00000000000;e@EF`00001?4@Yf
0000054B2]a?4@Yf^Q01?AB>]04>^]5g37dC06Af00P000009@0000`0000100009@0000`0000=0020
9@0000`000010000500000`0000=00004P0000`000010000E00006`0002<1@00/P400;0500330@00
0@000000nT400?Y1S0D00;8100050000C00000000000000000000?ooooooooooF00005D0LP1Y06h0
I@0000/000050000100000P0000900009@0000`0000=00208P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001P0000<0000k0<000l2000R000030000?oooolH0000
30000000000I000030000?ooo`0U000030000000080U0000300000d008160000:00001`00017A4U3
0P0008D6002e0@00b@H00<`100000000AP00050000140000ADe6:bY0000T000060000000P3l00020
0000P000P3l000200000P0Y00<0L000040000?ooool10000QPJf0D805@0Q000020000680000<0000
0@0002@0000T00000020?@00000000000020?@00000000000P0002D0000<00000`0002D0000<0000
2000P5H0000`0000Q@H00;D100381P00b`4000D0001HJ5PKF6RX77Q/Z1ahK5PKF6QH6bD0000<0000
1`00P2D0000<00000000P2@0000T00000020@@00000000000020@@00000000000P0004H0002<0000
P00004E=AR/8@0X2@00003@000024<3K00000=H0000000000020?`80000200000000@@8000000000
0Q30f`00003ooooo240;0b`0000P00000Q30f`@00000@000QPJf0HH6b`781//1b0Jf0@010H4E@0/0
400000@0000:0000>P0000`000080000900002@00000080m000000000000080m0000000000020000
G`0003P000040000>0000000000h00000000000P0@0@000000000?ooo`00000000000000000U0000
300000@0000U0000300000D0081F0000;00007T6002Y0@00e0H00=L100040000F6QH6eQXZ1ahK:PL
N6aH6bD0000<00001`00P2D0000<00000000P2@0000T00000020@@00000000000020@@0000000000
0P0002P0000<0000100003X0000<00002P000280000<0000ooooodH0000L0000400004E=AR/4@000
3000000000160000500000P00017A4U30`000240000800007P0001P0002:1P00]`400<D6003;0@00
9@0000`0000100009@0000`0000=00209@0000`000010000500000`0000=00004P0000`000010000
E0000700002:1P00^0400;h600390@000@000000nT400?Y1RPH00;P100060000C000000000000000
00000?ooooooooooF00004H0H@1U06<0I@1c00X0000900002@0000P000090000200002D0000<0000
3@00P280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000H0000
30000>`3000?0P008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000000020
9@0000`0000=0020AP0002P0000L0000AdA9@`80002Y1@00B@400?d5002Z0@00000004H0000P0@00
504004E=AR/Z@000900001P00000080o0000P0000800080o0000P0000808@0`2X00009@000024<3K
00000=h@00000000ZjZZ?`80003o00000P00000004420000000005P000024<3K0000004000020000
EUEE@00000000000000000008440080o0000000000000000000001`000024<3K0`00001P00020?co
00000?koo?l00H530Q30f`000000003o240=0c`0000`00000Q30f`@000000000082oA000YD<0P;m4
g7nb@`3P]DCLOk930>2eA000e4<00@415D0=010000040000300002P0000<00000`00024000080000
HP0000`000010000900002@00000080m000000000000080m0000000000020000G`0003P000030000
>0000000000h00000000000B0@0@0000000000000000000000000000000U0000300000<0000W0000
600000@00000000000000000000U0000300000@0000C000030000080000k0000200001/0000@0000
`el009PD000f000040000<=O00185P00F00002P00000000000000?oooooooooo0`000<=OCQJnGe<F
^5mC5UT0000X000000000000003oooooooooo`<0003XFU<FleY85_=J<AYH0000=000000000000000
ooooooooool60000leXg6^iJ?1[XFS`JheXl6]iJ=a[NFS4J=P000100003NFP00B1H005P0000X0000
00000000003oooooooooo`<0003NFT<FheXn5^QJ?QII0000:000000000000000ooooooooool30000
^5ln5ZiOB1J^GiPDF00003@00000000000000?oooooooooo1P000:iOTaBcGhhD^5n>5;iOSQC3Gi<D
`enH53d0000800006`000100000XF`00n1T005T0000T000000000000003oooooooooo`80003XFWPJ
Z5[h6Cd000080000?00000P0000o000060000:T500170@00oPD00:T1000C000030000040000U0000
30000000080U0000300000L0080T000090000000P440000000000000P440000000000080000X0000
300000<0000R000030000?oooom60000700001000015CDH[140000`000000000AP0001@000080000
AdA9@`<000160000:00001`00017A4U30P000;l5002O0@0020H00<@100000000AP0000`100000@00
ADe6:bY0000T000060000000P3l000200000P000P3l000200000P0Q03P:P0000U000008@`=/00000
gQ000000002[ZZXo0P000?l0000200000000@@8000000000F000008@`=/000000@000080001FEEE0
0000000000000000000P@@00P3l0000000000000000000007000008@`=/3000006000080o?l00000
o_olo`01PD824<3K000000000?l8@0l3:00001`000024<3K0`00001000071Z011`Jn0L45_P400@41
5D0?0100000400003P00024000080000HP0000`000010000900002@00000080m000000000000080m
0000000000020000G`0003P000030000>0000000000h00000000000B0@0@00000000000000000000
00000000000U0000300000<0000U0000300000@0000C000030000080000k0000200001/0000@0000
Lf000?PI000f0000400007=P003H6`00F00002P00000000000000?oooooooooo0`0007=PgQ]^H><K
J63S6cH0000@0000D5`00><K001H0000=000000000000000ooooooooool60000BUcS6dELgQ]5G=PK
AEcC6dYLcQ]@G<hKF@0002P00000000000000?oooooooooo0`0006QPcQ]NH=PKGV3h6EP0000d0000
00000000003oooooooooo`H0001NH?<IHf3^6FQPkQU^H>hILf3c6G=Pn1Tm0000200001/0000@0000
R5`001PL001I00009000000000000000ooooooooool2000025cH6hQLV1/m0000200003`000080000
?`0001P0002o1@00W@4000T600330@004`0000`0000100009@0000`0000000209@0000`000070020
900002@00000081100000000000008110000000000020000:00000`0000300008P0000`0003ooooo
AP0001`0000@0000ADe6:`A0000<0000000004H0000D0000200004M4BD<30000AP0002P0000L0000
AdA9@`80002Q1@00Z`000;P500330000000004H0001@0000A00004E=AR/Z@000900001P00000080o
0000P0000800080o0000P000080:@03070000100003ooooo0@000:85[00E01H0:00000`000040000
8@0000P0001R000030000040000T000090000000P3d0000000000000P3d0000000000080000W0000
600000@000000000oooo0000000U0000300000@0000U0000300000P0081F0000<0000:45002[0000
]`D00<800005000065Zh2QQJ60aXFaP<J5^h2QQJ^0XU0000300000L0080U000030000000080T0000
90000000P440000000000000P44000000000008000160000S00008000015CDH[240@0T00000d0000
0Q30f`00003F000000000000P3l200000P000000044200000000008@`=/00000ooooo`Q04@</0000
8000008@`=/4000004000:85[02R1L80]`G20;L5[0000@615D0A010000040000400003X0000<0000
200002@0000T00000020?@00000000000020?@00000000000P0005l0000h00000`0003P000000000
>00000000000804040000000003oool000000000000000009@0000`0000300009@0000`000050020
EP0002`0002E1@00W`000<<5003>0000100001QJ^0XHFQP<J5/H36QK^0XU0000300000L0080U0000
30000000080T000090000000P440000000000000P440000000000080000X0000300000<0000j0000
300000X0000R000030000?oooom60000700001000015CDH[140000`000000000AP0001@000080000
AdA9@`<0000Q0000200001h0000H0000Y@D00:d0002e1@00`P0002D0000<00000P000580001`0@00
0`000?Ooool0000000000000002@0@000000000002110780J@1Q06`0000000000000000000000000
000000000000000000000000000000000000000000000000000C0;_b032HO1<047`C00`000090000
0`0000<000000000?7`C054B2]`70000DA8:g>Qm4`1^[00`T2:d0Fan4`0<0000aK00<6an4`2@8[@1
30000>[/031/OQ<0T2:d0@H0002`NK@1I84C00K^031DfDL0T040000000400000E01Q06P0K`1]0640
Y7`C00UA5E/4000060000000000<00002@0000D000030000000003<00000000000000040003140X;
cKL1<00000000000;e@EF`00003/4PZU0P00054B2]c140X;^Q01?I0R]04>^]5g37dC06Af00P00000
9@0000`0000300009@0000`0000200009@0000`0000=00209@0000`0000300009@0000`000020000
500000`0000=00004P0000`000010000E00005@0002U1@00[`000:/5002n00000@000000nT400?Y1
Y@D00:l000010000C00000000000000000000?ooooooooooD00007<0000700009@0000`000030000
E00005P0002/1@00]@000;<5003000000@000000nT400?Y1[0D00;D000020000C000000000000000
00000?ooooooooooD0000700M00500000`0002D0000<00003@00P280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000H000030000>`3000?0P008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000000209@0000`0000=0020AP0002P0000L0000
AdA9@`80002R1@00h`000;`500030@00000004H0001@0000A00004E=AR/Z@000900001P00000080o
0000P0000800080o0000P000080:@03070000100003ooooo0@000:<5i00H01h08@0000P0001R0000
30000040000T000090000000P3d0000000000000P3d0000000000080000U0000300000@0000U0000
300000P0081F0000<0000:85003S0000^`D0008100050000:5Xh3RQJ612XFaP@Z5/h3RQJ>0hU0000
300000L0080U000030000000080T000090000000P440000000000000P44000000000008000160000
S00008000015CDH[240B0T00000d00000Q30f`00003F000000000000P3l200000P00000004420000
0000008@`=/00000ooooo`Q04`</00008000008@`=/4000004000:<5i02S1@81^`D20K/5i0000@61
5D0C0100000400004P0003X0000<0000200002@0000T00000020?@00000000000020?@0000000000
0P0005l0000h00001@0003P000000000>00000000000804040000000003oool00000000000000000
9@0000`0000500009@0000`000050020EP0002`0002F1@00e`000<L5000>0@00100002QJ>0hXFQP@
Z5/H4:QK>0hU0000300000L0080U000030000000080T000090000000P440000000000000P4400000
00000080000X0000300000D0000j0000300000X0000R000030000?oooom60000700001000015CDH[
140000`000000000AP0001@000080000AdA9@`<0000Q0000200001h0000H0000YPD00>D0002i1@00
0P4002D0000<00000P0002D0000<00000`0002D0000<00000P0002D0000<00003@00P2D0000<0000
0`0002D0000<00000P0001@0000<00003@000180000<00000@0005@0001D0000YPD00>L0002/1@00
mP00004000000?Y1003j@JH5003W00000@0004`00000000000000000003ooooooooooe00001c0000
1`0002D0000<00000`0005@0001D0000[@D00>d0002a1@00n000004000000?Y1003j@Jd5003]0000
0@0004`00000000000000000003ooooooooooe00001`00001@0002D0000<00003@00P280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000H000030000>`3000?0P00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000000209@0000`0000=0020
AP0002P0000L0000AdA9@`80003=1@00]P0006H6003H0000000004H0001@0000A00004E=AR/Z@000
900001P00000080o0000P0000800080o0000P000080:@03070000100003ooooo0@000<h5]`2G0200
8@0000P0001R000030000040000T000090000000P3d0000000000000P3d0000000000080000U0000
300000@0000U0000300000P0081F0000<0000<d5002f0000I@H00=L000050000f5aX2mQLJ0e8IVP=
B6IX2mQLJ0/U0000300000L0080U000030000000080T000090000000P440000000000000P4400000
0000008000160000S00008000015CDH[240D0T00000d00000Q30f`00003F000000000000P3l20000
0P000000044200000000008@`=/000000000o`Q05@</00008000008@`=/4000004000<h5]`3>1ML0
I@KG06D6]`000@615D0E010000040000500003X0000<0000200002@0000T00000020?@0000000000
0020?@00000000000P0005l0000h00001@0003P000000000>0000000000080404000000000000000
00000000000000009@0000`0000500009@0000`000050020EP0002`000311@00ZP000746003S0000
10000=QLJ0_HG6P=B6IX3DQVJ0/U0000300000L0080U000030000000080T000090000000P4400000
00000000P440000000000080000X0000300000D0000j0000300000X0000R000030000?oooom60000
700001000015CDH[140000`000000000AP0001@000080000AdA9@`<0000Q0000200001h0000H0000
dPD00;P0001R1P00e`000580001`0@001@000>goool0000000000000002@0@000000000002110780
J@1Q06`0000000000000000000000000000000000000000000000000000000000000000000000000
000000D000050000flX2<0X<00010000n7dC00D000000;@12oc:<54B2]`B0000DA8:g>Qm4`1^[00`
C8bd0Fan4`0<0000aK00<6an4`1<S;@130000>[/031/OQ<0C8bd0@H0000X][@1I84C00K^031DfDL0
T040000000400000E01Q06P0K`1]0640Y7`C00UA5E/400006P000000000<00002P0000D000020000
000003<00000000000000040001?4@Y`cKL1<00000000000;e@EF`00001?4@Yd0000054B2]a?4@Yd
^Q01?Db<]04>^]5g37dC06Af00P000009@0000`0000500009@0000`0000=00209@0000`000050000
500000`0000=00004P0000`000010000E000060000071P00^@0002`6003>00000@000000nT400?Y1
1`H00;T000030000C00000000000000000000?ooooooooooE0000500E01C00003@0000`0000=0000
9@0000`0000=00208P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001P0000<0000k0<000l2000R000030000?oooolH000030000000000I000030000?ooo`0U0000
30000000080U0000300000d008160000:00001`00017A4U30P000>85003`0000n@D000`100000000
AP00050000140000ADe6:bY0000T000060000000P3l000200000P000P3l000200000P0Y00<0L0000
40000?ooool10000h`Ga01D06P0Q000020000680000<00000@0002@0000T00000020?@0000000000
0020?@00000000000P0002D0000<0000100002D0000<00002000P5H0000`0000hPD00?00003h1@00
2`4000D0000XGPP?:5jX47QOZ11hG`P?:5h83bD0000<00001`00P2D0000<00000000P2@0000T0000
0020@@00000000000020@@00000000000P0004H0002<0000P00004E=AR/8@1H2@00003@000024<3K
00000=H0000000000020?`80000200000000@@80000000000Q30f`00003ooooo240G0b`0000P0000
0Q30f`@00000@000h`Ga0><52`7h1@/1n0Ga00010H4E@1L0400000@0000F0000>P0000`000080000
900002@00000080m000000000000080m0000000000020000G`0003P000060000>0000000000h0000
0000000P0@0@000000000?ooo`00000000000000000U0000300000H0000U0000300000D0081F0000
;0000=H5003T000010H001L100040000:5h83bQNZ11hGjP@N5l83bD0000<00001`00P2D0000<0000
0000P2@0000T00000020@@00000000000020@@00000000000P0002P0000<00001P0003X0000<0000
2P000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000500000P00017A4U3
0`000240000800007P0001P0003V1@00lP000?H5000;0@009@0000`0000200009@0000`000030000
9@0000`0000200009@0000`0000=00209@0000`0000300009@0000`000020000500000`0000=0000
4P0000`000010000E00005@0003V1@00m0000>`500030@000@000000nT400?Y1iPD00?@000010000
C00000000000000000000?ooooooooooD00007<0000700009@0000`000030000E00005@0003/1@00
nP000>l500050@000@000000nT400?Y1k@D00?X000010000C00000000000000000000?oooooooooo
D00007@0000300009@0000`0000=00208P0000`0003ooooo8@0000P0000I000030000?ooo`0H0000
30000000000N0000600001P0000<0000k0<000l2000R000030000?oooolH000030000000000I0000
30000?ooo`0U000030000000080U0000300000d008160000:00001`00017A4U30P000?@5000X0@00
70H0050100000000AP000=@000380000ADe6:bY0000T000060000000P3l000200000P000P3l00020
0000P0Q060>@0000Q000008@`=/=000000000000`D@0P9A3<K2oA020U4<0X;i4aL2H@`2P_T@009i3
0:2nA3/oXd<a/;m4082W@`00`D@0P:M3cdo2A020Yd<0H<=4>cnS@`1P`d@009i30633A<G0V4??Cl94
082D@`00`D@0P9A300<30`<30`<30`<3P`0701A0680@000010000?oooolQ000020000680000<0000
0@0002@0000T00000020?@00000000000020?@00000000000P0002D0000<0000100001<0000<0000
0@0003/000080000E@0005000000000000000?oooooooooo3@0007QPR1;AGhPBB5lA4dQO^1=8Gf0D
dEoX57QPj1@PHNPDZ65P5:QQ^1>XHA4C86684WQPR18l0000200003h0000H0000m0D002P1000K1P00
C`4001<0000<00000@0002D0000<00000000P2@0000T00000020@@00000000000020@@0000000000
0P0004H0001T0000F00004E=AR/8@1T2A00003P000024<3K00000=h0000000000020?`8000020000
0P000000044200000000008@`=/000000000oaE0600@0000100001T0000T000090000000P3d00000
00000000P3d0000000000080001O0000>00000H0000h0000000003P0000000000001010000000000
0000000000000000000002D0000<00001P0002D0000<00001@00P5D0001@0000l`D002L1000L1P00
D04000d0001hH8PBdEn84TQO4A=8GkPCB5mP5=5Oj1AhH>PD867X5:QQH1BXHKPCZ64A4b1QR19hH8PB
9@0000`0000700209@0000`000000020900002@00000081100000000000008110000000000020000
:00000`0000600008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000000004H0000D0000
200004M4BD<300008@0000P0000N000060000?h5000`0@0050H004X1000U000030000080001B0000
L04000H0003aoooo0000000000000000T04000000000000P@@1b06T0H@1/00000000000000000000
00000000000000000000000000000000000000000000000000000000000500001@000=_:0S0:3000
0@000?Qm4`050000W7dC00D0001A4P[L3P00054B2]cXOA<0KZ`0<91/]05/OQ<030000<F`031/OQ<0
T6bd0@`0003Zk00`K7hC091/]0460000n2bd0FB14`06kP0`E=U7090100000001000005@0H@1X06l0
K@1Q0:Al4`09DAEK?14HFa1m4`30fDL0c7`C01UH5E/8fdL0E=U708cIA`0`fDL00000000000010000
/P000<fg0C000000000002mD5E/00000k18:X`00001A4P[Lk18:XkX@0Cf@K;@13[[AM`am4`1TMP08
000002D0000<00001P0002D0000<00000P0002D0000<00003@00P2D0000<00001P0002D0000<0000
0P0001@0000<00003@000180000<00000@0005@0001D0000oPD0038100011P00@@40004000000?Y1
003j@Oh5000b0@000@0004`00000000000000000003ooooooooooe00000P0000100002D0000<0000
1P0005@0001D00000PH00341000;1P00@@40004000000?Y1003j@@86000a0@000@0004`000000000
00000000003ooooooooooe00001200002P0002D0000<00003@00P280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000H000030000>`3000?0P008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000000209@0000`0000=0020AP0002P0000L0000
AdA9@`80002E1P00``000;X6003V0000000004H0003D0000b00004E=AR/Z@000900001P00000080o
0000P0000800080o0000P0000808@1X3T00008@000024<3K3@0000000000l=A40014@kBjdd@004A3
0<3BA0ISBd<0`=94081D@`30dTCjW5e3];[CA000ID<0l=A4001U@d`UeT@006E3023GA?ZLGD<08=M4
081D@`0Ped@6Hd]3C2GFA000A4<0l=A40014@`030`<30`<30`<30h<0000D@1Z0400000@0003ooooo
8@0000P0001R000030000040000T000090000000P3d0000000000000P3d0000000000080000U0000
300000@0000C000030000040000k0000200005D0001@000000000000003oooooooooo`d0001`JSP<
eVTh35QY[`aHJD0=F6WB3MIYB0i`JTP>2f]83XQ[dPf8Jd0=R6^_30][>0a`JSP<?00000P0000n0000
600009D600330000^@H00>D0000C000030000040000U000030000000080T000090000000P4400000
00000000P44000000000008000160000I00005P00015CDH[240K0T@0000h00000Q30f`00003N0000
00000000P3l200000P000080000000110P00000000024<3K000000000?lE@1X0400000@0000K0000
900002@00000080m000000000000080m0000000000020000G`0003P000070000>0000000000h0000
000000000@0@0000000000000000000000000000000U0000300000L0000U0000300000D0081E0000
D00009@600320000^PH00>H0000=0000L6Xh3=IY>0aHJJl<F6U03EQYdPgFJDP>L6Y83P][B0j8Jm8=
R6]03HQ[[``;JcP<L6Xh32D0000<00001`00P2D0000<00000000P2@0000T00000020@@0000000000
0020@@00000000000P0002P0000<00001`000280000<0000ooooodH0000L0000400004E=AR/4@000
3000000000160000500000P00017A4U30`0004H0000X0000700004M4BD<20000UPH00001002k1P00
8`40000000160000e0000<P00015CDH[:T0002@0000H00000020?`00080000200020?`0008000020
240L0i00002400000Q30f`d000000000013EA020P4>df]=40820@`3PdTB3<HA30>3BA030R4<0h=94
ODj=@kCJdd@00953013EA000TD=<AMI4002A@`10edAmCXe3043GA030R4<0@=M4Pc64@da5eT@0P813
013EA020P4<00`<30`<30`<30`>3JP00540LP10000040000ooooob4000080000HP0000`000010000
900002@00000080m000000000000080m00000000000200009@0000`0000400004`0000`000010000
>`0000P0001E0000D000000000000000ooooooooool=0000P6X84>IY211XJGl@J6T@4FQYXQ7VJAPB
P6XH4Q][61:HJj8AV6/@4IQ[Oa0KJ`P@P6X843`000080000?P0001P0002F1P0000400;X6000R0@00
4`0000`0000100009@0000`000000020900002@00000081100000000000008110000000000020000
AP0006@0001H0000ADe6:`Q07@940000>000008@`=/00000gP0000000000080o0P00008000020000
0000@@80000000000Q30f`000000003o5D0L0100000400007@0002@0000T00000020?@0000000000
0020?@00000000000P0005l0000h00001`0003P000000000>0000000000000404000000000000000
00000000000000009@0000`0000700009@0000`000050020E@000500002E1P00o`000;/6000S0@00
3@00081Z213VJ@P@J6Uo46QY415XJJ8AiVTH4X1Z618KJaPBV6^R4IQ[416HJgl@6f/8481Z210U0000
300000L0080U000030000000080T000090000000P440000000000000P440000000000080000X0000
300000L0000R000030000?oooom60000700001000015CDH[140000`000000000AP0001@000080000
AdA9@`<000160000:00001`00017A4U30P0009P6000n0@00_@H0064100000000AP000=@000380000
ADe6:bY0000T000060000000P3l000200000P000P3l000200000P0Q07P>@0000Q000008@`=/=0000
0000001@eD@0P9m3]1[DA020Wd<08==4Pc6S@`0Pdd@0`:M3023CA7e>[4>d6]A4002`@`1@eD@00;13
C8GFA000/4<0P=M4ODj/@`20ed@0`:M3083GA8<aXd=<QMI4082O@`1@eD@0P9m300<30`<30`<30`<3
Pn0kA1A07X0@000010000?oooolQ000020000680000<00000@0002@0000T00000020?@0000000000
0020?@00000000000P0002D0000<0000100001<0000<00000@0003/000080000E@00050000000000
00000?oooooooooo3@000:1Zj1<6J^PCR6UO58QYl1B8JH8E1V[h5J1Zn1DkJoPE^6^25KQ[l1BhJelD
>f_X4j1Zj1<l0000200003h0000H0000V0H003h1002l1P00H04001<0000<00000@0002D0000<0000
0000P2@0000T00000020@@00000000000020@@00000000000P0004H0001T0000F00004E=AR/8@1l2
A00003P000024<3K00000=h0000000000020?`80000200000P000000044200000000008@`=/00000
0000oaE07P0@0000100001l0000T000090000000P3d0000000000000P3d0000000000080001O0000
>00000L0000h0000000003P00000000000010100000000000000000000000000000002D0000<0000
1`0002D0000<00001@00P5D0001@0000U`H003d1002m1P00H@4000d0002PJ^PC1V[X4hQYGaB8JO0D
R6V25@IZn1FPJ_PE>f_h5KQ[PQFhJo0D^6]O53][j1>PJ^PC9@0000`0000700209@0000`000000020
900002@00000081100000000000008110000000000020000:00000`0000700008P0000`0003ooooo
AP0001`0000@0000ADe6:`A0000<0000000004H0000D0000200004M4BD<30000AP0002P0000L0000
AdA9@`80002H1P00N0400;d6002K0@00000004H0003D0000b00004E=AR/Z@000900001P00000080o
0000P0000800080o0000P0000808@203T00008@000024<3K3@0000000000D=E4082l@k@Je4@0P;a3
023CA8<a`4<08==40<34@`0PddAmC/U3]1[DA000cD<0D=E4003=@db5eT@00<e3083GA7e>bD<0P=M4
0<34@`20edB3<L13C8GFA020_4<0D=E4082l@`030`<30`<30`<30h>O54@D@220400000@0003ooooo
8@0000P0001R000030000040000T000090000000P3d0000000000000P3d0000000000080000U0000
300000@0000C000030000040000k0000200005D0001@000000000000003oooooooooo`d0002PJXPG
1VZ85hQYoaN8JI0HR6TR6@IZV1VPJYPI>f^H6KQ[8QVhJi0H^6_o5c][R1NPJXPG?00000P0000n0000
600009P6001h0@00_0H009X1000C000030000040000U000030000000080T000090000000P4400000
00000000P44000000000008000160000I00005P00015CDH[240Q0T@0000h00000Q30f`00003N0000
00000000P3l200000P000080000000110P00000000024<3K000000000?lE@200400000@0000Q0000
900002@00000080m000000000000080m0000000000020000G`0003P000070000>0000000000h0000
000000000@0@0000000000000000000000000000000U0000300000L0000U0000300000D0081E0000
D00009L6001g0@00_@H009/1000=0000X6Z85`IZR1N8JOlGR6V@68QY8QT6JYPIX6ZH6C][V1VhJb8I
^6^@6;Q[oaLkJhPGX6Z85bD0000<00001`00P2D0000<00000000P2@0000T00000020@@0000000000
0020@@00000000000P0002P0000<00001`000280000<0000ooooodH0000L0000400004E=AR/4@000
3000000000160000500000P00017A4U30`0004H0000X0000700004M4BD<2000040H000T1002H1P00
<@40000000160000604000`10015CDH[:T0002@0000H00000020?`00080000200020?`0008000020
240R0Z`0002P00000Q30f`00003N400000000:^ZZSl20000o`000080000000110P000000001T0000
0Q30f`00000100000P0005IEED00000000000000000002110020?`000000000000000000000X0000
0Q30f`<000008000ZjZZ?`00P<00000000000:^ZZ[l008300061008@`=/000000000o`Q08`<X0000
7000008@`=/30000040009L62P4E1PX15@H_0@010@4E@2<0400000@0000R0000:00000`000040000
8@0000P0001R000030000040000T000090000000P3d0000000000000P3d0000000000080001O0000
>00000@0000h0000000003P00000000001810100000000000000000000000000000002D0000<0000
100002L0000H00001`00000000000000000002D0000<00001`0001<0000<00000P0003/000080000
6`000100001XJ@00Xa0005T0000X000000000000003oooooooooo`<00018HJ<@Df6H45=QXA9H0000
=000000000000000ooooooooool60000Df6W4TiQ[198HJ`B@f6/4SiQYa8nHJ4B=P000100000nH@00
V10005P0000X000000000000003oooooooooo`<0000nHI<@@f6>44QQSQ0f0000400006QY002>4000
F00003@00000000000000?oooooooooo1P0006iYSQ1cJI<@LfVH47=YWQ1^JJ<@J6VS43d000080000
6`000100001cH@00J18005T0000T000000000000003oooooooooo`800018HNPB7V5X4Sd000080000
?00000P0000o00006000010600070@00V@H00301000C000030000040000U000030000000080U0000
300000L0080T000090000000P440000000000000P440000000000080000X0000300000@0000R0000
30000?oooom60000700001000015CDH[140000`000000000AP0001@000080000AdA9@`<000160000
:00001`00017A4U30P000:D6000R0@00[`H0048100000000AP0001@100080@00ADe6:bY0000T0000
60000000P3l000200000P000P3l000200000P0Q090:/0000X000008@`=/00000gQ000000002[ZZXo
0P000?l0000200000000@@8000000000I000008@`=/000000@000080001FEEE00000000000000000
000P@@00P3l000000000000000000000:000008@`=/3000002000:^ZZSl0083000000000002[ZZZo
0020`001P@024<3K000000000?l8@2D3900001P000024<3K0P000010002Z1R<1ZPI00@010OlE@2D0
400000@0000T00008@0000P0001R000030000040000T000090000000P3d0000000000000P3d00000
00000080001O0000>00000@0000h0000000003P00000000001810100000000000000000000000000
000002D0000<0000100002D0000<00001`0001<0000<00000P0003/0000800006`000100002SJP00
:18003H0000@0000XfX00;4C001H0000=000000000000000ooooooooool60000XfZg4iiZ_1>HJ[`C
TfZl4hiZ]a>>J[4C=P000100002>JP00:18005P0000d000000000000003oooooooooo`H0002>JR<B
TfXN4YQZ7Q:NJQhBXfXS4Z=Z:18m0000200001/0000@0000`fX007PC001I00009000000000000000
ooooooooool20000V6[h4fiZN1<m0000200003`000080000?`0001P0002U1P0080400:h600110@00
4`0000`0000100009@0000`0000000209@0000`000070020900002@0000008110000000000000811
0000000000020000:00000`0000400008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000
000004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80002T1P00H0400:h6001l0@00
000004H0000D0@00204004E=AR/Z@000900001P00000080o0000P0000800080o0000P0000808@2H2
[0000:0000024<3K00000=h@00000000ZjZZ?`80003o00000P00000004420000000006@000024<3K
0000004000020000EUEE@00000000000000000008440080o0000000000000000000002P000024<3K
0`00000P002[ZZXo0020`00000000000ZjZZ_`00P<000H530Q30f`000000003o240W0b@0000H0000
0Q30f`800000@000Z@IQ0JT6NP400@<35D0W0100000400009P00024000080000HP0000`000010000
900002@00000080m000000000000080m0000000000020000G`0003P000040000>0000000000h0000
0000000B0@0@0000000000000000000000000000000U0000300000@0000U0000300000L0000C0000
30000080000k0000200001/0000@0000TfX000PF000f0000400009=Z001A5`00F00003@000000000
00000?oooooooooo1P0009=ZEaN>JU`GR6YL5h=ZG1MnJULGOVYA5cH0000@0000OVX000PF001H0000
=000000000000000ooooooooool60000OVX35X=ZoQF8J_hESV[n5I=Z0aJCJPPF?@0000P0000K0000
40000;=Z000H5`00F@0002@00000000000000?oooooooooo0P0008QZV1MNJQPG?@0000P0000l0000
200003l0000H0000Y0H005h1002]1P00N`4001<0000<00000@0002D0000<00000000P2D0000<0000
1`00P2@0000T00000020@@00000000000020@@00000000000P0002P0000<000010000280000<0000
ooooodH0000L0000400004E=AR/4@0003000000000160000500000P00017A4U30`0004H0000X0000
700004M4BD<20000Y0H00>@0002^1P000P40000000160000504000P10015CDH[:T0002@0000H0000
0020?`00080000200020?`0008000020240X0Z`0002P00000Q30f`00003N400000000:^ZZSl20000
o`000080000000110P000000001T00000Q30f`00000100000P0005IEED0000000000000000000211
0020?`000000000000000000000X00000Q30f`<000008000ZjZZ?`00P<00000000000:^ZZ[l00830
00610@8@`=/000000000o`Q0:@<T00006000008@`=/2000004000:T6i@2Y1P0100430aE0:@0@0000
100002P0000Q000020000680000<00000@0002@0000T00000020?@00000000000020?@0000000000
0P0005l0000h0000100003P000000000>000000000004P4040000000000000000000000000000000
9@0000`0000400009@0000`0000700004`0000`000020000>`0000P0000K0000400009=Z00183P00
=P000100002CJP00/@l005P0000d000000000000003oooooooooo`H0002CJ[L?SVZl3hQZ_0n3J[`?
OVZg3giZ/@lf0000400007iZ00183P00F00003@00000000000000?oooooooooo1P0007iZ@`j3JSh>
R6Xn3XiZ?PjCJT<>TfY83Sd0000800006`000100002cJP00N0l005T0000T000000000000003ooooo
ooooo`800028J_P?GVYh3cd000080000?00000P0000o000060000:@6003R0000[@H00041000C0000
30000040000U000030000000080U0000300000L0080T000090000000P440000000000000P4400000
00000080000X0000300000@0000R000030000?oooom60000700001000015CDH[140000`000000000
AP0001@000080000AdA9@`<000160000:00001`00017A4U30P000<D500250@00BPH009h100000000
AP00050000140000ADe6:bY0000T000060000000P3l000200000P000P3l000200000P0Y00<0L0000
40000?ooool10000aPF60H<05`0X0000300000L0000Q000020000680000<00000@0002@0000T0000
0020?@00000000000020?@00000000000P0002L0000H00001`000000003oool0000002D0000<0000
1`0002D0000<00002000P5H0000`0000a@D008D100191P00W@4000D0001HG5PHF5c86HQTb1V8I5PH
F5aH62D0000<00001`00P2D0000<00000000P2@0000T00000020@@00000000000020@@0000000000
0P0004H0002<0000P00004E=AR/8@2X2@00003@000024<3K00000=H0000000000020?`8000020000
0000@@80000000000Q30f`00003ooooo240[0b`0000P00000Q30f`@00000@000aPF60LH5W@591Yd1
B@J60@010H4E@2/0400000@0000Z0000>P0000`000080000900002@00000080m000000000000080m
0000000000020000G`0003P000040000>0000000000h00000000000P0@0@000000000?ooo`000000
00000000000U0000300000@0000U0000300000D0081F0000;0000;T5001i0@00E@H00:T100040000
F5aH65QLb1V8I<PIR6AH62D0000<00001`00P2D0000<00000000P2@0000T00000020@@0000000000
0020@@00000000000P0002P0000<0000100003X0000<00002P000280000<0000ooooodH0000L0000
400004E=AR/4@0003000000000160000500000P00017A4U30`000240000800007P0001P000391@00
Q`4004L6002M0@009@0000`0000200009@0000`0000=00209@0000`000020000500000`0000=0000
4P0000`000010000E0000<`000391@00Q`4004D6002F0@000@000000nT400?Y1b@D008L1000E0000
C00000000000000000000?ooooooooooN0000580I@1c07@0801_06H0801d06P0I@0P0680K`1T07T0
800X0580@P0Y00002@0000L000070000100000@0000700000`0000@0000400001`0000L000040000
1`0000L0000700001`0000@0000400002@0000T0000400009@0000`0000=00208P0000`0003ooooo
8@0000P0000I000030000?ooo`0H000030000000000N0000600001P0000<0000k0<000l2000R0000
30000?oooolH000030000000000I000030000?ooo`0U000030000000080U0000300000d008160000
:00001`00017A4U30P0009d6003:0000]0H00>0000000000AP00050000140000ADe6:bY0000T0000
60000000P3l000200000P000P3l000200000P0Y00<0L000040000?ooool10000WPK;01D0500Q0000
20000680000<00000@0002@0000T00000020?@00000000000020?@00000000000P0002D0000<0000
1`0002D0000<00002000P5H0000`0000W@H00<X0002c1P00g`0000D0003HJJP<f6WX3BQ[j0dXJjP<
f6VX32D0000<00001`00P2D0000<00000000P2@0000T00000020@@00000000000020@@0000000000
0P0004H0002<0000P00004E=AR/8@2`2@00003@000024<3K00000=H0000000000020?`8000020000
0000@@80000000000Q30f`00003ooooo240]0b`0000P00000Q30f`@00000@000WPK;09h6g`2c1]l0
/`K;00010H4E@2d0400000@0000/0000>P0000`000080000900002@00000080m000000000000080m
0000000000020000G`0003P000040000>0000000000h00000000000P0@0@000000000?ooo`000000
00000000000U0000300000@0000U0000300000D0081F0000;0000946002n0000_`H00>/000040000
f6VX3=QYj0dXJnP=:6^X32D0000<00001`00P2D0000<00000000P2@0000T00000020@@0000000000
0020@@00000000000P0002P0000<0000100003X0000<00002P000280000<0000ooooodH0000L0000
400004E=AR/4@0003000000000160000500000P00017A4U30`000240000800007P0001P0002Q1P00
c0000;46003O0000DP00070100040000mOooo`0000000000000009010000000000008440LP1Y0640
K0000000000000000000000000000000000000000000000000000000000000000000000000000000
1@0000D0003KbP8`2P`00040003hOA<01@000000]04;o<X`DA8:g0/0001A4P[Lj7dC06j/032/8K@1
K7hC00`00035/00`K7hC0:`Q]04<0000j^`0<6an4`2/8K@11P0003Qi]05TPA<01^h0<5CIA`2@0@00
00000@00001D0640J01_06d0H@2TO1<02E4EFc`A65/@OA<0`=U70<al4`0IF1EK2=]705CIA`2<fDL0
<=U70000000000000@000;80003=]`4`00000000000_E1EK00000>`B2Z@00000DA8:g>`B2ZBj404m
[26d0@jjdGL<OA<0I7H02000000U0000300000@0000U0000300000d0080U0000300000@0000D0000
300000d0000B000030000040001D0000F0000:46003<0000[@H00=T000010000003j@@00nT6Q1P00
c0000080001<00000000000000000000oooooooooom@0000D`1D00L0000600009@0000`0000=0020
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000600001P0000<0000
k0<000l2000R000030000?oooolH000030000000000I000030000?ooo`0U000030000000080U0000
300000d008160000:00001`00017A4U30P0009l600060@00]PH001`100000000AP00050000140000
ADe6:bY0000T000060000000P3l000200000P000P3l000200000P0Y00<0L000040000?ooool10000
X0H70AD0500Q000020000680000<00000@0002@0000T00000020?@00000000000020?@0000000000
0P0002D0000<00001`0002D0000<00002000P5H0000`0000W`H000H1002e1P006`4000D0003hJFP@
n6VX4DQ[Z158JfP@n6UX42D0000<00001`00P2D0000<00000000P2@0000T00000020@@0000000000
0020@@00000000000P0004H0002<0000P00004E=AR/8@2h2@00003@000024<3K00000=H000000000
0020?`80000200000000@@80000000000Q30f`00003ooooo240_0b`0000P00000Q30f`@00000@000
X0H70J066`6e1Q/1]@H70@010H4E@2l0400000@0000^0000>P0000`000080000900002@00000080m
000000000000080m0000000000020000G`0003P000080000>0000000000h00000000000P0@0@0000
00000?ooo`00000000000000000U0000300000P0000U0000300000D0081F0000;00009<6003j0000
`@H002L100040000n6UX4?QYZ158JjPAB6]X42D0000<00001`00P2D0000<00000000P2@0000T0000
0020@@00000000000020@@00000000000P0002P0000<0000200003X0000<00002P000280000<0000
ooooodH0000L0000400004E=AR/4@0003000000000160000500000P00017A4U30`00024000080000
7P0001P0002S1P0020400;<6000K0@009@0000`0000400009@0000`0000=00209@0000`000040000
500000`0000=00004P0000`000010000E00005P0002S1P0020400:/6000E0@000@000000nT400?Y1
X`H000P100020000C00000000000000000000?ooooooooooD00005<0B@0700000P0002D0000<0000
3@00P280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000H0000
30000>`3000?0P008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000000020
9@0000`0000=0020AP0002P0000L0000AdA9@`80002N1P00A`400;D6001M0@00000004H0001@0000
A00004E=AR/Z@000900001P00000080o0000P0000800080o0000P000080:@03070000100003ooooo
0@0009l6B04E01@08@0000P0001R000030000040000T000090000000P3d0000000000000P3d00000
00000080000U0000300000L0000U0000300000P0081F0000<00009h600170@00]0H005`100050000
j6Uh5>QY^1DhJkPE>6]h5>QYN1@U0000300000L0080U000030000000080T000090000000P4400000
00000000P44000000000008000160000S00008000015CDH[240`0T00000d00000Q30f`00003F0000
00000000P3l200000P000000044200000000008@`=/00000ooooo`Q0<@</00008000008@`=/40000
040009l6B06O1U`1]0IL0K@6B0400@615D0a010000040000<00003X0000<0000200002@0000T0000
0020?@00000000000020?@00000000000P0005l0000h0000200003P000000000>000000000008040
40000000003oool000000000000000009@0000`0000800009@0000`000050020EP0002`0002B1P00
>`400<06001X0@0010000>QYN1CXJKPE>6^h5CQ[N1@U0000300000L0080U000030000000080T0000
90000000P440000000000000P440000000000080000X0000300000P0000j0000300000X0000R0000
30000?oooom60000700001000015CDH[140000`000000000AP0001@000080000AdA9@`<0000Q0000
200001h0000H0000XPH004T1002b1P00G04002D0000<0000100002D0000<00003@00P2D0000<0000
100001@0000<00003@000180000<00000@0005@0001P0000XPH004T1002`1P00EP40004000000?Y1
003j@J8600190@000`0004`00000000000000000003ooooooooooe@0001E04`0B@0000L000060000
0P0002D0000<00003@00P280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000H000030000>`3000?0P008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000000209@0000`0000=0020AP0002P0000L0000AdA9@`80002O1P00O`400;H6002E0@00
000004H0001@0000A00004E=AR/Z@000900001P00000080o0000P0000800080o0000P000080:@030
70000100003ooooo0@000:06P04E01@08@0000P0001R000030000040000T000090000000P3d00000
00000000P3d0000000000080000U0000300000L0000U0000300000P0081F0000<00009l6001o0@00
]@H009@100050000n6Wh5oQY>1U8JcPIB6_h5oQYn1LU0000300000L0080U000030000000080T0000
90000000P440000000000000P44000000000008000160000S00008000015CDH[240b0T00000d0000
0Q30f`00003F000000000000P3l200000P000000044200000000008@`=/00000ooooo`Q0<`</0000
8000008@`=/4000004000:06P06P1Y@1]@JD0KD6P0400@615D0c010000040000<P0003X0000<0000
200002@0000T00000020?@00000000000020?@00000000000P0005l0000h0000200003P000000000
>00000000000804040000000003oool000000000000000009@0000`0000800009@0000`000050020
EP0002`0002C1P00L`400<46002P0@0010000?QYn1OhJCPIB6/h6DQ[n1LU0000300000L0080U0000
30000000080T000090000000P440000000000000P440000000000080000X0000300000P0000j0000
300000X0000R000030000?oooom60000700001000015CDH[140000`000000000AP0001@000080000
AdA9@`<0000Q0000200001h0000H0000X`H00841002c1P00U04002D0000<0000100002D0000<0000
3@00P2D0000<0000100001@0000<00003@000180000<00000@0005@0001P0000X`H00841002`1P00
SP40004000000?Y1003j@J<600210@000`0004`00000000000000000003ooooooooooe@0001<04`0
B@0000H0000600000P0002D0000<00003@00P280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000H000030000>`3000?0P008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000000209@0000`0000=0020AP0002P0000L0000AdA9@`80000I1P00
>@400:86001G0@00000004H0000D0@00204004E=AR/Z@000900001P00000080o0000P0000800080o
0000P0000808@3@2[0000:0000024<3K00000=h@00000000ZjZZ?`80003o00000P00000004420000
000006@000024<3K0000004000020000EUEE@00000000000000000008440080o0000000000000000
000002P000024<3K0`00000P002[ZZXo0020`00000000000ZjZZ_`00P<000H530Q30f`000000003o
240e0b@0000H00000Q30f`800000@0006PHj0Il6DP400CU35D0e010000040000=00002P0000<0000
1`00024000080000HP0000`000010000900002@00000080m000000000000080m0000000000020000
G`0003P000070000>0000000000h00000000000B0@0@0000000000000000000000000000000U0000
300000L0000W0000600000P00000000000000000000U0000300000P0000C000030000080000k0000
200001/0000@0000VV4008hC000f000040000:AY00015@00F00003@00000000000000?oooooooooo
1P000:YY0QF^J@PE[FT>5JaY51FVJALEXFTF5CH0000@0000Uf400:<C001H0000=000000000000000
ooooooooool60000TF6R4heQW1>>HILCSf6A4iEQSA>JHHhC?@0000P0000K00004000079Y003H5000
F@0002@00000000000000?oooooooooo0P000>QY61ESJB`E?@0000P0000l0000200003l0000H0000
5`H003L1002P1P00E@4001<0000<00000@0002D0000<00000000P2D0000<00001`00P2@0000T0000
0020@@00000000000020@@00000000000P0002P0000<00001`000280000<0000ooooodH0000L0000
400004E=AR/4@0003000000000160000500000P00017A4U30`0004H0000X0000700004M4BD<20000
EPH004d1002Q1P00V@40000000160000:04001`10015CDH[:T0002@0000H00000020?`0008000020
0020?`0008000020240f0[P0002/00000Q30f`00003N4@0000000:^ZZSl20000o`00008000000011
0P000000000200000020@000@41T00000Q30f`00000100000P0005IEED0000000000000000000211
0020?`000000000000000000000X00000Q30f`<000008000ZjZZ?`00P<00000000000:^ZZ[l00830
0061P@8@`=/000000000o`Q0=`</00008000008@`=/40000040005L6V05k1YP1N`IB0Il6DP400@41
5D0g010000040000=P00024000080000HP0000`000010000900002@00000080m000000000000080m
0000000000020000G`0003P000070000>0000000000h00000000000B0@0@00000000000000000000
00000000000U0000300000L0000U0000300000P0000C000030000080000k0000200001/0000@0000
J6D006hI000f000040000:QU001^6@00F00003@00000000000000?oooooooooo1P000:iUKQVcIG<I
/fEh6K=UOQV^IH<IZ6F36CH0000@0000J6D008<I001H0000=000000000000000ooooooooool60000
HfF36EiUOQUNIGPIGVEc6F=UKQUXIFhI?@0000P0000K000040000?iU001^6@00=P000100000nIP00
KQT005P0000d000000000000003oooooooooo`H00014IVhIB6Ic6DQVN1U8IWhIA6J36CiVPaTf0000
40000?iU00236@00F00003@00000000000000?oooooooooo1P000?QUPaWcIGhIlfEh6O=ULaWhIFhI
oVE^6Cd0000800006`000100002CIP00KQT003H0000@0000dfH006hI001H0000=000000000000000
ooooooooool60000fFI^6MiVLaWNIWPIgVIn6MUVPaWCIX<I=P000100002CIP00PaT005P0000d0000
00000000003oooooooooo`H0002=IX<IR6In6HQVN1V8IW<ISFI^6I=VKQTm0000200001/0000@0000
:6L006hI000f0000400006QW001^6@00F00003@00000000000000?oooooooooo1P0006iWKQUcIg<I
LfMh6G=WOQU^Ih<IJ6N36CH0000@0000:6L008<I001H0000=000000000000000ooooooooool60000
8fN36AiWOQTNIgPI7VMc6B=WKQTXIfhI?@0000P0000K0000400009iW001S6@00=P000100002NI`00
8aT005P0000d000000000000003oooooooooo`H0002NIadIXfLH6JQW61V^IaPI/fLM6K=W8aTf0000
40000;=W001S6@00F00003@00000000000000?oooooooooo1P000;=WJAV^IfhIZ6M^6J=WKQVNIfTI
WVMS6Cd0000800006`000100002NI`00cQP003H0000@0000WVL008hH001H0000=000000000000000
ooooooooool60000WVN86:=WPaRXIh<H[VN36;=WR1RcIhhH=P000100002cI`00cQP005P0000d0000
00000000003oooooooooo`H0002cIm@H[VOH6:QWf1RSImPHWVOD69iWcQPm0000200001/0000@0000
WVL003PH000f0000400009iW003h5`00F00003@00000000000000?oooooooooo1P0009iWlaNSInhG
Z6O^5jiWkQNcIo<G/fOh5cH0000@0000/fL003PH001H0000=000000000000000ooooooooool60000
/fLn6:iW@aRXId<HXfM369iW?QRNIcPH?@0000P0000K0000400009iW002S5`00=P000100002NI`00
HaL005P0000d000000000000003oooooooooo`H0002NIedGXfMH5jQWF1N^IePG/fMM5k=WHaLf0000
40000;=W002S5`00F00003@00000000000000?oooooooooo1P000;=WZAN^IjhGZ6N^5j=W[QNNIjTG
WVNS5cd0000800006`000100002NI`003QL003H0000@0000WVL00<hF001H0000=000000000000000
ooooooooool60000WVO85Z=W`aJXIl<F[VO35[=Wb1JcIlhF=P000100002cI`003QL005P0000d0000
00000000003oooooooooo`H0002cIa@G[VLH5jQW61NSIaPGWVLD5iiW3QLm0000200001/0000@0000
WVL007PF000f0000400009iW000h5P00F00003@00000000000000?oooooooooo1P0009iW<aJSIbhF
Z6L^5ZiW;QJcIc<F/fLh5SH0000@0000/fL007PF001H0000=000000000000000ooooooooool60000
/fMn5ZiWPaJXIh<FXfN35YiWOQJNIgPF?@0000P0000K0000400009iW003S5@00=P000100002NI`00
XaD005P0000d000000000000003oooooooooo`H0002NIidEXfNH5JQWV1F^IiPE/fNM5K=WXaDf0000
40000;=W003S5@00F00003@00000000000000?oooooooooo1P000;=WjAF^InhEZ6O^5J=WkQFNInTE
WVOS5Cd0000800006`000100002NI`00CQD003H0000@0000WVL001PE001H0000:000000000000000
ooooooooool30000WVLC5J=W3QFXI`hE=P000100002cI`003QD005P0000d000000000000003ooooo
ooooo`H0002iI`hE_VLC5KiW61FnIahE^FLS5K=W8aEI0000:000000000000000ooooooooool30000
Z6LS5K=W61FcIdhEF00003@00000000000000?oooooooooo1P000;=WE1F^IePEZ6MH5J=WF1FNIe@E
WVM>5Cd0000800006`0001000008J0003QD003H0000@0000B6P000hE001H0000=000000000000000
ooooooooool60000CVP>5E=X4aECJ1PEDfPN5DiX8aE8J2<E=P0001000008J0008aD005P0000d0000
00000000003oooooooooo`H00003J2<EoVLN5OiW61GnIa<E0fP>5@QX3QDm0000200001/0000@0000
WVP000hE000f000040000=iX000>5@00F00003@00000000000000?oooooooooo1P000>AX3QGXJ1<E
j6PH5NQX7QGTJ2<EgVPS5CH0000@0000WVP002<E001H0000=000000000000000ooooooooool60000
V6PS5I=X7QFCJ1PETfPC5IQX3QFNJ0hE?@0000P0000K0000400003=Y000>5@00=P000100001cJ@00
3QD005P0000d000000000000003oooooooooo`H0001iJ@hEOVTC5GiY61EnJAhENFTS5G=Y8aDf0000
400003=Y000S5@00F00003@00000000000000?oooooooooo1P0002eY8aDXJAhE:6TH5BQY4aD]J@hE
<fT>5Cd0000800006`000100001XJ@00kQ@005T0000T000000000000003oooooooooo`80003XJAPE
J6U35Cd000080000?00000P0000o0000600005@6001=0@00X0H009X1000C000030000040000U0000
30000000080U0000300000L0080T000090000000P440000000000000P440000000000080000X0000
300000L0000R000030000?oooom60000700001000015CDH[140000`000000000AP0001@000080000
AdA9@`<000160000:00001`00017A4U30P0004D5003B0000oPD003L100000000AP0009`0002@0000
ADe6:bY0000T000060000000P3l000200000P000P3l000200000P0Q0>0=H0000C000008@`=/70000
00000;i4^DC;DI53IgFiA2?RSd<hhjQ4HYEI@hY4ZDC3eU=3^MJiA=@2SD=R1kY4;9>;@al/_dCg99Y3
00410@41PH4D@3R0400000@0003ooooo:00000`0000800008@0000P0001R000030000040000T0000
90000000P3d0000000000000P3d0000000000080000W0000600000P000000000oooo0000000U0000
300000P0000C000030000040000U0000300000P0081F0000>00004H5003C0000n@D003@100070000
Ve`S4[=LmA5ZE98=Ve@f3NALVA7lG6/ASelm4bD0000<00001`00P1<0000<00000@0002D0000<0000
0000P2@0000T00000020@@00000000000020@@00000000000P0004H0001T0000F00004E=AR/8@3T2
A00003P000024<3K00000=h0000000000020?`80000200000P000000044200000000008@`=/00000
0000oaE0>00@0000100003T0000T000090000000P3d0000000000000P3d0000000000080001O0000
>00000L0000h0000000003P00000000000010100000000000000000000000000000002D0000<0000
1`0002D0000<00001@00P5H0000h0000A@D00=40003k1@00=P4000L0002KG2<B/ece4FYDTPfKE3H=
i5bI4OaLJa6?GcdC9@0000`0000700209@0000`000000020900002@0000008110000000000000811
0000000000020000:00000`0000700008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000
000004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80002G1@00_P000=45003=0000
000004H0002L0000T00004E=AR/Z@000900001P00000080o0000P0000800080o0000P0000808@3X3
F00004`000024<3K1`0000000000:;Q40010@`0X^4@004=3002cA000@d<00;=40019@`0X^4@004U3
02RhA000C4<0h;U40016@`010@410H54540jP10000040000ooooob4000080000HP0000`000010000
900002@00000080m000000000000080m00000000000200009@0000`0000800004`0000`000010000
9@0000`000080020EP0003P0002G1@00_`000<l5003<00001`0000aLn0/<G2P<N5TX37QIR0`<G8P<
35bh3>QLF0`U0000300000L0080C000030000040000U000030000000080T000090000000P4400000
00000000P44000000000008000160000I00005P00015CDH[240k0T@0000h00000Q30f`00003N0000
00000000P3l200000P000080000000110P00000000024<3K000000000?lE@3X0400000@0000k0000
900002@00000080m000000000000080m0000000000020000G`0003P000070000>0000000000h0000
000000000@0@0000000000000000000000000000000U0000300000L0000U0000300000D0081F0000
>00009H5002n0000d0D00<d00007000035ch2`aL:0ahFBP<N5V830aLR0`<G;P<j5aH32D0000<0000
1`00P2D0000<00000000P2@0000T00000020@@00000000000020@@00000000000P0002P0000<0000
1`000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000500000P00017A4U3
0`0004H0000X0000700004M4BD<20000nPD00=H000081P00<040000000160000W00009000015CDH[
:T0002@0000H00000020?`00080000200020?`0008000020240l0eP0001<00000Q30f`L000000000
082oA030Rd<0d;m40<2;@`3@_d@005M30730A000Ed<0L<140<2;@`30`4@0`8]30230A020UT<00@41
0@61A1A0?80@000010000?oooolQ000020000680000<00000@0002@0000T00000020?@0000000000
0020?@00000000000P0002D0000<0000200001<0000<00000@0002D0000<00002000P5H0000h0000
n`D00=H000061P00;@4000L0002hGg0Ah5m`4N1OJ0d`H6P=<61`4EQPL148H<PB9@0000`000070020
4`0000`0000100009@0000`000000020900002@00000081100000000000008110000000000020000
AP0006@0001H0000ADe6:`Q0?@940000>000008@`=/00000gP0000000000080o0P00008000020000
0000@@80000000000Q30f`000000003o5D0l010000040000?@0002@0000T00000020?@0000000000
0020?@00000000000P0005l0000h00001`0003P000000000>0000000000000404000000000000000
00000000000000009@0000`0000700009@0000`000050020EP0003P0003j1@00e@0000L6000^0@00
1`000;QOL17PGg0Ah5mX3C1PJ0d`H70AF61`4@QPb18U0000300000L0080U000030000000080T0000
90000000P440000000000000P440000000000080000X0000300000L0000R000030000?oooom60000
700001000015CDH[140000`000000000AP0001@000080000AdA9@`<000160000:00001`00017A4U3
0P0006@600360000UPH00=/000000000AP000201000D0@00ADe6:bY0000T000060000000P3l00020
0000P000P3l000200000P0Q0?P:P0000U000008@`=/00000gQ000000002[ZZXo0P000?l000020000
0000@@8000000000F000008@`=/000000@000080001FEEE00000000000000000000P@@00P3l00000
00000000000000007000008@`=/3000006000080o?l00000o_olo`01P@024<3K000000000?l8@3l3
?000030000024<3K100000000000X<a40017@oaocd@004M3o7o?A000ED<0P=94001E@`010@4E@3l0
400000@0000n0000:00000`0000800008@0000P0001R000030000040000T000090000000P3d00000
00000000P3d0000000000080001O0000>00000P0000h0000000003P0000000000181010000000000
0000000000000000000002D0000<0000200002L0000H00001`00000000000000000002D0000<0000
1`0001<0000<00000P0003/0000800006`0001000018IP00GP`003H0000@0000^6L005h<001H0000
:000000000000000ooooooooool30000_VMN3<=WH`c3IfP<F@0002P00000000000000?oooooooooo
0`000<=WB0fhIch=lFPn3EP0000d000000000000003oooooooooo`H0003gJ3h=o6Q33OaXB0glJ4h=
mfQC3O5XD`df000040000;QW001C3@00F00002P00000000000000?oooooooooo0`000;=WD`f^Idh=
[VM83ET0000X000000000000003oooooooooo`<0002^IfP<^6Mc34QVL`aH0000=000000000000000
ooooooooool60000@fIc33iVKP`nIVP<?VIS34=VGPa8IUh<?@0000P0000K000040000;QX00083@00
F@0002@00000000000000?oooooooooo0P0003QYB0fhJ8P=?@0000P0000l0000200003l0000H0000
HPH00<@0002E1P00fP0001<0000<00000@0002D0000<00000000P2D0000<00001`00P2@0000T0000
0020@@00000000000020@@00000000000P0002P0000<000020000280000<0000ooooodH0000L0000
400004E=AR/4@0003000000000160000500000P00017A4U30`0004H0000X0000700004M4BD<20000
EPH000L1002I1P00SP40000000160000704001010015CDH[:T0002@0000H00000020?`0008000020
0020?`000800002024000Z`0002P00000Q30f`00003N4@0000000:^ZZSl20000o`00008000000011
0P000000000200000000@@00@41H00000Q30f`00000100000P0005IEED0000000000000000000211
0020?`000000000000000000000L00000Q30f`<00000H0000P3lo`00003nooco0061008@`=/00000
0000o`Q00@</00008000008@`=/40000040005L6S@5g1Xd1M`H=0IL63@400@415D01010000040000
0000024000080000HP0000`000010000900002@00000080m000000000000080m0000000000020000
G`0003P000080000>0000000000h00000000000B0@0@0000000000000000000000000000000U0000
300000P0000U0000300000L0000C000030000080000k0000200001/0000@0000J6D00;hH000f0000
40000?iU002n6000F00003@00000000000000?oooooooooo1P0000AV_QP8I/<H26K860QVcQP4I]<H
oVGC63H0000@0000J6D00=<H001H0000=000000000000000ooooooooool60000HfGC65iUcQQNILPH
GVG366=U_QQXIKhH?@0000P0000K0000400005=V002n6000=P000100003XIP00_QP005P0000d0000
00000000003oooooooooo`H0003^I[hHlfK36?=Vb1ScI/hHkVKC6>QVdaPf0000400005=V003C6000
F00003@00000000000000?oooooooooo1P0004eVdaQ8I/hHB6K864QV`aQ=I[hHDfJn63d000080000
6`000100000nI`00_QP005T0000X000000000000003oooooooooo`<0001XIkhHGVO865iWGQQH0000
=000000000000000ooooooooool60000GVMH66=WDaQXIe<HKVMC67=WF1QcIehH=P000100001cI`00
b1P005P0000X000000000000003oooooooooo`<0001cIlhHKVOC66QWdaPf0000400003iW003C6000
F00003@00000000000000?oooooooooo1P0003QWdaPcIlhH<fO863=W`aPhIkhH?VNn63d000080000
6`000100001NI`0021P003H0000@0000GVL007<G001H0000=000000000000000ooooooooool60000
GVM]5f=WJ1MXIfPGKVMX5g=WKAMcIg<G=P000100001cI`0021P005P0000d000000000000003ooooo
ooooo`H0001cI`hHKVLC66QW4aQSIa<HGVL>65iW21Pm0000200001/0000@0000GVL001hG000f0000
400005iW00285P00F00003@00000000000000?oooooooooo1P0005iWPaISIghFJ6Mn5ViWOQIcIh<F
LfN85SH0000@0000LfL001hG001H0000=000000000000000ooooooooool60000LfLT5fiW:1MXIbPG
HfLX5eiW91MNIahG?@0000P0000K0000400005iW000c5P00=P000100001NI`00WQD005P0000d0000
00000000003oooooooooo`H0001NIiPEHfNC5FQWTaE^Ii<ELfNH5G=WWQDf0000400007=W000c5P00
F00003@00000000000000?oooooooooo1P0007=W>AI^IchFJ6Ln5V=W?QINIcTFGVLc5Sd000080000
6`000100001NI`00B1D003H0000@0000GVL00;<D001H0000=000000000000000ooooooooool60000
GVN]56=WZ1AXIjPDKVNX57=W[AAcIk<D=P000100001cI`00B1D005P0000d000000000000003ooooo
ooooo`H0001cIdhEKVMC5FQWDaESIe<EGVM>5EiWB1Dm0000200001/0000@0000GVL005hD000f0000
400005iW00384`00F00003@00000000000000?oooooooooo1P0005iW`a=SIkhCJ6Nn4fiW_Q=cIl<C
LfO84cH0000@0000LfL005hD001H0000=000000000000000ooooooooool60000LfMT56iWJ1AXIfPD
HfMX55iWI1ANIehD?@0000P0000K0000400005iW001c4`00=P000100001NI`00gQ8005P0000d0000
00000000003oooooooooo`H0001NImPBHfOC4VQWda9^Im<BLfOH4W=WgQ8f0000400007=W001c4`00
F00003@00000000000000?oooooooooo1P0007=WNA=^IghCJ6Mn4f=WOQ=NIgTCGVMc4cd000080000
6`000100001NI`00R18003H0000@0000GVL00?<A001H0000=000000000000000ooooooooool60000
GVO]4F=Wj15XInPAKVOX4G=WkA5cIo<A=P000100001cI`00R18005P0000d000000000000003ooooo
ooooo`H0001cIhhBKVNC4VQWTa9SIi<BGVN>4UiWR18m0000200001/0000@0000GVL009hA000f0000
400005iW00084@00F00003@00000000000000?oooooooooo1P0005iW0a5SIoh@J6On46iWoQ1cI`<A
LfL84CH0000@0000LfL009hA001H0000=000000000000000ooooooooool60000LfNT4FiWZ15XIjPA
HfNX4EiWY15NIihA?@0000P0000K0000400007iW002n4000=P000100000CJ000_Q0005P0000d0000
00000000003oooooooooo`H0000IJ;h@7VS341iXb10NJ<h@6FSC41=Xda0f0000400007iW003C4000
F00003@00000000000000?oooooooooo1P0007QWda1cIlh@LfO847=W`a1hIkh@OVNn43d000080000
6`000100001XJ000_Q0003H0000@0000oVP00;h@001H0000=000000000000000ooooooooool60000
16Vn40QY`a08JLP@26W>40AYda3nJ=<@=P000100001XJ000da0005P0000d000000000000003ooooo
ooooo`H0001SJ=<@GVS>45iXb11NJ<<@HfRn46QX_Q0m0000200001/0000@0000j6P008P@001I0000
9000000000000000ooooooooool20000J6W84>QX214m0000200003`000080000?`0001P0001D1P00
1`4009P6002?0@004`0000`0000100009@0000`0000000209@0000`000070020900002@000000811
00000000000008110000000000020000:00000`0000800008P0000`0003oooooAP0001`0000@0000
ADe6:`A0000<0000000004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80003g1@00
D04000`600230@00000004H0000@0@00104004E=AR/Z@000900001P00000080o0000P0000800080o
0000P0000808@082X00009@000024<3K00000=h@00000000ZjZZ?`80003o00000P00000004420000
000005P000024<3K0000004000020000EUEE@00000000000000000008440080o0000000000000000
000001`000024<3K0`00001P00020?co00000?koo?l00H400Q30f`000000003o24030b`0000P0000
0Q30f`@00000@0002`IA0@/6J@7m1FT1o@F10@010@4E@0<0400000@0000200008@0000P0001R0000
30000040000T000090000000P3d0000000000000P3d0000000000080001O0000>00000P0000h0000
000003P00000000001810100000000000000000000000000000002D0000<0000200002D0000<0000
1`0001<0000<00000P0003/0000800006`000100002cH00021D003H0000@0000/f0008PF001H0000
:000000000000000ooooooooool30000/f2>5ZiPTaJXH9<FF@0002P00000000000000?oooooooooo
0`000<QOTaKCGhPFdeo15eP0000d000000000000003oooooooooo`H0003CGlLGcUo<5lQOc1O3Gl`G
_Uo75kiO`ALf000040000;iO00285P00F00002P00000000000000?oooooooooo0`000;iOPaK3GghF
b5mn5UT0000X000000000000003oooooooooo`<0002XH7hFWV285YiP21EH0000=000000000000000
ooooooooool60000WV035J=PoQBXH?hD[V3n5;=P0aFcH0PE?@0000P0000K0000400000QP00285`00
F@0002@00000000000000?oooooooooo0P000<QO21R8GhPG?@0000P0000l0000200003l0000H0000
m`D004h1000=1P00PP4001<0000<00000@0002D0000<00000000P2D0000<00001`00P2@0000T0000
0020@@00000000000020@@00000000000P0002P0000<000020000280000<0000ooooodH0000L0000
400004E=AR/4@0003000000000160000500000P00017A4U30`0004H0000X0000700004M4BD<20000
B`H00>l0001T1P002@40000000160000D00004@00015CDH[:T0002@0000H00000020?`0008000020
0020?`00080000202T00`1`0000@0000ooooo`40001;1^l06@0J02P0000<00001`00024000080000
HP0000`000010000900002@00000080m000000000000080m00000000000200009`0001P000070000
00000?ooo`0000009@0000`0000700009@0000`000080020EP000300001:1P00kP0006@600090@00
1@000:QTj0jXI8P@>6J843QVj0jXI>P>9@0000`0000700209@0000`000000020900002@000000811
000000000000081100000000000200008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000
000004H0000D0000200004M4BD<300008@0000P0000N0000600004h6003`0000H@H000P1001B0000
L04000P0003coooo0000000000000000T04000000000000P@@1b06T0H@1/00000000000000000000
00000000000000000000000000000000000000000000000000000000000500001@000=_:0S0:3000
0@000?Qm4`050000002d0@_lbS1A4P[L3@00054B2]cXOA<0KZ`0<7@S]05/OQ<030000<F`031/OQ<0
M2>d0@`0003Zk00`K7hC07@S]0460000:7Zd0FB14`06kP0`E=U7090100000001000005@0H@1X06l0
K@1Q0:Al4`09DAEK100001P000000000300000T0000500000`000000000c00000000000000010000
`A0:2lfg0C000000000002mD5E/00000`A0:3000001A4P[L`A0:3;X@0Ced8k@13[[AM`am4`1TMP08
000002D0000<0000200002D0000<00000`0002D0000<0000200002D0000<00003@00P2D0000<0000
0`0002D0000<0000200001@0000<00003@000180000<00000@0005@0001D0000CPH00?80001D1P00
0@40004000000?Y1003j@Dh6003b00000@0004`00000000000000000003ooooooooooe00002k0`00
1`0002D0000<00000`0005@0001D0000E@H00?P0001J1P000`40004000000?Y1003j@ED6003h0000
0@0004`00000000000000000003ooooooooooe00001200001P0002D0000<00003@00P280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000H000030000>`3000?0P00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000000209@0000`0000=0020
AP0002P0000L0000AdA9@`80000<1@00/@0009`5003H0000000004H0001@0000A00004E=AR/Z@000
900001P00000080o0000P0000800080o0000P000080:@03070000100003ooooo0@0000d5/P2>02D0
8@0000P0001R000030000040000T000090000000P3d0000000000000P3d0000000000080000U0000
300000L0000U0000300000P0081F0000<00000`5002a0000V`D00=L000050000b50H2lQ@J0fXFFP=
Z5TH2lQ@60/U0000300000L0080U000030000000080T000090000000P440000000000000P4400000
0000008000160000S00008000015CDH[24040T00000d00000Q30f`00003F000000000000P3l20000
0P000000044200000000008@`=/000000000o`Q01@</00008000008@`=/40000040000d5/P0=1ML0
V`GG09/5/P000@615D05010000040000100003X0000<0000200002@0000T00000020?@0000000000
0020?@00000000000P0005l0000h00002@0003P000000000>0000000000080404000000000000000
00000000000000009@0000`0000900009@0000`000050020EP0002`000001@00Y@000:L5003S0000
10000<Q@60_8D6P=Z5UX3JQI60/U0000300000L0080U000030000000080T000090000000P4400000
00000000P440000000000080000X0000300000T0000j0000300000X0000R000030000?oooom60000
700001000015CDH[140000`000000000AP0001@000080000AdA9@`<0000Q0000200001h0000H0000
4@D00;<0002H1@00e`0002D0000<00001@0002D0000<00003@00P2D0000<00001@0001@0000<0000
3@000180000<00000@0005@0001P0000A0D00;@0001S1@00b@00004000000?Y1003j@D@5002d0000
0`0004`00000000000000000003ooooooooooe@0001@04T0D`0000d0000600003@0002D0000<0000
3@00P280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000H0000
30000>`3000?0P008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000000020
9@0000`0000=0020AP0002P0000L0000AdA9@`80002J1@00Z`000:h600360000000004H0000/0@00
804004E=AR/Z@000900001P00000080o0000P0000800080o0000P0000808@0H2X00009@000024<3K
00000=h@00000000ZjZZ?`80003o00000P00000004420000000005P000024<3K0000004000020000
EUEE@00000000000000000008440080o0000000000000000000001`000024<3K0`00001P00020?co
00000?koo?l00H530Q30f`000000003o24070dP0000l00000Q30f`D000000000062cA000AD?R];=4
0015@n:d/d@002a3003EA000;4<00=E40014@`010@41I`005D070100000400001P0002P0000<0000
1`00024000080000HP0000`000010000900002@00000080m000000000000080m0000000000020000
G`0003P000070000>0000000000h00000000000B0@0@0000000000000000000000000000000U0000
300000L0000W0000600000T00000000000000000000U0000300000T0000C000030000080000k0000
200001/0000@0000Z5T003h<001I0000:000000000000000ooooooooool30000deTn3<QIB0c8FKP:
F00002P00000000000000?oooooooooo0`000<QI/`[=FJh:deV^2SH0000@0000N6X00:h:001H0000
:000000000000000ooooooooool30000OVZ^2X=Z/`Z3J[P:=P0001000023JP00l@/005P0000d0000
00000000003oooooooooo`H00023J_L;OV[l2gQZo0]cJ_`;KV[g2fiZl@]I0000<000000000000000
ooooooooool50000KVZh2WQZ``[CFL<:gUVh2]iIB0aH0000:000000000000000ooooooooool30000
gUU>3=UID`cCFE<<=P000100002XF@00D``005P0000d000000000000003oooooooooo`H0002SFE<<
WUU>39iIB0bNFD<<XeTn3:QI?P`m0000200001/0000@0000^6X00;P;001I00009000000000000000
ooooooooool20000N6Xh33QZ^0/m0000200003`000080000?`0001P0002H1@00Z@000:d600370000
4`0000`0000100009@0000`0000000209@0000`000070020900002@0000008110000000000000811
0000000000020000:00000`0000700008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000
000004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80001b1@00OP000985002F0000
000004H0001@0000A00004E=AR/Z@000900001P00000080o0000P0000800080o0000P000080:@030
70000100003ooooo0@0007<5O`0N01H0:00000`0000900008@0000P0001R000030000040000T0000
90000000P3d0000000000000P3d0000000000080000W0000600000T000000000oooo0000000U0000
300000T0000U0000300000P0081F0000<0000785001n0000T@D009D000050000:5OX1bQGB0T8FDP9
25WX1bQGj0LU0000300000L0080U000030000000080T000090000000P440000000000000P4400000
0000008000160000S00008000015CDH[24080T00000d00000Q30f`00003F000000000000P3l20000
0P000000044200000000008@`=/000000000o`Q02@</00008000008@`=/40000040007<5O`1c1ID0
T@FE0945O`000@615D09010000040000200003X0000<0000200002@0000T00000020?@0000000000
0020?@00000000000P0005l0000h00001`0003P000000000>0000000000080404000000000000000
00000000000000009@0000`0000700009@0000`000050020EP0002`0001V1@00LP0009d5002Q0000
100002QGj0LXEdP925U82@QIj0LU0000300000L0080U000030000000080T000090000000P4400000
00000000P440000000000080000X0000300000L0000j0000300000X0000R000030000?oooom60000
700001000015CDH[140000`000000000AP0001@000080000AdA9@`<0000Q0000200001h0000H0000
MPD00800002?1@00U@0002D0000<00000P0002D0000<00000`0002D0000<00000P0002D0000<0000
3@00P2D0000<00000`0002D0000<00000P0001@0000<00003@000180000<00000@0005@0001H0000
MPD0088000251@00T@00004000000?Y1003j@GH5002200000P0004`00000000000000000003ooooo
oooooe00001505@02@0000L0000U0000300000<0001D0000E00008H500280000RPD009<000010000
003j@@00nT661@00R0000040001<00000000000000000000oooooooooom@0000<@0000D0000U0000
300000d0080R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
600000`0003/0`003`800280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
0000P2D0000<00003@00P4H0000X0000700004M4BD<20000EPD00780001e1@00U@00000000160000
/0000:@00015CDH[:T0002@0000H00000020?`00080000200020?`0008000020240:0f`0001P0000
0Q30f`T000000000062^A7BB2T=E=Je4Q2@1@eDe[DAlf`E3Z`Z/A7cK1D>[2Za4003V@P3PZT@00>I2
0>2ZA0Q93d=E=Je424T?@eDe[D@001A300410@410@61niI3540:P10000040000ooooob4000080000
HP0000`000010000900002@00000080m000000000000080m00000000000200009@0000`000090000
4`0000`0000100009@0000`000080020EP000400001F1@00LP0007<5002D00002@0002QGXPRCEP/8
TeIF2?iEEPSnEBP7J5DX1fQEk@RCE^d8TeHh2BD0000<00001`00P1<0000<00000@0002D0000<0000
0000P2@0000T00000020@@00000000000020@@00000000000P0004H0001T0000F00004E=AR/8@0/2
A00003P000024<3K00000=h0000000000020?`80000200000P000000044200000000008@`=/00000
0000oaE02P0@0000100000/0000T000090000000P3d0000000000000P3d0000000000080001O0000
>00000L0000h0000000003P00000000000010100000000000000000000000000000002D0000<0000
1`0002D0000<00001@00P5H000100000E@D00740001d1@00U@0000T0000XEj88TeH;29=FEPSnEEH8
oUDX1fQE:0MXENd8TeK]29=F>0TU0000300000L0080U000030000000080T000090000000P4400000
00000000P440000000000080000X0000300000L0000R000030000?oooom60000700001000015CDH[
140000`000000000AP0001@000080000AdA9@`<000160000:00001`00017A4U30P0004h5001^0000
GPD00;@000000000AP0009`0002@0000ADe6:bY0000T000060000000P3l000200000P000P3l00020
0000P0Q030=H0000C000008@`=/7000000000000ZT@0@253062ZA0108D<0H:Y4003N@P0PZd@00=i2
022[A0108D<0P:]4040Q@`30ZT@0039300410@41PD@D@0b0400000@0003ooooo8@0000P0001R0000
30000040000T000090000000P3d0000000000000P3d0000000000080000U0000300000T0000C0000
30000040000U0000300000P0081F0000>00004l5001^0000G0D00;8000070000n5@<2RQE30XXENP6
R5GX1XQE30ZhE@`:F5DH2bD0000<00001`00P1<0000<00000@0002D0000<00000000P2@0000T0000
0020@@00000000000020@@00000000000P0004H0001T0000F00004E=AR/8@0d2A00003P000024<3K
00000=h0000000000020?`80000200000P000000044200000000008@`=/000000000oaE0300@0000
100000d0000T000090000000P3d0000000000000P3d0000000000080001O0000>00000L0000h0000
000003P00000000000010100000000000000000000000000000002D0000<00001`0002D0000<0000
1@00P5H0000h0000CPD006d0001M1@00/`0000L0003hE0`::5D<2RQEj0J8ENP6R5D<2[QE30YHEAP;
9@0000`0000700209@0000`000000020900002@00000081100000000000008110000000000020000
:00000`0000700008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000000004H0000D0000
200004M4BD<30000AP0002P0000L0000AdA9@`80001:1@00F00006h5001`0000000004H0001@0000
A00004E=AR/Z@000900001P00000080o0000P0000800080o0000P000080:@03070000100003ooooo
0@0004/5F@0R01H08@0000P0001R000030000040000T000090000000P3d0000000000000P3d00000
00000080000U0000300000T0000U0000300000P0081F0000<00004X5001H0000K@D006l000050000
Z5B81JQDj0K8E^P6b5J81JQDR0DU0000300000L0080U000030000000080T000090000000P4400000
00000000P44000000000008000160000S00008000015CDH[240>0T00000d00000Q30f`00003F0000
00000000P3l200000P000000044200000000008@`=/00000ooooo`Q03`</00008000008@`=/40000
040004/5F@1;1Fl0K@E_06d5F@000@615D0?0100000400003P0003X0000<0000200002@0000T0000
0020?@00000000000020?@00000000000P0005l0000h00001`0003P000000000>000000000008040
40000000003oool000000000000000009@0000`0000700009@0000`000050020EP0002`0000n1@00
C00007T5001k000010000:QDR0FXE>P6b5KX1/QFR0DU0000300000L0080U000030000000080T0000
90000000P440000000000000P440000000000080000X0000300000L0000j0000300000X0000R0000
30000?oooom60000700001000015CDH[140000`000000000AP0001@000080000AdA9@`<0000Q0000
200001h0000H0000C`D005X0001Z1@00K`000580001`0@001`000?3oool0000000000000002l0P00
0000000002110780J@1Q06`000000000000000000000000000000000000000000000000000000000
0000000000000000000000D000050000flX2<0X<00010000n7dC00D000000;@12oc:<54B2]`?0000
DA8:g>Qm4`1^[00`M6fd0Fan4`0<0000aK00<6an4`1dKK@130000>[/031/OQ<0M6fd0@H0002lR;@1
I84C00K^031DfDL0T040000000400000E01Q06P0K`1]0640Y7`C00UA5E/4000060000000000<0000
2@0000D000030000000003<00000000000000040003140X;cKL1<00000000000;e@EF`00003140X>
0000054B2]c140X>^Q01?GA]]04>^]5g37dC06Af00P000009@0000`0000700009@0000`000010000
DP000701000:0000l?ooo`0000000000000009010001000000008440LP1Y0640K000000000000000
00000000000000000000000000000000000000000000000000000000000000001@0000D0003KbP8`
2P`00040003hOA<01@000000]04;o<X`DA8:g100001A4P[Lj7dC06j/033hS[@1K7hC00`00035/00`
K7hC0?R>]04<0000j^`0<6an4`3hS[@11P0009C>]05TPA<01^h0<5CIA`2@0@0000000@00001D0640
J01_06d0H@2TO1<02E4EF`@0000J0000000000`0000:00001@00008000000000<`00000000000000
0@0004lA2W3=]`4`00000000000_E1EK000004lA2WL00000DA8:g4lA2WNj404mn8jd0@jjdGL<OA<0
I7H02000000U0000300000X0000U000030000040000U0000300000L0000U0000300000d0080U0000
30000040000U0000300000L0000D0000300000d0000B000030000040001D0000E00004l5001K0000
F0D006d000010000003j@@00nT5?1@00F`000040001<00000000000000000000oooooooooom@0000
HP0000X0000U000030000040001D0000E00005T5001K0000G@D006`000010000003j@@00nT5I1@00
F`000040001<00000000000000000000oooooooooom@0000:00000D0000U0000300000X0001D0000
E00005h5001J0000H@D006`000010000003j@@00nT5N1@00FP000040001<00000000000000000000
oooooooooom@0000M00000@0000U000030000040001D0000E00006D5001K0000J@D006`000010000
003j@@00nT5U1@00F`000040001<00000000000000000000oooooooooom@0000:@0000D0000U0000
300000d0080R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
600000`0003/0`003`800280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
0000P2D0000<00003@00P4H0000X0000700004M4BD<20000LPD004l0002o1@00I@00000000160000
500000P00017A4U30`000240000800007P0001P0001f1@00D@000;/5001S00009@0000`000020000
9@0000`0000=00209@0000`000020000500000`0000=00004P0000`000010000E00008P0001f1@00
D@000;D5001P00000@000000nT400?Y1MPD00540000:0000C00000000000000000000?oooooooooo
H00004D0KP1f06T0LP1_06d0I@1^07@02@0000L0000500000`0000@0000700002`0000L000070000
100002D0000<00003@00P280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000H000030000>`3000?0P008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000000209@0000`0000=0020AP0002P0000L0000AdA9@`80002?1@00H`0009h5002;0000
000004H0000<0@00004004E=AR/Z@000900001P00000080o0000P0000800080o0000P0000808@102
X00009@000024<3K00000=h@00000000ZjZZ?`80003o00000P00000004420000000005P000024<3K
0000004000020000EUEE@00000000000000000008440080o0000000000000000000001`000024<3K
0`00001P00020?co00000?koo?l00H7o0Q30f`000000003o240A0bP0000L00000Q30f`<00000@000
T0F:09P5RP2H1FD00041@aE04@0@000010000100000X0000300000T0000Q000020000680000<0000
0@0002@0000T00000020?@00000000000020?@00000000000P0005l0000h00002@0003P000000000
>000000000004P40400000000000000000000000000000009@0000`0000900009`0001P0000;0000
00000000000000009@0000`0000;00004`0000`000020000>`0000P0000K000040000?QH002>2000
F@0002P00000000000000?oooooooooo0`0007QISPQ^FIP8KUV@1UP0000d000000000000003ooooo
ooooo`H0001^FHX6LeV51WQIQ@InFHD6PeV:1X=IT0Hf0000400008=I002H2000F00002P000000000
00000?oooooooooo0`0008=IWPQnFJ<8N5VS23H0000@0000n5P00:<8001H0000=000000000000000
ooooooooool60000leRS2>iHWPS^F9P8kURC2?=HSPShF8h8?@0000P0000K0000400003QI00381P00
F@0002@00000000000000?oooooooooo0P0007QIB0JhFLP6?@0000P0000l0000200003l0000H0000
S@D006<0002M1@00S00001<0000<00000@0002D0000<00000000P2D0000<00001`00P2@0000T0000
0020@@00000000000020@@00000000000P0002P0000<00002@000280000<0000ooooodH0000L0000
400004E=AR/4@0003000000000160000500000P00017A4U30`0004H0000X0000700004M4BD<20000
b`D00800001C1P00U000000000160000D00004@00015CDH[:T0002@0000H00000020?`0008000020
0020?`00080000202T00`1`0000@0000ooooo`40003;1H00R00D02P0000<00002`00024000080000
HP0000`000010000900002@00000080m000000000000080m00000000000200009`0001P0000;0000
00000?ooo`0000009@0000`0000;00009@0000`000080020EP000300003:1@00O`0005<6002D0000
1@000:QLn0NXG3P9:6Dh2BQUn0NXG?P79@0000`0000700209@0000`000000020900002@000000811
000000000000081100000000000200008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000
000004H0000D0000200004M4BD<300008@0000P0000N000060000<h500210000D0H009<0000U0000
300000H0000U0000300000d0080U0000300000H0000D0000300000d0000B000030000040001D0000
^0000<h500220000?@H0098000010000003j@@00nT7>1@00PP000180001<00000000000000000000
oooooooooom`0000DP1U07<0L01Y0780H@1d06l0LP1i0200801d0780H@1S07@02`0000P000080000
200000<000050000200000@0000800001@0000L000040000100000@000050000200000P000040000
9@0000`0000=00208P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001P0000<0000k0<000l2000R000030000?oooolH000030000000000I000030000?ooo`0U0000
30000000080U0000300000d008160000500000P00017A4U30`0001P0000<0000000001T0000<0000
oooo02D0000<00000000P2D0000<00003@00P280000<0000ooooodH0000d0000:00004E=AR/Z@000
900001P00000080o0000P0000800080o0000P000080Q000020000680000<00000@0004`0001T0000
0`D005P0003N1P00b`4000<5001H0000g04007@1000Y0:X0000000000000080o000000000000080o
0000000000000000000000000000000000000000000R000030000?oooom60000700001000015CDH[
0T0000`0000000003P0001@000000000400001@0
\>"], "Text",
 ImageSize->{417.25, 336.625},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Fig. 1 Conceptual ICRP Model applied for particle intakes by inhalation. The \
particles are deposited in some compartments of the RT. From the RT the flow \
goes to the ST (Stomach) or to B. \[OpenCurlyDoubleQuote]Rest of Body\
\[CloseCurlyDoubleQuote] represents the systemic compartments, the detailed \
flow diagram is specific to each kind of element. The dashed arrows mean that \
the flow can be follow this way or not, depending on the characteristic of \
the element. The particles are eliminated through faecal or urine excretion. \
The disintegration can be considered as elimination from each compartment to \
away from the system; it is given by the disintegration constant of the \
isotope.\
\>", "Commentary"],

Cell[TextData[{
 "The format applied to introduce the inputs depends on whether it is used \
BIOKMOD directly or ",
 ButtonBox["BiokmodWed",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://www3.enusa.es/webMathematica/Public/biokmod.html"], None}],
 ", a friendly interface to run BIOKMOD using a web browser. The user can \
modify the respiratory tract and gastrointestinal tract parameters included \
by default. The reference worker parameters are used by default. Three kinds \
of intake way (injection, ingestion or inhalation) can be chosen. The day (d) \
will be used as unit of time. The radioactive decay constant, in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["day", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 ", of the isotope must be introduced by the user. More details can be found \
in the BIOKMOD Help (more than 300 pages). We summarize below the equations \
used by BIOKMOD."
}], "Text"],

Cell[TextData[{
 "If we consider a single intake ",
 StyleBox["I",
  FontSlant->"Italic"],
 " at ",
 StyleBox["t",
  FontSlant->"Italic"],
 " = 0 then the content ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["q", "i"], "(", "t", ")"}], TraditionalForm]]],
 " in each compartment ",
 StyleBox["i",
  FontSlant->"Italic"],
 " of a ",
 StyleBox["n",
  FontSlant->"Italic"],
 "-compartmental system at time ",
 StyleBox["t",
  FontSlant->"Italic"],
 ", is given by\t "
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["q", "i"], "(", "t", ")"}], " ", "=", " ", 
   RowBox[{"I", " ", 
    RowBox[{
     SubscriptBox["u", "i"], "(", "t", ")"}]}]}], 
  TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["u", "i"], "(", "t", ")"}], TraditionalForm]]],
 " is usually called the unit impulse-response function. It can be \
represented with the following pattern"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["u", "i"], "(", "t", ")"}], "=", 
   RowBox[{
    SubscriptBox["F", "i"], "(", 
    RowBox[{
     SubscriptBox["l", "1"], ",", "...", ",", 
     SubscriptBox["l", "m"], ",", " ", 
     SubscriptBox["s", "p"], ",", " ", 
     SubscriptBox["s", "pt"], ",", " ", 
     SubscriptBox["s", "t"], ",", " ", 
     SubscriptBox["f", "1"], ",", " ", 
     SubscriptBox["\[Lambda]", "1"], ",", "...", ",", " ", 
     SubscriptBox["\[Lambda]", "n"], ",", 
     RowBox[{
      SubscriptBox["h", "1"], "..."}], ",", " ", 
     SubscriptBox["h", "r"], ",", 
     SubscriptBox["\[Lambda]", "R"], ",", "t"}], ")"}]}], 
  TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "i"], TraditionalForm]]],
 "denote the rate transfers for RT compartments, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", "i"], TraditionalForm]]],
 " the rate transfers for GI compartments and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "1"], TraditionalForm]]],
 ", \[Ellipsis], ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["h", "r"], TraditionalForm]]],
 "  the rate transfers for systemic compartments, and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", "R"], TraditionalForm]]],
 " is the decay constant of the isotope; ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["u", "i"], "(", "t", ")"}], " "}], TraditionalForm]]],
 "is a sum of exponentials  [see  e.g.:Sanchez and Lopez-Fidalgo 2003], that \
is "
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{"\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["u", "i"], "(", "t", ")"}], "=", " ", 
    RowBox[{
     UnderscriptBox["\[Sum]", 
      RowBox[{"r", "=", "1"}]], 
     RowBox[{
      SubscriptBox["a", "r"], 
      SuperscriptBox["e", 
       RowBox[{
        RowBox[{"-", " ", 
         SubscriptBox["k", "r"]}], "t"}]]}]}]}]}], 
  TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
 "The predicted value for a kind of bioassay ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]]],
 " (lung retention, urine excretion, etc.) after an acute input \
\[OpenCurlyDoubleQuote]1\[CloseCurlyDoubleQuote] at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", "0"}], TraditionalForm]]],
 ", represented by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["r", "m"], "(", "t", ")"}], TraditionalForm]]],
 ", is obtained by the sum of the content of one or several compartments \
[Lopez-Fidalgo and Sanchez 2005]. It will also be a sum of exponentials"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{"\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["r", "m"], "(", "t", ")"}], "=", " ", 
    RowBox[{
     UnderscriptBox["\[Sum]", 
      RowBox[{"v", "=", "1"}]], 
     RowBox[{
      SubscriptBox["a", "v"], 
      SuperscriptBox["e", 
       RowBox[{
        RowBox[{"-", " ", 
         SubscriptBox["d", "v"]}], "t"}]]}]}]}]}], 
  TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "v"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "v"], TraditionalForm]]],
 " are the coefficients obtained solving the model for the specific case. \n\
This pattern is applicable for inhalation, ingestion or injection. In fact \
the ingestion can be considered a particular case of inhalation where the \
intake I happens directly in the stomach. In the same way, the injection is a \
particular case of ingestion where the intake I happens directly in the \
blood. \nIn the case of inhalation eqn(4) can be written as "
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{"\[IndentingNewLine]", 
   RowBox[{
    RowBox[{
     SubscriptBox["r", "m"], "(", "t", ")"}], "=", " ", 
    RowBox[{
     UnderscriptBox["\[Sum]", 
      RowBox[{"j", ",", "v"}]], 
     RowBox[{
      RowBox[{
       SubscriptBox["IDF", "j"], "(", "p", ")"}], 
      SubscriptBox["c", 
       RowBox[{"j", ",", "v"}]], " ", 
      SuperscriptBox["e", 
       RowBox[{
        RowBox[{"-", " ", 
         SubscriptBox["d", 
          RowBox[{"j", ",", "v"}]]}], " ", "t"}]]}]}]}]}], 
  TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
 "The mathematical criteria applied to obtain ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["q", "i"], "(", "t", ")"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["r", "m"], "(", "t", ")"}], TraditionalForm]]],
 " are described in Sanchez and Lopez-Fidalgo 2003. To simplify the notation \
we will write ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "(", "t", ")"}], TraditionalForm]]],
 " instead of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["r", "m"], "(", "t", ")"}], TraditionalForm]]],
 ". We will call ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "(", "t", ")"}], TraditionalForm]]],
 " standard retention function when we refer to an impulsive input \
\[OpenCurlyDoubleQuote]1\[CloseCurlyDoubleQuote] at ",
 StyleBox["t",
  FontSlant->"Italic"],
 " = 0. In other cases we will refer it as retention function, written ",
 Cell[BoxData[
  FormBox[
   RowBox[{"R", "(", "t", ")"}], TraditionalForm]]],
 ". Below we summarize how ",
 Cell[BoxData[
  FormBox[
   RowBox[{"R", "(", "t", ")"}], TraditionalForm]]],
 " is computed for different cases. \nThe analytical solutions given by the \
program can not be checked directly with other programs because in our \
knowledge there are no others with this capability. For this reason we have \
compared the numerical solution for acute intakes given by BIOKMOD for \
different times with the solutions given in the ICRP 78 obtaining a good \
match."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Single intake", "Subsection"],

Cell[TextData[{
 "The retention function ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["R", "A"], "(", "t", ")"}], TraditionalForm]]],
 " for a single or acute intake ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "0"], TraditionalForm]]],
 " at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "=", " ", "0"}], TraditionalForm]]],
 " is given by "
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["R", "A"], "(", "t", ")"}], " ", "=", " ", 
   RowBox[{
    SubscriptBox["I", "0"], " ", 
    RowBox[{"r", "(", "t", ")"}]}]}], TraditionalForm]], "NumberedEquation"],

Cell["It can be computed using the BIOKMOD functions:  ", "MathCaption"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{
   StyleBox["LungsRetention", "Input"], 
   StyleBox["[", "Input"], 
   StyleBox[
    RowBox[{
    "Intake", ",", " ", "IFD", " ", ",", " ", "FRA", ",", " ", "t", ",", " ", 
     "\[Lambda]", ",", " ", "options"}],
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"CompatibilityType"->0,
    "Masked"->False,
    "Outline"->False,
    "RotationAngle"->0,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Underline"->False}], 
   StyleBox["]", "Input"]}]]],
 " or ",
 StyleBox["BioakdataReport[", "Input"],
 StyleBox["element, \"IntakeWay\", \"IntakeType\", Report, ", "Input",
  FontSlant->"Italic"],
 StyleBox["Intake, IFD , FRA, t, \[Lambda], options",
  FontSlant->"Italic"],
 "] chosing as ",
 StyleBox["\"IntakeType\" -> Acute. ", "Input",
  FontSlant->"Italic"],
 "It is also computed when the intake type it is not indicated."
}], "DefinitionBox"],

Cell[TextData[{
 "This example shows the lung retention as a function of initial deposition \
fraction (IDF) ",
 StyleBox["t",
  FontSlant->"Italic"],
 " days after an acute intake (",
 Cell[BoxData[
  FormBox[
   RowBox[{"I", " ", "=", " ", "1"}], TraditionalForm]]],
 " at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", "0"}], TraditionalForm]]],
 ")  of radioactive aerosols type S and AMAD 5 \[Mu]m."
}], "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Collect", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"LungsRetention", "[", 
     RowBox[{"1", ",", 
      RowBox[{"{", 
       RowBox[{
        SubscriptBox["IDF", "AI"], ",", 
        SubscriptBox["IDF", "\"\<bb(fast+seq)\>\""], ",", 
        SubscriptBox["IDF", "bbslow"], ",", " ", 
        SubscriptBox["IDF", "\"\<BB(fast+seq)\>\""], " ", ",", " ", 
        SubscriptBox["IDF", "BBslow"], ",", "  ", 
        SubscriptBox["ET", "2"], ",", " ", 
        SubscriptBox["ET", "1"]}], "}"}], " ", ",", "S", ",", " ", "t", ",", 
      "0"}], "]"}], "//", "Chop"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["IDF", "AI"], ",", 
     SubscriptBox["IDF", "\"\<bb(fast+seq)\>\""], ",", 
     SubscriptBox["IDF", "bbslow"], ",", " ", 
     SubscriptBox["IDF", "\"\<BB(fast+seq)\>\""], " ", ",", " ", 
     SubscriptBox["IDF", "BBslow"], ",", "  ", 
     SubscriptBox["ET", "2"], ",", " ", 
     SubscriptBox["ET", "1"]}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[4]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.0002477542435107005`"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110.1`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0012387712175536691`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "102.1`"}], " ", "t"}]]}], "+", 
     RowBox[{"6.986020965054837`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.1`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.2480022457564893`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "+", 
     RowBox[{"1.2400112287824465`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.0001`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0069930139790349444`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0001`"}], " ", "t"}]]}]}], ")"}], " ", 
   SubscriptBox["IDF", "\<\"bb(fast+seq)\"\>"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"0.000991016974042802`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110.1`"}], " ", "t"}]]}], "+", 
     RowBox[{"6.986020965054837`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.1`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.9920089830259572`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0069930139790349444`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0001`"}], " ", "t"}]]}]}], ")"}], " ", 
   SubscriptBox["IDF", "\<\"BB(fast+seq)\"\>"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"1.6522149597360367`*^-7", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110.1`"}], " ", "t"}]]}], "-", 
     RowBox[{"4.160990610320783`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "102.1`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0003030312124272516`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.11999999999999`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0005991612638047705`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.101`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.00008317290463989713`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.10012`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.000016633383250131556`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.1`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0001653868828564822`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.004165155766087867`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.0001`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.30333454697424916`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0201`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.599761024829842`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0011`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.08325616080071588`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.00022`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.016650033283416535`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0001`"}], " ", "t"}]]}]}], ")"}], " ", 
   SubscriptBox["IDF", "AI"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1.2565127978773384`*^-6"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110.1`"}], " ", "t"}]]}], "-", 
     RowBox[{"8.73252620631898`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "102.1`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.001001006013046979`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.13`"}], " ", "t"}]]}], "+", 
     RowBox[{"6.986020965054837`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.1`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.0012577705684458532`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.008741267473793682`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.0001`"}], " ", "t"}]]}], "+", 
     RowBox[{"1.0020080210681968`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0301`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0069930139790349444`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0001`"}], " ", "t"}]]}]}], ")"}], " ", 
   SubscriptBox["IDF", "bbslow"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "6.986020965054837`*^-6"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110.1`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0009980029950078517`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.13`"}], " ", "t"}]]}], "+", 
     RowBox[{"6.986020965054837`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.1`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.006993013979034945`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.9990019970049921`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0301`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0069930139790349444`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0001`"}], " ", "t"}]]}]}], ")"}], " ", 
   SubscriptBox["IDF", "BBslow"]}]}]], "Output",
 CellChangeTimes->{
  3.3985840278862705`*^9, 3.3985921810653095`*^9, 3.413801561476365*^9, 
   3.480094121615631*^9, 3.480095499198631*^9, 3.4800959613966*^9, 
   3.480156286657*^9, 3.518532187444347*^9, 3.539699021155941*^9, 
   3.5920642877662125`*^9, {3.643609902180356*^9, 3.643609928180395*^9}},
 CellLabel->"Out[4]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Chronic intake", "Subsection"],

Cell[TextData[{
 "The retention function ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["R", "Cr"], "(", "t", ")"}], TraditionalForm]]],
 " for a constant intake ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"I", "(", "t", ")"}], " ", "=", " ", 
    SubscriptBox["I", "d"]}], TraditionalForm]]],
 " (daily rate intake) for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", "T"}], TraditionalForm]]],
 ", at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "=", " ", "T"}], TraditionalForm]]],
 " cease the intake, that is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"I", "(", "t", ")"}], " "}], TraditionalForm]]],
 "for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", ">", "T"}], TraditionalForm]]],
 ", then the retention is given by\t"
}], "Text"],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["R", "Cr"], "(", "t", ")"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["I", "d"], 
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "t"], 
       RowBox[{
        RowBox[{"r", "(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}], "  ", "for", " ", "0"}]}]}], "<", 
     "t", "\[LessEqual]", 
     RowBox[{"T", " ", "and", " ", 
      RowBox[{
       SubscriptBox["R", "Cr"], "(", "t", ")"}]}]}], "=", " ", 
    RowBox[{
     RowBox[{
      SubscriptBox["I", "d"], 
      RowBox[{
       SubsuperscriptBox["\[Integral]", 
        RowBox[{"t", "-", "T"}], "t"], 
       RowBox[{
        RowBox[{"r", "(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}], " ", "for", " ", "t"}]}]}], ">", 
     "T"}]}]}], TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{" "}], TraditionalForm]}], "NumberedEquation"],

Cell["It is computed by the BIOKMOD function ", "MathCaption"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"qConstant", "[", 
    RowBox[{
     FormBox[
      SubscriptBox["I", "b"],
      TraditionalForm], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"r", "[", "t", "]"}], ",", " ", "t"}], "}"}], ",", " ", 
     SubscriptBox["t", "i"], ",", " ", "T"}], "]"}], TraditionalForm]]],
 "  gives the retention the day ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 " after an intake ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "b"], TraditionalForm]]],
 " at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", "0"}], TraditionalForm]]],
 " assuming that it cease the intake at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", "T"}], TraditionalForm]]],
 "."
}], "FramedBox"],

Cell[TextData[{
 "The below figure shows the lung retention for a worker that has been \
exposed from ",
 StyleBox["t",
  FontSlant->"Italic"],
 " = 0 to ",
 StyleBox["t",
  FontSlant->"Italic"],
 " = 2000 day to a chronic intake by inhalation of 3 BqU/day of UO",
 StyleBox["2",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 " enriched  aerosols type S and AMAD 5",
 StyleBox[" \[Mu]m",
  FontFamily->"Times New Roman Greek"],
 ". On the day ",
 StyleBox["t",
  FontSlant->"Italic"],
 " = 2000  xceases the intaken.(Note: The enriched uranium contains   ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "238"], TraditionalForm]]],
 "U, ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "235"], TraditionalForm]]],
 "U and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "234"], TraditionalForm]]],
 "U, for this isotopes  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", "R"], TraditionalForm]]],
 "\[Rule] 0) "
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qLungU5", "[", "t_", "]"}], "=", 
   RowBox[{"LungsRetention", "[", 
    RowBox[{"1", ",", 
     RowBox[{"AMADAdultW", "[", "5", "]"}], ",", "S", ",", " ", "t", ",", 
     "0"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[5]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"qConstant", "[", 
    RowBox[{"3", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"qLungU5", "[", "t", "]"}], ",", "t"}], "}"}], ",", " ", "t1", 
     ",", " ", "2000"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t1", ",", " ", "0", ",", " ", "4000"}], "}"}], ",", " ", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", " ", 
     RowBox[{"\"\<Days\>\"", ",", "\"\<Bq\>\""}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[6]:="],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJxljms0lAkAhscQ1iVMR5rJiuWMSFYbsWfTvB2zE4udRJhvpE1oOLnbUZKD
nczYo0UXE5nvm3JZKZdVa+2my1pNbWySJokuw24UpdyOGLX29/54z3ueP+/z
2kUl7Yih02g03lL+67FJbQAv1pJDo113rDCZ2XKnxpDNPTPFoaXTKxfruzn3
TbIEzDO6yEkb2utR+4TTd81jSvfMCoDx/qZpzyuOoIyBd0p7KCPq8kuHtByW
fu7zKeVGoEA+M51vjMzNrZ+/VfpAVv5E7SFmwqJ1TcOcNxde2oUBjQMLtRul
n9AGuMg5z3T9+h4LaudQYzNLHmqPQ0fmZA035vSgS4Ev1oZleey8bYORmU9z
RCmBmKseiKt6ZYe6vuDhCWUwTh1KTU1uYsNW3uy/fDYY3F03Xcc+sFEaanHJ
xT8Ec6Z1WlO+I/LUdyRxMyHIuir8JXjcEYJeP/awXyiq4vV/XWHvBMNuTtyD
yXBUzWt4/XnrEKNaN9HGjURmAbt0j5Ebih/lLnLTo9HG6K3ZI3BHLyU9XbI3
Eal5D68Hqr4AL/yyz2HzdLyejHHme2+F30JUxWD4QTS7dG7QlnNRVGB3dYGX
jeONgqIqyTZsYfpqorpzUdG4yChK/QrHrr+bvZMoQc+hEL+X1oGQPd70lqXJ
hzjgxW5+Ah89Bl0Rm2UFYHCWZdzSbEfbj+MXvOmFsIE2QOd5ECTlUnNV0g8Q
wdCz5f4O8AOvTFoUFKMq2SHwnioYrrKs7qY/SvDou+oyh/IQtPw5Ev3bquO4
aysly5N3ot7dXCLddwJD7qqJYo9QiInskx3USXStis2zHgrFaP6p3fsnS9Eu
F61mHAuDc+LcaonrKahHZ9uULuFYGaFXon+kDDHv7t+KuR2OlLS/igLU5SCU
40FbIwQgvxzMoZtVwJ/t4Dg8KEC6jdzZfq8Cdj+Tuk+/IdBua5DAFCngyeiZ
uRJFwMI+o9EsQQErsaWkIppAg2OYu1asgHk9/9twEYEXblZb1N8rMGEwUt+Z
RCDSRx4kbVYg+5zoGJVNYJtIfmBMhwQ3vke7eJpAabzBZY0+CTELF+4qCPy9
P2Oxz5iEzXPpwlmKQF5KWF6HJYk3y5iZvEoCbZlWhQonEvSmzHlZHQG3o3KK
H0TC8eN/7LStBFjNctVFJYkIvbIHp9UElp9ztSqpJnEgTdUp6CNAV97Yl1hH
oiZVT2TVT2Ds6JSh0yUSLc+sS0sGl/bj+P7kTRKhqtrO3GECu+0M7spek/DW
JS4GvSUQsoq0jZ0i8biQxjaaIuBr5pHiM0dCdTZya/v00p/FKMZ7HQpeH86l
bphb8vVfDUmzpNARE9Zu/IHAbPfO6u0sCvMHTxz+nSbES9X4zPo1FBy2C4bE
dCF6L7Hko2sptLRqap8tE+LW+Z9GbqyncOPNQ6OTBkK0nfX1qvyMgvWmayv9
PhKiqeypLMeTgjmvoUtrJERVsbh/12YK0eprLk0m/+d/AWPKBVw=
      "]], LineBox[CompressedData["
1:eJwV0fkznAcAh/Ftmqo0QkxjB5sQMW2DsKWO1ru7vqvi2HE0rrWKVoQoyTgS
gjZmSCsoEUFRxr5YwlrvS2tIG2kiW5EIcdUgbpstcTTqCCmq6Q/PfP6Ax+B0
lGfoHgaDYfe6/81OliRpO4qhNtvqQW77IzWOeLwuEMPhqu/pphf+iD/Xzxrw
EMMw98GNnRl/ODmbBTmHiCFvz+noa/TH/K5yxiJTjLBEf9MiX3+wo3wW3x4W
o6/pZyW3WQQes2fWfVyMAI0uvo1MBNc7zoqCGTEYlvsWnCpEiNjPeWq4JAZz
v0Wu7JoIA16az/TfILH6wNMhNlwEjeWNPoJJQvjwnvslfRGuHm+vvwASM6N3
9kQX+eFS8RehinwSgtuNtmPVQlzcZMhFhSS8/Y41WZNCxAorjvYWk3DLH+ku
KBbinJZytLWMRKu8rCg4S4gvcyM8f6ghAW+2xDRWCJeMODuXVhKstsDHGTwh
WInf69AKEjvDrJyNEV/c9WvpTrIoh0rxrbpGHV8EsEJvOI2XY7br9sJcoTca
Yv9mvfy2AjLmBeMinhfO3yTLAgwqoZsVzs5meiJ5suryZmclOiU/0rwXn2Fz
rdvH9SsJmNdm0gMUHjAS/7GSsrcKPOsOqYm2O2hX88VFWRU27iXqTri6omyo
YUJDUI2y2q3EiTYBpkPTTMPXquHXa9SjZ+OC7L7kuIS8m2h0GY12Vzhhuc8n
NYJdA4uPzgYpKUfUDKYu5A7XIDBE7X154kk8au53i4mvBdu2OUsvygG8kgS1
NAMpVv/5enEr5FNEHtrJ+eaRFGfeU0wuxtiDESlRMwmrQ0a8Yqma5GP+93Kl
+kEZHubzwvAE4G63tUgpGXwGBnPVtQGn19+OC+pRVOLWG6LgobpQy350pR6l
E9+lluRxcd4h28zxOoVo9hBbJZqDJ/Y1Wm/lUdC25lkdieTgQ758W15AIeHd
y79ahXGwxn3VyS+hIHFwt48M4CDJJvQst5qC2sK4zZwzB+nGXNKylYJjZiCM
jnEgObikaThHIV/lyK58kICKhuqr6XkKMq+PV/b1EQg/YDhFLlFI9lv2OtVF
wOQdEaW3SsFi8HDws/sEfnqzXaD7L4Wg57/lsRoI3H1ZekXzEA0UZii7Mwkc
XW+J6GXSiD8xdMU4jUDqav+pHB0aZzpj0tNTCDguqx49oE+DaZBy3zmBQNfz
i62qxjRiLW8tjIQSMJvLqew4QWOs9jDFDyZw/U9pZhqbxgr3l35pAAEvxZTf
Xisa6ox8pHgRaJrespPb0Oh17kn/y50Ac4r5QaotDamSYx4oIJAwYa7O59Io
nfz8k+6TBJ6Oua7v2tEYjq4jeXwC/wGeiNuZ
      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"Days\"", TraditionalForm], 
    FormBox["\"Bq\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0, 4000}, {0., 108.1982528565764}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.398584031323279*^9, 3.3985921852319336`*^9, 3.4138015658201985`*^9, 
   3.4800941253596306`*^9, 3.480095503239031*^9, 3.4800959633466*^9, 
   3.4801562918050003`*^9, 3.5185321897256403`*^9, 3.5396990228747234`*^9, 
   3.592064291093979*^9, {3.643609902305354*^9, 3.643609929102274*^9}},
 CellLabel->"Out[6]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Continuous intake", "Subsection"],

Cell[TextData[{
 "The retention function ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["R", "C"], "(", "t", ")"}], TraditionalForm]]],
 " for a continuous intake ",
 Cell[BoxData[
  FormBox[
   RowBox[{"I", "(", "t", ")"}], TraditionalForm]]],
 ", is given by\n"
}], "Text"],

Cell[BoxData[{
 FormBox[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["R", "C"], "(", "t", ")"}], "=", 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "t"], 
     RowBox[{
      RowBox[{"I", "(", "\[Tau]", ")"}], 
      RowBox[{"r", "(", 
       RowBox[{"t", "-", "\[Tau]"}], ")"}], 
      RowBox[{"\[DifferentialD]", "\[Tau]"}]}]}]}], "  "}], 
  TraditionalForm], "\[IndentingNewLine]", 
 FormBox[
  RowBox[{" "}], TraditionalForm]}], "NumberedEquation"],

Cell["It is computed by the BIOKMOD function ", "MathCaption"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"qContinuous", "[", 
    RowBox[{
     RowBox[{
      FormBox["I",
       TraditionalForm], "(", "t", ")"}], ",", 
     RowBox[{"{", 
      RowBox[{"r", "[", "t", "]"}], "}"}], ",", " ", "t", ",", " ", 
     SubscriptBox["t", "i"]}], "]"}], TraditionalForm]]],
 "  gives the retention the day ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 " after an intake ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"I", "(", "t", ")"}], " ", "starting", " ", "at"}], 
   TraditionalForm]]],
 " at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", "0"}], TraditionalForm]]],
 ". "
}], "FramedBox"],

Cell[TextData[{
 "Here it is asumed the lung retention asuming an a continous intake given by \
 ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"I", "(", "t", ")"}], " ", "=", " ", 
    RowBox[{"0.3", "+", 
     RowBox[{"0.3", " ", 
      RowBox[{"Cos", "[", "t", "]"}]}]}]}], TraditionalForm]]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"qContinuous", "[", 
     RowBox[{
      RowBox[{"0.3", "+", 
       RowBox[{"0.3", " ", 
        RowBox[{"Cos", "[", "t", "]"}]}]}], ",", 
      RowBox[{"{", 
       RowBox[{"qLungU5", "[", "t", "]"}], "}"}], ",", "t", ",", " ", "t1"}], 
     "]"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t1", ",", " ", "0", ",", " ", "200"}], "}"}], ",", " ", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", " ", 
     RowBox[{"\"\<Days\>\"", ",", "\"\<Bq\>\""}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[7]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwUV3c4lv8XlijZm1QyM7P3OsfevLxWKGRkVdKShvZOklBmRkZZGRllZZeZ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"Days\"", TraditionalForm], 
    FormBox["\"Bq\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0, 200}, {0., 2.3701330401327203`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.3985840387779765`*^9, 3.3985921938158054`*^9, 3.413801574117233*^9, 
   3.480094133331231*^9, 3.4800955088706307`*^9, 3.480095968479*^9, 
   3.4801563016246*^9, 3.5185321960070114`*^9, 3.539699026531044*^9, 
   3.592064312263172*^9, {3.6436099024772387`*^9, 3.6436099307429132`*^9}},
 CellLabel->"Out[7]="]
}, Open  ]],

Cell[TextData[{
 "It can be also used:  ",
 Cell[BoxData[
  RowBox[{
   StyleBox["LungsRetention", "Input"], 
   StyleBox["[", "Input"], 
   StyleBox[
    RowBox[{
    "Intake", ",", " ", "IFD", " ", ",", " ", "FRA", ",", " ", "t", ",", " ", 
     "\[Lambda]", ",", " ", "options"}],
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"CompatibilityType"->0,
    "Masked"->False,
    "Outline"->False,
    "RotationAngle"->0,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Underline"->False}], 
   StyleBox["]", "Input"]}]]],
 " or ",
 StyleBox["BioakdataReport[", "Input"],
 StyleBox["element, \"IntakeWay\", \"IntakeType\", Report, ", "Input",
  FontSlant->"Italic"],
 StyleBox["Intake, IFD , FRA, t, \[Lambda], options",
  FontSlant->"Italic"],
 "] chosing as IntakeType\[Rule]\"Continuous\"."
}], "MathCaption"],

Cell["\<\
The example represents a biexponential input (I(t) = 0.6 Exp[-10.2 t]+0.02 \
Exp[-6.0 t]) of iodo-131 by injection and the corresponding solution.It is \
been chosen that output gives the retention function for typical \
bioassays,but other output reports are available such as graphics \
representation,retention function for each compartment,or number of \
disintegrations accumulated in each compartment.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "iodine", ",", "\"\<Injection\>\"", ",", " ", "\"\<Continuous\>\"", ",", 
    "\"\<Automatic\>\"", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       RowBox[{"0.6", " ", 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "10.2"}], " ", "t"}], "]"}]}], " ", "+", 
       RowBox[{"0.02", " ", 
        RowBox[{"Exp", "[", 
         RowBox[{
          RowBox[{"-", "6.0"}], " ", "t"}], "]"}]}]}], " ", ",", "t"}], "}"}],
     ",", "1", ",", "t", ",", 
    RowBox[{
     RowBox[{"Log", "[", "2", "]"}], "/", "8.0"}]}], "]"}], "//", 
  "Chop"}]], "Input",
 CellLabel->"In[8]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qDailyUrine", "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"10999.177804495737`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t"}]]}], "-", 
     RowBox[{"2461.1978323402345`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "10.2`"}], " ", "t"}]]}], "-", 
     RowBox[{"1.5202263126739002`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "6.`"}], " ", "t"}]]}], "+", 
     RowBox[{"1.2030336848660466`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240243`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.00010668672573523443`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567382675`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.00009883925231888441`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935381`"}], " ", "t"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qDailyFaecal", "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "3.881279260290757`*^-6"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "10.2`"}], " ", "t"}]]}], "-", 
     RowBox[{"8.52054479685508`*^-8", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "6.`"}], " ", "t"}]]}], "+", 
     RowBox[{"5.522341246040508`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240243`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.00001249672861945116`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.886643397569994`"}], " ", "t"}]]}], "-", 
     RowBox[{"8.418895759885914`*^-7", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699932`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.000013593088741831927`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699934`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.000040826778233410107`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567382675`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.000035549576903507775`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935381`"}], " ", "t"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qWholebody", "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"0.06758169937914833`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.15909500062383783`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "10.2`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.007502633414605772`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "6.`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.08020641089949089`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240243`"}], " ", "t"}]]}], "-", 
     RowBox[{"2.474772488083773`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.886643397569994`"}], " ", "t"}]]}], "-", 
     RowBox[{"1.667224458582014`*^-7", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699932`"}], " ", "t"}]]}], "+", 
     RowBox[{"7.910861022153858`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699934`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.0023795290470355534`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567382675`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.021183783440751693`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935381`"}], " ", "t"}]]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.398584039562681*^9, 3.3985921945833416`*^9, 3.4138015749141235`*^9, 
   3.4800941362640305`*^9, 3.4800955092606306`*^9, 3.480095968791*^9, 
   3.480156303883*^9, 3.518532196460145*^9, 3.5396990268904257`*^9, 
   3.5920643128769712`*^9, {3.6436099025241055`*^9, 3.643609930914772*^9}},
 CellLabel->"Out[8]="]
}, Open  ]],

Cell[TextData[{
 "The below example represents the daily faecal and urine excretion  for an \
acute intake ",
 Cell[BoxData[
  FormBox[
   RowBox[{"I", " ", "=", " ", "1"}], TraditionalForm]]],
 " Bq at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", "0"}], TraditionalForm]]],
 "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "iodine", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "1", ",", "180", ",", 
   RowBox[{
    RowBox[{"Log", "[", "2", "]"}], "/", "8.0"}]}], "]"}]], "Input",
 CellLabel->"In[9]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwd13k8VF8bAPCZO7ZsWSbJeockS5ZoSHJOSFpJogilkhQttFBZUtmyRCpE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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV13k4VdsbB/Bz9j6OIYSO27ll3uY5MiTarzI1SUhdY8YrFRKXVIYmylCh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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -26.578420936596494`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-26.578420936596494`, 1.8405131283573786`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Acute intake in t = 0\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{
  3.398584042434702*^9, 3.3985921978571177`*^9, 3.4138015830549045`*^9, 
   3.4800941378084307`*^9, 3.480095510118631*^9, 3.4800959692746*^9, 
   3.480156313789*^9, 3.5185321972414103`*^9, 3.5396990278123183`*^9, 
   3.5920643152134085`*^9, {3.6436099025553555`*^9, 3.643609931071026*^9}},
 CellLabel->"Out[9]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Multiple single intakes", "Subsection"],

Cell[TextData[{
 "For multiple single inputs: {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "1"], TraditionalForm]]],
 ", \[Ellipsis], ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "i"], TraditionalForm]]],
 ", \[Ellipsis] , ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "n"], TraditionalForm]]],
 "} that happen at times: {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "1"], TraditionalForm]]],
 ", \[Ellipsis], ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ", \[Ellipsis]",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "n"], TraditionalForm]]],
 "}, where ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "\[Dash]", " ", 
    SubscriptBox["t", "i"]}], TraditionalForm]]],
 " is the time since the input ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "i"], TraditionalForm]]],
 " occurred. Then, taken ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["t", "0"], " ", "=", " ", "0"}], TraditionalForm]]],
 ", the retention function, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["R", "M"], "(", "t", ")"}], TraditionalForm]]],
 " is given by . \t "
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["R", "M"], "(", "t", ")"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["I", "1"], 
        RowBox[{"r", "(", "t", ")"}]}], " ", "+", " ", 
       RowBox[{
        SubscriptBox["I", "2"], 
        RowBox[{"r", "(", 
         RowBox[{"t", "-", 
          SubscriptBox["t", "1"]}], ")"}]}], "+"}], "..."}], "+", 
     RowBox[{
      SubscriptBox["I", "n"], 
      RowBox[{"r", "(", 
       RowBox[{"t", "-", 
        SubscriptBox["t", 
         RowBox[{"n", "-", "1"}]]}], ")"}]}]}], "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "n"], 
     RowBox[{
      SubscriptBox["I", "i"], 
      RowBox[{"r", "(", 
       RowBox[{"t", "-", 
        SubscriptBox["t", 
         RowBox[{"i", "-", "1"}]]}], ")"}]}]}]}]}], 
  TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
 "If the time is considered to be a discrete variable measured in days and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "j"], TraditionalForm]]],
 " represents the intake that happened on the day ",
 StyleBox["j",
  FontSlant->"Italic"],
 ", then the previous equation can be written:"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["R", "M"], "(", "t", ")"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        SubscriptBox["I", "1"], 
        RowBox[{"r", "(", "t", ")"}]}], " ", "+", " ", 
       RowBox[{
        SubscriptBox["I", "2"], 
        RowBox[{"r", "(", 
         RowBox[{"t", "-", "1"}], ")"}]}], "+"}], "..."}], "+", 
     RowBox[{
      SubscriptBox["I", "n"], 
      RowBox[{"r", "(", "1", ")"}]}]}], "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"j", "=", "1"}], "t"], 
     RowBox[{
      SubscriptBox["I", "j"], 
      RowBox[{"r", "(", 
       RowBox[{"t", "-", "j", "+", "1"}], ")"}]}]}]}]}], 
  TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
 "It is computed by the BIOKMOD function ",
 StyleBox["qMultiple.", "Input"]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", 
  StyleBox["qMultiple", "Input"]}]], "Input",
 CellLabel->"In[10]:="],

Cell[BoxData[
 StyleBox["\<\"qMultiple[inputsdata,{u[t],t}, tt] gives the \\nretention the \
time tt for multiples(constant:{...,{bi,ti,Ti},...}\\nand \
singles{...,{bi,ti},...})inputs,being u[t] the unit-inpulse\\nresponse\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.643609931164774*^9},
 CellTags->"Info3643617131-9686839"]
}, Open  ]],

Cell[TextData[{
 "Example.- A worker started to work in an area exposed to UO2 (AMAD 5 \[Mu]m \
 and type S) radioactive aerosols starting the day ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "=", " ", "0"}], TraditionalForm]]],
 ". The quantities intaken  since then has been ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{"I", ",", " ", "t"}], "}"}], TraditionalForm]]],
 ": "
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"intakendata1", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"5", ",", "0"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"3", ",", " ", "2"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"2", ",", " ", "3"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"2", ",", " ", "4"}], "}"}], " ", ",", " ", 
      RowBox[{"{", 
       RowBox[{"3", ",", " ", "7"}], "}"}], " ", ",", " ", 
      RowBox[{"{", 
       RowBox[{"8", ",", " ", "9"}], "}"}]}], " ", "}"}]}], ";"}], 
  "  "}]], "Input",
 CellLabel->"In[11]:="],

Cell["\<\
So, the estimated lung retention since the started the first inkake can be \
represented as follows:\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"qMultiple", "[", 
     RowBox[{"intakendata1", ",", " ", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"qLungU5", "[", "t", "]"}], ",", "t"}], "}"}], ",", " ", 
      "t1"}], "]"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t1", ",", " ", "0", ",", " ", "20"}], "}"}], ",", 
   RowBox[{"ExclusionsStyle", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"Blue", ",", "Blue"}], "}"}]}], ",", " ", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", " ", 
     RowBox[{"\"\<Days\>\"", ",", "\"\<Bq\>\""}], "}"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.4800953851002307`*^9, 3.4800953918862305`*^9}},
 CellLabel->"In[12]:="],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwV0nk41NsfB3By0227EXW1oZJKYnDbKO+KKKmkfo8lZatr7ae6qrFE0WIJ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      "]], LineBox[CompressedData["
1:eJwllGtMkwcUhr+vpf1YmJYZCoMVnbZonDjRIRelnuNQVCiolQ0viE4pFPAG
YSpWEUNlU4EN3UQZ3QaiXBSLixd03HSzboCIyFS2CucDCpV5RYYGTVmX/Tg5
ef68yZvn5EzcsFWtETAME2Kf/7b2jGTMK47Byc6D+st/8uDEv+lROTOYfUy+
x9bCg21103CbJ4PrlHEHpbU8WCK0sq4ABrfh3NwThTy4mDYp0hcyGF7fWNiY
y8PHymRvTzWDDQGm2xX7ePhx2q6gNUkMpmoqZRsTeLhVnL5gZAeD/GLJHa8Y
e757puq4nkFd+un7n6/gIdoxO/qegcHdaSkuBuDh0N6vY7dXMBgWmhep8ePh
yvA3m6SXGHw0rGgvnM6Dm8Wwe0Urgx7x83LQk4eQ6GL9oJnBi6YvPiqS8pB6
51R23kMGy12fWVaN5aHtqrHwloDFCn8b1TM8sIHnS7ZIWPS58tA9doTAp6r6
zBgZi7sNZ/0ihghyvr9aEzabRb7lpanXSlAjNf06MJ/FY3rvCQd7CAayG5sP
RLDom3vbM76TYLHujvlGPIsF1ihxTTvBjsF7vXGpLNoOSaM/bCU4lWB+JNrH
onnA+MHNJgLhSsub4AIW51xyr8/6haDO96WsoZlFi5eVNZ4neHz6tWJdB4s7
c+QhS84RyOTMdJuFxcUlk9TMWYK0d95SBo2y2LDly/66UgLfJx5rq2cKcLpR
WbCqkGCjZoImap4AWzIfOlw4TnDYLN88HCrAUKVtlzyf4Gmj9x7fWAEqiv17
Zx8mqCidZ6g6KsCpQZIn7gcIOsYHn1x6QoAXWp/mDmcROB5dVPnEKMD11xu9
SE+g0S+r9f5dgEKFdeBeBsH7n214UPZagHlrlqWHpRHke2R5Fq0X4ua7/bGW
JILhnpbSiC1CPJW0cOycRILISrdZb3RCdHIu0h/VEozD8pCofCHKrs8o1WgI
sjXNW8e0CHHnqpqIT9YRZFSNu5Y21wEVeFO7JJKgM22NasoSB9ywVx9vUxMo
g0vutn/qgBVLo/ovLScY+WP23zNSHDBxoNvqv5Qg9fVKl74yB7yb6FGjDSXQ
hvwQp3YV4cWTJ/t3zCcwSazPRuUiXBQ0tF2LBF4dPrrKmSLMuPDSKRoIupOu
feUYLsKEwRtilZIgOs9SXZcpwoJHfobwQIJl5mlO056L8Eif4FbTTILAlGqj
sFmMi0L/eZyoIGgdnRuT3CFGt5+6isrkBHE59W939YnRZ/IIY51k91NmSrjC
chgw1bksaaL9vjrb5cn+HPoVlbzYP97ef9PKts4FHFatdlzd6kngOvJXhkrN
oaoiUCmzc7C058GUzRwW+LfFVr9HUBj2PL+zmMPuA9+Vs+4EszpSQ1RVHFoa
0uKi3iX4Le7V0OVaDmU+kp1n3QhihnQnpjRxGK6u7hDbeWjf6PJv73O49nFv
1npXgoOSTEbYx6H5iJvuZ6ndt0Fs3PaCw/HelnNudt7z/0NBHenrulwI/gVa
nAZw
      "]], LineBox[CompressedData["
1:eJwV1H881AcYB/DrKN/vHd/v6Ha11JYfpZo0JpMXnocuG/LrwrJKEiZa16SY
l6KSaRRynbbapdzrjCLlxU6xVpOWtmKVVsjWPWdqJeyyXpHt+uN5Pa/3f5/X
8zyvxy5eIU8UCgSCAFO97nvLVw2PWjB43aZ6riLYACE6K8uVHIMHRdYlnisM
QCtKzzfbMii4q3Vo9zRA1i3JJqeFDE7Y2HbMXWwA7ZBtu1DG4HCTmV/XDAN4
Zx9P3xrBoPn1faqpnAF+Yx0cHsQyGB12SthqboBJx0W5zV8wWC27oir9h0B5
rtbF6UsGF2+3zz3+N8EidO1TKhmUru7PsCaC6DWeXlvPMJiisMtluwmeDF4Y
7Gth8NOglMK8mwR7dkB5cAeDgxouP+QawZnSAON8A4Ppy/tHmloJAt7pOKkc
ZbCIaRsK1RH0ng6JEApYfNzWMOjQQMD8HFnXN4tFeNpVu6OaIG4yPlkZzqI0
8pJf8hGCscIBqTCWRcumaOdiJUHRWylXFKksDkpkD3tKCJrdP7cPzmex98wa
rwf7CcIvGzt1ZSz+2FxlLM4nGAjLzJl/gkVVRYJ2/V4Cm9Sc3iktLC6094mX
7yT47oWwUHGNxVdj0YlpWQS++fnL+rpZ7POvDq3JIEg5cUClG2HRj3nUujaN
4Ke7R8MVTiKU9HodO51sml98lPH5+yJcrYm1OJREkPSUO5KNIjzqEifYl0Ag
MtvTvz9GhNzQnBmlcaZ8LslbNIUidK+qm+UWQ2DfbGfz7hERHjB7NLztYwLj
8p7GsxoRrmuf8/bFKILymNBXP7SKsL5yo0EhJ3iQ515075kI/X1yFrmuJKjn
h5bETYhw17Oe4oYg0z6+qbo1wIgxbcdKtXcgwbz6WbZGOzE+CzlbvyGAYHOP
oIaLFKNOusBnBAleuv56dblOjM7juw+OexD80pKf2tEmxu7Da3tvLiVQf4h8
RJcYc+faPK9yJ/Bb1xAd+1iM5ievSja6ERQUfG3InG2JEr1+qdCFQNqfaFaX
a4kzzQ91ds4jcC2a9J0ZaIWWEd7kO4PAbdNEQm20FcrvvKBIKYF7wMuv/BOs
0OlawNTP3iTwEIx1b86xwp28e3bldALv9KdbLjVaYVn5B14L3iD4aG2vOsWe
wxq5efF+liBo2f22/5ZweGpD5YZWhiBY+vtjpQ+HJY6XO0ctCEI7b3lcXM3h
e5n3UuKnEUTKrt+YXszh7Dx7/Soz0705n59sGedwINVnLOuVHuJZnaOc5fG+
dl33lQk9bBxoDPpLyqP5Badxa5OTKs6qrN14/MNrk6DupR42S6pdkpJ59K6b
ssv4rx62jGgjx7fzqC5wtQg0WXFDk1Wyl8eovIxz6jE9pBVUtJ9X8/iJLHZ9
yHM9bEtUPwk7zaMqdGmM1qiHdP9jNoZmHjnHg4kCkzMmymP5OzzeLv5T+/2o
HjLvHc7TPOQxQVZyW2JyVlNZzbJhHu1kC6ZtG9HDt3tePxQejbq6LrnJ/wNW
4gDH
      "]], LineBox[CompressedData["
1:eJwV0ntUjHkYB/DcEor3nTGVee1sTa7jUi1aKj3PdJWSjlLKUJTskJSIbquL
VJbQjbSSqE5RLaWTkMlpM3ILlVjUon6/EqFIJPvuH895zuef73nO9zyGG7ev
2jRSQ0PDh5//90WrhS2JmgyGr/VV50u74HqBfUqUNoOuB9u2xeh1AWbYGToI
GTwQWbA1Y0IXyHfYODwzYHCoavSah58o3PC1flowk8GTaee8m99QsF4p3xYy
n0Er/QttPi8p2M6FNE1LBmfurHnc0Ujhb7HVjAfWDP65wMnxgZqC/bill7Md
Gaz2/JxlVEvBodO8zcSTwekxEbWvLlIIeNTUk7iOwTXPOgwqzlPYpwr6+sKP
waCJfT4NBRRqT+SJDgUzWPo6tb0qm0J7oqXR6zAGhW0aNDmTwvDOFhOLaAaT
MuzcUo9SsFg53rkrmcGUASpZmkTB2/KsFx7h842LW57EU9gz22rzsUwG1VXJ
2Xl7KVwatSPO7gyD8iLz6tLdFIyrnlSdvsrgiDCN1l1KCi75ofVfbjBo5n5I
aRZAITBVp2nlLQYHb/rLhH4UigLlvd+bGXzzYNCNW0fByLBouncvg+n5L7Pk
q/i+JtosuPCJwcygQqealRR8vz1DrSEGxdouG1asoHCymVFUarEYsLqbObWM
gt6BPakCKYv9AmvVIFAw2y3IVc5iUT9XJ+DjUgru/udLVPNZHA5P9R6woHDU
ql0dZMFiWf8EarSYwoQ+hx8N7iyuP816DZpQkLX/qy1dy6LOTOkXO2MKy+5G
isM3sGhyKU03ex6FhMKyRTODWPSRBm5YJ6PwY61eYHwii5K3ofOWTKMgcbwQ
/vQQi33JNjkqKQVLM6dE03QWT++ZPs3FkEI4szevLZdFtVlEfISEQl9dZ6tF
NX+vm3+9YAoFMq/Srr+HxWt3nBZykyhIo7dtmtPHYrHCuKhPh4LizrSEjYMs
ftmvjryvTaFxS1pd4xgBNiu7Wo+Mp1BdGGxTIhGgjvKU5mJNCgcN58gDXAWY
0HKzduwwAVNRrmVruQCz2nV3OfUSCPT3VEyqFuC+0nF+298RKCifGGWvEqDQ
vn8g/S0B8aroKxV3BBhkGv319RsCow97mx/tEGDT/U+FxyiBFi3R4uV6QmxO
/tnX+iWByKHkBVcjhJie/VzrQAuBezv90iNihVjTcHZA3UzA4K3lp8VJQtzR
lPXTON51z3srL2UI0cUu7fvBRwS0r682L/tLiOVLHh7LaySQE2soz+sUouuu
l7UjbhOo1bzskrRqMk49sjVyt4rAWJYq3WUiXJZITpwpIfA5UWF3ykSEk/Nz
FQa8O4cbDbrNRDgra3PqyfME6nsuP95rI8KAwhz3rHME9qv/sDunEKF2v8HE
zCICmjHGhiMPi/B1RYrZmXzevWGtZX18/jUN49E5BMbcHeMw4Zou2jsb6Bcf
JvDtXklgaog+yuY0jFoYSqDDs3SKRCJGmw9e5qZefJ9rvt9QTBNjT3mA78M1
BH7zcg7MlonxxQ9JWijvbu/uGv1fxWgbIpFUehJ4v26Gv9BVjB8b5DctPAgM
+eWUasWJsTIhwsXRjYAwOMWmr0OMNOxdfOAKAk3Bz3tMe8Q4zlepM4l3Zsjc
zOCPYpQpknMvOBPQD22gb4fFeHzsllefnQhIwjRTqB6HHrkZT2KXE5BF/d76
3JFDxe2U3VkOBHqi7sZOdeWw5dapVEveJdFT56z14DClalFlmz0Bk73V0a0b
OayvKNOdwdss7rP0USSHUSKpRbktAXlS0DZ1CYd3TtwefV/O/8/FNs+UCj7v
pG3jFt79/7hau1/hsDut+Kwm7wLjBXrtag7rggc3WyGBGK+zIwruc6h8r/J4
CgS84kU9W1s49E37xSWMt/bjAdXAKw4/PnjkUWrF962hPHetm8PL1a82L+dd
I3uaEf+BQ5XP+tjOpQSOuzvFOH7h0HnLwjNxvF1qb8/eM8jhvYe+i0J4/wcg
s8C5
      "]], LineBox[CompressedData["
1:eJwVlHk0lnkUx6XGIGWJkp53eUqDiBLqIPdmaZMIabENetsI0+Yt1NQIqciQ
VCNUpyzlPQnZItHCZN/SMLRYe34PKYneNM/8cc89n/M9537P+d57Lu0b5CyS
lZGR8eTq/55rZdIWJUchI8kwDJUfBu2m63BNiULVuVbrP4yz8P2b8hKfORTe
XhKx6VYfC22LT6nraFFYWnv1l8A2FiSOo1OMkMJ/AFp0n7MQfcxvMFeHwpnT
PHIfFbJgUWtXZmVKoYeirtmK6yyojxdkzLCkMLQk4P3XeBZYoW5CjTWFZ+uC
tHwiWUg7rLjXzYnC9eKRhpFgFo5fD3WmtlFofrBTVm4PCy4vGMu3nhSKvL+y
yZ4syFH1qoH+FIbXV+fP38RCtx1KVxzk/OMLbk3YsFAYdL9vQkyhzFN2l4Ul
C/6VCSVnIinM+dZE1S5lwZbMuG1/gUJ/c2tvNR0W+POOXlRNpJDtSJDeFLLQ
sH+7KCWdwhJ2ru9VdRayEqsd/TIojLHQHPoym4U/yszN9SQU7p4bYxOnwIKZ
Gk85v5TCm69GUkQ/CChbxk4cr6Qw90TVmpRJAgOiH++whsKku41j078QuFb0
pvBlO5dfTU6/CyEg43Pb9/0ohdb2i+1Kuwh0xMxzyJqgsCUzLEDvNYHcvOiV
wTI81C2zWZrXRkAk768kncXD0zWZC6gGAjUSo4I5ejxMPrrLaXYVgVsdaWkd
Rjwsjr0nxAoC4dPVzqWa8XCZRpbKmTICy7Z99ta35aHTab7YtojApalCBRtv
HkpdP107JSGgpPM08JKIh0pNrLz7PQIRjo3N/f48vEtRNyCbwMG0wZTzYh4O
1I8f0L1DYLO1lnFbPA+bHeL2BaQSkIsM3bmvioc95bFRQfGcf05UeUkNx93V
A7VxBD63JWjPbuTh0uwKfeNYAm917rK5Xdy8tOSYmecIlFd3npZ+4eG7vwvT
pBEExLOssuP0+Li3bn9KwTECw6YbVd4a8XHteWmmt5jAbi+3IyZmfPyh57dF
KYSAqyQQOqz5XL6yc4IPE1i+JbV5oQcfb6gkyXsHERhKlJHmx/LR5ojinRoR
AXeqclPnJz4WD953DHHl9AMfR/Mn+ZiesXuzlwvnXy64EjdNgMp8/Yh1zgSS
fMN6rZUF2PHr5UChE4GmDNMTmUsEqPHdds0HewIbTTMkR30EqBnuk9VlQ8B8
8wU11XoB7hoY/zzDlEB1aknhUKsAH3qNK2ibENj+cdCrqlOA7KcHobYrCBxJ
XJsdMiTA/j4D37PLOZ38oIdlhYh5U4ULDQkkrigq3soX4qSPbHGcDrevx/rM
wq1CTIrLKli5gMvzypYXJ7cLsc7IsTZci8DDQyG3Ot2FqHnOsKxqPgFfnUqP
JF8hqtiIFm3V5PTYnbUKwUJ8LrtBclKD0z3P5ozEcPPd+qMmlAkUTvYFlz0W
4iLFVXVBP3H3Z3pjbIcBjRcUeg9PfmQgJlZDOdyIxlfLAz4FcZzTH62bZkyj
SovGs94RBr5cCXLvW0XjkzrGr2mYgegpy4qDdjS+l9XcIyEMZD1vP3/Oi8aU
BJfHIYMMsDtmaT+6SKOB/b1RizcMqD34fXVPAo3J2s3rinsYMFP67Db9Mo1h
VXT7Ko5Plr0+uyGFxjWZyelm3QyoLMoYbs2kUdwx0WzSxYAxY13CPqExnb9t
sUUHA252BS2qz2j8d2h9U+krhvs3eqxJNY3LQiokVhxXOqnQofU05jbwJq3b
GXDN74r8uZPG2+8qHjm0MiCevSVtSTeNoWMLehpaGEjZU1Xk8JZGaUSroSvH
ffOzmYQBGlfn/ebo3syA4iG+3MMPNL484CnsbmLA8GW84DVLo3598QI/jkNO
iJ2FYzRma5A4/0YGdJkwpaivNAb+mXejt4GBVztOPSPfuLz+Muj15vhOT696
qZRGpfZplsjxf+rU0Ww=
      "]], LineBox[CompressedData["
1:eJwV0Xs4VXkXB3AhjTMmJBqkYe9DqFzOLkllrTRv7jNIhW7OOC5vDWbkUnHk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      "]]}, 
    {RGBColor[0, 0, 1], 
     LineBox[{{8.993622448979592, 0.9004212543502219}, {9., 
      1.2251959230498077`}, {9.006377551020408, 1.549970591749443}}], 
     LineBox[{{6.9936224489795915`, 0.7262502710860532}, {6.999999999999999, 
      0.848017785732775}, {7.0063775510204085`, 0.9697853003794967}}], 
     LineBox[{{3.993622448979592, 0.6232084365235822}, {4., 
      0.7043439392549006}, {4.0063775510204085`, 0.7854794419862251}}], 
     LineBox[{{2.9961186623086733`, 0.5025480958056642}, {3., 
      0.5840031795012639}, {3.0038813376913267`, 0.6654582631968763}}], 
     LineBox[{{1.9961089114753567`, 0.313487096911825}, {2., 
      0.43571844377074986`}, {2.003891088524643, 
      0.557949790629668}}]}}, {{}, {}, 
    {RGBColor[0, 0, 1], 
     PointBox[{{9.006377551020408, 1.549970591749443}, {8.993622448979592, 
      0.9004212543502219}, {7.0063775510204085`, 0.9697853003794967}, {
      6.9936224489795915`, 0.7262502710860532}, {4.0063775510204085`, 
      0.7854794419862251}, {3.993622448979592, 0.6232084365235822}, {
      3.0038813376913267`, 0.6654582631968763}, {2.9961186623086733`, 
      0.5025480958056642}, {2.003891088524643, 0.557949790629668}, {
      1.9961089114753567`, 0.313487096911825}}]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"Days\"", TraditionalForm], 
    FormBox["\"Bq\"", TraditionalForm]},
  AxesOrigin->{0, 0.25},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0, 20}, {0.313487096911825, 1.549970591749443}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.398584050470081*^9, 3.3985922056264615`*^9, 3.4138015910394325`*^9, 
   3.4800941416616306`*^9, 3.480095407626631*^9, 3.480095515719031*^9, 
   3.4800959719110003`*^9, 3.4801563179854*^9, 3.5185322001789665`*^9, 
   3.5396990299998603`*^9, 3.5920643311046796`*^9, {3.643609902758481*^9, 
   3.6436099316804113`*^9}},
 CellLabel->"Out[12]="]
}, Open  ]],

Cell["It can be also used:  ", "MathCaption"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{
   StyleBox["LungsRetention", "Input"], 
   StyleBox["[", "Input"], 
   StyleBox[
    RowBox[{
    "Intake", ",", " ", "IFD", " ", ",", " ", "FRA", ",", " ", "\[Tau]", ",", 
     " ", "\[Lambda]", ",", " ", "options"}],
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"CompatibilityType"->0,
    "Masked"->False,
    "Outline"->False,
    "RotationAngle"->0,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Underline"->False}], 
   StyleBox["]", "Input"]}]]],
 " or ",
 StyleBox["BioakdataReport[", "Input"],
 StyleBox["element, \"IntakeWay\", \"IntakeType\", Report, ", "Input",
  FontSlant->"Italic"],
 StyleBox["Intake, IFD , FRA, \[Tau] , \[Lambda], options",
  FontSlant->"Italic"],
 "] chosing as IntakeType\[Rule]\"MultiInputs\" give the retention or \
excretion \[Tau] days after the last intake {",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["I", "n"], " ", ",", " ", 
    FormBox[
     SubscriptBox["t", "n"],
     TraditionalForm]}], TraditionalForm]]],
 "}  happened"
}], "DefinitionBox"],

Cell[TextData[{
 "In the same example, the lung retention for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Tau]", " ", "=", " ", "5"}], TraditionalForm]]],
 " is "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LungsRetention", "[", 
  RowBox[{"intakendata1", ",", 
   RowBox[{"AMADAdultW", "[", "5", "]"}], ",", "S", ",", " ", "5", ",", " ", 
   "0", ",", " ", 
   RowBox[{"IntakeType", "\[Rule]", "\"\<MultiInputs\>\""}]}], "]"}]], "Input",
 CellLabel->"In[13]:="],

Cell[BoxData["1.3444214959318188`"], "Output",
 CellChangeTimes->{
  3.3985840507368803`*^9, 3.3985922058300934`*^9, 3.4138015912738123`*^9, 
   3.480094142082831*^9, 3.4800959720358*^9, 3.4801563183129997`*^9, 
   3.5185322003508444`*^9, 3.5396990301561136`*^9, 3.5920643314822097`*^9, {
   3.6436099028053555`*^9, 3.6436099317272778`*^9}},
 CellLabel->"Out[13]="]
}, Open  ]],

Cell[TextData[{
 "It can be compared with the obteinded using  qMultiple (taking into account \
that ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Tau]", " ", "=", "  ", 
    RowBox[{"t", " ", "-", " ", 
     FormBox[
      SubscriptBox["t", "n"],
      TraditionalForm]}]}], TraditionalForm]]],
 ")  "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qMultiple", "[", 
  RowBox[{"intakendata1", ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qLungU5", "[", "t", "]"}], ",", "t"}], "}"}], ",", " ", 
   RowBox[{"9", "+", "5"}]}], "]"}]], "Input",
 CellLabel->"In[14]:="],

Cell[BoxData["1.3444214959318188`"], "Output",
 CellChangeTimes->{
  3.3985840536873713`*^9, 3.3985922087435975`*^9, 3.4138015941644926`*^9, 
   3.4800941426756306`*^9, 3.4800959725662003`*^9, 3.4801563191554003`*^9, 
   3.518532200600849*^9, 3.5396990302967415`*^9, 3.5920643443882456`*^9, {
   3.643609902820981*^9, 3.643609931930399*^9}},
 CellLabel->"Out[14]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Multiple constant intakes", "Subsection"],

Cell[TextData[{
 "In many situations the intake ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "j"], TraditionalForm]]],
 " happens for a few hours every day. However, from a practical point of view \
it can be assumed that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "j"], TraditionalForm]]],
 " is an acute intake. But if we want to consider {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "0"], TraditionalForm]]],
 ", \[Ellipsis], ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "i"], TraditionalForm]]],
 ", \[Ellipsis] , ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "n"], TraditionalForm]]],
 "} as multiple constant intakes that happen at times: {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "1"], TraditionalForm]]],
 ", \[Ellipsis], ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ", \[Ellipsis]",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", 
    FormBox[
     SubscriptBox["", "n"],
     TraditionalForm]}], TraditionalForm]]],
 "} during a time ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     FormBox[
      SubscriptBox["T", "0"],
      TraditionalForm], ",", "...", ",", 
     FormBox[
      SubscriptBox["T", "i"],
      TraditionalForm], ",", "...", ",", 
     FormBox[
      SubscriptBox["T", "n"],
      TraditionalForm]}], "}"}], TraditionalForm]]],
 ", where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Tau]", "i"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "\[Dash]", " ", 
    SubscriptBox["t", "i"]}], TraditionalForm]]],
 " is the time since the input ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "i"], TraditionalForm]]],
 " occurred. "
}], "Text"],

Cell[TextData[{
 "We want consider the case where it happens multiple constant inputs {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "0"], TraditionalForm]]],
 ", \[Ellipsis], ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "i"], TraditionalForm]]],
 ", \[Ellipsis] , ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "n"], TraditionalForm]]],
 "}  that start at times: {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "1"], TraditionalForm]]],
 ", \[Ellipsis], ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ", \[Ellipsis]",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", 
    FormBox[
     SubscriptBox["", "n"],
     TraditionalForm]}], TraditionalForm]]],
 "} during a time {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "0"], TraditionalForm]]],
 ",..., ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "i"], TraditionalForm]]],
 ", ..., ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "n"], TraditionalForm]]],
 "}. "
}], "Text"],

Cell[TextData[{
 "We call ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "(", "t", ")"}], TraditionalForm]]],
 " the unit function for a constant input"
}], "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"r", "(", 
    RowBox[{"t", ",", " ", 
     SubscriptBox["T", "i"]}], ")"}], "=", 
   RowBox[{"{", 
    RowBox[{"0", " ", ",", " ", 
     RowBox[{"t", "<", "0"}], ",", " ", 
     RowBox[{
      RowBox[{
       SubsuperscriptBox["\[Integral]", "0", "t"], 
       RowBox[{
        RowBox[{"u", "(", "t", ")"}], 
        RowBox[{"\[DifferentialD]", "t"}], "  ", "for", " ", "0"}]}], "<", 
      "t", "\[LessEqual]", 
      RowBox[{
       SubscriptBox[
        RowBox[{"T", " "}], "i"], "and", "  ", 
       RowBox[{
        SubsuperscriptBox["\[Integral]", 
         RowBox[{"t", "-", 
          SubscriptBox["T", "i"]}], "t"], 
        RowBox[{
         RowBox[{"u", "(", "t", ")"}], 
         RowBox[{"\[DifferentialD]", "t"}], " ", "for", " ", "t"}]}]}], ">", 
      SubscriptBox["T", "i"]}]}], "}"}], " "}], 
  TraditionalForm]], "EquationNumber"],

Cell["\<\
Then, the retention function for multiple constant inputs is given by\
\>", "Text"],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["q", "MC"], "(", "t", ")"}], " ", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{
       RowBox[{
        FractionBox[
         SubscriptBox["b", "0"], 
         SubscriptBox["T", "0"]], 
        RowBox[{"r", "(", 
         RowBox[{"t", "-", 
          SubscriptBox["t", "0"]}], ")"}]}], " ", "+", " ", 
       RowBox[{
        FractionBox[
         SubscriptBox["b", "1"], 
         SubscriptBox["T", "1"]], 
        RowBox[{"r", "(", 
         RowBox[{"t", "-", 
          SubscriptBox["t", "1"]}], ")"}]}], "+"}], "..."}], "+", 
     RowBox[{
      FractionBox[
       SubscriptBox["b", "n"], 
       SubscriptBox["T", "n"]], 
      RowBox[{"r", "(", 
       RowBox[{"t", "-", 
        SubscriptBox["t", "n"]}], ")"}]}]}], "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "n"], 
     RowBox[{
      FractionBox[
       SubscriptBox["b", "i"], 
       SubscriptBox["T", "i"]], 
      RowBox[{"r", "(", 
       RowBox[{"t", "-", 
        SubscriptBox["t", "i"]}], ")"}]}]}]}]}], 
  TraditionalForm]], "NumberedEquation"],

Cell[TextData[{
 "This equation is implemented in the  BIOKMOD function ",
 StyleBox["qMultiple", "Input"],
 ". This function can be used also for multiple acute inputs even for \
combination multiples acute and constant inputs.  "
}], "Text"],

Cell["\<\
Example.-  A worker works  in an area expose to UO2 (AMAD 5 \[Mu]m  and type \
S) radioactive aerosols during the last 2000 days. He works 5 days per week 8 \
hours a day, he also has 4 holiday weeks per year (with these criteria 2000 \
days are 1330 working days). It is estimated that in this time he has intaken \
13300 BqU. We want to calculate the lung retention evolution.  Regular \
weekends and holidays will be assumed. \
\>", "Commentary"],

Cell["We will need the single-impulse function for lung", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qLungU5S", "[", "t_", "]"}], "=", 
   RowBox[{"LungsRetention", "[", 
    RowBox[{"1", ",", 
     RowBox[{"AMADAdultW", "[", "5", "]"}], ",", "S", ",", " ", "t", ",", 
     "0"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[15]:="],

Cell[TextData[{
 "The lung retention for a single intake 1 Bq/day with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "i"], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", "T", " "}], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"8", " ", "h"}], 
    RowBox[{"24", " ", "h"}]], TraditionalForm]]],
 "=",
 Cell[BoxData[
  FormBox[
   FractionBox["1", "3"], TraditionalForm]]],
 "  is given by"
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"days", "=", " ", "2000"}], ";", " ", 
  RowBox[{"Ti", " ", "=", " ", 
   RowBox[{"1", "/", "3"}]}], ";"}]], "Input",
 CellLabel->"In[16]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"lungret", "=", " ", 
   RowBox[{
    RowBox[{
     RowBox[{
      RowBox[{"1", "/", "Ti"}], "  ", 
      RowBox[{"qConstant", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"qLungU5S", "[", "t", "]"}], ",", "t"}], "}"}], ",", "#", 
        ",", "Ti"}], "]"}]}], "&"}], "/@", 
    RowBox[{"Range", "[", "days", "]"}]}]}], ";"}]], "Input",
 CellLabel->"In[17]:="],

Cell["\<\
The average intake during this period conisdering all days is\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"totalintake", " ", "=", " ", "13300"}], ";"}]], "Input",
 CellLabel->"In[18]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"avgintake", "=", " ", 
  RowBox[{"totalintake", " ", "/", "days"}]}]], "Input",
 CellLabel->"In[19]:="],

Cell[BoxData[
 FractionBox["133", "20"]], "Output",
 CellChangeTimes->{3.3985840975523806`*^9, 3.3985922532920136`*^9, 
  3.4138016394466124`*^9, 3.480094171161231*^9, 3.4800959970582*^9, 
  3.4801563567202*^9, 3.5185322346952543`*^9, 3.539699051375271*^9, 
  3.592064386807889*^9, 3.643609902930356*^9, 3.643609943914807*^9},
 CellLabel->"Out[19]="]
}, Open  ]],

Cell["Now we want calculated the number of  working days. ", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"workingdays", " ", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "7"}], "]"}], "\[Equal]", " ", "0"}], " ", "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "7"}], "]"}], "\[Equal]", " ", "6"}], "||", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "0"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "364"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "363"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "362"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "361"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "360"}], "||", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "359"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "358"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "357"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "356"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "355"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "354"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "353"}], "||", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "352"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "351"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "350"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "349"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "348"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "347"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "346"}], "||", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "345"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "344"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "343"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "342"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "341"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "340"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "339"}], "||", 
         " ", 
         RowBox[{
          RowBox[{"Mod", "[", 
           RowBox[{"n", ",", "365"}], "]"}], "\[Equal]", " ", "338"}]}], ",", 
        "0", " ", ",", " ", "1"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"n", ",", "days"}], "}"}]}], "]"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[20]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"wdays", "=", 
  RowBox[{"Total", "[", "workingdays", "]"}]}]], "Input",
 CellLabel->"In[21]:="],

Cell[BoxData["1330"], "Output",
 CellChangeTimes->{3.3985840976465454`*^9, 3.3985922533546696`*^9, 
  3.4138016395091133`*^9, 3.480094173423231*^9, 3.4800959970894003`*^9, 
  3.4801563567514*^9, 3.5185322347577553`*^9, 3.539699051422147*^9, 
  3.592064386876644*^9, 3.6436099029928565`*^9, 3.643609943930418*^9},
 CellLabel->"Out[21]="]
}, Open  ]],

Cell["\<\
The average daily intake considering only the working days is\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"avgintakewd", "=", " ", 
  RowBox[{"totalintake", "/", "wdays"}]}]], "Input",
 CellLabel->"In[22]:="],

Cell[BoxData["10"], "Output",
 CellChangeTimes->{3.398584097709322*^9, 3.398592253401662*^9, 
  3.4138016395559893`*^9, 3.480094174733631*^9, 3.480095997105*^9, 
  3.480156356767*^9, 3.5185322347890058`*^9, 3.5396990514533978`*^9, 
  3.5920643869141474`*^9, 3.643609903024106*^9, 3.643609943930418*^9},
 CellLabel->"Out[22]="]
}, Open  ]],

Cell["\<\
The lung retention take in into accound the period where there are not intake \
is\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"dailylungret", "=", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Range", "[", "days", "]"}], ",", 
      RowBox[{"ListConvolve", "[", " ", 
       RowBox[{"workingdays", ",", 
        RowBox[{"avgintakewd", "*", " ", "lungret"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "days"}], ",", " ", "1"}], "}"}], ",", " ", "0"}], 
       "]"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[23]:="],

Cell["The lung retention assuming a chronic intake is", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qLungU5SCr", "[", "t_", "]"}], "=", 
   RowBox[{"LungsRetention", "[", 
    RowBox[{"1", ",", 
     RowBox[{"AMADAdultW", "[", "5", "]"}], ",", "S", ",", " ", "t", ",", "0",
      ",", " ", 
     RowBox[{"IntakeType", "\[Rule]", " ", "\"\<Constant\>\""}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[24]:="],

Cell["Both solutions are plotted below ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig2", "=", " ", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"avgintake", " ", 
     RowBox[{"qLungU5SCr", "[", "t", "]"}]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"t", ",", " ", "1200", ",", "days"}], "}"}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<days\>\"", ",", "\"\<Bq\>\""}], "}"}]}], ",", " ", 
    RowBox[{"Epilog", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Hue", "[", "0", "]"}], ",", " ", 
       RowBox[{"PointSize", "[", "0.012", "]"}], ",", 
       RowBox[{"Map", "[", 
        RowBox[{"Point", ",", "dailylungret"}], "]"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellLabel->"In[25]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwVx3k4lAkAx3ErKclK7Uo2HTwydlspu3KO3zM6aMk6Ih5J86Q53vclPSEi
KUdFxxzGMWZeqVaUDkdm25LURokK64hKTKGLZN2mnf3j+3yfz0p2hE+YpoaG
hqe6/19UuFlLo1qI8vlXhH2pHDh5cl2n1N4/kdogSuOgcfjYkdG7QrTZPP7q
coyDEedHGh/vCRFeK9uSfZwDZovHTEetEOmvyVi3DA6aNHxGy54IITxk61Qo
4GAyMLif80oIfQ+foJA8Dn6bH/n4iUqIi6zdi8uuc9ClO7S8nyXCC+JVTuIr
DrJm4p0TjoiwkJvuckOHC+79NQuaq0Xw8q6alqzjgrHKLjxSSwzLuWdlO0O4
MIjbKslwFWOvVpOxIpWLAe5N96E0McwIw7Le61y0rfYo/a5ejFuJT1sVnVwM
9rxXVuhkIuul40GWJg+jNq8LaM9M9B1oL0j7iQeLGOWP2iczEfDnGwuxNw/h
p/W4P9dnYmxlx1RENA/nWBnWsm8lsD/h4PdZxoNmv9G9454SJPdW9wTV8PA7
Y6q7SiBBt/ZIdcAAD+XOs8rLWyQwNWvzN9Png7VxibfFoiwsKDqlP7aWjzt9
ybE9/ll4tHdnmHsAH2HxKsJYkoWEs/Ye5bF8TF5qGMh9noU6OmwmQ87HhWs1
S7tMstFlxPq4uYaPuMK/l+QGZ6M12HTMrpcPpv2ygvz8bLxzrLiUrE1g9e3k
EbPubKTPib7yvQUBa0ODac6yHJzRWhVauImA2bwvp0Z25aDet1WZxCXgMtTz
fiY/B66Jlna30ghsiWS0eL3JAWttd451EQGiVhTJZuTC4UXKDxceErihr9fx
eU8uTDxvrxX1ERga7qx/WJyL+lZlSvEcEn51imPL3uXiktS71M2cROO+vyZt
GFK0Vw5kfMMiYatYNC4gpLhS2jXcHEqibjD2DlksRZXDM/8NCSTca35deOaT
FPvo2e53pSRGUr9aWVvl4bNma1p/JYmKFYMaAjIPMvvDH9c3kwjb9kuIw7U8
+LUm+KYMkWDGp6WEDuZhQIc8LNSloM20tntiI4Pyml6BgEFB2aKiVdEy+C5e
wlZsoPBhR+ez4goZzEp0npaFUOhN0jtNT8gg6BNGieIoaGV7GhrYy5Ey1XnC
R0zB8WiZj2uMHB8yKmu3llAI1Ykwrroph6Wrb5hpHYWrSXaXKybkWGxezOzv
pjAvKfqfxkk56JezPfxfU9h9uFzVNyXHvKgov/tqGydaexur5Ig5KfDP76GQ
HM8YPaRJw7zqwfLtSgqBMUZw06VxThzx4EEfhVnUePPzpTToKD1O/icKIaTt
zBcTGtvijrfpDVJQEPtX6S2nETtm5npQ7XD+0AGXlTTqL1fo+g9RaOf0m5w3
p3GRuY2tO0yhhN3OoaxoXK1pNI/6l8JctqEgdQ2NTa2Bbj1qs3f53aStaST9
MXeP1ygFo9Cn85vW0TBqaBJajlE4sqPuuu16GrfYpqUvxil0BWt3etnRyE1v
KdkyQWF98AYtnj2NjgUl5yvV/hBU7S91pPE2semoYJLC5iBVYrkTDT+DFaRK
7YJAp6IGZxrk1kwvYorC9Pa4prdMGp9OrLNqVztgu2LqqwsNifH4nI3TFP4D
TsxTKA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"days\"", TraditionalForm], 
    FormBox["\"Bq\"", TraditionalForm]},
  AxesOrigin->{1200., 186.},
  DisplayFunction->Identity,
  Epilog->{
    Hue[0], 
    PointSize[0.012], {
     PointBox[{1, 0.648436191794957}], 
     PointBox[{2, 1.277059369056623}], 
     PointBox[{3, 1.8975382900632596`}], 
     PointBox[{4, 2.5115741977671107`}], 
     PointBox[{5, 3.1195212745882372`}], 
     PointBox[{6, 3.073112065810804}], 
     PointBox[{7, 3.040736344636315}], 
     PointBox[{8, 3.6592953052824626`}], 
     PointBox[{9, 4.258968423089556}], 
     PointBox[{10, 4.851196841294701}], 
     PointBox[{11, 5.437636415535664}], 
     PointBox[{12, 6.018620985200194}], 
     PointBox[{13, 5.945866516014725}], 
     PointBox[{14, 5.887747075166914}], 
     PointBox[{15, 6.481148623442749}], 
     PointBox[{16, 7.0562358114558705`}], 
     PointBox[{17, 7.624435348427447}], 
     PointBox[{18, 8.187389035168657}], 
     PointBox[{19, 8.745417025030356}], 
     PointBox[{20, 8.650221956494377}], 
     PointBox[{21, 8.570164918588368}], 
     PointBox[{22, 9.142119233590861}], 
     PointBox[{23, 9.696237244082525}], 
     PointBox[{24, 10.243933672811409`}], 
     PointBox[{25, 10.786838647000096`}], 
     PointBox[{26, 11.325260950864667`}], 
     PointBox[{27, 11.210892150005002`}], 
     PointBox[{28, 11.112082548849592`}], 
     PointBox[{29, 11.665694965606477`}], 
     PointBox[{30, 12.201871511777547`}], 
     PointBox[{31, 12.732016944692177`}], 
     PointBox[{32, 13.257751684688166`}], 
     PointBox[{33, 13.779375060698605`}], 
     PointBox[{34, 13.648569427900775`}], 
     PointBox[{35, 13.53367611860481}], 
     PointBox[{36, 14.071549210834519`}], 
     PointBox[{37, 14.592322301635711`}], 
     PointBox[{38, 15.107391853585469`}], 
     PointBox[{39, 15.61837020610708}], 
     PointBox[{40, 16.12554881535671}], 
     PointBox[{41, 15.980602366320959`}], 
     PointBox[{42, 15.851864718318609`}], 
     PointBox[{43, 16.37618266832787}], 
     PointBox[{44, 16.883682719196003`}], 
     PointBox[{45, 17.385754421183528`}], 
     PointBox[{46, 17.884003378452753`}], 
     PointBox[{47, 18.37871448425757}], 
     PointBox[{48, 18.221556028473948`}], 
     PointBox[{49, 18.08085563865894}], 
     PointBox[{50, 18.59345403905629}], 
     PointBox[{51, 19.089471814600756`}], 
     PointBox[{52, 19.58029274837557}], 
     PointBox[{53, 20.067516824119956`}], 
     PointBox[{54, 20.551423457550086`}], 
     PointBox[{55, 20.383675600123944`}], 
     PointBox[{56, 20.232595676440383`}], 
     PointBox[{57, 20.735019339677415`}], 
     PointBox[{58, 21.221062232132596`}], 
     PointBox[{59, 21.70210331930737}], 
     PointBox[{60, 22.1797378891348}], 
     PointBox[{61, 22.654240780103713`}], 
     PointBox[{62, 22.477270481921536`}], 
     PointBox[{63, 22.317145069890515`}], 
     PointBox[{64, 22.81069595740378}], 
     PointBox[{65, 23.288034653625168`}], 
     PointBox[{66, 23.760536094790993`}], 
     PointBox[{67, 24.229791640725693`}], 
     PointBox[{68, 24.69607230033276}], 
     PointBox[{69, 24.51103282969101}], 
     PointBox[{70, 24.342987663935055`}], 
     PointBox[{71, 24.82876466732197}], 
     PointBox[{72, 25.298471888548}], 
     PointBox[{73, 25.763480889748706`}], 
     PointBox[{74, 26.225379740775786`}], 
     PointBox[{75, 26.68443624251058}], 
     PointBox[{76, 26.492302022838665`}], 
     PointBox[{77, 26.317288466466813`}], 
     PointBox[{78, 26.79622046298099}], 
     PointBox[{79, 27.25920316020867}], 
     PointBox[{80, 27.717605291315408`}], 
     PointBox[{81, 28.173012167229018`}], 
     PointBox[{82, 28.62568889815278}], 
     PointBox[{83, 28.42728448778265}], 
     PointBox[{84, 28.246107761417896`}], 
     PointBox[{85, 28.718981112354975`}], 
     PointBox[{86, 29.176007253634026`}], 
     PointBox[{87, 29.62855254355565}], 
     PointBox[{88, 30.07819997657633}], 
     PointBox[{89, 30.525212403324304`}], 
     PointBox[{90, 30.321236623365984`}], 
     PointBox[{91, 30.13457931189953}], 
     PointBox[{92, 30.602060764773007`}], 
     PointBox[{93, 31.053781648888126`}], 
     PointBox[{94, 31.501106326411495`}], 
     PointBox[{95, 31.94561584439795}], 
     PointBox[{96, 32.3875711535707}], 
     PointBox[{97, 32.178617199879476`}], 
     PointBox[{98, 31.987058850020823`}], 
     PointBox[{99, 32.4497146353161}], 
     PointBox[{100, 32.89668350100001}], 
     PointBox[{101, 33.33932812934749}], 
     PointBox[{102, 33.77922792824473}], 
     PointBox[{103, 34.21664224893892}], 
     PointBox[{104, 34.00321447659783}], 
     PointBox[{105, 33.8072479548534}], 
     PointBox[{106, 34.26555972873358}], 
     PointBox[{107, 34.708247293022545`}], 
     PointBox[{108, 35.14667191449172}], 
     PointBox[{109, 35.58241161959034}], 
     PointBox[{110, 36.015724411344294`}], 
     PointBox[{111, 35.798252359081445`}], 
     PointBox[{112, 35.59829752216749}], 
     PointBox[{113, 36.05267569214723}], 
     PointBox[{114, 36.49148314033647}], 
     PointBox[{115, 36.926079939303946`}], 
     PointBox[{116, 37.358042949833745`}], 
     PointBox[{117, 37.78762903711375}], 
     PointBox[{118, 37.566479159766885`}], 
     PointBox[{119, 37.36289429291456}], 
     PointBox[{120, 37.813689169662084`}], 
     PointBox[{121, 38.248959028048496`}], 
     PointBox[{122, 38.680062931905816`}], 
     PointBox[{123, 39.108576757214884`}], 
     PointBox[{124, 39.53475640770274}], 
     PointBox[{125, 39.31024190329437}], 
     PointBox[{126, 39.10333330261742}], 
     PointBox[{127, 39.550844443938814`}], 
     PointBox[{128, 39.98286969158224}], 
     PointBox[{129, 40.410767256266666`}], 
     PointBox[{130, 40.8361121809569}], 
     PointBox[{131, 41.25915955596659}], 
     PointBox[{132, 41.031548606930095`}], 
     PointBox[{133, 40.82157861683832}], 
     PointBox[{134, 41.266062666517406`}], 
     PointBox[{135, 41.69509438060385}], 
     PointBox[{136, 42.12003124744696}], 
     PointBox[{137, 42.54244760453712}], 
     PointBox[{138, 42.96259785319812}], 
     PointBox[{139, 42.73212054615711}], 
     PointBox[{140, 42.51931430918704}], 
     PointBox[{141, 42.960991581206756`}], 
     PointBox[{142, 43.3872453598836}], 
     PointBox[{143, 43.80943252117202}], 
     PointBox[{144, 44.22912680438947}], 
     PointBox[{145, 44.64658202656535}], 
     PointBox[{146, 44.41343616967392}], 
     PointBox[{147, 44.19798730195004}], 
     PointBox[{148, 44.63704731766968}], 
     PointBox[{149, 45.060708682443156`}], 
     PointBox[{150, 45.480327752448304`}], 
     PointBox[{151, 45.89747775921282}], 
     PointBox[{152, 46.31241202367347}], 
     PointBox[{153, 46.07676804312954}], 
     PointBox[{154, 45.85884341228268}], 
     PointBox[{155, 46.29544956275194}], 
     PointBox[{156, 46.71667850810629}], 
     PointBox[{157, 47.13388616284254}], 
     PointBox[{158, 47.54864532692188}], 
     PointBox[{159, 47.961208899585635`}], 
     PointBox[{160, 47.7232139660758}], 
     PointBox[{161, 47.50295771844162}], 
     PointBox[{162, 47.93725119483527}], 
     PointBox[{163, 48.35618602432095}], 
     PointBox[{164, 48.77111774564453}], 
     PointBox[{165, 49.183618791558686`}], 
     PointBox[{166, 49.59394170243832}], 
     PointBox[{167, 49.35372321280202}], 
     PointBox[{168, 49.13126017192758}], 
     PointBox[{169, 49.56336328295735}], 
     PointBox[{170, 49.98012384752649}], 
     PointBox[{171, 50.39289708435168}], 
     PointBox[{172, 50.8032551133838}], 
     PointBox[{173, 51.211450169250845`}], 
     PointBox[{174, 50.96911868761582}], 
     PointBox[{175, 50.744557225627204`}], 
     PointBox[{176, 51.17457620087036}], 
     PointBox[{177, 51.589266635837006`}], 
     PointBox[{178, 51.99998347636871}], 
     PointBox[{179, 52.40829857565777}], 
     PointBox[{180, 52.814463907551286`}], 
     PointBox[{181, 52.5701156527667}], 
     PointBox[{182, 52.34355011920705}], 
     PointBox[{183, 52.77157748077832}], 
     PointBox[{184, 53.18428852173184}], 
     PointBox[{185, 53.59303795497722}], 
     PointBox[{186, 53.999397405963585`}], 
     PointBox[{187, 54.40361862586143}], 
     PointBox[{188, 54.15733757766016}], 
     PointBox[{189, 53.928850356368244`}], 
     PointBox[{190, 54.354966927721215`}], 
     PointBox[{191, 54.76577787241065}], 
     PointBox[{192, 55.17263770429472}], 
     PointBox[{193, 55.57711785417185}], 
     PointBox[{194, 55.97946988286347}], 
     PointBox[{195, 55.73132956721024}], 
     PointBox[{196, 55.500992820177686`}], 
     PointBox[{197, 55.92526942946676}], 
     PointBox[{198, 56.334249801654174`}], 
     PointBox[{199, 56.73928828030992}], 
     PointBox[{200, 57.14195612968479}], 
     PointBox[{201, 57.54250474770669}], 
     PointBox[{202, 57.292569751893694`}], 
     PointBox[{203, 57.0604468993766}], 
     PointBox[{204, 57.4829458254314}], 
     PointBox[{205, 57.89015678754157}], 
     PointBox[{206, 58.29343398343717}], 
     PointBox[{207, 58.694348534711395`}], 
     PointBox[{208, 59.093151699743075`}], 
     PointBox[{209, 58.841478959537945`}], 
     PointBox[{210, 58.607625937682926`}], 
     PointBox[{211, 59.028402138812424`}], 
     PointBox[{212, 59.43389769260264}], 
     PointBox[{213, 59.83546667174707}], 
     PointBox[{214, 60.23468007551048}], 
     PointBox[{215, 60.63178904259086}], 
     PointBox[{216, 60.37842893689941}], 
     PointBox[{217, 60.142895267457185`}], 
     PointBox[{218, 60.56199742680363}], 
     PointBox[{219, 60.96582543493753}], 
     PointBox[{220, 61.365733257232975`}], 
     PointBox[{221, 61.76329178794519}], 
     PointBox[{222, 62.15875206301839}], 
     PointBox[{223, 61.903749345815115`}], 
     PointBox[{224, 61.66657904696281}], 
     PointBox[{225, 62.08405046271636}], 
     PointBox[{226, 62.48625351884881}], 
     PointBox[{227, 62.88454208852194}], 
     PointBox[{228, 63.2804869757493}], 
     PointBox[{229, 63.67433912815683}], 
     PointBox[{230, 63.41773372267137}], 
     PointBox[{231, 63.17896608532369}], 
     PointBox[{232, 63.59484542957246}], 
     PointBox[{233, 63.995461600150534`}], 
     PointBox[{234, 64.3921683909006}], 
     PointBox[{235, 64.78653652819683}], 
     PointBox[{236, 65.17881688367164}], 
     PointBox[{237, 64.92064455986366}], 
     PointBox[{238, 64.68031480998796}], 
     PointBox[{239, 65.09463677622497}], 
     PointBox[{240, 65.49370023353097}], 
     PointBox[{241, 65.88885890744135}], 
     PointBox[{242, 66.28168345745988}], 
     PointBox[{243, 66.67242468975405}], 
     PointBox[{244, 66.4127176427718}], 
     PointBox[{245, 66.17085750698038}], 
     PointBox[{246, 66.58365336312643}], 
     PointBox[{247, 66.98119492601857}], 
     PointBox[{248, 67.37483586230148}], 
     PointBox[{249, 67.76614677381431}], 
     PointBox[{250, 68.1553784102661}], 
     PointBox[{251, 67.89416575482029}], 
     PointBox[{252, 67.65080394380932}], 
     PointBox[{253, 68.06210200496929}], 
     PointBox[{254, 68.45814960119995}], 
     PointBox[{255, 68.85030034831053}], 
     PointBox[{256, 69.24012479835915}], 
     PointBox[{257, 69.62787365230167}], 
     PointBox[{258, 69.36518184555653}], 
     PointBox[{259, 69.1203444676943}], 
     PointBox[{260, 69.53017050065532}], 
     PointBox[{261, 69.92474956248387}], 
     PointBox[{262, 70.31543522505586}], 
     PointBox[{263, 70.70379799739736}], 
     PointBox[{264, 71.09008853831631}], 
     PointBox[{265, 70.8259417419439}], 
     PointBox[{266, 70.57965265740833}], 
     PointBox[{267, 70.98803022703416}], 
     PointBox[{268, 71.3811640300577}], 
     PointBox[{269, 71.77040760033617}], 
     PointBox[{270, 72.15733140965135}], 
     PointBox[{271, 72.54218608032322}], 
     PointBox[{272, 72.27660647073532}], 
     PointBox[{273, 72.02888759499231}], 
     PointBox[{274, 72.4358383611046}], 
     PointBox[{275, 72.82754831468594}], 
     PointBox[{276, 73.21537095665099}], 
     PointBox[{277, 73.60087672650131}], 
     PointBox[{278, 73.9843162149271}], 
     PointBox[{279, 73.7173242493165}], 
     PointBox[{280, 73.46819581340225}], 
     PointBox[{281, 73.8737397854294}], 
     PointBox[{282, 74.26404568184347}], 
     PointBox[{283, 74.65046697497165}], 
     PointBox[{284, 75.03457407629955}], 
     PointBox[{285, 75.41661754905805}], 
     PointBox[{286, 75.14823219372323}], 
     PointBox[{287, 74.89771296764884}], 
     PointBox[{288, 75.30186872322389}], 
     PointBox[{289, 75.69078895154973}], 
     PointBox[{290, 76.07582710011053}], 
     PointBox[{291, 76.45855355603788}], 
     PointBox[{292, 76.83921885868848}], 
     PointBox[{293, 76.56945778513467}], 
     PointBox[{294, 76.31756526978388}], 
     PointBox[{295, 76.72035014252953}], 
     PointBox[{296, 77.10790187241739}], 
     PointBox[{297, 77.49157388530662}], 
     PointBox[{298, 77.87293654712407}], 
     PointBox[{299, 78.25224037643649}], 
     PointBox[{300, 77.98112012992763}], 
     PointBox[{301, 77.72787072201282}], 
     PointBox[{302, 78.12930096298027}], 
     PointBox[{303, 78.51550030264889}], 
     PointBox[{304, 78.89782214802153}], 
     PointBox[{305, 79.27783684653106}], 
     PointBox[{306, 79.65579489860602}], 
     PointBox[{307, 79.38333104313924}], 
     PointBox[{308, 79.12874017709612}], 
     PointBox[{309, 79.52883109364663}], 
     PointBox[{310, 79.91369322581897}], 
     PointBox[{311, 80.29467996414374}], 
     PointBox[{312, 80.67336163989401}], 
     PointBox[{313, 81.04998873764407}], 
     PointBox[{314, 80.77619598073169}], 
     PointBox[{315, 80.52027825086185}], 
     PointBox[{316, 80.91904432622992}], 
     PointBox[{317, 81.30258362517071}], 
     PointBox[{318, 81.68224952379653}], 
     PointBox[{319, 82.05961233923216}], 
     PointBox[{320, 82.43492254216572}], 
     PointBox[{321, 82.15981484230772}], 
     PointBox[{322, 81.90258410798904}], 
     PointBox[{323, 82.30003910427754}], 
     PointBox[{324, 82.68226923662388}], 
     PointBox[{325, 83.06062786849327}], 
     PointBox[{326, 83.43668530459428}], 
     PointBox[{327, 83.81069200342668}], 
     PointBox[{328, 83.53428266273716}], 
     PointBox[{329, 83.27575213910782}], 
     PointBox[{330, 83.67190918607369}], 
     PointBox[{331, 84.0528431977607}], 
     PointBox[{332, 84.42990752651397}], 
     PointBox[{333, 84.80467246612264}], 
     PointBox[{334, 85.17738846436316}], 
     PointBox[{335, 84.89969020845007}], 
     PointBox[{336, 84.63987254462367}], 
     PointBox[{337, 85.03474421625992}], 
     PointBox[{338, 84.76595841571134}], 
     PointBox[{339, 84.5131176918502}], 
     PointBox[{340, 84.26612357055902}], 
     PointBox[{341, 84.0235252472028}], 
     PointBox[{342, 83.7850394090787}], 
     PointBox[{343, 83.55054294988867}], 
     PointBox[{344, 83.31993660364788}], 
     PointBox[{345, 83.09312643426814}], 
     PointBox[{346, 82.87002127515116}], 
     PointBox[{347, 82.6505323286934}], 
     PointBox[{348, 82.43457305953343}], 
     PointBox[{349, 82.22205912894702}], 
     PointBox[{350, 82.01290833623631}], 
     PointBox[{351, 81.80704056241613}], 
     PointBox[{352, 81.60437771548524}], 
     PointBox[{353, 81.40484367721217}], 
     PointBox[{354, 81.20836425137719}], 
     PointBox[{355, 81.0148671134101}], 
     PointBox[{356, 80.8242817613637}], 
     PointBox[{357, 80.63653946823491}], 
     PointBox[{358, 80.45157323558678}], 
     PointBox[{359, 80.269317748386}], 
     PointBox[{360, 80.08970933107358}], 
     PointBox[{361, 79.91268590482731}], 
     PointBox[{362, 79.73818694598357}], 
     PointBox[{363, 79.56615344553828}], 
     PointBox[{364, 79.3965278697681}], 
     PointBox[{365, 79.22925412191812}], 
     PointBox[{366, 79.7127136966821}], 
     PointBox[{367, 80.17860405397789}], 
     PointBox[{368, 80.63854194636127}], 
     PointBox[{369, 81.09417790472754}], 
     PointBox[{370, 80.89738046782458}], 
     PointBox[{371, 80.71651935480303}], 
     PointBox[{372, 81.18845553773889}], 
     PointBox[{373, 81.6433264648152}], 
     PointBox[{374, 82.09253190832166}], 
     PointBox[{375, 82.53768731914744}], 
     PointBox[{376, 82.97908711763762}], 
     PointBox[{377, 82.76840881693116}], 
     PointBox[{378, 82.57398897420035}], 
     PointBox[{379, 83.0326769588499}], 
     PointBox[{380, 83.47460172532274}], 
     PointBox[{381, 83.91115515905719}], 
     PointBox[{382, 84.34394508726947}], 
     PointBox[{383, 84.77325851829967}], 
     PointBox[{384, 84.55076575311836}], 
     PointBox[{385, 84.34479633025255}], 
     PointBox[{386, 84.79219278854308}], 
     PointBox[{387, 85.22307743475213}], 
     PointBox[{388, 85.64883568449021}], 
     PointBox[{389, 86.07106906810827}], 
     PointBox[{390, 86.49005846528453}], 
     PointBox[{391, 86.25746821191785}], 
     PointBox[{392, 86.04162204055783}], 
     PointBox[{393, 86.4793568387997}], 
     PointBox[{394, 86.9007894126488}], 
     PointBox[{395, 87.31729982332692}], 
     PointBox[{396, 87.73048438915549}], 
     PointBox[{397, 88.14061891624354}], 
     PointBox[{398, 87.89936280160205}], 
     PointBox[{399, 87.67503496988571}], 
     PointBox[{400, 88.10446762821425}], 
     PointBox[{401, 88.51777302606278}], 
     PointBox[{402, 88.92632678867693}], 
     PointBox[{403, 89.33172091567931}], 
     PointBox[{404, 89.73422700856503}], 
     PointBox[{405, 89.4855003707008}], 
     PointBox[{406, 89.25385594105389}], 
     PointBox[{407, 89.6761220460813}], 
     PointBox[{408, 90.08240715675882}], 
     PointBox[{409, 90.48408321923273}], 
     PointBox[{410, 90.88273865072297}], 
     PointBox[{411, 91.27864156439989}], 
     PointBox[{412, 91.02344386683266}], 
     PointBox[{413, 90.78545718924266}], 
     PointBox[{414, 91.20150663698367}], 
     PointBox[{415, 91.6016975442266}], 
     PointBox[{416, 91.99739880233602}], 
     PointBox[{417, 92.39019585355825}], 
     PointBox[{418, 92.78035391374567}], 
     PointBox[{419, 92.51952206771006}], 
     PointBox[{420, 92.27600919844456}], 
     PointBox[{421, 92.68663773461893}], 
     PointBox[{422, 93.08151040334474}], 
     PointBox[{423, 93.47199355667937}], 
     PointBox[{424, 93.85967016349588}], 
     PointBox[{425, 94.24480303043212}], 
     PointBox[{426, 93.97903889553014}], 
     PointBox[{427, 93.73068435578246}], 
     PointBox[{428, 94.13655961299895}], 
     PointBox[{429, 94.52676522499013}], 
     PointBox[{430, 94.91266543053393}], 
     PointBox[{431, 95.29584113974698}], 
     PointBox[{432, 95.67655315357797}], 
     PointBox[{433, 95.40644625603282}], 
     PointBox[{434, 95.1538251403457}], 
     PointBox[{435, 95.55550815350435}], 
     PointBox[{436, 95.94159404612904}], 
     PointBox[{437, 96.32344529617961}], 
     PointBox[{438, 96.70264109808784}], 
     PointBox[{439, 97.0794405810535}], 
     PointBox[{440, 96.80548690011082}], 
     PointBox[{441, 96.54908316115707}], 
     PointBox[{442, 96.94704616437917}], 
     PointBox[{443, 97.32947315305964}], 
     PointBox[{444, 97.70772513624038}], 
     PointBox[{445, 98.08337987683862}], 
     PointBox[{446, 98.45669510895982}], 
     PointBox[{447, 98.1793126279951}], 
     PointBox[{448, 97.91953421472437}], 
     PointBox[{449, 98.31417537782697}], 
     PointBox[{450, 98.69333210180992}], 
     PointBox[{451, 99.06836416880631}], 
     PointBox[{452, 99.4408481458531}], 
     PointBox[{453, 99.81104060139529}], 
     PointBox[{454, 99.53058219458572}], 
     PointBox[{455, 99.26777359862069}], 
     PointBox[{456, 99.65942924249799}], 
     PointBox[{457, 100.0356440582166}], 
     PointBox[{458, 100.40777680186585`}], 
     PointBox[{459, 100.77740304020946`}], 
     PointBox[{460, 101.1447783665191}], 
     PointBox[{461, 100.86154248922313`}], 
     PointBox[{462, 100.5959951545985}], 
     PointBox[{463, 100.98494988791478`}], 
     PointBox[{464, 101.35850074003093`}], 
     PointBox[{465, 101.7280056078927}], 
     PointBox[{466, 102.09503922055184`}], 
     PointBox[{467, 102.45985635444276`}], 
     PointBox[{468, 102.17409592148495`}], 
     PointBox[{469, 101.90605689125528`}], 
     PointBox[{470, 102.29255203162049`}], 
     PointBox[{471, 102.66367465482907`}], 
     PointBox[{472, 103.03078193752575`}], 
     PointBox[{473, 103.39544790630345`}], 
     PointBox[{474, 103.75792665251439`}], 
     PointBox[{475, 103.46985641992796`}], 
     PointBox[{476, 103.19953552646638`}], 
     PointBox[{477, 103.58377610441562`}], 
     PointBox[{478, 103.95267084610032`}], 
     PointBox[{479, 104.31757632350147`}], 
     PointBox[{480, 104.68006597341491`}], 
     PointBox[{481, 105.04039331188082`}], 
     PointBox[{482, 104.75019602147383`}], 
     PointBox[{483, 104.47777187267572`}], 
     PointBox[{484, 104.85993246373653`}], 
     PointBox[{485, 105.22676996600737`}], 
     PointBox[{486, 105.58964044322332`}], 
     PointBox[{487, 105.9501168363417}], 
     PointBox[{488, 106.30845217765355`}], 
     PointBox[{489, 106.0162836777657}], 
     PointBox[{490, 105.74190864667582`}], 
     PointBox[{491, 106.12213823334447`}], 
     PointBox[{492, 106.48706417073862`}], 
     PointBox[{493, 106.84804209484236`}], 
     PointBox[{494, 107.20664452922693`}], 
     PointBox[{495, 107.56312409889863`}], 
     PointBox[{496, 107.26911761702637`}], 
     PointBox[{497, 106.99292200576821`}], 
     PointBox[{498, 107.3713480356019}], 
     PointBox[{499, 107.73448707013179`}], 
     PointBox[{500, 108.0936943848757}], 
     PointBox[{501, 108.45054215160113`}], 
     PointBox[{502, 108.80528265196469`}], 
     PointBox[{503, 108.50955236402424`}], 
     PointBox[{504, 108.23164788286121`}], 
     PointBox[{505, 108.60837965970478`}], 
     PointBox[{506, 108.96983874655254`}], 
     PointBox[{507, 109.32738011475479`}], 
     PointBox[{508, 109.68257563917328`}], 
     PointBox[{509, 110.03567731163999`}], 
     PointBox[{510, 109.73832132728836`}], 
     PointBox[{511, 109.45880400500513`}], 
     PointBox[{512, 109.83393552639056`}], 
     PointBox[{513, 110.19380668021162`}], 
     PointBox[{514, 110.54977218083235`}], 
     PointBox[{515, 110.90340365221314`}], 
     PointBox[{516, 111.25495284122245`}], 
     PointBox[{517, 110.95605570381906`}], 
     PointBox[{518, 110.67500832536105`}], 
     PointBox[{519, 111.04862065942865`}], 
     PointBox[{520, 111.40698327214159`}], 
     PointBox[{521, 111.76145066045166`}], 
     PointBox[{522, 112.11359423602181`}], 
     PointBox[{523, 112.4636655384046}], 
     PointBox[{524, 112.16330032110594`}], 
     PointBox[{525, 111.88079447177589`}], 
     PointBox[{526, 112.25295775091138`}], 
     PointBox[{527, 112.60988053606386`}], 
     PointBox[{528, 112.96291714001852`}], 
     PointBox[{529, 113.31363879456765`}], 
     PointBox[{530, 113.66229686358353`}], 
     PointBox[{531, 113.3605269289815}], 
     PointBox[{532, 113.07662471080843`}], 
     PointBox[{533, 113.44739980585146`}], 
     PointBox[{534, 113.80294243174777`}], 
     PointBox[{535, 114.15460674507415`}], 
     PointBox[{536, 114.50396382503064`}], 
     PointBox[{537, 114.8512648864228}], 
     PointBox[{538, 114.54814536554167`}], 
     PointBox[{539, 114.26290084016924`}], 
     PointBox[{540, 114.63234076810562`}], 
     PointBox[{541, 114.98655523119803`}], 
     PointBox[{542, 115.3368982533549}], 
     PointBox[{543, 115.68494078415708`}], 
     PointBox[{544, 116.03093391175854`}], 
     PointBox[{545, 115.72651294870501`}], 
     PointBox[{546, 115.43997335186283`}], 
     PointBox[{547, 115.80812446087808`}], 
     PointBox[{548, 116.1610562421429}], 
     PointBox[{549, 116.51012260674746`}], 
     PointBox[{550, 116.85689439401601`}], 
     PointBox[{551, 117.2016225843623}], 
     PointBox[{552, 116.89594238503665`}], 
     PointBox[{553, 116.60814914999916`}], 
     PointBox[{554, 116.97505211832478`}], 
     PointBox[{555, 117.32674115811163`}], 
     PointBox[{556, 117.67457008437647`}], 
     PointBox[{557, 118.0201096425469}], 
     PointBox[{558, 118.3636107212547}], 
     PointBox[{559, 118.05670843803681`}], 
     PointBox[{560, 117.76769805916169`}], 
     PointBox[{561, 118.1333887379852}], 
     PointBox[{562, 118.48387025880747`}], 
     PointBox[{563, 118.83049635473347`}], 
     PointBox[{564, 119.17483769111101`}], 
     PointBox[{565, 119.51714507828343`}], 
     PointBox[{566, 119.20905355725267`}], 
     PointBox[{567, 118.9188583194574}], 
     PointBox[{568, 119.28336844509403`}], 
     PointBox[{569, 119.63267364693509`}], 
     PointBox[{570, 119.97812758814669`}], 
     PointBox[{571, 120.321300865692}], 
     PointBox[{572, 120.66244422304881`}], 
     PointBox[{573, 120.35319263583496`}], 
     PointBox[{574, 120.06184123155194`}], 
     PointBox[{575, 120.42519902787453`}], 
     PointBox[{576, 120.77335567643325`}], 
     PointBox[{577, 121.11766478059961`}], 
     PointBox[{578, 121.45969687886296`}], 
     PointBox[{579, 121.79970265750937`}], 
     PointBox[{580, 121.48931703622615`}], 
     PointBox[{581, 121.19683508780912`}], 
     PointBox[{582, 121.55906577642642`}], 
     PointBox[{583, 121.90609870137637`}], 
     PointBox[{584, 122.24928741483926`}], 
     PointBox[{585, 122.59020240523311`}], 
     PointBox[{586, 122.92909430986319`}], 
     PointBox[{587, 122.6175980005019}], 
     PointBox[{588, 122.3240085030747}], 
     PointBox[{589, 122.68513473589842`}], 
     PointBox[{590, 123.0310662534115}], 
     PointBox[{591, 123.3731565639064}], 
     PointBox[{592, 123.71297611286671`}], 
     PointBox[{593, 124.05077549558852`}], 
     PointBox[{594, 123.73818954274165`}], 
     PointBox[{595, 123.44351324003588`}], 
     PointBox[{596, 123.80355546643814`}], 
     PointBox[{597, 124.14840573787998`}], 
     PointBox[{598, 124.48941752497463`}], 
     PointBox[{599, 124.8281612363356}], 
     PointBox[{600, 125.16488743117606`}], 
     PointBox[{601, 124.85123090485544`}], 
     PointBox[{602, 124.55548660852719`}], 
     PointBox[{603, 124.91446338733604`}], 
     PointBox[{604, 125.25825072411473`}], 
     PointBox[{605, 125.59820205707932`}], 
     PointBox[{606, 125.93588776313366`}], 
     PointBox[{607, 126.27155837045248`}], 
     PointBox[{608, 125.95684864401343`}], 
     PointBox[{609, 125.66005350523318`}], 
     PointBox[{610, 126.01798177014487`}], 
     PointBox[{611, 126.36072289308052`}], 
     PointBox[{612, 126.69963028436023`}], 
     PointBox[{613, 127.0362742935721}], 
     PointBox[{614, 127.37090542215238`}], 
     PointBox[{615, 127.05515840890082`}], 
     PointBox[{616, 126.75732814959844`}], 
     PointBox[{617, 127.11422343517965`}], 
     PointBox[{618, 127.45593369540578`}], 
     PointBox[{619, 127.79381231653117`}], 
     PointBox[{620, 128.1294296245802}], 
     PointBox[{621, 128.46303609791462`}], 
     PointBox[{622, 128.14626645273648`}], 
     PointBox[{623, 127.84741556269701`}], 
     PointBox[{624, 128.20329219705707`}], 
     PointBox[{625, 128.54398576435216`}], 
     PointBox[{626, 128.8808496300478}], 
     PointBox[{627, 129.21545409980243`}], 
     PointBox[{628, 129.54804963203395`}], 
     PointBox[{629, 129.230270923406}], 
     PointBox[{630, 128.93041282842995`}], 
     PointBox[{631, 129.28528409762177`}], 
     PointBox[{632, 129.6249741211476}], 
     PointBox[{633, 129.9608362464777}], 
     PointBox[{634, 130.29444076164395`}], 
     PointBox[{635, 130.6260381077923}], 
     PointBox[{636, 130.30726296466258`}], 
     PointBox[{637, 130.00641017018415`}], 
     PointBox[{638, 130.36028845862475`}], 
     PointBox[{639, 130.6989872042294}], 
     PointBox[{640, 131.0338597388662}], 
     PointBox[{641, 131.36647633527696`}], 
     PointBox[{642, 131.6970874196207}], 
     PointBox[{643, 131.37732765695304`}], 
     PointBox[{644, 131.07549187080855`}], 
     PointBox[{645, 131.42838878134648`}], 
     PointBox[{646, 131.76610774898165`}], 
     PointBox[{647, 132.10000209202684`}], 
     PointBox[{648, 132.43164206993578`}], 
     PointBox[{649, 132.76127809584062`}], 
     PointBox[{650, 132.44054482202586`}], 
     PointBox[{651, 132.1377370595053}], 
     PointBox[{652, 132.48966351616212`}], 
     PointBox[{653, 132.8264135403745}], 
     PointBox[{654, 133.15934043865118`}], 
     PointBox[{655, 133.49001445887436`}], 
     PointBox[{656, 133.81868600282675`}], 
     PointBox[{657, 133.49698971166404`}], 
     PointBox[{658, 133.19322038548364`}], 
     PointBox[{659, 133.54418672146247`}], 
     PointBox[{660, 133.8799780574817}], 
     PointBox[{661, 134.21194768975005`}], 
     PointBox[{662, 134.54166585604582`}], 
     PointBox[{663, 134.86938294824392`}], 
     PointBox[{664, 134.54673359777757`}], 
     PointBox[{665, 134.24201259520527`}], 
     PointBox[{666, 134.5920286283493}], 
     PointBox[{667, 134.92687102590708`}], 
     PointBox[{668, 135.25789307507824`}], 
     PointBox[{669, 135.58666500480393`}], 
     PointBox[{670, 135.91343719828313`}], 
     PointBox[{671, 135.58984427843524`}], 
     PointBox[{672, 135.28418102746593`}], 
     PointBox[{673, 135.63325612499457`}], 
     PointBox[{674, 135.96715889167348`}], 
     PointBox[{675, 136.29724260680098`}], 
     PointBox[{676, 136.62507749156066`}], 
     PointBox[{677, 136.95091392154083`}], 
     PointBox[{678, 136.62638651218552`}], 
     PointBox[{679, 136.31979003836182`}], 
     PointBox[{680, 136.66793317248425`}], 
     PointBox[{681, 137.0009052281291}], 
     PointBox[{682, 137.33005947764858`}], 
     PointBox[{683, 137.65696613540433`}], 
     PointBox[{684, 137.98187557028234`}], 
     PointBox[{685, 137.6564223911449}], 
     PointBox[{686, 137.34890136639672`}], 
     PointBox[{687, 137.69612116210217`}], 
     PointBox[{688, 138.0281710855993}], 
     PointBox[{689, 138.35640440311442`}], 
     PointBox[{690, 138.6823913229873}], 
     PointBox[{691, 139.0063822081891}], 
     PointBox[{692, 138.6800116617698}], 
     PointBox[{693, 138.37157444642236`}], 
     PointBox[{694, 138.71787922259762`}], 
     PointBox[{695, 139.04901529212032`}], 
     PointBox[{696, 139.3763359157917}], 
     PointBox[{697, 139.70141129662238`}], 
     PointBox[{698, 140.02449179234753`}], 
     PointBox[{699, 139.69721200086366`}], 
     PointBox[{700, 139.38786667980213`}], 
     PointBox[{701, 139.73326448463706`}], 
     PointBox[{702, 140.06349471229555`}], 
     PointBox[{703, 139.74147442697176`}], 
     PointBox[{704, 139.43702303327214`}], 
     PointBox[{705, 139.13872212599597`}], 
     PointBox[{706, 138.8449412473036}], 
     PointBox[{707, 138.5553717615746}], 
     PointBox[{708, 138.26988614925682`}], 
     PointBox[{709, 137.9883835853246}], 
     PointBox[{710, 137.7107689849197}], 
     PointBox[{711, 137.43695011160608`}], 
     PointBox[{712, 137.16683713138337`}], 
     PointBox[{713, 136.90034249913492`}], 
     PointBox[{714, 136.6373808915457}], 
     PointBox[{715, 136.37786914771857`}], 
     PointBox[{716, 136.12172621214125`}], 
     PointBox[{717, 135.86887307933472`}], 
     PointBox[{718, 135.61923274005022`}], 
     PointBox[{719, 135.37273012888767`}], 
     PointBox[{720, 135.12929207332127`}], 
     PointBox[{721, 134.88884724413373`}], 
     PointBox[{722, 134.65132610719536`}], 
     PointBox[{723, 134.4166608765038}], 
     PointBox[{724, 134.1847854685137}], 
     PointBox[{725, 133.95563545772063`}], 
     PointBox[{726, 133.72914803341615`}], 
     PointBox[{727, 133.5052619576042}], 
     PointBox[{728, 133.2839175240498}], 
     PointBox[{729, 133.06505651847408`}], 
     PointBox[{730, 132.8486221797483}], 
     PointBox[{731, 133.28299535395018`}], 
     PointBox[{732, 133.69987286775813`}], 
     PointBox[{733, 134.110870855438}], 
     PointBox[{734, 133.8692030523301}], 
     PointBox[{735, 133.6434228057048}], 
     PointBox[{736, 134.07041748611613`}], 
     PointBox[{737, 134.48032962046167`}], 
     PointBox[{738, 134.88456113273128`}], 
     PointBox[{739, 135.28472918864463`}], 
     PointBox[{740, 135.68112982457245`}], 
     PointBox[{741, 135.42544211773867`}], 
     PointBox[{742, 135.18600414486428`}], 
     PointBox[{743, 135.59966675242714`}], 
     PointBox[{744, 135.99656033072733`}], 
     PointBox[{745, 136.38807816100666`}], 
     PointBox[{746, 136.77582942736183`}], 
     PointBox[{747, 137.16010245713935`}], 
     PointBox[{748, 136.89256883350674`}], 
     PointBox[{749, 136.6415593413791}], 
     PointBox[{750, 137.04391773119198`}], 
     PointBox[{751, 137.42976748744195`}], 
     PointBox[{752, 137.81049517054765`}], 
     PointBox[{753, 138.1877034236769}], 
     PointBox[{754, 138.5616742081866}], 
     PointBox[{755, 138.28407291138174`}], 
     PointBox[{756, 138.02322428777978`}], 
     PointBox[{757, 138.4159662183258}], 
     PointBox[{758, 138.7924164745226}], 
     PointBox[{759, 139.16395605600368`}], 
     PointBox[{760, 139.53218219318634`}], 
     PointBox[{761, 139.8973715786545}], 
     PointBox[{762, 139.61118447097928`}], 
     PointBox[{763, 139.3419406321514}], 
     PointBox[{764, 139.72647308307478`}], 
     PointBox[{765, 140.0948948640739}], 
     PointBox[{766, 140.45858236895305`}], 
     PointBox[{767, 140.81912834422212`}], 
     PointBox[{768, 141.17680511716225`}], 
     PointBox[{769, 140.88326869641514`}], 
     PointBox[{770, 140.60683470626785`}], 
     PointBox[{771, 140.98433213909317`}], 
     PointBox[{772, 141.34587011289335`}], 
     PointBox[{773, 141.70282120246918`}], 
     PointBox[{774, 142.0567744358434}], 
     PointBox[{775, 142.40799851959605`}], 
     PointBox[{776, 142.1081459367997}], 
     PointBox[{777, 141.8255288787283}], 
     PointBox[{778, 142.19697299479503`}], 
     PointBox[{779, 142.55258414765376`}], 
     PointBox[{780, 142.90373174199965`}], 
     PointBox[{781, 143.25200171868914`}], 
     PointBox[{782, 143.5976597778385}], 
     PointBox[{783, 143.2923554745774}], 
     PointBox[{784, 143.00439814864285`}], 
     PointBox[{785, 143.37061067225486`}], 
     PointBox[{786, 143.72109620321885`}], 
     PointBox[{787, 144.06722151178383`}], 
     PointBox[{788, 144.41056997285918`}], 
     PointBox[{789, 144.75140478728008`}], 
     PointBox[{790, 144.4413730757703}], 
     PointBox[{791, 144.14878180679347`}], 
     PointBox[{792, 144.51045154274004`}], 
     PointBox[{793, 144.85648319138022`}], 
     PointBox[{794, 145.19824133112195`}], 
     PointBox[{795, 145.5373072016757}], 
     PointBox[{796, 145.87394192379875`}], 
     PointBox[{797, 145.55979059178946`}], 
     PointBox[{798, 145.2631581999104}], 
     PointBox[{799, 145.62086338717805`}], 
     PointBox[{800, 145.96300518746162`}], 
     PointBox[{801, 146.30094635342692`}], 
     PointBox[{802, 146.636266345919}], 
     PointBox[{803, 146.96922455245465`}], 
     PointBox[{804, 146.65146437851547`}], 
     PointBox[{805, 146.3512891727889}], 
     PointBox[{806, 146.70551597079884`}], 
     PointBox[{807, 147.04424224390846`}], 
     PointBox[{808, 147.37882922216755`}], 
     PointBox[{809, 147.71085488264026`}], 
     PointBox[{810, 148.04057716687572`}], 
     PointBox[{811, 147.71963807120179`}], 
     PointBox[{812, 147.4163395709884}], 
     PointBox[{813, 147.76749736333903`}], 
     PointBox[{814, 148.10320761517528`}], 
     PointBox[{815, 148.43483028518568`}], 
     PointBox[{816, 148.7639421112859}], 
     PointBox[{817, 149.0907998272402}], 
     PointBox[{818, 148.76704425213498`}], 
     PointBox[{819, 148.46097621384044`}], 
     PointBox[{820, 148.80941029092003`}], 
     PointBox[{821, 149.14244155995772`}], 
     PointBox[{822, 149.4714289167723}], 
     PointBox[{823, 149.797948063151}], 
     PointBox[{824, 150.1222547227809}], 
     PointBox[{825, 149.79598873003994`}], 
     PointBox[{826, 149.4874499527948}], 
     PointBox[{827, 149.83345203366724`}], 
     PointBox[{828, 150.16408913673695`}], 
     PointBox[{829, 150.49071926814764`}], 
     PointBox[{830, 150.81491726224135`}], 
     PointBox[{831, 151.13693799691998`}], 
     PointBox[{832, 150.80842048186798`}], 
     PointBox[{833, 150.49766378080403`}], 
     PointBox[{834, 150.84148075222672`}], 
     PointBox[{835, 151.16996479558316`}], 
     PointBox[{836, 151.4944731713785}], 
     PointBox[{837, 151.81657998682334`}], 
     PointBox[{838, 152.13653941071271`}], 
     PointBox[{839, 151.80598976118307`}], 
     PointBox[{840, 151.493229427519}], 
     PointBox[{841, 151.8350706104514}], 
     PointBox[{842, 152.16160606789848`}], 
     PointBox[{843, 152.48419243466208`}], 
     PointBox[{844, 152.80440320766706`}], 
     PointBox[{845, 153.1224919604432}], 
     PointBox[{846, 152.7900964304978}], 
     PointBox[{847, 152.47551444075202`}], 
     PointBox[{848, 152.81555763946983`}], 
     PointBox[{849, 153.1403182456463}], 
     PointBox[{850, 153.4611523683556}], 
     PointBox[{851, 153.77963299165725`}], 
     PointBox[{852, 154.09601318875053`}], 
     PointBox[{853, 153.76193020902548`}], 
     PointBox[{854, 153.44568139918766`}], 
     PointBox[{855, 153.78407794289058`}], 
     PointBox[{856, 154.10721160582716`}], 
     PointBox[{857, 154.42643805478394`}], 
     PointBox[{858, 154.74332984227925`}], 
     PointBox[{859, 155.058139620441}], 
     PointBox[{860, 154.7225042277896}], 
     PointBox[{861, 154.40472061011366`}], 
     PointBox[{862, 154.7415995598397}], 
     PointBox[{863, 155.0632324608884}], 
     PointBox[{864, 155.38097460749057`}], 
     PointBox[{865, 155.69639818858928`}], 
     PointBox[{866, 156.00975550149087`}], 
     PointBox[{867, 155.67268303843656`}], 
     PointBox[{868, 155.35347740725115`}], 
     PointBox[{869, 155.68894907051725`}], 
     PointBox[{870, 156.00918909022056`}], 
     PointBox[{871, 156.3255524463694}], 
     PointBox[{872, 156.63961102120203`}], 
     PointBox[{873, 156.9516168126574}], 
     PointBox[{874, 156.61320602075688`}], 
     PointBox[{875, 156.29267496807645`}], 
     PointBox[{876, 156.6268338387465}], 
     PointBox[{877, 156.94577342293286`}], 
     PointBox[{878, 157.2608484352861}], 
     PointBox[{879, 157.57363049899112`}], 
     PointBox[{880, 157.88437135908165`}], 
     PointBox[{881, 157.54470696866832`}], 
     PointBox[{882, 157.22293340926257`}], 
     PointBox[{883, 157.55586062963596`}], 
     PointBox[{884, 157.87357919015506`}], 
     PointBox[{885, 158.1874435810961}], 
     PointBox[{886, 158.49902520655974`}], 
     PointBox[{887, 158.80857559765712`}], 
     PointBox[{888, 158.4677304986087}], 
     PointBox[{889, 158.14478578694636`}], 
     PointBox[{890, 158.4765512122534}], 
     PointBox[{891, 158.7931171403779}], 
     PointBox[{892, 159.10583787163492`}], 
     PointBox[{893, 159.41628462461176`}], 
     PointBox[{894, 159.72470874924156`}], 
     PointBox[{895, 159.3827458127982}], 
     PointBox[{896, 159.0586915199994}], 
     PointBox[{897, 159.3893554516366}], 
     PointBox[{898, 159.70482780869673`}], 
     PointBox[{899, 160.0164627304702}], 
     PointBox[{900, 160.32583127825708`}], 
     PointBox[{901, 160.6331846483531}], 
     PointBox[{902, 160.2901582579613}], 
     PointBox[{903, 159.96504766519652`}], 
     PointBox[{904, 160.29466230764342`}], 
     PointBox[{905, 160.6090922463876}], 
     PointBox[{906, 160.91969148404877`}], 
     PointBox[{907, 161.22803094840918`}], 
     PointBox[{908, 161.53436170531853`}], 
     PointBox[{909, 161.19031904453618`}], 
     PointBox[{910, 160.86419839966572`}], 
     PointBox[{911, 161.19280908663166`}], 
     PointBox[{912, 161.50624104765367`}], 
     PointBox[{913, 161.81584816920994`}], 
     PointBox[{914, 162.12320126559575`}], 
     PointBox[{915, 162.4285512917686}], 
     PointBox[{916, 162.08353342913227`}], 
     PointBox[{917, 161.75644300539807`}], 
     PointBox[{918, 162.08408923301477`}], 
     PointBox[{919, 162.39656195308146`}], 
     PointBox[{920, 162.7052149532553}], 
     PointBox[{921, 163.01161895125122`}], 
     PointBox[{922, 163.31602480764343`}], 
     PointBox[{923, 162.97006761158536`}], 
     PointBox[{924, 162.642042600627}], 
     PointBox[{925, 162.96875889909728`}], 
     PointBox[{926, 163.28030626196258`}], 
     PointBox[{927, 163.5880383926904}], 
     PointBox[{928, 163.89352592670775`}], 
     PointBox[{929, 164.19701964414995`}], 
     PointBox[{930, 163.85015455553759`}], 
     PointBox[{931, 163.5212258215591}], 
     PointBox[{932, 163.8470424914012}], 
     PointBox[{933, 164.15769424657657`}], 
     PointBox[{934, 164.46453471874344`}], 
     PointBox[{935, 164.76913447312234`}], 
     PointBox[{936, 165.0717442212114}], 
     PointBox[{937, 164.7239989064268}], 
     PointBox[{938, 164.3941936238458}], 
     PointBox[{939, 164.71913735850734`}], 
     PointBox[{940, 165.02891972920082`}], 
     PointBox[{941, 165.33489430625357`}], 
     PointBox[{942, 165.63863159491962`}], 
     PointBox[{943, 165.94038224805558`}], 
     PointBox[{944, 165.59178115173677`}], 
     PointBox[{945, 165.2611233449668}], 
     PointBox[{946, 165.58521775794802`}], 
     PointBox[{947, 165.89415395584524`}], 
     PointBox[{948, 166.19928545654346`}], 
     PointBox[{949, 166.50218271400627`}], 
     PointBox[{950, 166.8030963309302}], 
     PointBox[{951, 166.4536611443282}], 
     PointBox[{952, 166.12217214522005`}], 
     PointBox[{953, 166.44543821687762`}], 
     PointBox[{954, 166.75354887855946`}], 
     PointBox[{955, 167.05785760324585`}], 
     PointBox[{956, 167.35993480098165`}], 
     PointBox[{957, 167.66003103149762`}], 
     PointBox[{958, 167.30978108977965`}], 
     PointBox[{959, 166.97747992573386`}], 
     PointBox[{960, 167.29993638241461`}], 
     PointBox[{961, 167.60723993973164`}], 
     PointBox[{962, 167.91074403216928`}], 
     PointBox[{963, 168.21201903211224`}], 
     PointBox[{964, 168.5113154624463}], 
     PointBox[{965, 168.16026808210478`}], 
     PointBox[{966, 167.82717180572365`}], 
     PointBox[{967, 168.14883544184397`}], 
     PointBox[{968, 168.45534843660351`}], 
     PointBox[{969, 168.7580641914467}], 
     PointBox[{970, 169.05855304642208`}], 
     PointBox[{971, 169.35706549277353`}], 
     PointBox[{972, 169.0052362584711}], 
     PointBox[{973, 168.67136022784854`}], 
     PointBox[{974, 168.9922461797958}], 
     PointBox[{975, 169.29798353142826`}], 
     PointBox[{976, 169.59992565578477`}], 
     PointBox[{977, 169.89964286511622`}], 
     PointBox[{978, 170.1973856234577}], 
     PointBox[{979, 169.84478863215122`}], 
     PointBox[{980, 169.51014674946452`}], 
     PointBox[{981, 169.83026872876962`}], 
     PointBox[{982, 170.13524396220973`}], 
     PointBox[{983, 170.43642579837712`}], 
     PointBox[{984, 170.73538452558856`}], 
     PointBox[{985, 171.0323705844528}], 
     PointBox[{986, 170.6790186533733}], 
     PointBox[{987, 170.34362356816524`}], 
     PointBox[{988, 170.66299406021778`}], 
     PointBox[{989, 170.96721950014998`}], 
     PointBox[{990, 171.26765321548362`}], 
     PointBox[{991, 171.56586547390083`}], 
     PointBox[{992, 171.86210669580709`}], 
     PointBox[{993, 171.50801153982627`}], 
     PointBox[{994, 171.17187482239967`}], 
     PointBox[{995, 171.4905052559509}], 
     PointBox[{996, 171.79399219252565`}], 
     PointBox[{997, 172.09368894144973`}], 
     PointBox[{998, 172.39116575259226`}], 
     PointBox[{999, 172.68667302891274`}], 
     PointBox[{1000, 172.33184541194794`}], 
     PointBox[{1001, 171.99497770140212`}], 
     PointBox[{1002, 172.31287859330746`}], 
     PointBox[{1003, 172.61563742365178`}], 
     PointBox[{1004, 172.91460748603663`}], 
     PointBox[{1005, 173.2113590149259}], 
     PointBox[{1006, 173.50614239818574`}], 
     PointBox[{1007, 173.1505922625705}], 
     PointBox[{1008, 172.81300339330284`}], 
     PointBox[{1009, 173.13018447222566`}], 
     PointBox[{1010, 173.4322248214272}], 
     PointBox[{1011, 173.73047772088842`}], 
     PointBox[{1012, 174.0265133917301}], 
     PointBox[{1013, 174.320582208744}], 
     PointBox[{1014, 173.96431878587578`}], 
     PointBox[{1015, 173.62601789579006`}], 
     PointBox[{1016, 173.9424882080322}], 
     PointBox[{1017, 174.24381903263503`}], 
     PointBox[{1018, 174.5413636377624}], 
     PointBox[{1019, 174.83669223295914`}], 
     PointBox[{1020, 175.13005518167142`}], 
     PointBox[{1021, 174.7730870867212}], 
     PointBox[{1022, 174.4340827098744}], 
     PointBox[{1023, 174.74985070998935`}], 
     PointBox[{1024, 175.05048038662648`}], 
     PointBox[{1025, 175.34732499768492`}], 
     PointBox[{1026, 175.6419547426421}], 
     PointBox[{1027, 175.93461997508135`}], 
     PointBox[{1028, 175.57695528814855`}], 
     PointBox[{1029, 175.23725543412786`}], 
     PointBox[{1030, 175.55232906257925`}], 
     PointBox[{1031, 175.8522654639484}], 
     PointBox[{1032, 176.14841788719195`}], 
     PointBox[{1033, 176.44235652302336`}], 
     PointBox[{1034, 176.73433171643165`}], 
     PointBox[{1035, 176.37597805213068`}], 
     PointBox[{1036, 176.0355902741388}], 
     PointBox[{1037, 176.34997702390757`}], 
     PointBox[{1038, 176.6492275839321}], 
     PointBox[{1039, 176.94469519537026`}], 
     PointBox[{1040, 177.23795004128226`}], 
     PointBox[{1041, 177.52924245915273`}], 
     PointBox[{1042, 177.17020702633596`}], 
     PointBox[{1043, 176.82913847962757`}], 
     PointBox[{1044, 177.14284545339325`}], 
     PointBox[{1045, 177.44141722317494`}], 
     PointBox[{1046, 177.73620702331272`}], 
     PointBox[{1047, 178.02878503017502`}], 
     PointBox[{1048, 178.3194015746784}], 
     PointBox[{1049, 177.95969122773297`}], 
     PointBox[{1050, 177.61794871981027`}], 
     PointBox[{1051, 177.93098267906998`}], 
     PointBox[{1052, 178.2288823749633}], 
     PointBox[{1053, 178.5230010358526}], 
     PointBox[{1054, 178.8149088322383}], 
     PointBox[{1055, 179.10485608927527`}], 
     PointBox[{1056, 178.74447737221993`}], 
     PointBox[{1057, 178.40206740599248`}], 
     PointBox[{1058, 178.71443481330314`}], 
     PointBox[{1059, 179.01166885825302`}], 
     PointBox[{1060, 179.30512276394978`}], 
     PointBox[{1061, 179.59636669573467`}], 
     PointBox[{1062, 179.88565097369778`}], 
     PointBox[{1063, 179.52461015812003`}], 
     PointBox[{1064, 179.1815389690359}], 
     PointBox[{1065, 179.49324602435715`}], 
     PointBox[{1066, 179.78982058347125`}], 
     PointBox[{1067, 180.08261586485617`}], 
     PointBox[{1068, 179.7247658375129}], 
     PointBox[{1069, 179.38477002339053`}], 
     PointBox[{1070, 179.05103041189534`}], 
     PointBox[{1071, 178.72189126947012`}], 
     PointBox[{1072, 178.3970395938536}], 
     PointBox[{1073, 178.07634635247018`}], 
     PointBox[{1074, 177.75970961697487`}], 
     PointBox[{1075, 177.44703327756787`}], 
     PointBox[{1076, 177.13822410574926`}], 
     PointBox[{1077, 176.8331913015638}], 
     PointBox[{1078, 176.53184637857143`}], 
     PointBox[{1079, 176.2341030960137}], 
     PointBox[{1080, 175.93987739870443`}], 
     PointBox[{1081, 175.6490873593994}], 
     PointBox[{1082, 175.36165312286448`}], 
     PointBox[{1083, 175.07749685144216`}], 
     PointBox[{1084, 174.79654267208616`}], 
     PointBox[{1085, 174.5187166248421}], 
     PointBox[{1086, 174.2439466127654}], 
     PointBox[{1087, 173.97216235310805`}], 
     PointBox[{1088, 173.70329532987478`}], 
     PointBox[{1089, 173.43727874767046`}], 
     PointBox[{1090, 173.17404748677654`}], 
     PointBox[{1091, 172.91353805941722`}], 
     PointBox[{1092, 172.655688567224}], 
     PointBox[{1093, 172.40043865988184`}], 
     PointBox[{1094, 172.14772949481505`}], 
     PointBox[{1095, 171.89750369798418`}], 
     PointBox[{1096, 172.29814151756617`}], 
     PointBox[{1097, 172.6813391969153}], 
     PointBox[{1098, 172.41027610935316`}], 
     PointBox[{1099, 172.154850833}], 
     PointBox[{1100, 172.5521344004543}], 
     PointBox[{1101, 172.93229577066455`}], 
     PointBox[{1102, 173.30674197958527`}], 
     PointBox[{1103, 173.6770923775685}], 
     PointBox[{1104, 174.04364474841748`}], 
     PointBox[{1105, 173.75807981767713`}], 
     PointBox[{1106, 173.48873725813866`}], 
     PointBox[{1107, 173.87246946752464`}], 
     PointBox[{1108, 174.23940834459523`}], 
     PointBox[{1109, 174.6009486375553}], 
     PointBox[{1110, 174.95870095713315`}], 
     PointBox[{1111, 175.31295501809294`}], 
     PointBox[{1112, 175.01538375287856`}], 
     PointBox[{1113, 174.7343192586033}], 
     PointBox[{1114, 175.10660656183535`}], 
     PointBox[{1115, 175.46237038814178`}], 
     PointBox[{1116, 175.81299850490478`}], 
     PointBox[{1117, 176.16009472908837`}], 
     PointBox[{1118, 176.5039421635965}], 
     PointBox[{1119, 176.19620730591205`}], 
     PointBox[{1120, 175.90521599022097`}], 
     PointBox[{1121, 176.26780714747326`}], 
     PointBox[{1122, 176.61409957032097`}], 
     PointBox[{1123, 176.95547525148334`}], 
     PointBox[{1124, 177.29353238716268`}], 
     PointBox[{1125, 177.6285486091872}], 
     PointBox[{1126, 177.31218508954868`}], 
     PointBox[{1127, 177.01276247853588`}], 
     PointBox[{1128, 177.36711466092817`}], 
     PointBox[{1129, 177.7053555171655}], 
     PointBox[{1130, 178.03886225804786`}], 
     PointBox[{1131, 178.3692284246019}], 
     PointBox[{1132, 178.69672711675378`}], 
     PointBox[{1133, 178.37301509451288`}], 
     PointBox[{1134, 178.06640871284293`}], 
     PointBox[{1135, 178.4137376746586}], 
     PointBox[{1136, 178.74511178892016`}], 
     PointBox[{1137, 179.0719043023342}], 
     PointBox[{1138, 179.3957048962904}], 
     PointBox[{1139, 179.71678291270996`}], 
     PointBox[{1140, 179.3867914524563}], 
     PointBox[{1141, 179.07404330752922`}], 
     PointBox[{1142, 179.4153647114608}], 
     PointBox[{1143, 179.74086209487086`}], 
     PointBox[{1144, 180.06190541469903`}], 
     PointBox[{1145, 180.38008114875277`}], 
     PointBox[{1146, 180.695655519218}], 
     PointBox[{1147, 180.36027858881346`}], 
     PointBox[{1148, 180.04226019077677`}], 
     PointBox[{1149, 180.37842367712068`}], 
     PointBox[{1150, 180.69887267210453`}], 
     PointBox[{1151, 181.01497439944643`}], 
     PointBox[{1152, 181.32831267490226`}], 
     PointBox[{1153, 181.63915112785378`}], 
     PointBox[{1154, 181.29913729561238`}], 
     PointBox[{1155, 180.9765785515902}], 
     PointBox[{1156, 181.30829585179737`}], 
     PointBox[{1157, 181.62439048660025`}], 
     PointBox[{1158, 181.93622740627333`}], 
     PointBox[{1159, 182.2453882119559}], 
     PointBox[{1160, 182.55213437566758`}], 
     PointBox[{1161, 182.20811133308078`}], 
     PointBox[{1162, 181.88162441020435`}], 
     PointBox[{1163, 182.20949256843406`}], 
     PointBox[{1164, 182.52181515490005`}], 
     PointBox[{1165, 182.82995522665223`}], 
     PointBox[{1166, 183.13549254028032`}], 
     PointBox[{1167, 183.43868677063853`}], 
     PointBox[{1168, 183.09118160235835`}], 
     PointBox[{1169, 182.76128065530636`}], 
     PointBox[{1170, 183.08580122843836`}], 
     PointBox[{1171, 183.3948410489923}], 
     PointBox[{1172, 183.69976159554523`}], 
     PointBox[{1173, 184.00214108653427`}], 
     PointBox[{1174, 184.30223769791746`}], 
     PointBox[{1175, 183.9516936536474}], 
     PointBox[{1176, 183.61881115012037`}], 
     PointBox[{1177, 183.94040609903846`}], 
     PointBox[{1178, 184.24657487566583`}], 
     PointBox[{1179, 184.5486776409433}], 
     PointBox[{1180, 184.84829132910338`}], 
     PointBox[{1181, 185.1456728644597}], 
     PointBox[{1182, 184.79246325101795`}], 
     PointBox[{1183, 184.45696349609952`}], 
     PointBox[{1184, 184.77598835238481`}], 
     PointBox[{1185, 185.07963306538892`}], 
     PointBox[{1186, 185.37925669480484`}], 
     PointBox[{1187, 185.676435101374}], 
     PointBox[{1188, 185.97142416294895`}], 
     PointBox[{1189, 185.61586386340122`}], 
     PointBox[{1190, 185.2780542155517}], 
     PointBox[{1191, 185.59480900255073`}], 
     PointBox[{1192, 185.89622252469738`}], 
     PointBox[{1193, 186.193652920156}], 
     PointBox[{1194, 186.4886751512103}], 
     PointBox[{1195, 186.78154421971698`}], 
     PointBox[{1196, 186.42389925543773`}], 
     PointBox[{1197, 186.0840394384021}], 
     PointBox[{1198, 186.39877773973402`}], 
     PointBox[{1199, 186.69820766793174`}], 
     PointBox[{1200, 186.9936865890597}], 
     PointBox[{1201, 187.28678871249616`}], 
     PointBox[{1202, 187.5777683058912}], 
     PointBox[{1203, 187.21826378301165`}], 
     PointBox[{1204, 186.87657362563908`}], 
     PointBox[{1205, 187.18951012394234`}], 
     PointBox[{1206, 187.487166122298}], 
     PointBox[{1207, 187.78089833906301`}], 
     PointBox[{1208, 188.07228035190045`}], 
     PointBox[{1209, 188.36156581231674`}], 
     PointBox[{1210, 188.00039253311638`}], 
     PointBox[{1211, 187.65705840990654`}], 
     PointBox[{1212, 187.96837516109383`}], 
     PointBox[{1213, 188.26443507333505`}], 
     PointBox[{1214, 188.5565943209488}], 
     PointBox[{1215, 188.846425950893}], 
     PointBox[{1216, 189.1341830969681}], 
     PointBox[{1217, 188.77150306693142`}], 
     PointBox[{1218, 188.4266832636825}], 
     PointBox[{1219, 188.73653492494924`}], 
     PointBox[{1220, 189.03114986843218`}], 
     PointBox[{1221, 189.32188381091407`}], 
     PointBox[{1222, 189.61030935295105`}], 
     PointBox[{1223, 189.8966791927965}], 
     PointBox[{1224, 189.5326302132361}], 
     PointBox[{1225, 189.18645940250656`}], 
     PointBox[{1226, 189.49497759372298`}], 
     PointBox[{1227, 189.78827620976614`}], 
     PointBox[{1228, 190.0777105821532}], 
     PointBox[{1229, 190.36485293547756`}], 
     PointBox[{1230, 190.64995560110677`}], 
     PointBox[{1231, 190.2846551037838}], 
     PointBox[{1232, 189.93724808232832`}], 
     PointBox[{1233, 190.24454502884112`}], 
     PointBox[{1234, 190.53663703339282`}], 
     PointBox[{1235, 190.82487910267366`}], 
     PointBox[{1236, 191.11084314424355`}], 
     PointBox[{1237, 191.39478118003575`}], 
     PointBox[{1238, 191.02832943276275`}], 
     PointBox[{1239, 190.67978424643482`}], 
     PointBox[{1240, 190.98595582538675`}], 
     PointBox[{1241, 191.27693497878835`}], 
     PointBox[{1242, 191.56407643912803`}], 
     PointBox[{1243, 191.84895184628928`}], 
     PointBox[{1244, 192.131812960898}], 
     PointBox[{1245, 191.76429575056795`}], 
     PointBox[{1246, 191.41469631026587`}], 
     PointBox[{1247, 191.7198246011886}], 
     PointBox[{1248, 192.00977119513038`}], 
     PointBox[{1249, 192.2958905928169}], 
     PointBox[{1250, 192.57975420785155`}], 
     PointBox[{1251, 192.86161357991875`}], 
     PointBox[{1252, 192.49310446090703`}], 
     PointBox[{1253, 192.14252273513858`}], 
     PointBox[{1254, 192.44667815812875`}], 
     PointBox[{1255, 192.73566110082507`}], 
     PointBox[{1256, 193.02082586782032`}], 
     PointBox[{1257, 193.30374368119465`}], 
     PointBox[{1258, 193.58466589359548`}], 
     PointBox[{1259, 193.21522807425322`}], 
     PointBox[{1260, 192.8637259291078}], 
     PointBox[{1261, 193.16696903946143`}], 
     PointBox[{1262, 193.4550476061126}], 
     PointBox[{1263, 193.73931576747782`}], 
     PointBox[{1264, 194.02134458332728`}], 
     PointBox[{1265, 194.3013852477761}], 
     PointBox[{1266, 193.931073175213}], 
     PointBox[{1267, 193.57870392032987`}], 
     PointBox[{1268, 193.88108691668657`}], 
     PointBox[{1269, 194.1683122207674}], 
     PointBox[{1270, 194.45173383001435`}], 
     PointBox[{1271, 194.73292266648414`}], 
     PointBox[{1272, 195.0121297897582}], 
     PointBox[{1273, 194.64099048279837`}], 
     PointBox[{1274, 194.28780017190127`}], 
     PointBox[{1275, 194.5893681651856}], 
     PointBox[{1276, 194.87578439658034`}], 
     PointBox[{1277, 195.15840274379212`}], 
     PointBox[{1278, 195.43879401188676`}], 
     PointBox[{1279, 195.7172091461448}], 
     PointBox[{1280, 195.34528331784134`}], 
     PointBox[{1281, 194.991311844145}], 
     PointBox[{1282, 195.2921039265372}], 
     PointBox[{1283, 195.57774939474888`}], 
     PointBox[{1284, 195.85960202466686`}], 
     PointBox[{1285, 196.13923252185572`}], 
     PointBox[{1286, 196.41689173436143`}], 
     PointBox[{1287, 196.04421473843746`}], 
     PointBox[{1288, 195.6894967583869}], 
     PointBox[{1289, 195.98954690493446`}], 
     PointBox[{1290, 196.2744549191145}], 
     PointBox[{1291, 196.55557449012264`}], 
     PointBox[{1292, 196.8344762387975}], 
     PointBox[{1293, 197.11141093037435`}], 
     PointBox[{1294, 196.73801356016375`}], 
     PointBox[{1295, 196.38257927335016`}], 
     PointBox[{1296, 196.68191710332493`}], 
     PointBox[{1297, 196.96611671552859`}], 
     PointBox[{1298, 197.24653172526556`}], 
     PointBox[{1299, 197.52473268114113`}], 
     PointBox[{1300, 197.80097027777725`}], 
     PointBox[{1301, 197.42687944145518`}], 
     PointBox[{1302, 197.07075524987425`}], 
     PointBox[{1303, 197.3694066704531}], 
     PointBox[{1304, 197.65292330413115`}], 
     PointBox[{1305, 197.93265870315338`}], 
     PointBox[{1306, 198.21018335447076`}], 
     PointBox[{1307, 198.48574789242323`}], 
     PointBox[{1308, 198.11098718435397`}], 
     PointBox[{1309, 197.75419625033265`}], 
     PointBox[{1310, 198.05218400142672`}], 
     PointBox[{1311, 198.33503998347663`}], 
     PointBox[{1312, 198.61411769484818`}], 
     PointBox[{1313, 198.89098756980923`}], 
     PointBox[{1314, 199.16590019117567`}], 
     PointBox[{1315, 198.79049037590755`}], 
     PointBox[{1316, 198.4330530948024}], 
     PointBox[{1317, 198.73039721074406`}], 
     PointBox[{1318, 199.01261222244773`}], 
     PointBox[{1319, 199.29105158219028`}], 
     PointBox[{1320, 199.56728567916323`}], 
     PointBox[{1321, 199.84156505209737`}], 
     PointBox[{1322, 199.46552447483066`}], 
     PointBox[{1323, 199.10745887598608`}], 
     PointBox[{1324, 199.40417707719746`}], 
     PointBox[{1325, 199.68576853682725`}], 
     PointBox[{1326, 199.96358666767952`}], 
     PointBox[{1327, 200.2392018203381}], 
     PointBox[{1328, 200.51286449576355`}], 
     PointBox[{1329, 200.13620943084797`}], 
     PointBox[{1330, 199.77753151806982`}], 
     PointBox[{1331, 200.07363954370427`}], 
     PointBox[{1332, 200.35462293151897`}], 
     PointBox[{1333, 200.63183506047568`}], 
     PointBox[{1334, 200.9068462480487}], 
     PointBox[{1335, 201.17990696280214`}], 
     PointBox[{1336, 200.80265190993254`}], 
     PointBox[{1337, 200.4433759509064}], 
     PointBox[{1338, 200.73888784165385`}], 
     PointBox[{1339, 201.01927697625501`}], 
     PointBox[{1340, 201.2958967046173}], 
     PointBox[{1341, 201.5703173157815}], 
     PointBox[{1342, 201.84278925049546`}], 
     PointBox[{1343, 201.46494718673245`}], 
     PointBox[{1344, 201.10508595931873`}], 
     PointBox[{1345, 201.40001429811156`}], 
     PointBox[{1346, 201.67982157167503`}], 
     PointBox[{1347, 201.95586110494622`}], 
     PointBox[{1348, 202.22970316252858`}], 
     PointBox[{1349, 202.50159816124943`}], 
     PointBox[{1350, 202.1231807556702}], 
     PointBox[{1351, 201.76274575770228`}], 
     PointBox[{1352, 202.05710187477578`}], 
     PointBox[{1353, 202.33633845350084`}], 
     PointBox[{1354, 202.61180879732663`}], 
     PointBox[{1355, 202.88508314981823`}], 
     PointBox[{1356, 203.15641190721226`}], 
     PointBox[{1357, 202.7774297039125}], 
     PointBox[{1358, 202.4164313320968}], 
     PointBox[{1359, 202.71022547987607`}], 
     PointBox[{1360, 202.98890147494893`}], 
     PointBox[{1361, 203.26381260224764`}], 
     PointBox[{1362, 203.53652908720503`}], 
     PointBox[{1363, 203.80730130830983`}], 
     PointBox[{1364, 203.42776388258628`}], 
     PointBox[{1365, 203.06621158519772`}], 
     PointBox[{1366, 203.3594530875917}], 
     PointBox[{1367, 203.63757770114893`}], 
     PointBox[{1368, 203.91193869482666`}], 
     PointBox[{1369, 204.18410627841544`}], 
     PointBox[{1370, 204.4543308150795}], 
     PointBox[{1371, 204.0742469068436}], 
     PointBox[{1372, 203.7121493141736}], 
     PointBox[{1373, 204.0048466941295}], 
     PointBox[{1374, 204.28242834399728`}], 
     PointBox[{1375, 204.55624751893123`}], 
     PointBox[{1376, 204.8278744152022}], 
     PointBox[{1377, 205.09755938272968`}], 
     PointBox[{1378, 204.71693701057092`}], 
     PointBox[{1379, 204.35430204648569`}], 
     PointBox[{1380, 204.64646313508723`}], 
     PointBox[{1381, 204.92350956147286`}], 
     PointBox[{1382, 205.1967945688495}], 
     PointBox[{1383, 205.46788834178903`}], 
     PointBox[{1384, 205.73704121875068`}], 
     PointBox[{1385, 205.35588777756104`}], 
     PointBox[{1386, 204.99272275497563`}], 
     PointBox[{1387, 205.2843547848302}], 
     PointBox[{1388, 205.56087314165927`}], 
     PointBox[{1389, 205.83363105831867`}], 
     PointBox[{1390, 206.10419870924045`}], 
     PointBox[{1391, 206.37282642294937`}], 
     PointBox[{1392, 205.99114876753225`}], 
     PointBox[{1393, 205.627460470201}], 
     PointBox[{1394, 205.91857015544076`}], 
     PointBox[{1395, 206.19456708862145`}], 
     PointBox[{1396, 206.46680449361733`}], 
     PointBox[{1397, 206.7368525360563}], 
     PointBox[{1398, 207.00496153583407`}], 
     PointBox[{1399, 206.62276605258026`}], 
     PointBox[{1400, 206.2585608052168}], 
     PointBox[{1401, 206.54915441010172`}], 
     PointBox[{1402, 206.8246361246425}], 
     PointBox[{1403, 207.09635916490288`}], 
     PointBox[{1404, 207.365893688852}], 
     PointBox[{1405, 207.63349000888303`}], 
     PointBox[{1406, 207.25078267726678`}], 
     PointBox[{1407, 206.88606640571217`}], 
     PointBox[{1408, 207.17614980350237`}], 
     PointBox[{1409, 207.45112212110718`}], 
     PointBox[{1410, 207.72233656778997`}], 
     PointBox[{1411, 207.9913632948519}], 
     PointBox[{1412, 208.25845260814418`}], 
     PointBox[{1413, 207.87523905352475`}], 
     PointBox[{1414, 207.5100173364117}], 
     PointBox[{1415, 207.7995960599173}], 
     PointBox[{1416, 208.0740644684617}], 
     PointBox[{1417, 208.34477576537486`}], 
     PointBox[{1418, 208.61330009613553`}], 
     PointBox[{1419, 208.87988776088332`}], 
     PointBox[{1420, 208.4961732998724}], 
     PointBox[{1421, 208.13045141302743`}], 
     PointBox[{1422, 208.41953069806993`}], 
     PointBox[{1423, 208.69350039413047`}], 
     PointBox[{1424, 208.9637136993464}], 
     PointBox[{1425, 209.23174075410589`}], 
     PointBox[{1426, 209.49783185355204`}], 
     PointBox[{1427, 209.11362153303367`}], 
     PointBox[{1428, 208.7474044876676}], 
     PointBox[{1429, 209.03598931045076`}], 
     PointBox[{1430, 209.30946523587775`}], 
     PointBox[{1431, 209.57918545753952`}], 
     PointBox[{1432, 209.84672011136092`}], 
     PointBox[{1433, 209.4638832963073}], 
     PointBox[{1434, 209.09899494154791`}], 
     PointBox[{1435, 208.7404317733707}], 
     PointBox[{1436, 208.3865337041574}], 
     PointBox[{1437, 208.03698623119487`}], 
     PointBox[{1438, 207.69165923114153`}], 
     PointBox[{1439, 207.3504497632506}], 
     PointBox[{1440, 207.0132607381817}], 
     PointBox[{1441, 206.67999797399452`}], 
     PointBox[{1442, 206.35056974190962`}], 
     PointBox[{1443, 206.02488665052573`}], 
     PointBox[{1444, 205.7028615772681}], 
     PointBox[{1445, 205.3844096076738}], 
     PointBox[{1446, 205.06944797718344`}], 
     PointBox[{1447, 204.7578960145808}], 
     PointBox[{1448, 204.44967508697866`}], 
     PointBox[{1449, 204.14470854630338`}], 
     PointBox[{1450, 203.84292167725746`}], 
     PointBox[{1451, 203.544241646655}], 
     PointBox[{1452, 203.2485974541106}], 
     PointBox[{1453, 202.9559198841231}], 
     PointBox[{1454, 202.66614145941287`}], 
     PointBox[{1455, 202.37919639551396`}], 
     PointBox[{1456, 202.09502055658038`}], 
     PointBox[{1457, 201.81355141245393`}], 
     PointBox[{1458, 201.53472799680225`}], 
     PointBox[{1459, 201.25849086639755`}], 
     PointBox[{1460, 200.9847820615472}], 
     PointBox[{1461, 201.3619812593398}], 
     PointBox[{1462, 201.0733479544063}], 
     PointBox[{1463, 200.79874637505526`}], 
     PointBox[{1464, 201.1765927969315}], 
     PointBox[{1465, 201.5372398532108}], 
     PointBox[{1466, 201.8921210240605}], 
     PointBox[{1467, 202.24286078395147`}], 
     PointBox[{1468, 202.5897591134591}], 
     PointBox[{1469, 202.2844984976881}], 
     PointBox[{1470, 201.99542026986174`}], 
     PointBox[{1471, 202.35937843587462`}], 
     PointBox[{1472, 202.70650645782055`}], 
     PointBox[{1473, 203.0482006044304}], 
     PointBox[{1474, 203.38607296545595`}], 
     PointBox[{1475, 203.7204146943392}], 
     PointBox[{1476, 203.402900122974}], 
     PointBox[{1477, 203.1018627097672}], 
     PointBox[{1478, 203.45414880549296`}], 
     PointBox[{1479, 203.78988442384693`}], 
     PointBox[{1480, 204.1204585852544}], 
     PointBox[{1481, 204.44747632560922`}], 
     PointBox[{1482, 204.77122193356388`}], 
     PointBox[{1483, 204.44336306008825`}], 
     PointBox[{1484, 204.1322266614704}], 
     PointBox[{1485, 204.47465276024167`}], 
     PointBox[{1486, 204.80076121096414`}], 
     PointBox[{1487, 205.12193503938653`}], 
     PointBox[{1488, 205.43977344666897`}], 
     PointBox[{1489, 205.75455504228503`}], 
     PointBox[{1490, 205.41794194931902`}], 
     PointBox[{1491, 205.09825574331143`}], 
     PointBox[{1492, 205.4323312091604}], 
     PointBox[{1493, 205.7502831029941}], 
     PointBox[{1494, 206.06348948751724`}], 
     PointBox[{1495, 206.37354473253183`}], 
     PointBox[{1496, 206.68072274424972`}], 
     PointBox[{1497, 206.33668106708217`}], 
     PointBox[{1498, 206.00973681910043`}], 
     PointBox[{1499, 206.33672044562496`}], 
     PointBox[{1500, 206.64774247787904`}], 
     PointBox[{1501, 206.95417686522586`}], 
     PointBox[{1502, 207.25761397264944`}], 
     PointBox[{1503, 207.55832380711502`}], 
     PointBox[{1504, 207.20796011649415`}], 
     PointBox[{1505, 206.87483632222666`}], 
     PointBox[{1506, 207.19577927020921`}], 
     PointBox[{1507, 207.50089598681103`}], 
     PointBox[{1508, 207.80155700854527`}], 
     PointBox[{1509, 208.09934937706367`}], 
     PointBox[{1510, 208.39453986308956`}], 
     PointBox[{1511, 208.03877906298737`}], 
     PointBox[{1512, 207.70037732914494`}], 
     PointBox[{1513, 208.0161585186233}], 
     PointBox[{1514, 208.3162267470154}], 
     PointBox[{1515, 208.61194971601168`}], 
     PointBox[{1516, 208.9049117063479}], 
     PointBox[{1517, 209.19537679974843`}], 
     PointBox[{1518, 208.83499297355795`}], 
     PointBox[{1519, 208.49206802924914`}], 
     PointBox[{1520, 208.80342333923852`}], 
     PointBox[{1521, 209.09916059896392`}], 
     PointBox[{1522, 209.39064515272608`}], 
     PointBox[{1523, 209.67945898495316`}], 
     PointBox[{1524, 209.96586394050078`}], 
     PointBox[{1525, 209.60150581770216`}], 
     PointBox[{1526, 209.25469029532474`}], 
     PointBox[{1527, 209.56223667788032`}], 
     PointBox[{1528, 209.85424464624236`}], 
     PointBox[{1529, 210.14207758206322`}], 
     PointBox[{1530, 210.42731555764996`}], 
     PointBox[{1531, 210.71021855492137`}], 
     PointBox[{1532, 210.34243055715774`}], 
     PointBox[{1533, 209.99225547467336`}], 
     PointBox[{1534, 210.2965108888831}], 
     PointBox[{1535, 210.58529480173388`}], 
     PointBox[{1536, 210.86996895893404`}], 
     PointBox[{1537, 211.15211183869167`}], 
     PointBox[{1538, 211.4319818695717}], 
     PointBox[{1539, 211.06122152116026`}], 
     PointBox[{1540, 210.70813322868793`}], 
     PointBox[{1541, 211.00953313607664`}], 
     PointBox[{1542, 211.2955178443803}], 
     PointBox[{1543, 211.57744773405113`}], 
     PointBox[{1544, 211.8568999527322}], 
     PointBox[{1545, 212.1341316322006}], 
     PointBox[{1546, 211.76078397815004`}], 
     PointBox[{1547, 211.40515819394403`}], 
     PointBox[{1548, 211.70406922282262`}], 
     PointBox[{1549, 211.9876124955224}], 
     PointBox[{1550, 212.26714725175037`}], 
     PointBox[{1551, 212.54424952719472`}], 
     PointBox[{1552, 212.81917536972242`}], 
     PointBox[{1553, 212.44356492842454`}], 
     PointBox[{1554, 212.08571837665312`}], 
     PointBox[{1555, 212.3824496535352}], 
     PointBox[{1556, 212.66385321091678`}], 
     PointBox[{1557, 212.9412873341812}], 
     PointBox[{1558, 213.21632712861884`}], 
     PointBox[{1559, 213.48922773500325`}], 
     PointBox[{1560, 213.11162841802002`}], 
     PointBox[{1561, 212.7518284887289}], 
     PointBox[{1562, 213.04664104550312`}], 
     PointBox[{1563, 213.32615972039957`}], 
     PointBox[{1564, 213.6017419994481}], 
     PointBox[{1565, 213.87496220848948`}], 
     PointBox[{1566, 214.14607472823042`}], 
     PointBox[{1567, 213.76671808217918`}], 
     PointBox[{1568, 213.40519085861567`}], 
     PointBox[{1569, 213.69830545106055`}], 
     PointBox[{1570, 213.97615480417772`}], 
     PointBox[{1571, 214.25009573361274`}], 
     PointBox[{1572, 214.52170191140206`}], 
     PointBox[{1573, 214.7912270805972}], 
     PointBox[{1574, 214.4103091427815}], 
     PointBox[{1575, 214.0472460796447}], 
     PointBox[{1576, 214.33884969304935`}], 
     PointBox[{1577, 214.61521235056193`}], 
     PointBox[{1578, 214.8876903049097}], 
     PointBox[{1579, 215.15785667903032`}], 
     PointBox[{1580, 215.4259646803465}], 
     PointBox[{1581, 215.04365168793504`}], 
     PointBox[{1582, 214.67921517376595`}], 
     PointBox[{1583, 214.9694664424489}], 
     PointBox[{1584, 215.24449737644275`}], 
     PointBox[{1585, 215.5156637552022}], 
     PointBox[{1586, 215.7845382399335}], 
     PointBox[{1587, 216.0513735875681}], 
     PointBox[{1588, 215.66780673765322`}], 
     PointBox[{1589, 215.3021347333117}], 
     PointBox[{1590, 215.5911684607131}], 
     PointBox[{1591, 215.86499939402898`}], 
     PointBox[{1592, 216.13498291431893`}], 
     PointBox[{1593, 216.40269129403356`}], 
     PointBox[{1594, 216.66837691075045`}], 
     PointBox[{1595, 216.28367633382743`}], 
     PointBox[{1596, 215.9168862451259}], 
     PointBox[{1597, 216.2048171782676}], 
     PointBox[{1598, 216.47756026335955`}], 
     PointBox[{1599, 216.74647054567998`}], 
     PointBox[{1600, 217.01311996996048`}], 
     PointBox[{1601, 217.2777605939336}], 
     PointBox[{1602, 216.89202867477823`}], 
     PointBox[{1603, 216.5242205896563}], 
     PointBox[{1604, 216.81114657478219`}], 
     PointBox[{1605, 217.08289746996775`}], 
     PointBox[{1606, 217.35082803712686`}], 
     PointBox[{1607, 217.61650994439026`}], 
     PointBox[{1608, 217.88019497947982`}], 
     PointBox[{1609, 217.49351913599298`}], 
     PointBox[{1610, 217.1247785337798}], 
     PointBox[{1611, 217.4107831578591}], 
     PointBox[{1612, 217.68162360280536`}], 
     PointBox[{1613, 217.94865439111487`}], 
     PointBox[{1614, 218.21344695717087`}], 
     PointBox[{1615, 218.4762528604768}], 
     PointBox[{1616, 218.08870787180638`}], 
     PointBox[{1617, 217.7191078934524}], 
     PointBox[{1618, 218.00426269800477`}], 
     PointBox[{1619, 218.2742626726201}], 
     PointBox[{1620, 218.540462137254}], 
     PointBox[{1621, 218.80443232851496`}], 
     PointBox[{1622, 219.0664246127804}], 
     PointBox[{1623, 218.67807457222858`}], 
     PointBox[{1624, 218.3076779249791}], 
     PointBox[{1625, 218.59204426376198`}], 
     PointBox[{1626, 218.86126380008477`}], 
     PointBox[{1627, 219.1266906823588}], 
     PointBox[{1628, 219.38989597965445`}], 
     PointBox[{1629, 219.65113089471436`}], 
     PointBox[{1630, 219.26203084990144`}], 
     PointBox[{1631, 218.89089140723897`}], 
     PointBox[{1632, 219.1745220069904}], 
     PointBox[{1633, 219.44301271173558`}], 
     PointBox[{1634, 219.70771752441954`}], 
     PointBox[{1635, 219.97020737201782`}], 
     PointBox[{1636, 220.230733318466}], 
     PointBox[{1637, 219.84093065053503`}], 
     PointBox[{1638, 219.46909479779083`}], 
     PointBox[{1639, 219.75203507109484`}], 
     PointBox[{1640, 220.01984140661312`}], 
     PointBox[{1641, 220.28386768378772`}], 
     PointBox[{1642, 220.54568470893201`}], 
     PointBox[{1643, 220.8055434281002}], 
     PointBox[{1644, 220.41507901289006`}], 
     PointBox[{1645, 220.04258678033148`}], 
     PointBox[{1646, 220.32487593133487`}], 
     PointBox[{1647, 220.5920362946307}], 
     PointBox[{1648, 220.85542164468595`}], 
     PointBox[{1649, 221.11660268523798`}], 
     PointBox[{1650, 221.37583026210777`}], 
     PointBox[{1651, 220.98473944894496`}], 
     PointBox[{1652, 220.61162546706478`}], 
     PointBox[{1653, 220.89329742384126`}], 
     PointBox[{1654, 221.15984505659316`}], 
     PointBox[{1655, 221.42262205045822`}], 
     PointBox[{1656, 221.6831990218691}], 
     PointBox[{1657, 221.9418267313219}], 
     PointBox[{1658, 221.5501401690754}], 
     PointBox[{1659, 221.17643447494092`}], 
     PointBox[{1660, 221.45751867662437`}], 
     PointBox[{1661, 221.72348243358542`}], 
     PointBox[{1662, 221.98567935485408`}], 
     PointBox[{1663, 222.24567998247264`}], 
     PointBox[{1664, 222.50373500422083`}], 
     PointBox[{1665, 222.11147933927583`}], 
     PointBox[{1666, 221.73720805796472`}], 
     PointBox[{1667, 222.01773012007072`}], 
     PointBox[{1668, 222.28313511865275`}], 
     PointBox[{1669, 222.54477659782788`}], 
     PointBox[{1670, 222.8042250361807}], 
     PointBox[{1671, 223.06173105944657`}], 
     PointBox[{1672, 222.66892952614893`}], 
     PointBox[{1673, 222.29411544731266`}], 
     PointBox[{1674, 222.5740977247403}], 
     PointBox[{1675, 222.83896589480122`}], 
     PointBox[{1676, 223.10007344618407`}], 
     PointBox[{1677, 223.35899080328096`}], 
     PointBox[{1678, 223.61596853883435`}], 
     PointBox[{1679, 223.2226414595468}], 
     PointBox[{1680, 222.84730452577548`}], 
     PointBox[{1681, 223.12676658977813`}], 
     PointBox[{1682, 223.39111713947025`}], 
     PointBox[{1683, 223.65170961615974`}], 
     PointBox[{1684, 223.9101143979026}], 
     PointBox[{1685, 224.1665820121264}], 
     PointBox[{1686, 223.772747221218}], 
     PointBox[{1687, 223.39690494219118`}], 
     PointBox[{1688, 223.67586398491989`}], 
     PointBox[{1689, 223.9397137958595}], 
     PointBox[{1690, 224.1998077757694}], 
     PointBox[{1691, 224.45771626304668`}], 
     PointBox[{1692, 224.71368974632807`}], 
     PointBox[{1693, 224.31936295005562`}], 
     PointBox[{1694, 223.94303075413347`}], 
     PointBox[{1695, 224.22150193212747`}], 
     PointBox[{1696, 224.48486589498154`}], 
     PointBox[{1697, 224.74447600871673`}], 
     PointBox[{1698, 225.00190257774554`}], 
     PointBox[{1699, 225.2573960574618}], 
     PointBox[{1700, 224.86259113978443`}], 
     PointBox[{1701, 224.48578267280175`}], 
     PointBox[{1702, 224.76377939895156`}], 
     PointBox[{1703, 225.0266706987245}], 
     PointBox[{1704, 225.28580990835013`}], 
     PointBox[{1705, 225.5427673030856}], 
     PointBox[{1706, 225.79779330980088`}], 
     PointBox[{1707, 225.4025225925123}], 
     PointBox[{1708, 225.02524997199987`}], 
     PointBox[{1709, 225.30278416398312`}], 
     PointBox[{1710, 225.56521452280938`}], 
     PointBox[{1711, 225.82389435912248`}], 
     PointBox[{1712, 226.0803939231467}], 
     PointBox[{1713, 226.3349636172572}], 
     PointBox[{1714, 225.93923808149225`}], 
     PointBox[{1715, 225.56151211317314`}], 
     PointBox[{1716, 225.8385944050577}], 
     PointBox[{1717, 226.10057428902428`}], 
     PointBox[{1718, 226.3588050537271}], 
     PointBox[{1719, 226.61485692786397`}], 
     PointBox[{1720, 226.8689802927446}], 
     PointBox[{1721, 226.47280976779123`}], 
     PointBox[{1722, 226.09464013014244`}], 
     PointBox[{1723, 226.37128005280675`}], 
     PointBox[{1724, 226.6328188483258}], 
     PointBox[{1725, 226.89060978642908`}], 
     PointBox[{1726, 227.1462230772905}], 
     PointBox[{1727, 227.39990908408066`}], 
     PointBox[{1728, 227.0033024084727}], 
     PointBox[{1729, 226.62469781022568`}], 
     PointBox[{1730, 226.90090394533743`}], 
     PointBox[{1731, 227.16201010969021`}], 
     PointBox[{1732, 227.41936955670815`}], 
     PointBox[{1733, 227.67455248060216`}], 
     PointBox[{1734, 227.9278092289103}], 
     PointBox[{1735, 227.53077438800653`}], 
     PointBox[{1736, 227.1517427026651}], 
     PointBox[{1737, 227.4275228142103}], 
     PointBox[{1738, 227.6882040041616}], 
     PointBox[{1739, 227.94513951187673`}], 
     PointBox[{1740, 228.19989951779309`}], 
     PointBox[{1741, 228.4527343559604}], 
     PointBox[{1742, 228.05527859954464`}], 
     PointBox[{1743, 227.67582698038467`}], 
     PointBox[{1744, 227.95118812714156`}], 
     PointBox[{1745, 228.2114513089287}], 
     PointBox[{1746, 228.4679697529512}], 
     PointBox[{1747, 228.72231362775142`}], 
     PointBox[{1748, 228.97473325572608`}], 
     PointBox[{1749, 228.5768631986267}], 
     PointBox[{1750, 228.1969981771122}], 
     PointBox[{1751, 228.47194680889177`}], 
     PointBox[{1752, 228.7317983523571}], 
     PointBox[{1753, 228.98790602420294`}], 
     PointBox[{1754, 229.24183998267824`}], 
     PointBox[{1755, 229.49385054010344`}], 
     PointBox[{1756, 229.09557224835075`}], 
     PointBox[{1757, 228.7152998184031}], 
     PointBox[{1758, 228.98984185848948`}], 
     PointBox[{1759, 229.24928761771648`}], 
     PointBox[{1760, 229.5049903036798}], 
     PointBox[{1761, 229.7585200657171}], 
     PointBox[{1762, 230.01012720741176`}], 
     PointBox[{1763, 229.61144627207688`}], 
     PointBox[{1764, 229.23077196231105`}], 
     PointBox[{1765, 229.50491287812588`}], 
     PointBox[{1766, 229.76395826057814`}], 
     PointBox[{1767, 230.01926130937392`}], 
     PointBox[{1768, 230.27239216611363`}], 
     PointBox[{1769, 230.52360112680523`}], 
     PointBox[{1770, 230.12452272733677`}], 
     PointBox[{1771, 229.74345166302902`}], 
     PointBox[{1772, 230.0171965267598}], 
     PointBox[{1773, 230.27584655259295`}], 
     PointBox[{1774, 230.5307549333824}], 
     PointBox[{1775, 230.78349180401037`}], 
     PointBox[{1776, 231.03430745390105`}], 
     PointBox[{1777, 230.63483641248934`}], 
     PointBox[{1778, 230.2533733687689}], 
     PointBox[{1779, 230.52672690941415`}], 
     PointBox[{1780, 230.78498626240713`}], 
     PointBox[{1781, 231.03950461464245`}], 
     PointBox[{1782, 231.29185209515902`}], 
     PointBox[{1783, 231.54227898764873`}], 
     PointBox[{1784, 231.1424198159261}], 
     PointBox[{1785, 230.7605692634757}], 
     PointBox[{1786, 231.03353591157185`}], 
     PointBox[{1787, 231.29140898290166`}], 
     PointBox[{1788, 231.54554165916034`}], 
     PointBox[{1789, 231.7975040642927}], 
     PointBox[{1790, 232.04754647699673`}], 
     PointBox[{1791, 231.6473034161854}], 
     PointBox[{1792, 231.26506956053825`}], 
     PointBox[{1793, 231.5376534866183}], 
     PointBox[{1794, 231.79514441248378`}], 
     PointBox[{1795, 232.0488955152979}], 
     PointBox[{1796, 232.30047691455857`}], 
     PointBox[{1797, 232.5501388845986}], 
     PointBox[{1798, 232.14951594004867`}], 
     PointBox[{1799, 231.7669027553904}], 
     PointBox[{1800, 231.39067171126828`}], 
     PointBox[{1801, 231.019161228026}], 
     PointBox[{1802, 230.6520557205854}], 
     PointBox[{1803, 230.2892240615981}], 
     PointBox[{1804, 229.9305623391541}], 
     PointBox[{1805, 229.5759725188542}], 
     PointBox[{1806, 229.22535949829933`}], 
     PointBox[{1807, 228.8786306521034}], 
     PointBox[{1808, 228.53569571539725`}], 
     PointBox[{1809, 228.19646671466558`}], 
     PointBox[{1810, 227.86085790646166`}], 
     PointBox[{1811, 227.52878571855712`}], 
     PointBox[{1812, 227.20016869282313`}], 
     PointBox[{1813, 226.8749274296461}], 
     PointBox[{1814, 226.55298453390094`}], 
     PointBox[{1815, 226.2342645623315}], 
     PointBox[{1816, 225.91869397238682`}], 
     PointBox[{1817, 225.6062010724452}], 
     PointBox[{1818, 225.29671597336923`}], 
     PointBox[{1819, 224.9901705413841}], 
     PointBox[{1820, 224.68649835219267`}], 
     PointBox[{1821, 224.3856346463869}], 
     PointBox[{1822, 224.08751628600928`}], 
     PointBox[{1823, 223.79208171228572`}], 
     PointBox[{1824, 223.49927090454116`}], 
     PointBox[{1825, 223.20902534017904`}], 
     PointBox[{1826, 222.92128795575374`}], 
     PointBox[{1827, 222.6360031090593}], 
     PointBox[{1828, 223.00155273409413`}], 
     PointBox[{1829, 223.34963471523483`}], 
     PointBox[{1830, 223.69186621502257`}], 
     PointBox[{1831, 224.02989816028486`}], 
     PointBox[{1832, 224.3640356638386}], 
     PointBox[{1833, 224.04596341568617`}], 
     PointBox[{1834, 223.74402451672267`}], 
     PointBox[{1835, 224.09507464137852`}], 
     PointBox[{1836, 224.42924886801154`}], 
     PointBox[{1837, 224.7579450367706}], 
     PointBox[{1838, 225.08277676601452`}], 
     PointBox[{1839, 225.40403669626892`}], 
     PointBox[{1840, 225.0734006061695}], 
     PointBox[{1841, 224.75920336162267`}], 
     PointBox[{1842, 225.09829268273776`}], 
     PointBox[{1843, 225.4207959154465}], 
     PointBox[{1844, 225.73810337632534`}], 
     PointBox[{1845, 226.05182136232912`}], 
     PointBox[{1846, 226.36223538903988`}], 
     PointBox[{1847, 226.0210143011775}], 
     PointBox[{1848, 225.6964862165039}], 
     PointBox[{1849, 226.0254922876348}], 
     PointBox[{1850, 226.33815346868113`}], 
     PointBox[{1851, 226.64585385526183`}], 
     PointBox[{1852, 226.95019368952376`}], 
     PointBox[{1853, 227.251452593837}], 
     PointBox[{1854, 226.90129367687118`}], 
     PointBox[{1855, 226.56803947318517`}], 
     PointBox[{1856, 226.8885257008486}], 
     PointBox[{1857, 227.19286802401646`}], 
     PointBox[{1858, 227.4924453889799}], 
     PointBox[{1859, 227.7888530253428}], 
     PointBox[{1860, 228.0823656759697}], 
     PointBox[{1861, 227.7246416994367}], 
     PointBox[{1862, 227.38399900608158`}], 
     PointBox[{1863, 227.6972688121917}], 
     PointBox[{1864, 227.99456239924368`}], 
     PointBox[{1865, 228.2872544467002}], 
     PointBox[{1866, 228.57693603004017`}], 
     PointBox[{1867, 228.86387784764025`}], 
     PointBox[{1868, 228.4997343202337}], 
     PointBox[{1869, 228.1528195240731}], 
     PointBox[{1870, 228.45996094229466`}], 
     PointBox[{1871, 228.75126622141934`}], 
     PointBox[{1872, 229.03810650148608`}], 
     PointBox[{1873, 229.3220694114977}], 
     PointBox[{1874, 229.60342229377966`}], 
     PointBox[{1875, 229.23381630099232`}], 
     PointBox[{1876, 228.8815623269125}], 
     PointBox[{1877, 229.18348475549163`}], 
     PointBox[{1878, 229.46968821509864`}], 
     PointBox[{1879, 229.75154090647425`}], 
     PointBox[{1880, 230.03062759604484`}], 
     PointBox[{1881, 230.30721283821308`}], 
     PointBox[{1882, 229.93294507036478`}], 
     PointBox[{1883, 229.5761325416904}], 
     PointBox[{1884, 229.87359706034727`}], 
     PointBox[{1885, 230.1554407458478}], 
     PointBox[{1886, 230.43302935522297`}], 
     PointBox[{1887, 230.707945274586}], 
     PointBox[{1888, 230.9804507397198}], 
     PointBox[{1889, 230.60219192943393`}], 
     PointBox[{1890, 230.2414748927825}], 
     PointBox[{1891, 230.53511929465574`}], 
     PointBox[{1892, 230.81322516665387`}], 
     PointBox[{1893, 231.08715623177326`}], 
     PointBox[{1894, 231.35849289452125`}], 
     PointBox[{1895, 231.62749546011548`}], 
     PointBox[{1896, 231.24580822648318`}], 
     PointBox[{1897, 230.88173541015354`}], 
     PointBox[{1898, 231.17209489055077`}], 
     PointBox[{1899, 231.4469849596341}], 
     PointBox[{1900, 231.71776764536253`}], 
     PointBox[{1901, 231.98602170061514`}], 
     PointBox[{1902, 232.25200582125103`}], 
     PointBox[{1903, 231.86736273698784`}], 
     PointBox[{1904, 231.50039513619743`}], 
     PointBox[{1905, 231.7879194091401}], 
     PointBox[{1906, 232.06003239658435`}], 
     PointBox[{1907, 232.32809471225687`}], 
     PointBox[{1908, 232.59368373079357`}], 
     PointBox[{1909, 232.85705680484796`}], 
     PointBox[{1910, 232.46985535504353`}], 
     PointBox[{1911, 232.10038079388332`}], 
     PointBox[{1912, 232.3854482680943}], 
     PointBox[{1913, 232.6551534064111}], 
     PointBox[{1914, 232.9208556411893}], 
     PointBox[{1915, 233.18413119555447`}], 
     PointBox[{1916, 233.44523629972977`}], 
     PointBox[{1917, 233.05581128023007`}], 
     PointBox[{1918, 232.68415648302047`}], 
     PointBox[{1919, 232.9670860151477}], 
     PointBox[{1920, 233.2346944918159}], 
     PointBox[{1921, 233.49834035732385`}], 
     PointBox[{1922, 233.7595988715487}], 
     PointBox[{1923, 234.01872532562396`}], 
     PointBox[{1924, 233.62735913050398`}], 
     PointBox[{1925, 233.2537997395089}], 
     PointBox[{1926, 233.53486038937498`}], 
     PointBox[{1927, 233.80063484673215`}], 
     PointBox[{1928, 234.0624807284815}], 
     PointBox[{1929, 234.32197248774008`}], 
     PointBox[{1930, 234.57936462897493`}], 
     PointBox[{1931, 234.1862957960455}], 
     PointBox[{1932, 233.81106469425453`}], 
     PointBox[{1933, 234.09048383089643`}], 
     PointBox[{1934, 234.35464626125633`}], 
     PointBox[{1935, 234.61490890852116`}], 
     PointBox[{1936, 234.87284554927172`}], 
     PointBox[{1937, 235.12871002817616`}], 
     PointBox[{1938, 234.7341403456009}], 
     PointBox[{1939, 234.35743457923888`}], 
     PointBox[{1940, 234.63540462425578`}], 
     PointBox[{1941, 234.8981429388876}], 
     PointBox[{1942, 235.15700586396952`}], 
     PointBox[{1943, 235.41356660804837`}], 
     PointBox[{1944, 235.66807846171343`}], 
     PointBox[{1945, 235.27217888484842`}], 
     PointBox[{1946, 234.8941654279103}], 
     PointBox[{1947, 235.17084947174482`}], 
     PointBox[{1948, 235.43232297284996`}], 
     PointBox[{1949, 235.68994178258293`}], 
     PointBox[{1950, 235.94527863196632`}], 
     PointBox[{1951, 236.19858634571466`}], 
     PointBox[{1952, 235.8015019291815}], 
     PointBox[{1953, 235.4223224893646}], 
     PointBox[{1954, 235.69785897442955`}], 
     PointBox[{1955, 235.95820291870646`}], 
     PointBox[{1956, 236.21470976163386`}], 
     PointBox[{1957, 236.46895183229395`}], 
     PointBox[{1958, 236.72118156320067`}], 
     PointBox[{1959, 236.32303557699592`}], 
     PointBox[{1960, 235.94281060721386`}], 
     PointBox[{1961, 236.2173172375733}], 
     PointBox[{1962, 236.47664664675185`}], 
     PointBox[{1963, 236.73215392709915`}], 
     PointBox[{1964, 236.9854110689691}], 
     PointBox[{1965, 237.23667017428983`}], 
     PointBox[{1966, 236.83756754306006`}], 
     PointBox[{1967, 236.4563995939124}], 
     PointBox[{1968, 236.72997660321363`}], 
     PointBox[{1969, 236.9883894496515}], 
     PointBox[{1970, 237.2429929327614}], 
     PointBox[{1971, 237.49535875708074`}], 
     PointBox[{1972, 237.74573874554977`}], 
     PointBox[{1973, 237.34576892582723`}], 
     PointBox[{1974, 236.96374545069824`}], 
     PointBox[{1975, 237.236478337012}], 
     PointBox[{1976, 237.4940582101064}], 
     PointBox[{1977, 237.74783962218632`}], 
     PointBox[{1978, 237.99939403633118`}], 
     PointBox[{1979, 238.24897303974245`}], 
     PointBox[{1980, 237.84821242992587`}], 
     PointBox[{1981, 237.4654081349562}], 
     PointBox[{1982, 237.73736995228796`}], 
     PointBox[{1983, 237.9941882930411}], 
     PointBox[{1984, 238.2472175002547}], 
     PointBox[{1985, 238.49802883277414`}], 
     PointBox[{1986, 238.74687367836924`}], 
     PointBox[{1987, 238.3453876398084}], 
     PointBox[{1988, 237.96186645500265`}], 
     PointBox[{1989, 238.23311973570364`}], 
     PointBox[{1990, 238.48923771168228`}], 
     PointBox[{1991, 238.74157454888066`}], 
     PointBox[{1992, 238.99170133318455`}], 
     PointBox[{1993, 239.23986928344942`}], 
     PointBox[{1994, 238.83771383747313`}], 
     PointBox[{1995, 238.45353057204306`}], 
     PointBox[{1996, 238.72412894154473`}], 
     PointBox[{1997, 238.97959902204497`}], 
     PointBox[{1998, 239.2312948293535}], 
     PointBox[{1999, 239.48078730271794`}], 
     PointBox[{2000, 239.728327517752}]}},
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{1200, 2000}, {188.21576818460528`, 239.88342665155204`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.398584099121791*^9, 3.3985922547800937`*^9, 
  3.413801641212271*^9, 3.480094179164031*^9, 3.4800959980722*^9, 
  3.4801563580462*^9, 3.5185322365546646`*^9, 3.5396990517346525`*^9, 
  3.592064387490443*^9, 3.643609944180418*^9},
 CellLabel->"Out[25]="]
}, Open  ]],

Cell["\<\
 It can be observed that the differences between both methods are negligible \
in the middle of periods between two holiday  seasons, and maxima just after \
the holiday periods, but even in these cases they are not too important \
(lower than 5%)\
\>", "Commentary"],

Cell[TextData[{
 " The estimated lung retention different days after the intaken started it \
can be made directy using the  BIOKMOD function ",
 StyleBox["qMultiple ", "Input"]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", 
  StyleBox[
   RowBox[{"qMultiple", " "}], "Input"]}]], "Input",
 CellLabel->"In[26]:="],

Cell[BoxData[
 StyleBox["\<\"qMultiple[inputsdata,{u[t],t}, tt] gives the \\nretention the \
time tt for multiples(constant:{...,{bi,ti,Ti},...}\\nand \
singles{...,{bi,ti},...})inputs,being u[t] the unit-inpulse\\nresponse\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.643609944289793*^9},
 CellTags->"Info3643617144-9686839"]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"dailyinputs", "=", " ", 
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{"workingdays", ",", 
      RowBox[{"Range", "[", "2000", "]"}], ",", 
      RowBox[{"Table", "[", 
       RowBox[{
        RowBox[{"1", "/", "3"}], ",", " ", 
        RowBox[{"{", "2000", "}"}]}], "]"}]}], "}"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[27]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"#", ",", 
       RowBox[{"avgintakewd", " ", 
        RowBox[{"qMultiple", "[", 
         RowBox[{"dailyinputs", ",", " ", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"qLungU5S", "[", "t", "]"}], ",", "t"}], "}"}], ",", " ", 
          "#"}], "]"}]}]}], "}"}], "&"}], ",", 
    RowBox[{"{", 
     RowBox[{
     "100", ",", " ", "500", ",", " ", "1000", ",", " ", "1500", ",", " ", 
      "2000"}], "}"}]}], "]"}], "]"}]], "Input",
 CellLabel->"In[28]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"100", "32.44971463531567`"},
    {"500", "107.73448707013523`"},
    {"1000", "172.6866730289225`"},
    {"1500", "206.33672044566742`"},
    {"2000", "239.4807873027746`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.3985841106726484`*^9, 3.3985922665280933`*^9, 
  3.41380165338438*^9, 3.4800941969480305`*^9, 3.480096004203*^9, 
  3.480156367531*^9, 3.5185322426797824`*^9, 3.539699055359722*^9, 
  3.592064455405749*^9, 3.6436099466960473`*^9},
 CellLabel->"Out[28]//TableForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Random Intakes ", "Subsection"],

Cell[TextData[{
 "In real situations, such as workers being exposed to radioactive aerosols \
during the working days, the individual daily intake ",
 StyleBox["I",
  FontSlant->"Italic"],
 " is usually a random variable. In a previous article we found \
(Lopez-Fidalgo and Sanchez, 2005) that in some occasions the daily intake {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "1"], TraditionalForm]]],
 ", \[Ellipsis], ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "i"], TraditionalForm]]],
 ", \[Ellipsis] , ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "n"], TraditionalForm]]],
 "} can be fitted by a log-normal distribution LN(\[Micro], ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Sigma]", "2"], TraditionalForm]]],
 "), where \[Mu] and ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Sigma]", "2"], TraditionalForm]]],
 " are the mean and variance of the corresponding normal distribution. We \
showed that the retention function ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["R", "rand"], "(", "t", ")"}], TraditionalForm]]],
 " and the corresponding probability bands are given by"
}], "Text"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["R", "rand"], "(", "t", ")"}], "=", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["\[Mu]", "I"], " ", 
     RowBox[{
      UnderoverscriptBox["\[Sum]", 
       RowBox[{"j", "=", "1"}], "t"], 
      RowBox[{"r", "(", "j", ")"}]}]}], "\[PlusMinus]", 
    RowBox[{
     SubscriptBox[
      RowBox[{"z", " "}], 
      FractionBox[
       RowBox[{"\[Gamma]", "+", "1"}], "2"]], 
     SubscriptBox["\[Sigma]", "I"], 
     SqrtBox[
      RowBox[{
       UnderoverscriptBox["\[Sum]", 
        RowBox[{"j", "=", "1"}], "t"], 
       RowBox[{
        SuperscriptBox["r", "2"], "(", "j", ")"}]}]]}]}]}], 
  TraditionalForm]], "Text"]], "NumberedEquation"],

Cell[TextData[{
 "being ",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[Mu]", "^"], "I"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["1", "N"], 
    RowBox[{
     UnderscriptBox["\[Sum]", "t"], 
     SubscriptBox["I", "t"]}]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    SubscriptBox["\[Sigma]", "I"], "2"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox["1", 
     RowBox[{"N", "-", "1"}]], 
    RowBox[{
     UnderscriptBox["\[Sum]", "t"], 
     RowBox[{"(", 
      RowBox[{
       SubscriptBox["I", "i"], "-"}]}]}]}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    OverscriptBox["\[Mu]", "^"], "I"], TraditionalForm]]],
 ") and ",
 StyleBox["z",
  FontSlant->"Italic"],
 " is the 100 (\[Gamma] + 1) \[DivisionSlash] 2 -quantile of the standard \
normal distribution.\nIf in eqn. (10) I is a random variable, then ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["I", "j"], 
    RowBox[{"r", "(", 
     RowBox[{"t", "-", "j", "+", "1"}], ")"}]}], TraditionalForm]]],
 " usually will take small values, and considering a large number (<100) of \
single inputs Ii then eqn. (10) will be a sum of random and independent \
variables. In this case eqn.(13) can be used without requiring that {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "1"], TraditionalForm]]],
 ", \[Ellipsis], ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "i"], TraditionalForm]]],
 ", \[Ellipsis] , ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "n"], TraditionalForm]]],
 "} can be fitted to any distribution. It is a consequence of the Central \
Limit Theorem. We have also checked it by simulation using different \
distributions to generate {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "1"], TraditionalForm]]],
 ", \[Ellipsis], ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "i"], TraditionalForm]]],
 ", \[Ellipsis] , ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "n"], TraditionalForm]]],
 "} and testing that eqn (13) is verified."
}], "Text"],

Cell[TextData[{
 "Example.-In the previous example we known from historical data that the \
relative standard deviation of the daily intakes for workers of this area is \
about 20%, that is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["\[Sigma]", "I"], "/", 
    SubscriptBox["\[Mu]", "I"]}], TraditionalForm]]],
 "= 0.2. "
}], "Commentary"],

Cell["\<\
Eqn (13) is applied (with \[Gamma]= 0.95) for computing the upper and lower \
limit {uL,lL}\
\>", "MathCaption"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"rr1", " ", "=", " ", 
   RowBox[{"ListConvolve", "[", " ", 
    RowBox[{"workingdays", ",", " ", "lungret", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"-", "days"}], ",", " ", "1"}], "}"}], ",", " ", "0"}], 
    "]"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"rr2", " ", "=", " ", 
   RowBox[{
    RowBox[{"ListConvolve", "[", " ", 
     RowBox[{"workingdays", ",", " ", "lungret", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "days"}], ",", " ", "1"}], "}"}], ",", " ", "0"}], "]"}],
     "^", "2"}]}], ";"}]}], "Input",
 CellLabel->"In[29]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"uL", ",", "avg", ",", " ", "lL"}], "}"}], " ", "=", " ", 
   RowBox[{"Module", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"z", ",", " ", "s", ",", "k", ",", "d"}], "}"}], ",", "\n", 
     RowBox[{
      RowBox[{"z", " ", "=", " ", "2"}], ";", " ", 
      RowBox[{"s", "=", " ", 
       RowBox[{"0.2", "avgintakewd"}]}], ";", 
      RowBox[{"k", "=", 
       RowBox[{"z", "*", "s", "*", 
        SqrtBox["rr2"]}]}], ";", 
      RowBox[{"d", "=", 
       RowBox[{"Range", "[", "days", "]"}]}], ";", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"d", ",", " ", 
           RowBox[{
            RowBox[{"avgintakewd", " ", "rr1"}], "+", "k"}]}], "}"}], "]"}], 
        ",", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"d", ",", " ", 
           RowBox[{"avgintakewd", "  ", "rr1"}]}], "}"}], "]"}], ",", 
        RowBox[{"Transpose", "[", 
         RowBox[{"{", 
          RowBox[{"d", ",", " ", 
           RowBox[{
            RowBox[{"avgintakewd", "  ", "rr1"}], "-", "k"}]}], " ", "}"}], 
         "]"}]}], "}"}]}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[31]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", "avg", "]"}]], "Input",
 CellLabel->"In[32]:="],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.008333333333333333], 
     AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJw813lcTevbBvAoSkgRQihCEqKQRBeSEEIqU3aT5nnWtJvn2u321BYyFoXM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      "]]}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0, 2000.}, {0, 239.728327517752}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3985841109865303`*^9, 3.3985922668257093`*^9, 
  3.41380165365001*^9, 3.4800942001304307`*^9, 3.480096004281*^9, 
  3.4801563680302*^9, 3.5185322430235386`*^9, 3.539699055484725*^9, 
  3.5920644555757656`*^9, 3.643609946883548*^9},
 CellLabel->"Out[32]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Fig3", " ", "=", 
   RowBox[{"FilledListPlot", "[", 
    RowBox[{"lL", ",", "uL", ",", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<days\>\"", ",", "\"\<Bq\>\""}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[33]:="],

Cell["On the day 2000", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Last", "[", "rr1", "]"}], ",", 
   RowBox[{"Last", "[", "rr2", "]"}]}], "}"}]], "Input",
 CellLabel->"In[34]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"23.9728327517752`", ",", "574.6967101445857`"}], "}"}]], "Output",
 CellChangeTimes->{3.398584111237636*^9, 3.3985922668413734`*^9, 
  3.413801653728136*^9, 3.4800942002240305`*^9, 3.4800960043122*^9, 
  3.4801563680769997`*^9, 3.5185322430547895`*^9, 3.539699055562851*^9, 
  3.5920644555957675`*^9, 3.643609946914798*^9},
 CellLabel->"Out[34]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Last", "[", "uL", "]"}], ",", 
    RowBox[{"Last", "[", "avg", "]"}], ",", 
    RowBox[{"Last", "[", "lL", "]"}]}], "}"}], "  "}]], "Input",
 CellLabel->"In[35]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"2000", ",", "335.6196585248528`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2000", ",", "239.728327517752`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2000", ",", "143.8369965106512`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.3985841112847185`*^9, 3.3985922668883657`*^9, 
  3.413801653837514*^9, 3.480094200286431*^9, 3.4800960043278*^9, 
  3.4801563681082*^9, 3.5185322431016655`*^9, 3.5396990556253524`*^9, 
  3.592064455639772*^9, 3.6436099469460473`*^9},
 CellLabel->"Out[35]="]
}, Open  ]],

Cell[TextData[{
 "That is",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     RowBox[{
      SubscriptBox["\[Mu]", "I"], " ", "=", " ", "10"}], ";"}]}], 
   TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]", "I"], " ", "=", " ", 
     RowBox[{
      RowBox[{"0.2", "  ", 
       SubscriptBox["\[Mu]", "I"]}], "=", " ", "2"}]}], ";"}], 
   TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"j", "=", "1"}], "t"], 
     RowBox[{"r", "(", "j", ")"}]}]}], TraditionalForm]]],
 " = 23.97;",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderoverscriptBox["\[Sum]", 
     RowBox[{"j", "=", "1"}], "t"], 
    RowBox[{
     SuperscriptBox["r", "2"], "(", "j", ")"}]}], TraditionalForm]]],
 " =574.70;  them the estimated lung content is   BqU (computed with a \
confidence interval of 95%, z \[TildeTilde] 2), and hence 143.8 BqU \
\[LessEqual] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["RA", "Lung"], TraditionalForm]]],
 "(2000) \[LessEqual]335.6 BqU.  "
}], "Text"],

Cell["\<\
It can be compared with the value obtaining assuming an chronic intake\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"avgintake", "*", 
   RowBox[{"LungsRetention", "[", 
    RowBox[{"1", ",", 
     RowBox[{"AMADAdultW", "[", "5", "]"}], ",", "S", ",", " ", "2000", ",", 
     "0", ",", " ", 
     RowBox[{"IntakeType", "\[Rule]", " ", "\"\<Constant\>\""}]}], 
    "]"}]}]}]], "Input",
 CellLabel->"In[36]:="],

Cell[BoxData["239.88342744157927`"], "Output",
 CellChangeTimes->{3.3985841115044355`*^9, 3.3985922670763335`*^9, 
  3.4138016540250173`*^9, 3.480094200551631*^9, 3.4800960044526*^9, 
  3.4801563682018003`*^9, 3.5185322432579184`*^9, 3.5396990557659802`*^9, 
  3.5920644558347917`*^9, 3.643609947024173*^9},
 CellLabel->"Out[36]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "qLungs5S", ",", "days", ",", "totalintake", ",", "inputdata", ",", 
   "avgintake", ",", "avgintakewd", ",", " ", "workingdays", ",", " ", "rr1", 
   ",", " ", "rr2", ",", " ", "uL", ",", "avg", ",", " ", "lL"}], 
  "]"}]], "Input",
 CellLabel->"In[37]:="],

Cell[TextData[{
 "The program has a specific input and output for random intakes. The \
estimated daily intakes average and their standard deviation, calculated \
using historical data, must be introduced. It will also be indicated the \
number of working days per week, so if the worker rests at the weekend the \
program will take ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["I", "j"], " ", "=", " ", "0"}], TraditionalForm]]],
 " for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"j", " ", "=", " ", 
    RowBox[{"7", "k"}]}], TraditionalForm]]],
 "  and ",
 Cell[BoxData[
  FormBox[
   RowBox[{"j", " ", "=", " ", 
    RowBox[{"7", "k", " ", "\[Dash]", " ", "1"}]}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", " ", "2", ",", "\[Ellipsis]"}], "}"}]}], 
   TraditionalForm]]],
 ". "
}], "Text"],

Cell[TextData[{
 " Predicted urine excretion (BqU/day) for a worker where he will work during \
5 days per week in an area being exposed to uranium aerosols (type S, AMAD 5 \
\[Mu]m and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", "R"], TraditionalForm]]],
 " \[Rule]0). The estimated average daily intake in this area is 3.3 BqU with \
a standard deviation of 5.1 BqU. The worker was previously exposed to a total \
intake of 5100 BqU from 1995-05-13 to 2005-10-13. The effect of the weekends \
without exposures can be observed."
}], "Commentary"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"urineExc", ",", "faecalExc", ",", "wholebodyRet"}], "}"}], "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"qDailyUrine", "[", "t", "]"}], ",", 
      RowBox[{"qDailyFaecal", "[", "t", "]"}], ",", 
      RowBox[{"qWholebody", "[", "t", "]"}]}], "}"}], "/.", 
    "\[InvisibleSpace]", 
    RowBox[{"BiokdataReport", "[", 
     RowBox[{
     "uranium", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
      "\"\<Automatic\>\"", ",", "1", ",", " ", 
      RowBox[{"AMADAdultW", "[", "5", "]"}], ",", " ", "S", ",", "0.002", ",",
       "t", ",", "0"}], "]"}]}]}], ";"}]], "Input",
 CellLabel->"In[38]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"totaltime", "=", 
   RowBox[{"Round", "[", 
    FractionBox[
     RowBox[{
      RowBox[{"AbsoluteTime", "[", 
       RowBox[{"{", 
        RowBox[{"2005", ",", "10", ",", "13", ",", "0", ",", "0", ",", "0"}], 
        "}"}], "]"}], "-", 
      RowBox[{"AbsoluteTime", "[", 
       RowBox[{"{", 
        RowBox[{"1995", ",", "5", ",", "13", ",", "0", ",", "0", ",", "0"}], 
        "}"}], "]"}]}], 
     RowBox[{"3600", " ", "24"}]], "]"}]}], ";"}]], "Input",
 CellLabel->"In[39]:="],

Cell["\<\
Now it is applied the function qRandom (See in Biokmod Help: Advance function)\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sol", "=", 
   RowBox[{"qRandom", "[", 
    RowBox[{
    "5100", ",", "totaltime", ",", "urineExc", ",", "3.3", ",", "5.1", ",", 
     "1.96", ",", "300", ",", " ", "5", ",", " ", "t"}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[40]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "days", ",", " ", "me", ",", " ", "int", ",", " ", "ul", ",", " ", "ll"}],
     "}"}], "=", 
   RowBox[{"Transpose", "[", "sol", "]"}]}], ";"}]], "Input",
 CellLabel->"In[41]:="],

Cell["\<\
The blue color represents the confidence interval for the daily  urine \
excretion, it can be observed the effect of the weekeng where there are not \
intakes.  \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"days", ",", "ll"}], "}"}], "]"}], ",", 
     RowBox[{"Transpose", "[", 
      RowBox[{"{", 
       RowBox[{"days", ",", "ul"}], "}"}], "]"}]}], "}"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<days\>\"", ",", "\"\<Bq/day\>\""}], "}"}]}], " ", ",", " ", 
   RowBox[{"Filling", "->", " ", 
    RowBox[{"{", 
     RowBox[{"1", "\[Rule]", 
      RowBox[{"{", "2", "}"}]}], "}"}]}], ",", 
   RowBox[{"FillingStyle", "\[Rule]", 
    RowBox[{"Opacity", "[", "0.3", "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{
  3.3992718915212955`*^9, {3.3992719507182655`*^9, 3.3992719652674675`*^9}, {
   3.39927204901524*^9, 3.3992720632050104`*^9}, {3.3992728662292027`*^9, 
   3.3992728665732517`*^9}, {3.399273754531166*^9, 3.399273755985677*^9}, {
   3.3992738517644243`*^9, 3.399273882950385*^9}, {3.399274080638721*^9, 
   3.399274100079117*^9}, {3.3992741301390047`*^9, 3.3992741313276367`*^9}},
 CellLabel->"In[42]:="],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJztmmlYzWvbxheVIZWkXVLZmRIiiiTT2S5tKs2aNa6p1mpNQuakgUSU3Q5b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    "], {{{}, {}, {}, {}, {}, {}, {}, {}, {}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.3], 
       LineBox[{1, 503}], LineBox[{253, 504}], LineBox[{254, 505}], 
       LineBox[{255, 506}], LineBox[{256, 507}], LineBox[{257, 508}], 
       LineBox[{258, 509}], LineBox[{259, 510}], LineBox[{260, 511}], 
       LineBox[{261, 512}], LineBox[{262, 513}], LineBox[{263, 514}], 
       LineBox[{264, 515}], LineBox[{265, 516}], LineBox[{266, 517}], 
       LineBox[{267, 518}], LineBox[{268, 519}], LineBox[{269, 520}], 
       LineBox[{270, 521}], LineBox[{271, 522}], LineBox[{272, 523}], 
       LineBox[{273, 524}], LineBox[{274, 525}], LineBox[{275, 526}], 
       LineBox[{276, 527}], LineBox[{277, 528}], LineBox[{278, 529}], 
       LineBox[{279, 530}], LineBox[{280, 531}], LineBox[{281, 532}], 
       LineBox[{282, 533}], LineBox[{283, 534}], LineBox[{284, 535}], 
       LineBox[{285, 536}], LineBox[{286, 537}], LineBox[{287, 538}], 
       LineBox[{288, 539}], LineBox[{289, 540}], LineBox[{290, 541}], 
       LineBox[{291, 542}], LineBox[{292, 543}], LineBox[{293, 544}], 
       LineBox[{294, 545}], LineBox[{295, 546}], LineBox[{296, 547}], 
       LineBox[{297, 548}], LineBox[{298, 549}], LineBox[{299, 550}], 
       LineBox[{300, 551}], LineBox[{301, 552}], LineBox[{302, 553}], 
       LineBox[{303, 554}], LineBox[{304, 555}], LineBox[{305, 556}], 
       LineBox[{306, 557}], LineBox[{307, 558}], LineBox[{308, 559}], 
       LineBox[{309, 560}], LineBox[{310, 561}], LineBox[{311, 562}], 
       LineBox[{312, 563}], LineBox[{313, 564}], LineBox[{314, 565}], 
       LineBox[{315, 566}], LineBox[{316, 567}], LineBox[{317, 568}], 
       LineBox[{318, 569}], LineBox[{319, 570}], LineBox[{320, 571}], 
       LineBox[{321, 572}], LineBox[{322, 573}], LineBox[{323, 574}], 
       LineBox[{324, 575}], LineBox[{325, 576}], LineBox[{326, 577}], 
       LineBox[{327, 578}], LineBox[{328, 579}], LineBox[{329, 580}], 
       LineBox[{330, 581}], LineBox[{331, 582}], LineBox[{332, 583}], 
       LineBox[{333, 584}], LineBox[{334, 585}], LineBox[{335, 586}], 
       LineBox[{336, 587}], LineBox[{337, 588}], LineBox[{338, 589}], 
       LineBox[{339, 590}], LineBox[{340, 591}], LineBox[{341, 592}], 
       LineBox[{342, 593}], LineBox[{343, 594}], LineBox[{344, 595}], 
       LineBox[{345, 596}], LineBox[{346, 597}], LineBox[{347, 598}], 
       LineBox[{348, 599}], LineBox[{349, 600}], LineBox[{350, 601}], 
       LineBox[{351, 602}], LineBox[{352, 603}], LineBox[{353, 604}], 
       LineBox[{354, 605}], LineBox[{355, 606}], LineBox[{356, 607}], 
       LineBox[{357, 608}], LineBox[{358, 609}], LineBox[{359, 610}], 
       LineBox[{360, 611}], LineBox[{361, 612}], LineBox[{362, 613}], 
       LineBox[{363, 614}], LineBox[{364, 615}], LineBox[{365, 616}], 
       LineBox[{366, 617}], LineBox[{367, 618}], LineBox[{368, 619}], 
       LineBox[{369, 620}], LineBox[{370, 621}], LineBox[{371, 622}], 
       LineBox[{372, 623}], LineBox[{373, 624}], LineBox[{374, 625}], 
       LineBox[{375, 626}], LineBox[{376, 627}], LineBox[{377, 628}], 
       LineBox[{378, 629}], LineBox[{379, 630}], LineBox[{380, 631}], 
       LineBox[{381, 632}], LineBox[{382, 633}], LineBox[{383, 634}], 
       LineBox[{384, 635}], LineBox[{385, 636}], LineBox[{386, 637}], 
       LineBox[{387, 638}], LineBox[{388, 639}], LineBox[{389, 640}], 
       LineBox[{390, 641}], LineBox[{391, 642}], LineBox[{392, 643}], 
       LineBox[{393, 644}], LineBox[{394, 645}], LineBox[{395, 646}], 
       LineBox[{396, 647}], LineBox[{397, 648}], LineBox[{398, 649}], 
       LineBox[{399, 650}], LineBox[{400, 651}], LineBox[{401, 652}], 
       LineBox[{402, 653}], LineBox[{403, 654}], LineBox[{404, 655}], 
       LineBox[{405, 656}], LineBox[{406, 657}], LineBox[{407, 658}], 
       LineBox[{408, 659}], LineBox[{409, 660}], LineBox[{410, 661}], 
       LineBox[{411, 662}], LineBox[{412, 663}], LineBox[{413, 664}], 
       LineBox[{414, 665}], LineBox[{415, 666}], LineBox[{416, 667}], 
       LineBox[{417, 668}], LineBox[{418, 669}], LineBox[{419, 670}], 
       LineBox[{420, 671}], LineBox[{421, 672}], LineBox[{422, 673}], 
       LineBox[{423, 674}], LineBox[{424, 675}], LineBox[{425, 676}], 
       LineBox[{426, 677}], LineBox[{427, 678}], LineBox[{428, 679}], 
       LineBox[{429, 680}], LineBox[{430, 681}], LineBox[{431, 682}], 
       LineBox[{432, 683}], LineBox[{433, 684}], LineBox[{434, 685}], 
       LineBox[{435, 686}], LineBox[{436, 687}], LineBox[{437, 688}], 
       LineBox[{438, 689}], LineBox[{439, 690}], LineBox[{440, 691}], 
       LineBox[{441, 692}], LineBox[{442, 693}], LineBox[{443, 694}], 
       LineBox[{444, 695}], LineBox[{445, 696}], LineBox[{446, 697}], 
       LineBox[{447, 698}], LineBox[{448, 699}], LineBox[{449, 700}], 
       LineBox[{450, 701}], LineBox[{451, 702}], LineBox[{452, 703}], 
       LineBox[{453, 704}], LineBox[{454, 705}], LineBox[{455, 706}], 
       LineBox[{456, 707}], LineBox[{457, 708}], LineBox[{458, 709}], 
       LineBox[{459, 710}], LineBox[{460, 711}], LineBox[{461, 712}], 
       LineBox[{462, 713}], LineBox[{463, 714}], LineBox[{464, 715}], 
       LineBox[{465, 716}], LineBox[{466, 717}], LineBox[{467, 718}], 
       LineBox[{468, 719}], LineBox[{469, 720}], LineBox[{470, 721}], 
       LineBox[{471, 722}], LineBox[{472, 723}], LineBox[{473, 724}], 
       LineBox[{474, 725}], LineBox[{475, 726}], LineBox[{476, 727}], 
       LineBox[{477, 728}], LineBox[{478, 729}], LineBox[{479, 730}], 
       LineBox[{480, 731}], LineBox[{481, 732}], LineBox[{482, 733}], 
       LineBox[{483, 734}], LineBox[{484, 735}], LineBox[{485, 736}], 
       LineBox[{486, 737}], LineBox[{487, 738}], LineBox[{488, 739}], 
       LineBox[{489, 740}], LineBox[{490, 741}], LineBox[{491, 742}], 
       LineBox[{492, 743}], LineBox[{493, 744}], LineBox[{494, 745}], 
       LineBox[{495, 746}], LineBox[{496, 747}], LineBox[{497, 748}], 
       LineBox[{498, 749}], LineBox[{499, 750}], LineBox[{500, 751}], 
       LineBox[{501, 752}], LineBox[{502, 753}]}}, {{}, 
      {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
       0.011111111111111112`], AbsoluteThickness[1.6], 
       PointBox[CompressedData["
1:eJwNw1OQFQAAAMCXbbvLtm3btm3btm3btm3b+squ3ZkNata5WqdggUDglx+D
BwKf/OwXv/rN7/7wp7/87R//+s9AiEAgmMENYUhDGdowhjWc4Y1gRCMZ2ShG
NZrRjWFMYxnbOMY1nvFNYEITmdgkJjXIZCY3hSlNZWrTmNZ0pjeDGc1kZrOY
1WxmN4c5zWVu85jXfOa3gAUtZGGLWNRiFreEJS1lactY1nKWt4IVrWRlq1jV
ala3hjWtZW3rWNd61reBDW1kY5vY1GY2t4UtbWVr29jWdra3gx3tZGe72NVu
dreHPe1lb/vY1372d4ADHeRghzjUYQ53hCMd5WjHONZxjneCE53kZKc41WlO
d4YzneVs5zjXec53gQtd5GKXuNRlLneFK13late41nWud4Mb3eRmt7jVbW53
hzvd5W73uNd97veABz3kYY941GMe94QnPeVpz3jWc573ghe95GWveNVrXveG
N73lbe9413ve94EPfeRjn/jUZz73hS995Wvf+NZ3vveD/wGL74Bn
        "]]}, 
      {RGBColor[0.880722, 0.611041, 0.142051], PointSize[
       0.011111111111111112`], AbsoluteThickness[1.6], 
       PointBox[CompressedData["
1:eJwNw0OQHAAAALCtbbtX27Zt27Zt27Zt27Ztvmq7yUyCmnWu1ilYIBD45ZsQ
gcBb3/neD370k5/94le/+d0f/vSXv/3jX/8ZCBkIBDO4IQxpKEMbxrCGM7wR
jGgkIxvFqEYzujGMaSxjG8e4xjO+CUxoIhObxKQGmczkpjClqUxtGtOazvRm
MKOZzGwWs5rN7OYwp7nMbR7zms/8FrCghSxsEYtazOKWsKSlLG0Zy1rO8law
opWsbBWrWs3q1rCmtaxtHetaz/o2sKGNbGwTm9rM5rawpa1sbRvb2s72drCj
nexsF7vaze72sKe97G0f+9rP/g5woIMc7BCHOszhjnCkoxztGMc6zvFOcKKT
nOwUpzrN6c5wprOc7RznOs/5LnChi1zsEpe6zOWucKWrXO0a17rO9W5wo5vc
7Ba3us3t7nCnu9ztHve6z/0e8KCHPOwRj3rM457wpKc87RnPes7zXvCil7zs
Fa96zeve8Ka3vO0d73rP+z7woY987BOf+sznvvClr3ztfxyigXY=
        "]]}, {}}}], {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"days\"", TraditionalForm], 
    FormBox["\"Bq/day\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0, 300.}, {0, 0.015817080298892887`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.3992718921776505`*^9, {3.399271957891288*^9, 3.3992719670958853`*^9}, {
   3.3992720408420577`*^9, 3.3992720636738353`*^9}, 3.3992729162431574`*^9, 
   3.3992737570022707`*^9, 3.3992738278822975`*^9, 3.3992738834665017`*^9, {
   3.399274085143012*^9, 3.399274100939311*^9}, 3.399274132266031*^9, 
   3.413801678244232*^9, 3.480094219474431*^9, 3.4800960186642*^9, 
   3.4801563886572*^9, 3.5185322582425814`*^9, 3.5396990654849167`*^9, 
   3.592064497970005*^9, 3.643609951383554*^9},
 CellLabel->"Out[42]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Disintegrations", "Subsection"],

Cell[TextData[{
 "The nuclear transformations ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["U", "i"], "(", "t", ")"}], TraditionalForm]]],
 " that will happen up to time \[Tau] in a compartment i as consequence of \
the isotope content given by ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["q", "i"], "(", "t", ")"}], TraditionalForm]]],
 " are calculated using the eqn. (14) "
}], "Text"],

Cell[TextData[Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{
    SubscriptBox["U", "i"], "(", "\[Tau]", ")"}], "=", 
   RowBox[{
    SubscriptBox["f", "c"], 
    RowBox[{
     SubsuperscriptBox["\[Integral]", "0", "t"], 
     RowBox[{
      RowBox[{
       SubscriptBox["q", "i"], "(", "t", ")"}], 
      RowBox[{"\[DifferentialD]", "t"}]}]}]}]}], 
  TraditionalForm]]]], "NumberedEquation"],

Cell[TextData[{
 "where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "c"], TraditionalForm]]],
 " is a conversion factor applied to give the nuclear transformations in the \
desired units. So fc = 8.65\[Times]",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "4"}]], TraditionalForm]]],
 " (in s ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["d", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 ") to give ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["U", "i"], "(", "\[Tau]", ")"}], TraditionalForm]]],
 " in Bq when t is in days and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["q", "i"], "(", "t", ")"}], TraditionalForm]]],
 " is in Bq.\n",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["U", "i"], "(", "t", ")"}], " "}], TraditionalForm]]],
 "is widely used in internal dosimetry, for example to calculate the \
commitment dose. In some publications (examples: apart. 9.4 in ICRP 66 or \
Loevinger 1988) ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["U", "i"], "(", "t", ")"}], TraditionalForm]]],
 " is usually computed using the mean residence times corrected with some \
mathematical tricks. It is already an approximated method. BIOKMOD computes \
analytically the eqn. (14) obtaining the exact solution."
}], "Text"],

Cell[TextData[{
 "This function compute the accumulated disintegrations in the thyroid at \
time ",
 StyleBox["t",
  FontSlant->"Italic"],
 " after an acute intake by ingestion in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", "0"}], TraditionalForm]]],
 " for iodine stable (\[Lambda].\[Rule]0)"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"disThyIodine", "[", "t_", "]"}], "=", 
  RowBox[{
   RowBox[{
    SubscriptBox["q", "2"], "[", "t", "]"}], "/.", 
   RowBox[{"BiokdataReport", "[", 
    RowBox[{
    "iodine", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
     "\"\<Disintegrations\>\"", ",", "1", ",", "1", ",", "t", ",", "0"}], 
    "]"}]}]}]], "Input",
 CellLabel->"In[43]:="],

Cell[BoxData[
 RowBox[{"3.9362795220877323`*^6", "-", 
  RowBox[{"141.11363409767654`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "24"}], " ", "t"}]]}], "+", 
  RowBox[{"10603.521960675824`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2.772544338670251`"}], " ", "t"}]]}], "-", 
  RowBox[{"19567.145186672893`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.06014707810383513`"}], " ", "t"}]]}], "-", 
  RowBox[{"3.9271747852276377`*^6", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.006323910269362187`"}], " ", "t"}]]}]}]], "Output",
 CellChangeTimes->{3.3985841355321026`*^9, 3.398592291245886*^9, 
  3.413801678587989*^9, 3.4800942197240305`*^9, 3.4800960188514*^9, 
  3.4801563890004*^9, 3.518532258570712*^9, 3.5396990656567955`*^9, 
  3.592064498297037*^9, 3.6436099514929295`*^9},
 CellLabel->"Out[43]="]
}, Open  ]],

Cell["\<\
Here are presented the evolution of acumulated disintegrations\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"disThyIodine", "[", "t", "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "3000"}], "}"}], ",", 
   RowBox[{"PlotRange", "\[Rule]", " ", "All"}], ",", "  ", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<days\>\"", ",", " ", "\"\<Acumuled disintegrations\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[44]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwd1nc81H8cB3DZGQ07lcqqyBYien+VfSejspJVRrIyQ7L33ts5d0fDFooo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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"days\"", TraditionalForm], 
    FormBox["\"Acumuled disintegrations\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{All, All},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3985841356733494`*^9, 3.3985922913555336`*^9, 
  3.4138016786973658`*^9, 3.480094219786431*^9, 3.4800960189294*^9, 
  3.480156389172*^9, 3.518532258695715*^9, 3.5396990657349215`*^9, 
  3.5920644984090486`*^9, 3.6436099516023035`*^9},
 CellLabel->"Out[44]="]
}, Open  ]],

Cell[TextData[{
 "The accumulated disintegrations for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " "}], TraditionalForm]]],
 "50 year is"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"disThyIodine", "[", 
  RowBox[{"50", "*", "365"}], "]"}]], "Input",
 CellLabel->"In[45]:="],

Cell[BoxData["3.9362795220877323`*^6"], "Output",
 CellChangeTimes->{3.39858413575182*^9, 3.398592291386862*^9, 
  3.4138016787442417`*^9, 3.4800942198020306`*^9, 3.4800960189449997`*^9, 
  3.4801563892032003`*^9, 3.5185322587269654`*^9, 3.5396990657817974`*^9, 
  3.592064498452053*^9, 3.6436099516335545`*^9},
 CellLabel->"Out[45]="]
}, Open  ]],

Cell[TextData[{
 "Here is the same computation for iodine 131 (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["t", 
      RowBox[{"1", "/", "2"}]], " ", "=", " ", 
     RowBox[{"8.0", " ", "d"}]}], ")"}], TraditionalForm]]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"disThyIodine131", "[", "t_", "]"}], "=", 
  RowBox[{
   RowBox[{
    SubscriptBox["q", "2"], "[", "t", "]"}], "/.", 
   RowBox[{"BiokdataReport", "[", 
    RowBox[{
    "iodine", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
     "\"\<Disintegrations\>\"", ",", "1", ",", "1", ",", "t", ",", 
     RowBox[{
      RowBox[{"Log", "[", "2", "]"}], "/", "8"}]}], "]"}]}]}]], "Input",
 CellLabel->"In[46]:="],

Cell[BoxData[
 RowBox[{"265014.0060069634`", "\[VeryThinSpace]", "-", 
  RowBox[{"140.60602643728726`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "24.086643397569993`"}], " ", "t"}]]}], "+", 
  RowBox[{"10282.198125505389`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2.859187736240244`"}], " ", "t"}]]}], "-", 
  RowBox[{"8017.595177135395`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.1467904756738283`"}], " ", "t"}]]}], "-", 
  RowBox[{"267138.0029288961`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.09296730783935535`"}], " ", "t"}]]}]}]], "Output",
 CellChangeTimes->{3.398584136175561*^9, 3.3985922917627974`*^9, 
  3.413801679119249*^9, 3.480094220082831*^9, 3.4800960191478*^9, 
  3.4801563894996*^9, 3.5185322590550966`*^9, 3.5396990659536757`*^9, 
  3.592064498783086*^9, 3.64360995174293*^9},
 CellLabel->"Out[46]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"disThyIodine131", "[", 
  RowBox[{"50", "*", "365"}], "]"}]], "Input",
 CellLabel->"In[47]:="],

Cell[BoxData["265014.0060069634`"], "Output",
 CellChangeTimes->{3.3985841362383375`*^9, 3.3985922917941256`*^9, 
  3.4138016791817503`*^9, 3.480094220114031*^9, 3.480096019179*^9, 
  3.4801563894996*^9, 3.5185322591332235`*^9, 3.5396990660005517`*^9, 
  3.5920644988250904`*^9, 3.6436099517585545`*^9},
 CellLabel->"Out[47]="]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sensitivity and uncertainty analysis ", "Section"],

Cell[TextData[{
 "The estimation of isotope content in a compartment or region involves many \
uncertainties even assuming that the ICRP metabolic models are a good \
representation of the real behaviour of the particles intake in the human \
body. This is so because most of the true values of the parameters at a real \
situation are unknown. The parameters usually applied are based on the \
reference values given in ICRPs. \nLet\[CloseCurlyQuote]s be ",
 StyleBox["r",
  FontSlant->"Italic"],
 "(",
 StyleBox["t",
  FontSlant->"Italic"],
 ") expressed as function of certain parameters",
 StyleBox[" ",
  FontSlant->"Italic"],
 "{",
 StyleBox["k",
  FontSlant->"Italic"],
 StyleBox["1,",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "\[Ellipsis], ",
 StyleBox["k",
  FontSlant->"Italic"],
 StyleBox["r",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "} with their associated uncertainties: {",
 StyleBox["u",
  FontSlant->"Italic"],
 "(",
 StyleBox["k",
  FontSlant->"Italic"],
 StyleBox["1",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "),\[Ellipsis]",
 StyleBox["u",
  FontSlant->"Italic"],
 "(",
 StyleBox["k",
  FontSlant->"Italic"],
 StyleBox["r",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 ")}, then \n\t"
}], "Text"],

Cell[TextData[{
 StyleBox["r",
  FontSlant->"Italic"],
 "(",
 StyleBox["t",
  FontSlant->"Italic"],
 ") = ",
 StyleBox["F",
  FontSlant->"Italic"],
 "(",
 StyleBox["k",
  FontSlant->"Italic"],
 StyleBox["1",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 ", \[Ellipsis], ",
 StyleBox["k",
  FontSlant->"Italic"],
 StyleBox["n",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 ", ",
 StyleBox["t",
  FontSlant->"Italic"],
 ") \[PlusMinus] ",
 StyleBox["u",
  FontSlant->"Italic"],
 StyleBox["C",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["t",
  FontSlant->"Italic"],
 ")"
}], "NumberedEquation"],

Cell[TextData[{
 "being ",
 StyleBox["u",
  FontSlant->"Italic"],
 StyleBox["C",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["t",
  FontSlant->"Italic"],
 ") the combined standard uncertainty. \nAssuming that {",
 StyleBox["k",
  FontSlant->"Italic"],
 StyleBox["1,",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "\[Ellipsis], ",
 StyleBox["k",
  FontSlant->"Italic"],
 StyleBox["r",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "} are uncorrelated and taking the first-order Taylor series terms of ",
 StyleBox["F",
  FontSlant->"Italic"],
 "(",
 StyleBox["k",
  FontSlant->"Italic"],
 StyleBox["1",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 ", \[Ellipsis], ",
 StyleBox["k",
  FontSlant->"Italic"],
 StyleBox["n",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 ", ",
 StyleBox["\[Lambda]",
  FontFamily->"Times New Roman Greek"],
 ", ",
 StyleBox["t",
  FontSlant->"Italic"],
 "), then ",
 StyleBox["u",
  FontSlant->"Italic"],
 StyleBox["C",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["t",
  FontSlant->"Italic"],
 ") can be evaluated using\n"
}], "Text"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SuperscriptBox[
      FormBox[
       SubscriptBox["u", "c"],
       TraditionalForm], "2"], "(", 
     RowBox[{"r", "(", "t", ")"}], ")"}], " ", "=", " ", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{" ", 
       RowBox[{"i", " ", "=", "1"}]}], "r"], 
     RowBox[{
      SuperscriptBox[
       RowBox[{"(", 
        FractionBox[
         RowBox[{"\[PartialD]", " ", "F"}], 
         RowBox[{"\[PartialD]", " ", 
          SubscriptBox["k", "i"]}]], ")"}], "2"], 
      RowBox[{
       SuperscriptBox["u", "2"], "(", 
       SubscriptBox["k", "i"], ")"}]}]}]}], TraditionalForm]]],
 " "
}], "NumberedEquation"],

Cell["This is the expression used by BIOKMOD.", "Text"],

Cell[TextData[{
 "Of course, eqn (16) can be only applied when we can obtain the analytical \
solution of the model as function of the parameters {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "1"], TraditionalForm]]],
 ",\[Ellipsis], ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "r"], TraditionalForm]]],
 "), but  it is only possible when the model not involve recycling and in \
some particular cases of models with recycling.   No recycling models can be \
discomposed in catenary branches (Skrable et al, 1974), then, when {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "i"], TraditionalForm]]],
 " \[NotEqual] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "j"], TraditionalForm]]],
 "), the solution can be expressed as function of the parameters {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "1"], TraditionalForm]]],
 ",\[Ellipsis], ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "r"], TraditionalForm]]],
 "). \nThe HRTM is a non recycling model. So, eqn (16) can be use to study \
the HRTM uncertainties as it is shown in some of the examples below. "
}], "Text"],

Cell["\<\
Also, it included an example where the eqn (16) is applied in a non recycling \
model. \
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 "Example 1 .- Lung retention uncertainties associated with AMAD ",
 StyleBox["p",
  FontSlant->"Italic"],
 " and ",
 StyleBox["u",
  FontSlant->"Italic"],
 StyleBox["p",
  FontVariations->{"CompatibilityType"->"Subscript"}]
}], "SubsubsectionIcon"],

Cell[TextData[{
 "Lung retention predicted for a single intake of 1 Bq at ",
 StyleBox["t",
  FontSlant->"Italic"],
 " = 0, type S, decay constant negligible ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{
     SubscriptBox["\[Lambda]", "R"], "\[Rule]", "0"}], ")"}], 
   TraditionalForm]]],
 " and AMAD p = 5 \[Mu]m and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["u", "p"], " ", "=", " ", 
    SubscriptBox["s", "p"]}], TraditionalForm]]],
 " = 0.5 \[Mu]m . The dashed lines represent the confidence interval (95%) \
associated with the AMAD uncertainties."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rLung", "[", 
    RowBox[{"p_", ",", "t_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"LungsRetention", "[", 
     RowBox[{"1", ",", 
      RowBox[{"AMADfit", "[", "p", "]"}], ",", "S", ",", " ", "t", ",", "0"}],
      "]"}], "//", "Chop"}]}], ";"}]], "Input",
 CellLabel->"In[48]:="],

Cell[TextData[{
 "The evolution of the content with their associated uncertainties for a \
coverage factor ",
 Cell[BoxData[
  FormBox[
   RowBox[{"k", "=", "2"}], TraditionalForm]]],
 " is computed and represented as follow"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"yu", "[", "t1_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<mean\>\"", ",", " ", "\"\<uL\>\"", ",", " ", "\"\<lL\>\""}], "}"}],
      "/.", 
     RowBox[{"Uin", "[", 
      RowBox[{
       RowBox[{"rLung", "[", 
        RowBox[{"p", ",", "t1"}], "]"}], ",", " ", 
       RowBox[{"{", "p", "}"}], " ", ",", " ", 
       RowBox[{"{", "\[Sigma]p", "}"}], " ", ",", " ", "2"}], "]"}]}], " ", "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"p", "\[Rule]", " ", "5"}], ",", " ", 
      RowBox[{"\[Sigma]p", "\[Rule]", " ", "0.5"}]}], "}"}]}]}], 
  ";"}]], "Input",
 CellLabel->"In[49]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"yu", "[", "t", "]"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", "1", ",", " ", "100"}], "}"}], ",", " ", 
   RowBox[{"PlotRange", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0.1"}], "}"}]}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<days\>\"", ",", " ", "\"\<Bq\>\""}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "styles"}]}], "]"}]], "Input",
 CellLabel->"In[50]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwVy3s01Akfx/EJBxWRle0ykdoGo51120Xt+n5dUkg0Bj/KSRoMwp7NisjT
g6bNsOdxLWyP7G8wI5ffUSobE2NT2457tLtTGmTFyg5pSYZnnj8+531ef3zM
IxLZkRo0Go2r3v/rww0x1aApwUmztD9FTkFoio1JeLoSDMWLbkbDFPBydTZJ
lpTQXn6+f6qPAv7tZlXq3BxUmN/L9HhEQfHj3HfP4ufBVt7wol1KgfD56Tef
T89DWU73/XgJBVItoxdzY2/h176+et87FPRvnXrqd3IBDjN4/LQmChT72mX1
8gV4bcuL7G2gYJWT0Brz9B0EHOJFK2oo2F/1pHz04SJ88B0Y+bqcAq+WykJw
WwJT2zD3q9coILpTBNclS9BUlbJzqJiC5HeMtJC77yGmxqg7/z8UNB3MCu0X
fQBGyu7SN3wKOkJC2Z/tXQE+sq/UZ1PQF2/rnVe5AttbWlbTMimYLX7p7FWm
grOCCQvXDAqYfx7Y1iFYg+ADH/8enEwB/cKV7wy0aHgWnP5JTqLgE51vs13c
aHj039bbKr6hwG7HkfQfJDTUsdwQpZtIgb/7chxxdx0q7S4k2PEoyC0M8ukT
aWKD2cxQwXEKtBwMNrQLdPDypczTcg8KUmZlG5i9Olh40r6N607BjChnY5GR
LrKjtgz97UrB053a+rxSXVTmNys2AAWkjsrAsGY9Gr6T7GI7U+Amn94SLt2I
JgMlf5qwKLiY2WVOe2+AoeLjD2y2UpDxWkLfZW+MG/3ltBB5I8T7bjaP20xH
wUJhmMCtEUryPNO2vTLHHXmTVrxbDfBlmsWtTz9iYKd1S5yNWQPQFwJPPVq2
wiGG3MGivB6kZ2tObP6ChdVzwt58o3p4PeipkLFsMWd6brSloA4Et8K7B03t
kbbdb/XhrjrIN9EbbXL6HFf237Zuqr0JDjDS+JTliEUa7vphrjdBT7rctGWH
M45r1u1NGamFQ49Fz1m2B1A76qqw/1wtmBZd6MjZ8xXKJ364YkOvBWJ8XCYB
wFPi4l5mmxi4nt7a68WIy/1JUVpcMUyrmjU5N1zRRCfEKsJYDLvPxRoL6tzQ
1tuqsrpDBJYBTZnj1e5Y2xkZ2XBOBAqlm5blHQ+86Pjd5QmmCJruL5mltx/E
pFfXsx+M1QB7yrV07p4nDmtbddr8WAPC3wb3BnQdwtzm1jN6J2vgZ+Z7g+GO
w/gyOFxzancNrIrdi3j3vHB1t+6l/dPVMD09bD3Z6Y2J9x9rMxurQfi9atfl
Nh+M01axHM9Xg+HCGauPZEfwUIYu19i9Gkr462QNQ76Y41OxztRA/U+zksV1
H8UBzW0GGYoqUNqVvTT+ww8HRHvuPGusggiGnygx1h8dqCNje7Kr4PdfxutP
TPijrLGwezC0Cqx66G0PYo/hkgnUVn5WBYosszT7yWP4B2wKe6JbBV+Xdbnt
TGCjZWtrl71CCNERji0fz7BR9brbUXxfCH+1/7RSGh2A3LOe+vqlQjh8ccyr
4E0ASuZLLvUkCUFvbvBgeSwH6etrXD7hCEEsjfHZPs9B75t2Lm9thTDINDI1
PxeIQbQekWCzELge2RVObwNxpP7v0aMLJPRIyphdqUHoufLPxI9DJFRMn+dy
F4Mwz8WrbaaFBFVdfFzON8H4ysXuenEFCQ59WumMpWAsmHT9azyLhAFh5IHB
JAKLsn6xfhZLgsgyaHYtmUB5bDktRu1/1XlW7kslcFG6PL4cQ8K+2xY6/AsE
mu0JGjZVm985NeDEJ3AkgBUTHU2C81h87H+vEvhK47nHh9Mk3DBLLo35iUBf
6/Xtn4aRkExGHSlpJdBp03x4xwkSfC2C16QSAudS9AwD1V5mOUXSOwk8k//k
WvpxEjguyza9vxKYVEnnyEJI0A3LeOzwgsDU7huJCUEkjCgS0k69JLDrst+8
htrN3JOs70cJVLRpZF0NJCHiDBZNThAYmRjX084hoTVNI7xslsAdXYt6xgEk
FKzNGz1SErjXOX1NxCYhJmv84dt5AvfJZ9e+UttE8LO17yKB+vmFTN4xEmY2
NY+kvidQtrWdo/InQVpQlV/9gcBjd3tzC9S+ZlLiMagiUFf0YMBC7cQy/uLa
GoFKRh6jzY+E/wEXFfrj
     "]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwVzXk81Ikfx/EJizbrLLWbsxxRphLlKJ9P48iRJcQ3HWs1dmuEVVb8hhQe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     "]]}, 
   {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwVznk41IkfB/BRdkdYV+iyjg45ahTaWPL5NDmSEhP55pfCjs2ZHhulofWL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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"days\"", TraditionalForm], 
    FormBox["\"Bq\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0., 99.99999797959184}, {0, 0.1}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3985841372270656`*^9, 3.3985922927652936`*^9, 
  3.413801680119268*^9, 3.413801744401117*^9, 3.480094221003231*^9, 
  3.4800960199122*^9, 3.4801563904512*^9, 3.518532260164493*^9, 
  3.5396990665786877`*^9, 3.592064499967204*^9, 3.643609952086689*^9},
 CellLabel->"Out[50]="]
}, Open  ]],

Cell["\<\
It can be observed that a small difference in the AMAD value has an important \
consequence in the lung retention predicted. For this reason, when the value \
for AMAD is used to evaluate bioassay data and it it is not known then the \
intake estimated could have important uncertainties. \
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Example 2 .- Lung retention uncertainties associated with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["IDF", "i"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["u", 
    SubscriptBox["IDF", "i"]], TraditionalForm]]]
}], "SubsubsectionIcon"],

Cell[TextData[{
 "We want to evaluate for a reference worker the lung retention after an \
acute intake (",
 Cell[BoxData[
  FormBox[
   RowBox[{"I", " ", "=", " ", "1"}], TraditionalForm]]],
 " at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", "0"}], TraditionalForm]]],
 ") of  radioactive aerosols type S and  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", "R"], TraditionalForm]]],
 " \[TildeTilde] 0  assuming a relative standard deviation of 10% of the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["IDF", "i"], TraditionalForm]]],
 "  (that is ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["\[Sigma]", "i"], "/", 
     SubscriptBox["IDF", "i"]}], "=", "0.1"}], TraditionalForm]]],
 ")."
}], "Text"],

Cell[TextData[{
 "In this example we evaluate the lung uncertainties associated with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["IDF", "i"], TraditionalForm]]],
 ": {",
 Cell[BoxData[
  SubscriptBox["IDF", "AI"]]],
 ", ",
 Cell[BoxData[
  SubscriptBox["IDF", 
   RowBox[{"bb", 
    RowBox[{"(", 
     RowBox[{"fast", "+", "seq"}], ")"}]}]]]],
 ",",
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    SubscriptBox["IDF", "bbslow"], ",", " "}]}]]],
 Cell[BoxData[
  RowBox[{
   SubscriptBox["IDF", "\<\"BB(fast+seq)\"\>"], " "}]]],
 Cell[BoxData[
  RowBox[{",", " ", 
   SubscriptBox["IDF", "BBslow"]}]]],
 "} "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rLung", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "idfAI_", ",", "idfbbfs_", ",", "idfbbslow_", ",", " ", "idfBBfs_", ",",
        " ", "idfBBslow_", ",", " ", "ET2_", ",", " ", "ET1_"}], "}"}], ",", 
     "t_"}], "]"}], "=", 
   RowBox[{"Collect", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"LungsRetention", "[", 
       RowBox[{"1", ",", 
        RowBox[{"{", 
         RowBox[{
         "idfAI", ",", "idfbbfs", ",", "idfbbslow", ",", " ", "idfBBfs", ",", 
          " ", "idfBBslow", ",", " ", "ET2", ",", " ", "ET1"}], "}"}], " ", 
        ",", "S", ",", " ", "t", ",", "0"}], "]"}], "//", "Chop"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "idfAI", ",", "idfbbfs", ",", "idfbbslow", ",", " ", "idfBBfs", ",", 
       " ", "idfBBslow"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[51]:="],

Cell["Calling", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"idf", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["IDF", "AI"], ",", 
     SubscriptBox["IDF", 
      RowBox[{"bb", 
       RowBox[{"(", 
        RowBox[{"fast", "+", "seq"}], ")"}]}]], ",", " ", 
     SubscriptBox["IDF", "bbslow"], ",", " ", 
     SubscriptBox["IDF", "\"\<BB(fast+seq)\>\""], " ", ",", " ", 
     SubscriptBox["IDF", "BBslow"], ",", " ", "ET2", ",", " ", "ET1"}], 
    "}"}]}], ";"}]], "Input",
 CellLabel->"In[52]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"idf1", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["IDF", "AI"], ",", 
     SubscriptBox["IDF", 
      RowBox[{"bb", 
       RowBox[{"(", 
        RowBox[{"fast", "+", "seq"}], ")"}]}]], ",", " ", 
     SubscriptBox["IDF", "bbslow"], ",", " ", 
     SubscriptBox["IDF", "\"\<BB(fast+seq)\>\""], " ", ",", " ", 
     SubscriptBox["IDF", "BBslow"]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[53]:="],

Cell[TextData[{
 "Note that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     SubscriptBox["F", "Lung"], "(", 
     RowBox[{"t", ",", "p"}], ")"}], " ", "=", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "5"], 
     RowBox[{
      RowBox[{
       SubscriptBox["A", "i"], "(", "t", ")"}], " ", 
      RowBox[{
       SubscriptBox["IDF", "i"], "(", "p", ")"}]}]}]}], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"rLung", "[", 
  RowBox[{"idf", ",", "t"}], "]"}]], "Input",
 CellLabel->"In[54]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"0.000991016974042802`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110.1`"}], " ", "t"}]]}], "+", 
     RowBox[{"6.986020965054837`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.1`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.9920089830259572`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0069930139790349444`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0001`"}], " ", "t"}]]}]}], ")"}], " ", 
   SubscriptBox["IDF", "\<\"BB(fast+seq)\"\>"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{"1.6522149597360367`*^-7", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110.1`"}], " ", "t"}]]}], "-", 
     RowBox[{"4.160990610320783`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "102.1`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0003030312124272516`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.11999999999999`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0005991612638047705`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.101`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.00008317290463989713`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.10012`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.000016633383250131556`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.1`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0001653868828564822`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.004165155766087867`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.0001`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.30333454697424916`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0201`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.599761024829842`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0011`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.08325616080071588`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.00022`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.016650033283416535`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0001`"}], " ", "t"}]]}]}], ")"}], " ", 
   SubscriptBox["IDF", "AI"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1.2565127978773384`*^-6"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110.1`"}], " ", "t"}]]}], "-", 
     RowBox[{"8.73252620631898`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "102.1`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.001001006013046979`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.13`"}], " ", "t"}]]}], "+", 
     RowBox[{"6.986020965054837`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.1`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.0012577705684458532`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.008741267473793682`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.0001`"}], " ", "t"}]]}], "+", 
     RowBox[{"1.0020080210681968`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0301`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0069930139790349444`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0001`"}], " ", "t"}]]}]}], ")"}], " ", 
   SubscriptBox["IDF", "bbslow"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "6.986020965054837`*^-6"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110.1`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0009980029950078517`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.13`"}], " ", "t"}]]}], "+", 
     RowBox[{"6.986020965054837`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.1`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.006993013979034945`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.9990019970049921`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0301`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0069930139790349444`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0001`"}], " ", "t"}]]}]}], ")"}], " ", 
   SubscriptBox["IDF", "BBslow"]}], "+", 
  RowBox[{
   RowBox[{"(", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.0002477542435107005`"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110.1`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0012387712175536691`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "102.1`"}], " ", "t"}]]}], "+", 
     RowBox[{"6.986020965054837`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.1`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.2480022457564893`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "+", 
     RowBox[{"1.2400112287824465`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.0001`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0069930139790349444`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0001`"}], " ", "t"}]]}]}], ")"}], " ", 
   SubscriptBox["IDF", 
    RowBox[{"bb", " ", 
     RowBox[{"(", 
      RowBox[{"fast", "+", "seq"}], ")"}]}]]}]}]], "Output",
 CellChangeTimes->{3.3985841375252533`*^9, 3.3985922929845896`*^9, 
  3.4138016803536477`*^9, 3.4138017446042433`*^9, 3.4800942211124306`*^9, 
  3.4800960200682*^9, 3.4801563906071997`*^9, 3.5185322602894955`*^9, 
  3.5396990667349405`*^9, 3.5920645002002277`*^9, 3.6436099522116804`*^9},
 CellLabel->"Out[54]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"idfu", "[", "t1_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<mean\>\"", ",", " ", "\"\<uL\>\"", ",", " ", "\"\<lL\>\""}], "}"}],
      "/.", 
     RowBox[{"Uin", "[", 
      RowBox[{
       RowBox[{"rLung", "[", 
        RowBox[{"idf", ",", "t1"}], "]"}], ",", "idf1", " ", ",", " ", 
       RowBox[{"0.1", " ", "idf1"}], " ", ",", " ", "2"}], "]"}]}], " ", "/.", 
    RowBox[{"Thread", "[", 
     RowBox[{"idf", "\[Rule]", " ", 
      RowBox[{"AMADAdultW", "[", "5", "]"}]}], "]"}]}]}], ";"}]], "Input",
 CellLabel->"In[55]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig4", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"Evaluate", "[", 
     RowBox[{"idfu", "[", "t", "]"}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "1", ",", "100"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0.02`", ",", "0.08`"}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<days\>\"", ",", "\"\<Bq\>\""}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", "styles"}]}], "]"}]}]], "Input",
 CellLabel->"In[56]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV0Hk81AkfB/Ah21hZZ3SYhvHkTCIqVvl+GyFEcv6oNs2ybrVrV+x0IM9s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     "]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwVx3881IcfwPHryCnKb9UoqeZXpZSWarzfnUuEMsSHaswov9umRMoX+d6W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     "]]}, 
   {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwVx3k81AkfwHHH7OhaNjke5chjETEPUab0+H4bGedEzl92V3jchZ6U46FW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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"days\"", TraditionalForm], 
    FormBox["\"Bq\"", TraditionalForm]},
  AxesOrigin->{0, 0.02},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0., 99.99999797959184}, {0.02, 0.08}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.398584138058853*^9, 3.3985922935015016`*^9, 
  3.4138016808536572`*^9, 3.4138017451198716`*^9, 3.480094221502431*^9, 
  3.4800960203958*^9, 3.480156390966*^9, 3.518532260617627*^9, 
  3.5396990669849453`*^9, 3.5920645007252803`*^9, 3.6436099523366804`*^9},
 CellLabel->"Out[56]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Example 3 .- Whole body uncertainties of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "60"], TraditionalForm]]],
 "Co intake by ingestion associated with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 "."
}], "SubsubsectionIcon"],

Cell[TextData[{
 "The uncertainties of the retention functions associated with the rate \
transfer factors is other interesting topic to be investigated using \
analitycal methods.   Howerver, it is not always posible to obtain the \
analitical expresion of a model as function of one o several rate transter \
factors ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "i"], TraditionalForm]]],
 ". In fact, it is only posible when the model not involve recicling and in \
some particular cases of model with recycling.   The no recycling models can \
be descomposed  in catenary branches (Skrable el al, 1988).  Then, when it is \
verified that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "i"], TraditionalForm]]],
 "\[NotEqual] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "j"], TraditionalForm]]],
 ",  the retention function after an acute intake ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "0"], TraditionalForm]]],
 " at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", "0"}], TraditionalForm]]],
 " has the pattern that follows (Sanchez and Lopez -Fidalgo 1988):"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"r", 
   RowBox[{"(", 
    RowBox[{"I", ",", " ", 
     SubscriptBox["k", 
      RowBox[{"1", ",", " ", "...", ","}]], ",", 
     SubscriptBox["k", "n"], ",", 
     SubscriptBox["\[Lambda]", "R"], ",", "t"}], ")"}]}], " ", "=", " ", 
  RowBox[{
   SubscriptBox["I", "0"], 
   RowBox[{"(", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"r", "=", "1"}], "q"], 
     RowBox[{
      SubscriptBox["A", "r"], 
      RowBox[{"(", 
       RowBox[{
        SubscriptBox["k", 
         RowBox[{"1", ",", " ", "...", ","}]], ",", 
        SubscriptBox["k", "n"]}], ")"}], 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", " ", 
         SubscriptBox["a", "r"]}], 
        RowBox[{"(", 
         RowBox[{
          SubscriptBox["k", 
           RowBox[{"1", ",", " ", "...", ","}]], ",", 
          SubscriptBox["k", "n"]}], ")"}], "t"}]]}]}], ")"}], 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", 
      SubscriptBox["\[Lambda]", "R"]}], "t"}]]}]}]], "Text"],

Cell[TextData[{
 "being ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["A", "r"], TraditionalForm]]],
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["k", 
     RowBox[{"1", ",", " ", "...", ","}]], ",", 
    SubscriptBox["k", "n"]}], ")"}]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["a", "r"], TraditionalForm]]],
 Cell[BoxData[
  RowBox[{"(", 
   RowBox[{
    SubscriptBox["k", 
     RowBox[{"1", ",", " ", "...", ","}]], ",", 
    SubscriptBox["k", "n"]}], ")"}]]],
 " the coefficients obtained solving the model for the specific case. "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["K", "1"], "=", " ", 
   RowBox[{
    SubscriptBox["k", "1"], "+", "K1"}]}], ";", 
  RowBox[{
   SubscriptBox["K", "2"], "=", " ", 
   RowBox[{
    SubscriptBox["k", "2"], "+", "K2"}]}], ";", 
  RowBox[{
   SubscriptBox["K", "3"], "=", " ", 
   RowBox[{
    SubscriptBox["k", "2"], "+", "K3"}]}], ";"}]], "Input",
 CellLabel->"In[57]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"ff", "[", "t_", "]"}], "=", 
  StyleBox[
   RowBox[{
    RowBox[{"Catenary", "[", 
     RowBox[{
     "b", ",", " ", "3", ",", " ", "t", ",", "K", ",", " ", "k", ",", "0"}], 
     "]"}], "//", "Simplify"}], "Input"]}]], "Input",
 CellLabel->"In[58]:="],

Cell[BoxData[
 RowBox[{"b", " ", 
  SubscriptBox["k", "1"], " ", 
  SubscriptBox["k", "2"], " ", 
  RowBox[{"(", 
   RowBox[{
    FractionBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "t"}], " ", 
       RowBox[{"(", 
        RowBox[{"K1", "+", 
         SubscriptBox["k", "1"]}], ")"}]}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"K1", "-", "K2", "+", 
        SubscriptBox["k", "1"], "-", 
        SubscriptBox["k", "2"]}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{"K1", "-", "K3", "+", 
        SubscriptBox["k", "1"], "-", 
        SubscriptBox["k", "2"]}], ")"}]}]], "+", 
    FractionBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "t"}], " ", 
       RowBox[{"(", 
        RowBox[{"K2", "+", 
         SubscriptBox["k", "2"]}], ")"}]}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{"K2", "-", "K3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "K1"}], "+", "K2", "-", 
        SubscriptBox["k", "1"], "+", 
        SubscriptBox["k", "2"]}], ")"}]}]], "+", 
    FractionBox[
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "t"}], " ", 
       RowBox[{"(", 
        RowBox[{"K3", "+", 
         SubscriptBox["k", "2"]}], ")"}]}]], 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "K2"}], "+", "K3"}], ")"}], " ", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"-", "K1"}], "+", "K3", "-", 
        SubscriptBox["k", "1"], "+", 
        SubscriptBox["k", "2"]}], ")"}]}]]}], ")"}]}]], "Output",
 CellChangeTimes->{3.398584138529676*^9, 3.39859229392443*^9, 
  3.398593402497038*^9, 3.4138016812286644`*^9, 3.4138017455729995`*^9, 
  3.480094221798831*^9, 3.4800960206142*^9, 3.4801563912468*^9, 
  3.518532260898882*^9, 3.539699067156824*^9, 3.592064501346342*^9, 
  3.643609952492931*^9},
 CellLabel->"Out[58]="]
}, Open  ]],

Cell[TextData[{
 "We wish estimated the associated uncertainty for ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "60"], TraditionalForm]]],
 "Co whole body content retention, after an acute intake ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["I", "0"], " "}], TraditionalForm]]],
 "= 1 by ingestion, for  fractional absorption ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 " = 0.1 with an associated uncertainty of \[Sigma] = 20% ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 ". "
}], "Text"],

Cell[TextData[{
 "The first step is obtained the whole body content as function of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "0"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 ". It can be made as follows"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompartNumbers", "[", "cobalt", "]"}]], "Input",
 CellLabel->"In[59]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "\<\"Blood\"\>"},
    {"2", "\<\"Systemic A\"\>"},
    {"3", "\<\"Systemic B\"\>"},
    {"4", "\<\"Systemic C\"\>"},
    {"5", "\<\"Bladder\"\>"},
    {"6", "\<\"Urine\"\>"},
    {"7", "\<\"ULI\"\>"},
    {"8", "\<\"LLI\"\>"},
    {"9", "\<\"FEC\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.398584138592452*^9, 3.3985922939557576`*^9, 
  3.3985934025283656`*^9, 3.413801745682375*^9, 3.4800942218144307`*^9, 
  3.4800960206454*^9, 3.4801563912623997`*^9, 3.518532260945758*^9, 
  3.5396990672037*^9, 3.592064501635371*^9, 3.6436099525241814`*^9},
 CellLabel->"Out[59]//TableForm="]
}, Open  ]],

Cell["The GI compartments much be added ", "Text"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"Bladder (n-4) to urine(n-3)\"\>", "\<\"k[n-4,n-3]->\"\>", "12"},
    {"\<\"ULI (n-2) to LLI(n-1)\"\>", "\<\"k[n-2,n-1]->\"\>", 
     SubscriptBox["k", "ULI"]},
    {"\<\"LLI (n-1) to FEC(n)\"\>", "\<\"k[n-1,n]->\"\>", 
     SubscriptBox["k", "LLI"]},
    {"\<\"SI (n+1) to ULI(n-2)\"\>", "\<\"k[n+1,n-2]->\"\>", 
     SubscriptBox["k", "SI"]},
    {"\<\"ST (n+2) to SI (n+1)\"\>", "\<\"k[n+2,n+1]->\"\>", 
     SubscriptBox["k", "ST"]},
    {"\<\"SI (n+1) to B(1)\"\>", "\<\"k[n+1,1]->\"\>", 
     RowBox[{
      SubscriptBox["f", "B"], " ", 
      SubscriptBox["k", "SI"]}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output"],

Cell["Then the cobalt compartmental matrix is ", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cobaltextended", " ", "=", 
   RowBox[{
    RowBox[{"Join", "[", " ", 
     RowBox[{
      RowBox[{"icrp30Model", "[", 
       RowBox[{
        RowBox[{"6", "/", "7"}], ",", 
        RowBox[{"1", "/", "7"}], ",", 
        RowBox[{"{", 
         RowBox[{"6", ",", " ", "60", ",", " ", "800"}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"3", "/", "10"}], ",", 
          RowBox[{"1", "/", "10"}], ",", 
          RowBox[{"1", "/", "10"}]}], "}"}], ",", 
        RowBox[{"1", "/", "2"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"11", ",", "10", ",", 
          SubscriptBox["k", "ST"]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"10", ",", "1", ",", 
          RowBox[{
           SubscriptBox["f", "B"], " ", 
           SubscriptBox["k", "SI"]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"10", ",", "7", ",", " ", 
          SubscriptBox["k", "SI"]}], "}"}]}], "}"}]}], "]"}], "/.", 
    RowBox[{"Rationalize", "[", 
     RowBox[{"Options", "[", "qGI", "]"}], "]"}]}]}], ";"}]], "Input",
 CellLabel->"In[60]:="],

Cell[TextData[{
 "The content in each compartment, for ",
 StyleBox["I",
  FontSlant->"Italic"],
 " = 1, is given by  "
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "1"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "2"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "3"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "4"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "5"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "6"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "7"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "8"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "9"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "10"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "11"], "[", "t_", "]"}]}], "}"}], "=", 
   RowBox[{
    RowBox[{"MatrixExp", "[", 
     RowBox[{
      RowBox[{"CompartMatrix", "[", 
       RowBox[{"11", ",", "cobaltextended"}], "]"}], "*", "t"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
      "0", ",", "0", ",", " ", "0", ",", "1"}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.398592723619278*^9, 3.3985927258122377`*^9}},
 CellLabel->"In[61]:="],

Cell[TextData[{
 "Finally, the whole body content as function of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 "and ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 " is (note are obtained sum all compartment content except compartment 6 \
(urine) and 9 (fecal)"
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rWBCo", "[", 
    RowBox[{"fn1_", ",", "t_"}], "]"}], "=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"f1", "=", " ", "fn1"}], "}"}], ",", 
     RowBox[{"Plus", "@@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["q", "1"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["q", "2"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["q", "3"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["q", "4"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["q", "5"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["q", "7"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["q", "8"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["q", "10"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["q", "11"], "[", "t", "]"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[62]:="],

Cell[TextData[{
 "Them Uin function is applied to obtain the whole body rentencion  and their \
associated uncertainty for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 " = 0.1, \[Sigma] = 20% ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 ", and taking \[Gamma] =95% (then z = 2).  It is been account that the \
half-life for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["", "60"], "Co"}], TraditionalForm]]],
 " is 5.27 year. "
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"WBCou", "[", "t1_", "]"}], "=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<mean\>\"", ",", " ", "\"\<uL\>\"", ",", " ", "\"\<lL\>\""}], "}"}],
      "/.", 
     RowBox[{"Uin", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"rWBCo", "[", 
         RowBox[{"fn1", ",", "t1"}], "]"}], " ", 
        RowBox[{"Exp", "[", " ", 
         RowBox[{
          RowBox[{
           RowBox[{"-", 
            RowBox[{"Log", "[", "2", "]"}]}], "/", 
           RowBox[{"(", 
            RowBox[{"5.27", "*", "365.24"}], ")"}]}], " ", "t1"}], "]"}]}], 
       ",", 
       RowBox[{"{", "fn1", "}"}], " ", ",", " ", 
       RowBox[{"{", 
        RowBox[{"0.2", " ", "fn1"}], "}"}], " ", ",", " ", "2"}], "]"}]}], 
    " ", "/.", 
    RowBox[{"fn1", "\[Rule]", " ", "0.1"}]}]}], ";"}]], "Input",
 CellLabel->"In[63]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogPlot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"WBCou", "[", "t", "]"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "1", ",", "30"}], "}"}], ",", " ", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<days\>\"", ",", " ", "\"\<Bq\>\""}], "}"}]}], ",", 
   RowBox[{"PlotStyle", "\[Rule]", "styles"}]}], " ", "]"}]], "Input",
 CellLabel->"In[64]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwVznk4lAsbBnBZZ17DjJlhGBOylbI14Sje5mmjQyKiExVGpUWrqCSlTU5l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     "]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV0Hk01AsbB/Cx/WaMGcOMMYxBidyya1Dy46luaaeUitbhJkUbEUkpS1Sy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     "]]}, 
   {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwVy3k4lAsbx3FkHTPPrAwzY5aQEtnL9uR2OigV2qMdkWhTnHiJUolTIiqJ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"days\"", TraditionalForm], 
    FormBox["\"Bq\"", TraditionalForm]},
  AxesOrigin->{1, -4.958370952105207},
  CoordinatesToolOptions:>{"DisplayFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& ), "CopiedValueFunction" -> ({
      Part[#, 1], 
      Exp[
       Part[#, 2]]}& )},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{
     Charting`ScaledTicks[{Log, Exp}], 
     Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{1, 30}, {-4.958370952105207, 0.08224026197110224}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->FrontEndValueCache[{Automatic, 
     Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{-4.605170185988091, 
       FormBox["0.01`", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.995732273553991, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.05\"", 0.05, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 2.}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.3025850929940455`, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.10\"", 0.1, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 2.}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
       FormBox[
        TagBox[
         InterpretationBox["\"0.50\"", 0.5, AutoDelete -> True], 
         NumberForm[#, {
           DirectedInfinity[1], 2.}]& ], TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {0., 
       FormBox["1", TraditionalForm], {0.01, 0.}, {
        AbsoluteThickness[0.1]}}, {-5.298317366548036, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-5.115995809754082, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.961845129926823, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.8283137373023015`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-4.710530701645918, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-3.912023005428146, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-3.506557897319982, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-3.2188758248682006`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.8134107167600364`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.659260036932778, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.5257286443082556`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-2.4079456086518722`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-1.6094379124341003`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-1.2039728043259361`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.916290731874155, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {0.6931471805599453, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
       FormBox[
        InterpretationBox[
         StyleBox[
          
          GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
           Baseline], "CacheGraphics" -> False], 
         Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
        AbsoluteThickness[0.1]}}}}]]], "Output",
 CellChangeTimes->{3.398584138937722*^9, 3.3985922943003654`*^9, 
  3.3985934073528776`*^9, 3.4138017517136636`*^9, 3.480094225355631*^9, 
  3.4800960235158*^9, 3.4801563956616*^9, 3.518532263773937*^9, 
  3.539699068938108*^9, 3.5920645052097287`*^9, 3.6436099537898083`*^9},
 CellLabel->"Out[64]="]
}, Open  ]],

Cell["\<\
It can be observed that the uncertainty is almost constant for t>10 days\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"WBCou", "[", "t", "]"}], "[", 
       RowBox[{"[", "2", "]"}], "]"}], "-", 
      RowBox[{
       RowBox[{"WBCou", "[", "t", "]"}], "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], ")"}], "/", 
    RowBox[{
     RowBox[{"WBCou", "[", "t", "]"}], "[", 
     RowBox[{"[", "1", "]"}], "]"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "1", ",", "50"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[65]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV1Xk0Vd0bB3AumV4/Q4hMufO97iUXGSLnMdzcDFEaTUmRoYwZy1B5EZka
hArRJBopqTRRKOrNfEqDFCHSINOV3z5/7HXWZ62zvvt59tlnb7Jv6Ho/koiI
SBcaxHNPeIgSd1YHhNTbHHUdHKswSS5+PK8DpSOpzCFkYf684dwiMhwf4biW
UHBs7VR8k7EcGa6Nuyqso+HYz9qoiYvaZJCWVqk+y8QxS/Ngm2yMDHL9jydn
9HDslcWmQfcDZKh/JVQrNMcxyumO+OOHyfBF4e3Q75U4tlfoKv8yjwyv63TO
OFrimFq9o5l1GRkKuswXjVjhmK+VdQazgQxqP1nPvtni2CRw9X+LUwATPFmy
1BnHDJZaY6WyFDAdbectXYtjQT82ujopU8DPoeeZiguOvT+bFHGOSoEV2rY5
4utw7Bmp4/YGGwrEbLn5uW4DjuU3xmG3kiggyp7Zn+WBY/+dznbdnkaB157+
J909cUwmqnz7/3IosCS+to/mhWOJ9LZDfsUUqE3bIX/DG8f8U3WaVeop0O7q
SK7YjmMmgibX6FkKJD22/LVsF46F6fRtp5CokF6urNqIfHl6IuKlNBW+RmhO
+gXgmHaF+gnGUiqU9GQtlAXimIRMCN5tSoVmzy6G2G4c63mh7GsaRQX6hCnP
NwzHFp9jRw7sp0Kt8q39X5Cd9lul5KRQwaNa7o9/OI494gZcGDpGhX33hZk7
I3DsUta9kZM30fySSb8c9uJYrItv5PR3KtQUCPtbYnAsVMTa2GGaCjudFi5b
xKJ+biybPCVCg7qAsfpK5I1K76IxRRqQvFrepsbhmGHP5vhUQxr4yXdUsPfh
mG66iUXvShpEFZlEZSOTzVWEbFsa2C7Kvv8DWeFUe0KbGw0MVXd2V+/HsTFv
5wPKUTTYnDvVyUjEsc/yXBv/BBpIfhzQTkbueyQjdudfGjg3cRV7kZ9TmlM8
8mlQpZQslpKE+hm0SS+rpUHpnjOVrclof4SY5RjM0iD1vMCAfgjHti5TdT1I
ooPmTTN+MLLrf5MKnTJ0kK1463QdGTOsPhqjQYfehH12pik4pvlHL/+BJR3U
+47Ymv+LY0oXZTcr8OnQ1TjuGYMss2VU1deZDi4ewrQa5Jm6S4WLvOnglnCQ
zE3Fse4E6hmnJDqYiyg3KqThWJs+ybs4jQ7MaoU2e+TGDx+1J3Lo8MyEI5aI
XG1dXHqslA4VtASxr8i5i5aee/OYDo8j7CpvpuOYY5ZcZYA4A1pFcAY9A63v
7ZSvXFkGpNVey3JGlvowS/+hxIDLNZk7o5CfGQyVxlEZwMf2BzUg23Q+zM+w
YYDnkUa5rZk4tlIj/GBVMgNO15h57z6CY0vthh6GpTPAOyiv8gjy9G6veeNc
BjyfDU2tQr79YE1sfQkDfuhYjY4gG/pSQl4+YEBS3oYzvlmonoqOrRNCBpgq
dv60ysYx6fY1J2vEmTDg9vrVFuSvsw87Y2WZ4OP7el0E8gWnKhdRTSY43V3k
cA6ZMpHCX2zBhNA/e/TFc3BM3dSEZxzHhPULmu01yDPbqkKmk5lAvqaZ14Lc
m06pup/OhCmzV5LvkfPfyDH5BUyQexGoI5GL/ofEIc1NtUxY9zdU3Q1Z5mmB
VOwkExo1Zxf1I6ulyrJV5plQXnvV5wcywz55zU1xFiyx46SI5qH1atmV8U2J
BUO8PBYZOa7NRHa7IQt+FskIvZC/dnXKO4SyoIA9ufsl8p98gcFQNAt6XFmV
b5HFt9x3TUlkQbmSY/1X5GVvyvMeZLGAYtq1jXQUxza9j1AyqmKBg8fdq0bI
TwcVVDWHWRCQ++lnNnL7xRTTugkWrFFKulWI/DFgevOmaRbstf654RyycORD
Qa4kG17T3bh1yMbfr6ovYrCBo+Hh0I9cNuWkPe7Lhoai0UucYzh2/c4jq8wg
Njj8szXMGPlBnPE2VgQb6nbUaqxCfjOnUep7gA1Q3rNsLbKiyCi5p4QN0XZr
v4YgJ0sdpj/qY8PHB7+fVyI7lj2bJH1hg9hb88Jq5CWW4s/4Y2yQ/MN2vodc
FZrk/2Ie1XOsbNdzZLw76mK3ti4ccG8IH0I2PO/LHvPRhRca/lyt4zg2b1U6
szxQF/bJSB+kIjf3vmuJCNeFyDDZBjayt+zWoOkDukA1i5QyQc6IdKkUK9eF
w8lGFc7IA9aWeupfdOFJktvBOOSrb+PmPcd0ocZk7HoicnxUbVvJpC6cUPB+
dQhZocIwhC7BgXTzB31ZyJYK7GsGTA4USSvBWeTj71V49oEcyOH/cn+KvC3W
TTQjnAPu485lLci6i/Net8ZxwKhf2NeG/IgvG7E+gwMX7NX1upHHqkjVXpXI
6/evGkReve+78d4xDize84YvfgLt5yONB9iTHPBjTRdJIlcVF758L+RAml7w
kAyy4hPbgDWyXFjR2+qviNwnVXBKm8MF70PNJG3kiHwgtQRwISE7t3kFMv2S
iktiGBf6TpeXmiH31o2cMorlQsPn5+EWyKveHV9RnMaFmcA7C4AsRRsOiLzA
BY+2ylZH5JIbea+0PnOh9dMjKx/k9Q3+mh2jXGCODN/0RRbvsghM/8UFKcUM
sh9y0PQX0i+SHtx6ljAeiGyCrTRpJutBXz5/TSRya+un0xHb9OCilvzif5Gn
h4yCmt7ogWp1wfbzyAHt7f6UAT2wKmeEXCTqvR++I2FUDzK7U6MrkO/kXfM0
EuqBzSFh/BXkWAuOS4mWPuSP7dxwi8jLphjH+OgDb7piYyPhFYp/GYP68L5G
a/QDka9zffbAuD50XFM/0k/ky7hM9f3RB43qGN0BIv/DkYmjksth4+WYbYNE
/mGpgb+s5bBDI7fyG5HXt9DUHbwcOmprOqaJ73VoPC/1x3LIPfigUD4fxwok
MsPvziwHgeaKCQXkU43HWFMiBjCnKstfjLzS3kCKI20AvQMTw8rIsU6BTUeX
GgB/nkVWR/696S3fd6UBRLAr19CQR4Mf2ojuNwA3pvCsKTJ+Is0SWzCAlwMb
TTyQNY+dDVosxoP35IuGnsg+ufcKvkjwwAV31fdCHsz4/jtTjgeighrqNiI/
afOVXi0euH0aktiBLBfE1I6w5IH8ro3Xg5BtrJoWzsXxYDirsyAOuXJQokHm
Nw+k3oT8PYFMd3lsc2TeEPxOSJS+RD5eE7TRa9IIQsz1uv4S7/Nctn8WXQH2
HzR+6J/EseKawdY0aRNo0vAKc0dOM97zIn7BBI757hpJQlZr1W+gyphBdYaH
13nkEp8Pzppi5lC22vvgU2TRORsz3pQ5fFMYTv+E/M+Vfg3hwkrgXnMPXCDs
GXp0yZQFRBbdUFQrQPclxYw0RFoFN5/cijNANv1e/bpD2gocbjDsVhcQ5522
scKCFezrbGnbgjzs9Mn+gDjAjL+VVjDy5D0uVpYMoHyCVBGP/P2Kq/+6WYBP
HrZH05HrOYszPBKtYVpSfG0+sgTLMSZrxhqGU8J+nUWmXidvV0+yAdWdhsFX
kO/dDlV+NWcD/8REUWuRAU5OKUbbArYqvOMhcuFGz55rs7Ygwevf2Yy8Z7gg
OSraDqJv3qh4hawiHcnIF9rB+YLW9m7kykqG0C6ZD8ZyskbvkO+3rjulMceH
c0fbij8hn41TN3VOXg0Wt6Zmh5BFz7ufviBcDSNm5zO/Ibu47eVlR9tDGWv9
hQnk8CxOw3+z9pBZbH33N7Lcandti2gBROVomU4T/bk85PnGCuBMsMxqwgub
afzD8QJ42/JjA+GJwPHgnkQBFC25HkG4PetgXWSaAOpMRq8Qzu+6vKGqQAAO
d72oM8jL/OYytO4JoLrPTmYWWS3Ep9iuXgDt91LVCCvEPL0R/FAAD4MaGIRJ
h3N66xoEEGytZ0v4cxWVsalVACNKDfsIX/rt+Dj7nQCytsyMEi6dv95564MA
NjgPzxAulFjyta9fADzTTsk55Ay1j3KcQQEIfhVRCe+23OvZNC6Acadv7oR3
8vHQ8QkBrNGtCSDstdbqkMovAfyUi4kmvNZH6vKOKQHYTY3lEV4duKc+Y0YA
YQtnSwhjEe3/3ZgTwJTquiuEzfaZfu6dF4CC7dxdwgYpp6cWFgQgfqi0mfD/
ATEMSrM=
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.3922},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{1, 50}, {0.39258436459255086`, 0.39996237366180787`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3985841391103573`*^9, 3.3985922944256773`*^9, 
  3.3985934079167814`*^9, 3.413801752229292*^9, 3.480094225589631*^9, 
  3.4800960236874*^9, 3.4801563958487997`*^9, 3.518532264023942*^9, 
  3.539699069078736*^9, 3.5920645054827557`*^9, 3.643609953930433*^9},
 CellLabel->"Out[65]="]
}, Open  ]],

Cell["\<\
Note: The solution has been  tested with the given using \
BiokdataReport[cobalt, \"Ingestion\", \"Acute\", \"BioassayTable\", 1, 0. 1, \
180, Log[2]/(5.27*365.24)]//Chop\
\>", "SmallText"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"cobaltextended", ",", " ", "rWBCo", ",", "WBCou"}], " ", 
  "]"}]], "Input",
 CellLabel->"In[67]:="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Fitting bioassay data", "Section"],

Cell[CellGroupData[{

Cell["Basic equations", "SubsubsectionIcon"],

Cell[TextData[{
 "The bioassay measurements can be used to estimate the intake and, then, \
infer the internal dose. \nLet\[CloseCurlyQuote]s suppose a single intake ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "0"], TraditionalForm]]],
 " (unkown) in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", "0"}], TraditionalForm]]],
 " of radioactive particles, whose characteristics (AMAD, solubility, etc) \
are known, by a worker with a metabolism that responds to the ideal model for \
the standard worker. At time ",
 StyleBox["t",
  FontSlant->"Italic"],
 " after the intake, a bioassay is made obtaining a measurement ",
 StyleBox["m",
  FontSlant->"Italic"],
 ", with negligible uncertainties. Then, taken ",
 Cell[BoxData[
  FormBox[
   RowBox[{"m", " ", "=", " ", 
    RowBox[{
     SubscriptBox["R", "A"], "(", "t", ")"}]}], TraditionalForm]]],
 "  and using eqn (4), ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "0"], TraditionalForm]]],
 " will be calculated. However, it is an unrealistic situation; in the real \
world the evaluation of internal exposures using the bioassay data involves a \
lot of uncertainties. In fact, in an intercomparation exercise where the same \
cases, using the same data, have been evaluated by different experts, large \
discrepancies have been obtained (Doerfel 1999). "
}], "Text"],

Cell[TextData[{
 "The features included in BIOKMOD can be used to evaluate and minimize the \
uncertainties.\nIf all parameters (AMAD, absorption parameters, etc.) of the \
model, except the quantities intakes, are assumed to be known, the only \
uncertainties will be the ones of the measurements, and then we have a linear \
statistical model. Eqn (17) and eqn (18) are applied to estimate ",
 StyleBox["I",
  FontSlant->"Italic"],
 " and its associated uncertainty. They are based on the method described by \
Skrable el al. (2002):"
}], "Text"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"I", " ", "="}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "N"], 
     RowBox[{
      RowBox[{
       SubscriptBox["r", 
        RowBox[{"C", ",", "j"}]], "(", 
       SubscriptBox["t", "i"], ")"}], " ", 
      FractionBox[
       SubscriptBox["m", "i"], 
       SuperscriptBox[
        SubscriptBox["u", "i"], "2"]]}]}], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "N"], " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        SubscriptBox["r", 
         RowBox[{"C", ",", "j"}]], "2"], "(", 
       SubscriptBox["t", "i"], ")"}], 
      SuperscriptBox[
       SubscriptBox["u", "i"], "2"]]}]], TraditionalForm]]],
 " \n"
}], "NumberedEquation"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["u", "I"], " ", "="}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "N"], " ", 
     FractionBox[
      RowBox[{
       SuperscriptBox[
        SubscriptBox["r", 
         RowBox[{"C", ",", "j"}]], "2"], "(", 
       SubscriptBox["t", "i"], ")"}], 
      SuperscriptBox[
       SubscriptBox["u", "i"], "2"]]}]], TraditionalForm]]],
 " \t"
}], "NumberedEquation"],

Cell["where", "Text"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 " is the time from the start of the intake to the measurement ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]]],
 ".\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "i"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["u", "i"], TraditionalForm]]],
 "  are the measurement and their associated uncertainties (calculated with \
the same confidence level that ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["u", "I"], TraditionalForm]]],
 ").\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["r", 
    RowBox[{"C", ",", "j"}]], TraditionalForm]]],
 "(t), with ",
 StyleBox["C",
  FontSlant->"Italic"],
 " = {A (acute) or Cr (Chronic)} is the retention function, with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "0"], TraditionalForm]]],
 " = 1 or ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "d"], TraditionalForm]]],
 "= 1,  associated with measurement ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "i"], TraditionalForm]]],
 ".",
 "and j is the type of bioassay (note: different kinds of bioassays can be \
applied simultaneously)"
}], "SmallText"],

Cell["Eqs (17) and (18) are the apply by MLFit (See BIOKMOD Help)", "Text"],

Cell[TextData[{
 "Example: A worker has been exposed to an (unknown) acute intake of  uranium \
aerosols (class S, Type S) by inhalation in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", "0"}], TraditionalForm]]],
 ". With a lung counter have been taken measured after the intake:{1, 10, 30, \
60, 90,  obtaining the values given by sampleLungUnc:{",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "i"], TraditionalForm]]],
 ".",
 Cell[BoxData[
  FormBox[
   SubscriptBox["u", "i"], TraditionalForm]]],
 "}. "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sampleLungUnc", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "39", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"10", ",", "36", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30", ",", "29", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"60", ",", "26", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"90", ",", "23", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"120", ",", "22", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"180", ",", "20", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"270", ",", "18", ",", "5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"350", ",", "14", ",", "5"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[68]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MLFit", "[", 
  RowBox[{"sampleLungUnc", ",", 
   RowBox[{
    StyleBox["LungsRetention", "Input"], "[", 
    RowBox[{"1", ",", 
     RowBox[{"AMADAdultW", "[", "5", "]"}], ",", "S", ",", " ", "t", ",", 
     "0"}], "]"}], ",", "t"}], "]"}]], "Input",
 CellLabel->"In[69]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"Mean\"\>", "\[Rule]", "608.5453227642294`"}], ",", 
   RowBox[{"\<\"s\"\>", "\[Rule]", "38.461241420137796`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.398584139377157*^9, 3.3985922946136456`*^9, 
  3.413801861011238*^9, 3.480094225823631*^9, 3.4800960237966003`*^9, 
  3.480156395958*^9, 3.518532264211446*^9, 3.5396990691881127`*^9, 
  3.5920645057187796`*^9, 3.6436099540554333`*^9},
 CellLabel->"Out[69]="]
}, Open  ]],

Cell["\<\
Other authors recommend (ICRP Draft 2006) the maximum likelihood method which \
uses the following eqn 
\
\>", "Text"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"Log", " ", 
     RowBox[{"(", 
      OverscriptBox["I", "^"], ")"}]}], " ", "="}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "N"], 
     RowBox[{"(", 
      RowBox[{
       RowBox[{"Log", "(", " ", 
        FractionBox[
         SubscriptBox["m", 
          RowBox[{"i", ",", "j"}]], 
         RowBox[{
          SubscriptBox["r", 
           RowBox[{"C", ",", "j"}]], "(", 
          SubscriptBox["t", 
           RowBox[{"i", ",", "j"}]], ")"}]], ")"}], "/", 
       RowBox[{"(", 
        SuperscriptBox[
         RowBox[{"Log", "(", 
          SubscriptBox["SF", 
           RowBox[{"i", ",", "j"}]], ")"}], "2"], ")"}]}], ")"}]}], 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "N"], " ", 
     RowBox[{"(", 
      RowBox[{"1", "/", 
       SuperscriptBox[
        RowBox[{"Log", "(", 
         SubscriptBox["SF", 
          RowBox[{"i", ",", "j"}]], ")"}], "2"]}]}]}]], TraditionalForm]]],
 " \n"
}], "NumberedEquation"],

Cell[TextData[{
 "being ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["SF", "i"], TraditionalForm]]],
 " the scattering factor for ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "i"], TraditionalForm]]],
 ". If the bioassay data are log normally distributed then SF is the \
geometric standard deviation (SG) of the log-normal distribution."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MLFitLog", "[", 
  RowBox[{"sampleLungUnc", ",", 
   RowBox[{
    StyleBox["LungsRetention", "Input"], "[", 
    RowBox[{"1", ",", 
     RowBox[{"AMADAdultW", "[", "5", "]"}], ",", "S", ",", " ", "t", ",", 
     "0"}], "]"}], ",", "t"}], "]"}]], "Input",
 CellLabel->"In[70]:="],

Cell[BoxData[
 RowBox[{"\<\"Mean\"\>", "\[Rule]", "603.8986656657718`"}]], "Output",
 CellChangeTimes->{3.3985841395654864`*^9, 3.398592294817278*^9, 
  3.413801861167489*^9, 3.4800942260732307`*^9, 3.4800960239058*^9, 
  3.4801563961140003`*^9, 3.5185322643676987`*^9, 3.53969906929749*^9, 
  3.592064505961804*^9, 3.6436099541335583`*^9},
 CellLabel->"Out[70]="]
}, Open  ]],

Cell[TextData[{
 "When it is assumed, that not only the intake but also other parameters {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "1"], TraditionalForm]]],
 ",\[Ellipsis], ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "r"], TraditionalForm]]],
 "} are unknown (AMAD, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 ", etc.) then we have a problem of nonlinear fitting. BIOKMOD applies eqn \
(15) for fitting the bioassay data (It is minimized \[Chi]2):"
}], "Text"],

Cell[TextData[{
 "(",
 Cell[BoxData[
  FormBox[
   OverscriptBox["I", "^"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "1"], TraditionalForm]]],
 ", ...,",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "r"], TraditionalForm]]],
 ") : Arg ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox["Min", 
    RowBox[{
     RowBox[{
      FormBox[
       RowBox[{"[", "I"}],
       TraditionalForm], ",", 
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], ",", "...", ",", 
      FormBox[
       SubscriptBox["k", "r"],
       TraditionalForm]}], "]"}]], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "N"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"I", " ", 
          RowBox[{
           SubscriptBox["r", 
            RowBox[{"C", ",", "j"}]], "(", 
           RowBox[{
            SubscriptBox["t", "i"], ",", " ", 
            SubscriptBox["k", "1"], ",", " ", "...", ",", "  ", 
            SubscriptBox["k", "r"]}], ")"}]}], " ", "-", 
         SubscriptBox["m", "i"]}], 
        SubscriptBox["u", "i"]], ")"}], "2"]}], "]"}], TraditionalForm]]],
 "\nRestrictions: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"I", ">", "0"}], ",", 
    RowBox[{
     SubscriptBox["k", 
      RowBox[{"1", 
       RowBox[{"(", "min", ")"}]}]], "\[LessEqual]", " ", 
     SubscriptBox["k", "1"], "\[LessEqual]", 
     SubscriptBox["k", 
      RowBox[{"1", 
       RowBox[{"(", "max", ")"}]}]]}], ",", "...", ",", 
    RowBox[{
     SubscriptBox["k", 
      RowBox[{"r", "(", "min", ")"}]], "\[LessEqual]", " ", 
     SubscriptBox["k", "r"], "\[LessEqual]", 
     SubscriptBox["k", 
      RowBox[{"r", "(", "max", ")"}]], " "}]}], TraditionalForm]]]
}], "NumberedEquation"],

Cell["\<\
If the bioassay data are log normally distributed then the below eqn is used  
\
\>", "Text"],

Cell[TextData[{
 "(",
 Cell[BoxData[
  FormBox[
   OverscriptBox["I", "^"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "1"], TraditionalForm]]],
 ", ...,",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "r"], TraditionalForm]]],
 ") : Arg ",
 Cell[BoxData[
  FormBox[
   UnderscriptBox["Min", 
    RowBox[{
     RowBox[{
      FormBox[
       RowBox[{"[", "I"}],
       TraditionalForm], ",", 
      FormBox[
       SubscriptBox["k", "1"],
       TraditionalForm], ",", "...", ",", 
      FormBox[
       SubscriptBox["k", "r"],
       TraditionalForm]}], "]"}]], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"[", 
    RowBox[{
     UnderoverscriptBox["\[Sum]", 
      RowBox[{"i", "=", "1"}], "N"], 
     SuperscriptBox[
      RowBox[{"(", 
       FractionBox[
        RowBox[{
         RowBox[{"Log", "[", 
          RowBox[{"I", " ", 
           RowBox[{
            SubscriptBox["r", 
             RowBox[{"C", ",", "j"}]], "(", 
            RowBox[{
             SubscriptBox["t", "i"], ",", " ", 
             SubscriptBox["k", "1"], ",", " ", "...", ",", "  ", 
             SubscriptBox["k", "r"]}], ")"}]}], "]"}], " ", "-", 
         RowBox[{"Log", "[", 
          SubscriptBox["m", "i"], "]"}]}], 
        SubscriptBox["SG", "i"]], ")"}], "2"]}], "]"}], TraditionalForm]]],
 "\nRestrictions: ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"I", ">", "0"}], ",", 
    RowBox[{
     SubscriptBox["k", 
      RowBox[{"1", 
       RowBox[{"(", "min", ")"}]}]], "\[LessEqual]", " ", 
     SubscriptBox["k", "1"], "\[LessEqual]", 
     SubscriptBox["k", 
      RowBox[{"1", 
       RowBox[{"(", "max", ")"}]}]]}], ",", "...", ",", 
    RowBox[{
     SubscriptBox["k", 
      RowBox[{"r", "(", "min", ")"}]], "\[LessEqual]", " ", 
     SubscriptBox["k", "r"], "\[LessEqual]", 
     SubscriptBox["k", 
      RowBox[{"r", "(", "max", ")"}]], " "}]}], TraditionalForm]]]
}], "NumberedEquation"],

Cell["Eqn (20) or (21) are the apply by X2FitE (See BIOKMOD Help)", "Text"],

Cell[TextData[{
 "Note: If only a kind of bioassay is applied and all the uncertainties ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["u", "i"], TraditionalForm]]],
 " are the same or they are not available can be used the specific ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " functions for fitting (e.g. FindFit)  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Idenfication problems", "SubsubsectionIcon"],

Cell[TextData[{
 "In some occasions, using the same bioassay data, several solutions, \
mathematically equivalents can be obtained. For instance: For substances of \
type F (rapid absorption) and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["f", "1"], "=", "1"}], TraditionalForm]]],
 " almost all particles deposited in the respiratory tract (excluded that \
returned directly to the environment) are transferred quickly into the blood \
(B). This means that in this case an intake ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "0"], TraditionalForm]]],
 " in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", "0"}], TraditionalForm]]],
 " of radioactive aerosols of AMAD ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 " can be approximated by an instantaneous input ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "B"], TraditionalForm]]],
 " in B in t = 0 given by "
}], "Text"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["b", "B"], "=", " ", 
    RowBox[{
     SubscriptBox["I", "0"], " ", 
     RowBox[{
      UnderscriptBox["\[Sum]", "i"], 
      RowBox[{
       SubscriptBox["IDF", "i"], "(", "p", ")"}]}]}]}], TraditionalForm]]],
 "\t"
}], "NumberedEquation"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["\[Sum]", "i"], 
    RowBox[{
     SubscriptBox["IDF", "i"], "(", "p", ")"}]}], TraditionalForm]]],
 " includes all de ",
 StyleBox["IDF",
  FontSlant->"Italic"],
 " factor except ",
 StyleBox["IDF",
  FontSlant->"Italic"],
 StyleBox["ET1",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "."
}], "Text"],

Cell[TextData[{
 "If ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "0"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 " are unknown, and therefore ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["IDF", "i"], TraditionalForm]]],
 " values will be also unknown, then eqn (20) will be verified for an \
infinitum number of values. So if we replace ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["b", "B"], "(", "t", ")"}], TraditionalForm]]],
 " at eqn (6) using eqn (19) it will be found that bioassay data ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "i"], TraditionalForm]]],
 " can be fitted to different values of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "0"], TraditionalForm]]],
 " and ",
 StyleBox["p",
  FontSlant->"Italic"],
 ". However the accumulated disintegrations, given by eqn (14), will be the \
same as long as that eqn.(20) be satisfied, and hence the committed effective \
dose ",
 StyleBox["E",
  FontSlant->"Italic"],
 " will be also the same. For instance: If it is has been obtained by fitting \
an intake ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "1"], TraditionalForm]]],
 " assuming an AMAD ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "1"], TraditionalForm]]],
 " and the true (unknown) value is ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "2"], TraditionalForm]]],
 " with AMAD ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "2"], TraditionalForm]]],
 ", then it will be verified that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["I", "1"], 
    RowBox[{
     UnderscriptBox["\[Sum]", "i"], 
     RowBox[{
      SubscriptBox["IDF", "i"], "(", 
      SubscriptBox["p", "1"], ")"}]}]}], TraditionalForm]]],
 " =  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["I", "2"], 
    RowBox[{
     UnderscriptBox["\[Sum]", "i"], 
     RowBox[{
      SubscriptBox["IDF", "i"], "(", 
      SubscriptBox["p", "2"], ")"}]}]}], TraditionalForm]]],
 " and E1 \[TildeTilde] E2 being ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "1"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "1"], TraditionalForm]]],
 "DCF (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "1"], TraditionalForm]]],
 ") and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "2"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "2"], TraditionalForm]]],
 " DCF(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "2"], TraditionalForm]]],
 ") where DCF(",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "i"], TraditionalForm]]],
 ") is the dose conversion factor corresponding to an AMAD ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "i"], TraditionalForm]]],
 "."
}], "Text"],

Cell[TextData[{
 "In the same way, an intake ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "0"], TraditionalForm]]],
 " by ingestion with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 " = 1 is practically equivalent to an instantaneous input ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["b", "B"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "0"], TraditionalForm]]],
 " in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", "0"}], TraditionalForm]]],
 ". Theses conclusions can be extended to not acute inputs as consequence of \
the convolution theorem. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 1", "Subsubsection"],

Cell["\<\
As a result of Chernobyl accident (26 april 1986) a male 39 years old and 80 \
kg (member of the public) has been exposed to continuous and unknown \
ingestion  of Cs-137 (This data has been supplied by Ansoborlo)\
\>", "Text"],

Cell["\<\
The results of the whole body activity retention are given below : {time \
after the accident (d), activity (Bq)} \
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"wholeData", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"39", ",", "300"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"58", ",", "671"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"75", ",", "737"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"130", ",", "1661"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"156", ",", "1846"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"170", ",", "1882"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"198", ",", "2247"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"234", ",", "2493"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"263", ",", "2926"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"297", ",", "3224"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"325", ",", "3608"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"374", ",", "3883"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"408", ",", "3773"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"432", ",", "3723"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"494", ",", "3195"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"520", ",", "2740"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"556", ",", "2469"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"592", ",", "2375"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"625", ",", "1954"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"682", ",", "1614"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"744", ",", "1221"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"800", ",", "1174"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"880", ",", "739"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[71]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{"wholeData", ",", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellLabel->"In[72]:="],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.019444444444444445`],
      AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJxTTMoPSmViYGAQB2IQDQYNzg5g+kARhGbwhdA/WqDiQRCaox1COyRA6C8z
IXRDMoS+MQcqnwqhM+ZC9WdA6L6FUPlcCF21GEIXFEDoO8sg9ASoOwxWQuiA
Eih/DYROKIfQYeug9ldCzVsLdX81hBaD8h/UQehvK6D2N0DdtxRqXiOE9oK6
p6EJ6t5FELqjGUrPg7qnFUJbQP3vAA0XkclQ+zshdMQkqHndEFqi3QEAwpw5
NA==
      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0, 880.}, {0, 3883.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3985841396596513`*^9, 3.3985922948799334`*^9, 
  3.4138018819801226`*^9, 3.4800942262136307`*^9, 3.4800960239370003`*^9, 
  3.4801563961296*^9, 3.480157530929*^9, 3.5185322644145746`*^9, 
  3.539699069344366*^9, 3.592064506296837*^9, 3.6436099542116838`*^9},
 CellLabel->"Out[72]="]
}, Open  ]],

Cell["\<\
Here is evaluated the retention in the whole body for an acute intake \"1\" \
of Cs-137 in t=0 [More details in Help \"Isotope\"]\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"qWbCs137", "[", "t1_", "]"}], "=", 
  RowBox[{"qWholebody", "[", 
   RowBox[{
    RowBox[{"compartMatrix", "[", "caesium", "]"}], ",", "1", ",", " ", "1", 
    ",", "t1", ",", " ", 
    RowBox[{
     RowBox[{"Log", "[", "2", "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"30", "*", "365.24"}], ")"}]}]}], "]"}]}]], "Input",
 CellLabel->"In[73]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "0.0001773811540176362`"}], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "24.00006325951708`"}], " ", "t1"}]]}], "+", 
  RowBox[{"0.0016546204083943098`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "12.00006325951708`"}], " ", "t1"}]]}], "-", 
  RowBox[{"0.02303330801980154`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2.772653259517082`"}], " ", "t1"}]]}], "+", 
  RowBox[{"0.020769923715010356`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "1.8000632595170818`"}], " ", "t1"}]]}], "-", 
  RowBox[{"0.04304818930792356`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "1.000063259517081`"}], " ", "t1"}]]}], "+", 
  RowBox[{"0.13938708446501963`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.3460632595170811`"}], " ", "t1"}]]}], "+", 
  RowBox[{"0.9044472498933186`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.006363259517080529`"}], " ", "t1"}]]}]}]], "Output",
 CellChangeTimes->{3.398584139973533*^9, 3.3985922951462216`*^9, 
  3.4138018822613745`*^9, 3.4800942265724306`*^9, 3.480096024093*^9, 
  3.4801563963012*^9, 3.4801575313346*^9, 3.5185322646177034`*^9, 
  3.5396990694693685`*^9, 3.592064506680876*^9, 3.6436099543054333`*^9},
 CellLabel->"Out[73]="]
}, Open  ]],

Cell[TextData[{
 "This function supposes a daily chronic ingestion \"inp\" during a time t1.  \
The ingestion of caesium stop in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", "T"}], TraditionalForm]]],
 ", for ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", ">", "T"}], TraditionalForm]]],
 ", inp = 0. "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qConstant", "[", 
  RowBox[{"1", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qWbCs137", "[", "t", "]"}], ",", "t"}], "}"}], ",", " ", "t", 
   ",", " ", "2000"}], "]"}]], "Input",
 CellLabel->"In[74]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"\[Piecewise]", GridBox[{
       {"\<\"t1 must be non negative\"\>", 
        RowBox[{"t", "<", "0"}]},
       {
        RowBox[{"142.49893744583812`", "\[VeryThinSpace]", "+", 
         RowBox[{"7.390861936469971`*^-6", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "24.00006325951708`"}], " ", "t"}]]}], "-", 
         RowBox[{"0.00013788430715830217`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "12.00006325951708`"}], " ", "t"}]]}], "+", 
         RowBox[{"0.008307316445264163`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "2.772653259517082`"}], " ", "t"}]]}], "-", 
         RowBox[{"0.011538440999336035`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "1.8000632595170818`"}], " ", "t"}]]}], "+", 
         RowBox[{"0.04304546627251463`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "1.000063259517081`"}], " ", "t"}]]}], "-", 
         RowBox[{"0.4027792047602202`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "0.3460632595170811`"}], " ", "t"}]]}], "-", 
         RowBox[{"142.13584208935112`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "0.006363259517080529`"}], " ", "t"}]]}]}], 
        RowBox[{"0", "\[LessEqual]", "t", "\[LessEqual]", "2000"}]},
       {
        RowBox[{"0.`", "\[VeryThinSpace]", "-", 
         RowBox[{"7.390861936469971`*^-6", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "24.00006325951708`"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2000"}], "+", "t"}], ")"}]}]]}], "+", 
         RowBox[{"0.00013788430715830217`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "12.00006325951708`"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2000"}], "+", "t"}], ")"}]}]]}], "-", 
         RowBox[{"0.008307316445264163`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "2.772653259517082`"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2000"}], "+", "t"}], ")"}]}]]}], "+", 
         RowBox[{"0.011538440999336035`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "1.8000632595170818`"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2000"}], "+", "t"}], ")"}]}]]}], "-", 
         RowBox[{"0.04304546627251463`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "1.000063259517081`"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2000"}], "+", "t"}], ")"}]}]]}], "+", 
         RowBox[{"0.4027792047602202`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "0.3460632595170811`"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2000"}], "+", "t"}], ")"}]}]]}], "+", 
         RowBox[{"142.13584208935112`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "0.006363259517080529`"}], " ", 
            RowBox[{"(", 
             RowBox[{
              RowBox[{"-", "2000"}], "+", "t"}], ")"}]}]]}], "+", 
         RowBox[{"7.390861936469971`*^-6", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "24.00006325951708`"}], " ", "t"}]]}], "-", 
         RowBox[{"0.00013788430715830217`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "12.00006325951708`"}], " ", "t"}]]}], "+", 
         RowBox[{"0.008307316445264163`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "2.772653259517082`"}], " ", "t"}]]}], "-", 
         RowBox[{"0.011538440999336035`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "1.8000632595170818`"}], " ", "t"}]]}], "+", 
         RowBox[{"0.04304546627251463`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "1.000063259517081`"}], " ", "t"}]]}], "-", 
         RowBox[{"0.4027792047602202`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "0.3460632595170811`"}], " ", "t"}]]}], "-", 
         RowBox[{"142.13584208935112`", " ", 
          SuperscriptBox["\[ExponentialE]", 
           RowBox[{
            RowBox[{"-", "0.006363259517080529`"}], " ", "t"}]]}]}], 
        RowBox[{"t", ">", "2000"}]},
       {"0", 
        TagBox["True",
         "PiecewiseDefault",
         AutoDelete->True]}
      },
      AllowedDimensions->{2, Automatic},
      Editable->True,
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxItemSize->{
       "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.84]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}},
      Selectable->True]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxItemSize->{
    "Columns" -> {{Automatic}}, "ColumnsIndexed" -> {}, "Rows" -> {{1.}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.35]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  "Piecewise",
  DeleteWithContents->True,
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{3.3985841400363097`*^9, 3.3985922951932135`*^9, 
  3.4138018823238745`*^9, 3.480094226806431*^9, 3.4800960241398*^9, 
  3.4801563963168*^9, 3.4801575314126*^9, 3.5185322646645794`*^9, 
  3.539699069516244*^9, 3.592064506945902*^9, 3.643609954336688*^9},
 CellLabel->"Out[74]="]
}, Open  ]],

Cell["\<\
It can be observed that the retention was increasing until T.  We can suppose \
that the caesium ingestion happened until  T, when it ceased.  Now we can fit \
the experimental data to bearing in mind both periods. \
\>", "MathCaption"],

Cell["\<\
model2[t1_?NumericQ, p_?NumericQ, tt_?NumericQ] := p \
qConstant[1,{qWbCs137[t],t}, t1, tt]\
\>", "Input",
 CellLabel->"In[75]:="],

Cell["\<\
The funtion estimates the best fit for the intake I, in Bq/day, and the \
period T, in days \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"input", ",", " ", "timeIntake"}], "}"}], "=", " ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"p", ",", " ", "tt"}], "}"}], "/.", 
   RowBox[{"FindFit", "[", 
    RowBox[{"wholeData", ",", " ", 
     RowBox[{"model2", "[", 
      RowBox[{"t", ",", "p", ",", " ", "tt"}], "]"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"p", ",", " ", "tt"}], "}"}], ",", " ", "t"}], "]"}], 
   " "}]}]], "Input",
 CellLabel->"In[76]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"24.595201707979907`", ",", "533.9606810202038`"}], "}"}]], "Output",
 CellChangeTimes->{3.39858415485154*^9, 3.3985923101366696`*^9, 
  3.413801897339596*^9, 3.4800942379916306`*^9, 3.4800960322518*^9, 
  3.4801564086493998`*^9, 3.4801575430814*^9, 3.518532273774129*^9, 
  3.539699076703882*^9, 3.592064521048312*^9, 3.643609958555439*^9},
 CellLabel->"Out[76]="]
}, Open  ]],

Cell["Then, the accumulated intake is ", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"input", " ", "timeIntake"}]], "Input",
 CellLabel->"In[77]:="],

Cell[BoxData["13132.87065382223`"], "Output",
 CellChangeTimes->{3.398584154914316*^9, 3.3985923101993256`*^9, 
  3.4138018974177213`*^9, 3.4800942381320305`*^9, 3.480096032283*^9, 
  3.480156408665*^9, 3.4801575447506*^9, 3.5185322738366303`*^9, 
  3.539699076782009*^9, 3.5920645212873363`*^9, 3.64360995861794*^9},
 CellLabel->"Out[77]="]
}, Open  ]],

Cell["It can be observed the good mach obtained", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"qConstant", "[", 
    RowBox[{"input", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"qWbCs137", "[", "t", "]"}], ",", "t"}], "}"}], ",", "t1", ",",
      "timeIntake"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t1", ",", " ", "1", ",", "1000"}], "}"}], ",", " ", 
   RowBox[{"Epilog", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Hue", "[", "0.", "]"}], ",", " ", 
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", 
      RowBox[{"Map", "[", 
       RowBox[{"Point", ",", "wholeData"}], "]"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellLabel->"In[78]:="],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwV0HlM03cABfCuCE6OOJgcMkUawYmATNQMo8CTFSOIRUqVowakLRQsFFk5
SgH7JWjQrXZcI00rW4FC219GSDY8NjEDN9FMJ0pB5BjY2A0sEOZCwhoZ229/
vLx8kvfXYwmKublMBoMRRef/fjj96Jw348/YgtmXAYOyKBzfoJJsnluJbZTl
3/p4LBYPQ5PKNz1xxG45P3SHNH8CUfQf99d/fQde2z56XPckEUJV3tRfOje4
Nq47RJU87Ptyf92SzhfenZaVU+/lQLPVf9yuCwZGmN4LAVI85nvUvtYdAHNw
QcorqELolYzad5fZ0Ef3XYofvYoAy41Nv0xx4DVfsZxsbURQ+8/czBM8+A6t
jjLDW8H/Kq08uykDXcJ/jC3xWthTe2sOK7Ngu9M9v6Rvg/rD9B6LPQfejqXA
4AI9Dkhvvmy+KsLwcO6Y5UE7XDxXL8e+zUO5k1iROdcB8xl3n+/aC7D/0Iut
cHRC/reTn9cHhZgyFPWbJgzgCSey3tZLwdq9NjGp6wK5ffT485YL8Du46zPW
6W4ULm3UBg2XoEXW9PW/i92gP7Q+3ylDhEB5t77GiOsz44mcT0txVJf1qtVh
xLWK/KLDVBlWVybN3GwT5nKEl1Vr5ZDUHKtPHDAhTZF8JjVKjurm+M6BzWZE
2Lq2XVRXIoLtNnmSb4Y6UuIsnVGgUV3tseO6GU69LKPFtxoh05qquGdmWKvj
YtokNeg3hOZNO1EYlfPU06aL0Lj4Gk+FU+BkjDGss0osD7uc35tCwcelrGPX
70rcqx2XD9Ce+XYLu9CuBKcl7RCXS6HInVe/uqKEqd/jaWkqhaHs1y4bnQkU
abb0m6cp2Lzyr233J+AL69b2ZFIIrMzVJrIJznYkmKcEFC4lH5QsHSNgdPVF
i4QU5oOdjzQkELS62a4s0u4dMfw2xiH4kRHOXhNRiAmzBeZkEKjGe7h+Ygpn
ZwXGCimBZUfGmzgJhYEbkXL/EgKWkb3hAe0gFTPhroxgn2f208RCCgtRHXZm
JYGdf7slpYiCoskarq4jCFkPGOEXU9DEn+szaAjcn30OoYxC+nr7BX8dwaMG
R8kkbb9br8Ia2ggEkffEKaX0fre4q6qD4EjxlD6mjN5bTTlvDAT4Qmzro+2n
tW8XGwl6tPcX95RTeMENm5w2E3y/9/0f9LQ1btJW7jcEgxNFST4VFFwVrp47
ewiSQn4Kjab9H4bCono=
      "]], LineBox[CompressedData["
1:eJwVzn041AcAB/CbJc8Q0rllmYTJS21dIW/NN7dlk2V4ZprzEu4cO/GssHlp
v/NynJffT+zm8GhrCXdsRfFoo+a6Oi+ro2nyMpM9pISaHGFntz++z/f5PM/3
j++u6KQgjg6NRvPS5v8ug+6kZwsBi3HWW0KeDA9cDvRduUJgTF9D9EXKIJk/
ne/QRiDzTqKed6AMofVtrO/aCXykdGxS+ciwPWplg/4LgdDmTdlfO8tQMZDx
Je1XApEXIuY8t8sQUtjpnConIA7yjT6iLwODtfFsVkEgJtA4i78uxbdXs+OH
egikq1vrdR9qXSH67KffCdTRNGGsRq3DK7zYjwi0SlRFUz5ShDCGVwYeE9hi
Xp1Ed5WCoXqj1fcpAeVXkaxjDto9zu098JyASNQzOWGstc1FS/01Apcty2PS
/myA+HELrd1IgMQJmyd70xvwTcpdxTZXARy6emz72uvx/t3nqqsTAnhu89mh
11YL90p/vltBNngd0xs1Vj/AbW3nVKptDk4VK638dL7HbF5D6KM7OYgxWjbY
sVYNab20wZSfi91/x5491iRBo+ekyEovD7cjsnxOqsQ4saLiRF3KQ92oz79G
9HJY+7tahvkLsdBJPyr/oxQV3YED+WohJMfZ4cYJJXh9bCoqSZyP6z0WFzdm
RRg50SxwZxagN6DLr3JaiCCT/TUuIwW4ESzI9dHNxf1PnMRP00SAUdUFmlQA
Q8Vw/n3rQsRvWCa0DJ6BsPaGwfneQmjcpYOlq+kwsLDk744rgviMqsDkXhre
62Aq/zIpBu/lz3yN6jQKFjs1QZeK0f1sxZpx/AuY1AiUDX4lGMo5NG5/MBn+
SauF+xZLoL69qU/O5qP8wazjqVISFW/Tgw314iGJM4tglpOI3eohM3vJwzn1
u2cXxCTqg2/12c3yIKOXLX9eTcIws5EdpeJB/rGbIraORK2wymufhId/unPD
QzpIHAnVc/Z24iHo2pul7jMkZvqbU9ZD4hD6ge/N5Sck8gLGRtUfxiFiKFnd
OkdidH0ub8UrDglLN9n7F0kwuWXirTZxyGYmODhpSAxGzDOrFrhokbbJLegU
3JsU468UctHuNrE0wqDQoPPw/MksLq4rX3OoNKfQZM+In0zmoneKTZntpFDc
Zvti/FMuJne9yjZypMBu6qKc7LiYubyH+m0PhamlnM395lzMe4fIC9+hIPY4
Gp2xhYvVcKm9ngsF1nD+tekXHNDm7oXdOkghxDrox7oZDjZnrpM5HhRSDvel
Jo5xYGhgJz98SPtP18bUs58D06qApQ1vChnsogxjBQf/AZJSyQ0=
      "]]}, {}}, {{}, {}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Epilog->{
    Hue[0.], 
    PointSize[0.02], {
     PointBox[{39, 300}], 
     PointBox[{58, 671}], 
     PointBox[{75, 737}], 
     PointBox[{130, 1661}], 
     PointBox[{156, 1846}], 
     PointBox[{170, 1882}], 
     PointBox[{198, 2247}], 
     PointBox[{234, 2493}], 
     PointBox[{263, 2926}], 
     PointBox[{297, 3224}], 
     PointBox[{325, 3608}], 
     PointBox[{374, 3883}], 
     PointBox[{408, 3773}], 
     PointBox[{432, 3723}], 
     PointBox[{494, 3195}], 
     PointBox[{520, 2740}], 
     PointBox[{556, 2469}], 
     PointBox[{592, 2375}], 
     PointBox[{625, 1954}], 
     PointBox[{682, 1614}], 
     PointBox[{744, 1221}], 
     PointBox[{800, 1174}], 
     PointBox[{880, 739}]}},
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{1, 1000}, {0., 3387.6194745052253`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3985841563424797`*^9, 3.3985923116247497`*^9, 
  3.4138018988083553`*^9, 3.4800942390056305`*^9, 3.4800960331098003`*^9, 
  3.480156409913*^9, 3.4801575490874*^9, 3.518532274805399*^9, 
  3.539699077469522*^9, 3.5920645226204696`*^9, 3.643609959039816*^9},
 CellLabel->"Out[78]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Example 2",
 FontSize->12]], "Subsection"],

Cell[TextData[{
 "A researcher has been exposed to a single acute intake of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[InvisiblePrefixScriptBase]", "125"], 
    StyleBox["I",
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontTracking->"Plain",
     FontVariations->{"CompatibilityType"->0,
     "Masked"->False,
     "Outline"->False,
     "RotationAngle"->0,
     "Shadow"->False,
     "StrikeThrough"->False,
     "Underline"->False}]}], TraditionalForm]]],
 ". After the exposure it has been measured the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[InvisiblePrefixScriptBase]", "125"], 
    StyleBox["I",
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontTracking->"Plain",
     FontVariations->{"CompatibilityType"->0,
     "Masked"->False,
     "Outline"->False,
     "RotationAngle"->0,
     "Shadow"->False,
     "StrikeThrough"->False,
     "Underline"->False}]}], TraditionalForm]]],
 " in the thyroid obtaining: ",
 "{Days after accidental intake, Thyroid activity measured (Bq)} = {{7, \
5143},{14, 4773},{15, 4403},{21, 4070}, {28,3471}, {42, 2546}}",
 ". (Bioassay data taken from French C. S. et Al, 2003)."
}], "Text"],

Cell["\<\
The data in French C. S are in nCi, they has been converted to Bq\
\>", "SmallText"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sampleThy", "=", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"#1", ",", " ", 
      RowBox[{"37", "#2"}]}], "}"}], "&"}], "@@@", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"7", ",", " ", "139"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"14", ",", " ", "129"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"15", ",", " ", "119"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"21", ",", " ", "110"}], " ", "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"28", ",", " ", "93.8"}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"42", ",", " ", "68.8"}], "}"}]}], "}"}]}]}]], "Input",
 CellLabel->"In[79]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"7", ",", "5143"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"14", ",", "4773"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"15", ",", "4403"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"21", ",", "4070"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"28", ",", "3470.6`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"42", ",", "2545.6`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.398584156436644*^9, 3.3985923116874056`*^9, {3.4138018988864803`*^9, 
   3.4138019174803495`*^9}, 3.4800942390212307`*^9, 3.4800960331254*^9, 
   3.4801564099286003`*^9, 3.4801575491966*^9, 3.5185322748210244`*^9, 
   3.5396990775007725`*^9, 3.5920645226694746`*^9, 3.643609959071065*^9},
 CellLabel->"Out[79]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sol", "SubsubsectionIcon"],

Cell[TextData[{
 "The bioassay data have been fitted to the iodine thyroid retention function \
assuming an AMAD ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "1"], TraditionalForm]]],
 " = 1 \[Mu]m, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "2"], TraditionalForm]]],
 " = 5 \[Mu]m, and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "3"], TraditionalForm]]],
 " = 10 \[Mu]m. The solutions obtained have been (Fig. 5), respectively, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "1"], TraditionalForm]]],
 " = 57448.5 Bq, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "2"], TraditionalForm]]],
 " = 41412.1 Bq and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "3"], TraditionalForm]]],
 " = 46724.6 Bq. As ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["d", "1"], "=", 
    RowBox[{
     UnderscriptBox["\[Sum]", "i"], 
     RowBox[{
      SubscriptBox["IDF", "i"], "(", 
      RowBox[{"1", " ", "\[Mu]m"}], ")"}]}]}], TraditionalForm]]],
 "= 0.34665 ; ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["d", "2"], "=", 
    RowBox[{
     RowBox[{
      UnderscriptBox["\[Sum]", "i"], 
      RowBox[{
       SubscriptBox["IDF", "i"], "(", 
       RowBox[{"5", " ", "\[Mu]m"}], ")"}]}], "="}]}], TraditionalForm]]],
 " 0.480875, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "3"], TraditionalForm]]],
 "=  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{
     UnderscriptBox["\[Sum]", "i"], 
     RowBox[{
      SubscriptBox["IDF", "i"], "(", 
      RowBox[{"5", " ", "\[Mu]m"}], ")"}]}], "="}], TraditionalForm]]],
 " 0.426196, an hence ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "1"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "1"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "2"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "2"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "3"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "3"], TraditionalForm]]],
 " = 19914 Bq."
}], "Text"],

Cell[TextData[{
 "First it is computed the thyroid retention as funtion of ",
 StyleBox["t",
  FontSlant->"Italic"],
 " an ",
 StyleBox["p ",
  FontSlant->"Italic"],
 StyleBox["(previously we need to know the number used by Biokmod for thyroid \
compartment)",
  FontVariations->{"CompatibilityType"->0}]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompartNumbers", "[", "iodine", "]"}]], "Input",
 CellLabel->"In[80]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "\<\"Blood\"\>"},
    {"2", "\<\"Thyroid\"\>"},
    {"3", "\<\"Rest\"\>"},
    {"4", "\<\"Bladder\"\>"},
    {"5", "\<\"Urine\"\>"},
    {"6", "\<\"ULI\"\>"},
    {"7", "\<\"LLI\"\>"},
    {"8", "\<\"FEC\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{
  3.39858415649942*^9, 3.398592311734398*^9, {3.4138018989333563`*^9, 
   3.41380191754285*^9}, 3.4800942392240305`*^9, 3.4800960331566*^9, 
   3.4801564099442*^9, 3.4801575492434*^9, 3.5185322748679004`*^9, 
   3.5396990775632734`*^9, 3.592064522706478*^9, 3.64360995911794*^9},
 CellLabel->"Out[80]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"qThyAmad", "[", 
   RowBox[{"t_", ",", " ", "p_"}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    SubscriptBox["q", "2"], "[", "t", "]"}], "/.", 
   RowBox[{"BiokdataReport", "[", 
    RowBox[{
    "iodine", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
     "\"\<CompartmentContent\>\"", ",", "1", ",", 
     RowBox[{"AMADAdultW", "[", "p", "]"}], ",", "F", ",", " ", "1", ",", "t",
      ",", 
     RowBox[{
      RowBox[{"Log", "[", "2", "]"}], "/", "60.14"}]}], "]"}]}]}]], "Input",
 CellLabel->"In[81]:="],

Cell[TextData[{
 "This function is applied to obtain the retention for ",
 StyleBox["p",
  FontSlant->"Italic"],
 " (in \[Mu]m) = {1, 5 , 10} "
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qThyAmad1", "[", "t_", "]"}], ",", 
     RowBox[{"qThyAmad5", "[", "t_", "]"}], ",", 
     RowBox[{"qThyAmad10", "[", "t_", "]"}]}], "}"}], "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"qThyAmad", "[", 
       RowBox[{"t", ",", " ", "#"}], "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{"1", ",", "5", ",", "10"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[82]:="],

Cell[TextData[{
 "The bioassay data are fitted using AMAD ",
 StyleBox["p",
  FontSlant->"Italic"],
 "(in \[Mu]m)={1,5,10} to obtain ",
 Cell[BoxData[
  FormBox[
   RowBox[{"I", "(", "p", ")"}], TraditionalForm]]],
 " "
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"f1", ",", "f5", ",", " ", "f10"}], "}"}], " ", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"FindFit", "[", 
       RowBox[{"sampleThy", ",", 
        RowBox[{"intake", " ", "#"}], ",", 
        RowBox[{"{", "intake", "}"}], ",", " ", "t"}], "]"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"qThyAmad1", "[", "t", "]"}], ",", 
       RowBox[{"qThyAmad5", "[", "t", "]"}], ",", 
       RowBox[{"qThyAmad10", "[", "t", "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[83]:="],

Cell[TextData[{
 " The intake ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"I", "(", "p", ")"}], " "}], TraditionalForm]]],
 "for ",
 StyleBox["p",
  FontSlant->"Italic"],
 "(in \[Mu]m) = {1,5,10} are shown"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"I1", ",", " ", "I5", ",", " ", "I10"}], "}"}], "=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"intake", "/.", "f1"}], ",", 
    RowBox[{"intake", "/.", "f5"}], ",", 
    RowBox[{"intake", "/.", "f10"}]}], "}"}]}]], "Input",
 CellLabel->"In[84]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "57448.5446751183`", ",", "41412.05096440034`", ",", "46724.55016554835`"}],
   "}"}]], "Output",
 CellChangeTimes->{
  3.3985841618668027`*^9, 3.398592317216798*^9, {3.4138019044021406`*^9, 
   3.4138019235741386`*^9}, 3.4800942431552305`*^9, 3.4800960361986*^9, 
   3.4801564134698*^9, 3.4801575522074003`*^9, 3.518532278930478*^9, 
   3.539699080047696*^9, 3.5920645272189293`*^9, 3.643609960430443*^9},
 CellLabel->"Out[84]="]
}, Open  ]],

Cell["\<\
Fig.  I-125 thyroid retention function fitted using the experimental data. \
The continuous line actually is three lines superposed corresponding to three \
combination of intakes and AMADs. It can be observed that they are \
indistinguishable \
\>", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig5", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"I1", " ", 
       RowBox[{"qThyAmad1", "[", "t", "]"}]}], ",", 
      RowBox[{"I5", " ", 
       RowBox[{"qThyAmad5", "[", "t", "]"}]}], ",", " ", 
      RowBox[{"I10", " ", 
       RowBox[{"qThyAmad10", "[", "t", "]"}]}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"t", ",", " ", "0", ",", "50"}], "}"}], ",", " ", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<days\>\"", ",", " ", "\"\<Bq\>\""}], "}"}]}], ",", 
    RowBox[{"Epilog", "\[RuleDelayed]", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"{", 
         RowBox[{"Orange", ",", 
          RowBox[{"PointSize", "[", ".02", "]"}], ",", 
          RowBox[{"Point", "[", "##", "]"}]}], "}"}], "&"}], ",", 
       "sampleThy"}], "]"}]}]}], " ", "]"}]}]], "Input",
 CellLabel->"In[85]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwVknk81Gsbh2fGWEOoaCNrUSRZWpw8N8cyTpZIhZSRmLFUSNnqVKhM1o4i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     "]]}, 
   {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV03k81N0XB/Axxr4mW6ketKDHmiUi92QdKUkKlexLthJZ4nkUsiR7O6Gx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     "]]}, 
   {RGBColor[0.560181, 0.691569, 0.194885], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV0mk41G0bBvAZW9aishSVNSpZskTivhCmyJbssmRfivJIqXhQkr2SLOEZ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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"days\"", TraditionalForm], 
    FormBox["\"Bq\"", TraditionalForm]},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Epilog->{{
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{7, 5143}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{14, 4773}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{15, 4403}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{21, 4070}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{28, 3470.6}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{42, 2545.6}]}},
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0, 50}, {0., 5738.318234172351}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.3985841621179085`*^9, 3.3985923174517574`*^9, {3.4138019046052675`*^9, 
   3.4138019246053953`*^9}, 3.480094243436031*^9, 3.4800960363234*^9, 
   3.480156413579*^9, 3.4801575523946*^9, 3.5185322790398555`*^9, 
   3.539699080172699*^9, 3.592064527406948*^9, 3.643609960508568*^9},
 CellLabel->"Out[85]="]
}, Open  ]],

Cell[TextData[{
 "Now it is obtained the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["\[Sum]", "i"], 
    RowBox[{
     SubscriptBox["IRF", "i"], "(", "p", ")"}]}], TraditionalForm]]],
 ", being ",
 Cell[BoxData[
  FormBox[
   RowBox[{"i", "="}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  RowBox[{"{", "AI"}]]],
 ", ",
 Cell[BoxData[
  SubscriptBox["bb", 
   RowBox[{"fast", "+", "seq"}]]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["bb", "slow"], ","}]]],
 " ",
 Cell[BoxData[
  SubscriptBox["BB", 
   RowBox[{"fast", "+", "seq"}]]]],
 " ",
 Cell[BoxData[
  RowBox[{",", " ", 
   SubscriptBox["BB", "slow"], ",", " "}]]],
 " ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["ET", "2"], "}"}]]],
 " (It can be tested with the given in ANNEX F, Table F.1, of ICRP 66) for \
AMAD ",
 StyleBox["p ",
  FontSlant->"Italic"],
 "(in \[Mu]m) = {1,5,10} "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"idf1", ",", " ", "idf5", ",", " ", "idf10"}], "}"}], " ", "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"Plus", "@@", 
      RowBox[{"Drop", "[", 
       RowBox[{
        RowBox[{"AMADAdultW", "[", "#", "]"}], ",", 
        RowBox[{"-", "1"}]}], "]"}]}], "&"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"1", ",", "5", ",", "10"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[86]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.34664964`", ",", "0.4808745099999999`", ",", "0.42619640000000003`"}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.3985841621963787`*^9, 3.3985923174830856`*^9, {3.4138019046521425`*^9, 
   3.413801924699146*^9}, 3.480094243545231*^9, 3.4800960363389997`*^9, 
   3.4801564136102*^9, 3.4801575524258003`*^9, 3.518532279071106*^9, 
   3.5396990802039495`*^9, 3.59206452742295*^9, 3.6436099605554433`*^9},
 CellLabel->"Out[86]="]
}, Open  ]],

Cell[TextData[{
 "Finally it is obtained ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"I", "(", "p", ")"}], " ", 
    RowBox[{
     UnderscriptBox["\[Sum]", "i"], 
     RowBox[{
      SubscriptBox["IDF", "i"], "(", "p", ")"}]}]}], TraditionalForm]]],
 "  with  ",
 StyleBox["p ",
  FontSlant->"Italic"],
 " = {1,5,10}.  It can be obserbed that ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"I", "(", "1", ")"}], " ", 
    RowBox[{
     UnderscriptBox["\[Sum]", "i"], 
     RowBox[{
      SubscriptBox["IDF", "i"], "(", "1", ")"}]}]}], TraditionalForm]]],
 "   \[TildeTilde]  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"I", "(", "5", ")"}], 
    RowBox[{
     UnderscriptBox["\[Sum]", "i"], 
     RowBox[{
      SubscriptBox["IDF", "i"], "(", "5", ")"}]}]}], TraditionalForm]]],
 "  \[TildeTilde] ",
 Cell[BoxData[
  FormBox[
   RowBox[{"I", " ", 
    RowBox[{"(", "10", ")"}], " ", 
    RowBox[{
     UnderscriptBox["\[Sum]", "i"], 
     RowBox[{
      SubscriptBox["IDF", "i"], "(", "10", ")"}]}]}], TraditionalForm]]],
 ".  "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"idf1", ",", " ", "idf5", ",", " ", "idf10"}], "}"}], " ", 
  RowBox[{"{", 
   RowBox[{"I1", ",", " ", "I5", ",", " ", "I10"}], "}"}]}]], "Input",
 CellLabel->"In[87]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "19914.517330153674`", ",", "19913.999715601036`", ",", 
   "19913.835072176113`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.3985841622591553`*^9, 3.398592317530078*^9, {3.4138019046990175`*^9, 
   3.4138019247303963`*^9}, 3.480094243560831*^9, 3.4800960363546*^9, 
   3.4801564136102*^9, 3.4801575524726*^9, 3.518532279102357*^9, 
   3.5396990802352*^9, 3.5920645274729548`*^9, 3.643609960586693*^9},
 CellLabel->"Out[87]="]
}, Open  ]],

Cell[TextData[{
 "In the same way, taken into account that DCF for iodine 125 are ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["DCF", "1"], TraditionalForm]]],
 "(1 \[Mu]m) = 5.3 ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "6"}]], TraditionalForm]]],
 " mSv/Bq , ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["DCF", "2"], TraditionalForm]]],
 " (5 \[Mu]m) =7.3 ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "6"}]], TraditionalForm]]],
 " mSv/Bq, and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["DCF", "3"], TraditionalForm]]],
 " (10 \[Mu]m) =6.5 ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", 
    RowBox[{"-", "6"}]], TraditionalForm]]],
 " mSv/Bq. Therefore ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "1"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "1"], TraditionalForm]]],
 "  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["DCF", "1"], TraditionalForm]]],
 " = 0.305 mSv; ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "2"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "2"], TraditionalForm]]],
 "  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["DCF", "2"], TraditionalForm]]],
 " = 0.303 mSv; ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "3"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "3"], TraditionalForm]]],
 "  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["DCF", "3"], TraditionalForm]]],
 " = 0.304 mSv; that is ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "1"], TraditionalForm]]],
 " \[TildeTilde] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "2"], TraditionalForm]]],
 "  \[TildeTilde] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "3"], TraditionalForm]]],
 ". "
}], "Text"],

Cell[TextData[{
 "Here are computed  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"E", "(", "p", ")"}], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{"I", "(", "p", ")"}], TraditionalForm]]],
 "  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["DCF", "p"], TraditionalForm]]],
 " .  It can be observed that  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "1"], TraditionalForm]]],
 " \[TildeTilde] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "2"], TraditionalForm]]],
 "  \[TildeTilde] ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "3"], TraditionalForm]]],
 ". (being ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "1"], TraditionalForm]]],
 "= E(1); ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "2"], TraditionalForm]]],
 "= E(5); ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "3"], TraditionalForm]]],
 "= E(10));"
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"dcf1", ",", " ", "dcf5", ",", " ", "dcf10"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"5.3", 
      FormBox[
       SuperscriptBox["10", 
        RowBox[{"-", "6"}]],
       TraditionalForm]}], ",", "  ", 
     RowBox[{"7.3", 
      FormBox[
       SuperscriptBox["10", 
        RowBox[{"-", "6"}]],
       TraditionalForm]}], ",", " ", 
     RowBox[{"6.5", 
      FormBox[
       SuperscriptBox["10", 
        RowBox[{"-", "6"}]],
       TraditionalForm]}]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[88]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"E1", ",", " ", "E2", ",", " ", "E3"}], "}"}], "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"I1", " ", "dcf1"}], ",", " ", 
    RowBox[{"I5", " ", "dcf5"}], ",", " ", 
    RowBox[{"I10", " ", "dcf10"}]}], "}"}]}]], "Input",
 CellLabel->"In[89]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.3044772867781269`", ",", "0.30230797204012244`", ",", 
   "0.3037095760760643`"}], "}"}]], "Output",
 CellChangeTimes->{
  3.3985841623376255`*^9, 3.3985923175770693`*^9, {3.413801904730268*^9, 
   3.4138019247772713`*^9}, 3.480094243576431*^9, 3.4800960364014*^9, 
   3.4801564136258*^9, 3.4801575525506*^9, 3.518532279133607*^9, 
   3.539699080297701*^9, 3.59206452752496*^9, 3.643609960649193*^9},
 CellLabel->"Out[89]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "idf1", ",", " ", "idf5", ",", " ", "idf10", ",", " ", "I1", ",", " ", "I5",
    ",", " ", "I10", ",", " ", "E1", ",", " ", "E2", ",", " ", "E3"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.3985924911185255`*^9, 3.3985925091164618`*^9}},
 CellLabel->"In[90]:="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Example 3",
 FontSize->12]], "Subsection"],

Cell[TextData[{
 "A worker has been exposed from ",
 StyleBox["t",
  FontSlant->"Italic"],
 " = 0 to ",
 StyleBox["t",
  FontSlant->"Italic"],
 " = 2000 day to a chronic intake by inhalation of 3 BqU/day of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["UO", "2"], TraditionalForm]]],
 " aerosols type S and AMAD 5 \[Mu]m. On the day ",
 StyleBox["t",
  FontSlant->"Italic"],
 " = 2000 he accidentally intakes by inhalation an unknown ",
 StyleBox["I",
  FontSlant->"Italic"],
 " quantity of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["UO", "2"], TraditionalForm]]],
 ". The uranium lung content has been measured using a lung body counter \
obtaining: {Days after accidental intake, Lung content (BqU)} =",
 "{{1,186}, {5,181}, {30,161}, {70,149}, {120,143}, {250,113}}. It is \
supposed that the measured uncertainties is 30 Bq with a conficence level of \
95%",
 ". We wish to know the accidental quantity intaken."
}], "Text"],

Cell[TextData[{
 "Note.- The lung measurements have been simulated using a single intake of \
1700 BqU with AMAD 7 \[Mu]m with a random noise. The lung counters usually \
measure the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[InvisiblePrefixScriptBase]", "235"], 
    StyleBox["U",
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontTracking->"Plain",
     FontVariations->{"CompatibilityType"->0,
     "Masked"->False,
     "Outline"->False,
     "RotationAngle"->0,
     "Shadow"->False,
     "StrikeThrough"->False,
     "Underline"->False}]}], TraditionalForm]]],
 " but here it has been converted to give the data in BqU. The chronic and \
the accidental intakes are assumed to be from approximately the same \
enrichment (4.4% of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[InvisiblePrefixScriptBase]", "235"], 
    StyleBox["U",
     FontWeight->"Plain",
     FontSlant->"Plain",
     FontTracking->"Plain",
     FontVariations->{"CompatibilityType"->0,
     "Masked"->False,
     "Outline"->False,
     "RotationAngle"->0,
     "Shadow"->False,
     "StrikeThrough"->False,
     "Underline"->False}]}], TraditionalForm]]],
 ")."
}], "Text"],

Cell[CellGroupData[{

Cell["Sol", "SubsubsectionIcon"],

Cell["\<\
If it is assumed an AMAD of 5 \[Mu]m (recommended value by ICRP 66 when AMAD \
is unknown) then eqn (17) and eqn (18) can be applied. The solution obtained \
is that the accidental intake was 1205 \[PlusMinus] 254 BqU. If it is \
supposed that the AMAD is unknown then the eqn (20) is applied obtaining 1875 \
BqU and AMAD 7.8 \[Mu]m. These are nearer to the \[OpenCurlyDoubleQuote]true\
\[CloseCurlyDoubleQuote] values. \
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qLungU5", "[", "t_", "]"}], "=", 
   RowBox[{"LungsRetention", "[", 
    RowBox[{"1", ",", 
     RowBox[{"AMADAdultW", "[", "5", "]"}], ",", "S", ",", " ", "t", ",", 
     "0"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[91]:="],

Cell["The \"measured\" (it has been alredy simulated) data has been:", \
"MathCaption"],

Cell[BoxData[
 RowBox[{"SeedRandom", "[", "101", "]"}]], "Input",
 CellLabel->"In[92]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sampleLung1", "=", 
  RowBox[{
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{
         RowBox[{"qConstant", " ", "[", 
          RowBox[{"3", ",", 
           RowBox[{"{", 
            RowBox[{
             RowBox[{"qLungU5", "[", "t", "]"}], ",", "t"}], "}"}], ",", " ", 
           RowBox[{"#", " ", "+", "2000"}], ",", " ", "2000"}], "]"}], "+", 
         RowBox[{"1700", " ", 
          RowBox[{"LungsRetention", "[", 
           RowBox[{"1", ",", 
            RowBox[{"AMADAdultW", "[", "7", "]"}], ",", "S", ",", " ", "#", 
            ",", "0"}], "]"}]}], " ", "+", " ", 
         RowBox[{"Random", "[", 
          RowBox[{"NormalDistribution", "[", 
           RowBox[{"0", ",", " ", "5"}], "]"}], "]"}]}]}], "}"}], "&"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "1", ",", "5", ",", " ", "30", ",", " ", "70", ",", " ", "120", ",", 
       " ", "250"}], "}"}]}], "]"}], "//", "Round"}]}]], "Input",
 CellLabel->"In[93]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "186"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "181"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"30", ",", "161"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"70", ",", "149"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"120", ",", "143"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"250", ",", "113"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.398584163326354*^9, 3.3985923185795655`*^9, 
  3.4138019336992035`*^9, 3.4800942441536307`*^9, 3.4800960366977997`*^9, 
  3.4800979577286*^9, 3.4801564141406*^9, 3.4801575530498*^9, 
  3.518532279649242*^9, 3.5396990807195845`*^9, 3.5920645282830353`*^9, 
  3.643609960836694*^9},
 CellLabel->"Out[93]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sampleLung1", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "186"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "181"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"30", ",", "161"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"70", ",", "149"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"120", ",", "143"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"250", ",", "113"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[94]:="],

Cell["The first step is subtracted the chronic intake", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"timemeasured", ",", " ", "measured"}], "}"}], "=", 
   RowBox[{"Transpose", "[", "sampleLung1", "]"}]}], ";"}]], "Input",
 CellLabel->"In[95]:="],

Cell["That is the lung retention due to the chronic intake", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"cronicLung", "=", 
  RowBox[{
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"#", ",", 
        RowBox[{"qConstant", "[", 
         RowBox[{"3", ",", 
          RowBox[{"{", " ", 
           RowBox[{
            RowBox[{"qLungU5", "[", "t", "]"}], ",", "t"}], "}"}], ",", " ", 
          RowBox[{"#", " ", "+", "2000"}], ",", " ", "2000"}], "]"}]}], "}"}],
       "&"}], ",", " ", "timemeasured"}], "]"}], "//", "Round"}]}]], "Input",
 CellLabel->"In[96]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "108"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "107"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"30", ",", "104"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"70", ",", "99"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"120", ",", "95"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"250", ",", "85"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.398584163546071*^9, 3.3985923187675333`*^9, 
  3.4138019338710794`*^9, 3.480094244278431*^9, 3.480096036807*^9, 
  3.4800979577754*^9, 3.4801564142342*^9, 3.4801569232466*^9, 
  3.4801575532214003`*^9, 3.51853227978987*^9, 3.539699080844587*^9, 
  3.5920645287840858`*^9, 3.643609960946069*^9},
 CellLabel->"Out[96]="]
}, Open  ]],

Cell["\<\
The total retention minus the chronic retention gives the lung retention due \
to the accidental intake\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sampleLung2", " ", "=", " ", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{"timemeasured", ",", " ", 
     RowBox[{
      RowBox[{"Transpose", "[", 
       RowBox[{"sampleLung1", "-", "cronicLung"}], "]"}], "[", 
      RowBox[{"[", "2", "]"}], "]"}]}], "}"}], "]"}]}]], "Input",
 CellLabel->"In[97]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "78"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "74"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"30", ",", "57"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"70", ",", "50"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"120", ",", "48"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"250", ",", "28"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.3985841636088476`*^9, 3.3985923187988615`*^9, 
  3.4138019339023294`*^9, 3.480094244278431*^9, 3.4800960368226*^9, 
  3.4800979578066*^9, 3.4801564142497997`*^9, 3.480156923309*^9, 
  3.4801575532838*^9, 3.5185322798211203`*^9, 3.5396990808914623`*^9, 
  3.592064529015109*^9, 3.6436099609929533`*^9},
 CellLabel->"Out[97]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"int", ",", "p"}], "]"}]], "Input",
 CellLabel->"In[98]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"model1", "[", 
    RowBox[{"t_", ",", "int_", ",", " ", "p_"}], "]"}], "=", 
   RowBox[{
    StyleBox["LungsRetention", "Input"], "[", 
    RowBox[{"int", ",", 
     RowBox[{"AMADfit", "[", "p", "]"}], ",", "S", ",", " ", "t", ",", "0"}], 
    "]"}]}], ";"}]], "Input",
 CellLabel->"In[99]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"inputAcute", ",", " ", "pp"}], "}"}], "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"int", ",", " ", "p"}], "}"}], "/.", 
   RowBox[{"FindFit", "[", 
    RowBox[{"sampleLung2", ",", 
     RowBox[{"model1", "[", 
      RowBox[{"t", ",", "int", ",", " ", "p"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"int", ",", "500", ",", "1000"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"p", ",", "3", ",", "10"}], "}"}]}], "}"}], ",", "t"}], 
    "]"}]}]}]], "Input",
 CellLabel->"In[100]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1875.6871578474897`", ",", "7.834678153222669`"}], "}"}]], "Output",
 CellChangeTimes->{3.4801564150142*^9, 3.4801569335582*^9, 3.4801575537674*^9,
   3.518532280227378*^9, 3.539699081235219*^9, 3.592064529866194*^9, 
  3.643609961180444*^9},
 CellLabel->"Out[100]="]
}, Open  ]],

Cell["Here is fitted adding the measured uncertainties (30 Bq)  ", \
"MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sampleLungUnc2", " ", "=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Append", "[", 
       RowBox[{"#", ",", "30"}], "]"}], "&"}], ",", "sampleLung2"}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[101]:="],

Cell[CellGroupData[{

Cell[BoxData["sampleLungUnc2"], "Input",
 CellLabel->"In[102]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "78", ",", "30"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "74", ",", "30"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"30", ",", "57", ",", "30"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"70", ",", "50", ",", "30"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"120", ",", "48", ",", "30"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"250", ",", "28", ",", "30"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.3985841646289644`*^9, 3.3985923197700295`*^9, 
  3.413801934855461*^9, 3.480094244855631*^9, 3.4800960373062*^9, 
  3.4800979581186*^9, 3.4801564150453997`*^9, 3.4801569438854*^9, 
  3.4801575537986*^9, 3.518532280258629*^9, 3.539699081282095*^9, 
  3.592064530153223*^9, 3.6436099612273197`*^9},
 CellLabel->"Out[102]="]
}, Open  ]],

Cell["If the AMAD 5\[Mu]m is assumed  , then", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MLFit", "[", 
  RowBox[{"sampleLungUnc2", ",", 
   RowBox[{
    StyleBox["LungsRetention", "Input"], "[", 
    RowBox[{"1", ",", 
     RowBox[{"AMADAdultW", "[", "5", "]"}], ",", "S", ",", " ", "t", ",", 
     "0"}], "]"}], ",", "t"}], "]"}]], "Input",
 CellLabel->"In[103]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"Mean\"\>", "\[Rule]", "1205.276797384016`"}], ",", 
   RowBox[{"\<\"s\"\>", "\[Rule]", "253.80864472705827`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.398584164817293*^9, 3.3985923199736614`*^9, 
  3.41380193549609*^9, 3.480094245089631*^9, 3.4800960374154*^9, 
  3.4800979581498003`*^9, 3.4801564151702003`*^9, 3.4801569502502003`*^9, 
  3.4801575539702*^9, 3.518532280383631*^9, 3.539699081375847*^9, 
  3.5920645305222597`*^9, 3.6436099613054447`*^9},
 CellLabel->"Out[103]="]
}, Open  ]],

Cell["If the the AMAD fitted is assumed, then", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MLFit", "[", 
  RowBox[{"sampleLungUnc2", ",", 
   RowBox[{
    StyleBox["LungsRetention", "Input"], "[", 
    RowBox[{"1", ",", 
     RowBox[{"AMADAdultW", "[", "pp", "]"}], ",", "S", ",", " ", "t", ",", 
     "0"}], "]"}], ",", "t"}], "]"}]], "Input",
 CellLabel->"In[104]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"Mean\"\>", "\[Rule]", "1900.9833472479268`"}], ",", 
   RowBox[{"\<\"s\"\>", "\[Rule]", "400.3051504538274`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.3985841650213165`*^9, 3.3985923201616297`*^9, 
  3.413801935777342*^9, 3.480094245183231*^9, 3.480096037509*^9, 
  3.4800979581809998`*^9, 3.4801564152794*^9, 3.4801569504842*^9, 
  3.4801575542198*^9, 3.5185322804617577`*^9, 3.539699081485224*^9, 
  3.5920645308862963`*^9, 3.6436099613835697`*^9},
 CellLabel->"Out[104]="]
}, Open  ]],

Cell["\<\
Note that the solution is the same. It happens becouse the uncertainties are \
the same for all the measurements.\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"FindMinimum", "[", 
  RowBox[{
   RowBox[{"X2FitE", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"int", ",", " ", "p"}], "}"}], ",", "sampleLungUnc2", ",", 
     RowBox[{"model1", "[", 
      RowBox[{"t", ",", "int", ",", " ", "p"}], "]"}], ",", "t"}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"int", ",", " ", "1000", ",", " ", "3000"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"p", ",", "3", ",", "8"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[105]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.1118596937057999`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"int", "\[Rule]", "1875.6872224630329`"}], ",", 
     RowBox[{"p", "\[Rule]", "7.834678361570231`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.398584170247452*^9, 3.3985923254873896`*^9, 
  3.413801941511753*^9, 3.480094248240831*^9, 3.4800960406134*^9, 
  3.4800979582434*^9, 3.4801564190546*^9, 3.4801569541034*^9, 
  3.4801575573241997`*^9, 3.518532283399314*^9, 3.539699083454012*^9, 
  3.592064534798687*^9, 3.6436099621804447`*^9},
 CellLabel->"Out[105]="]
}, Open  ]],

Cell["\<\
Fig6..- Predicted lung retention after an acute intake assuming a previous \
chronic intake  The dashed line represents the underlying contribution from \
the chronic intake. \
\>", "Commentary"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qLungU7", "[", "t_", "]"}], "=", 
   RowBox[{"LungsRetention", "[", 
    RowBox[{"1", ",", 
     RowBox[{"AMADAdultW", "[", "pp", "]"}], ",", "S", ",", " ", "t", ",", 
     "0"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[106]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotLung1", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"qConstant", "[", 
      RowBox[{"3", ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"qLungU5", "[", "t", "]"}], ",", "t"}], "}"}], ",", 
       RowBox[{"t1", "+", "2000"}], ",", "2000"}], "]"}], "+", 
     RowBox[{"inputAcute", " ", 
      RowBox[{"qLungU7", "[", "t1", "]"}]}]}], ",", 
    RowBox[{"{", 
     RowBox[{"t1", ",", "1", ",", "300"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[107]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV0Hs8lIkeBvBxiWqlXHILKaLk0GVWjmgehbWR7FQavDPGMC+1g/GWVsnl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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 112.},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{1, 300}, {114.73857086971627`, 184.92679713851697`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.3985841729468374`*^9, 3.3985923282599173`*^9, 3.4138019442148952`*^9, 
   3.480094249878831*^9, 3.4800960421734*^9, {3.480097942659*^9, 
   3.4800979582902*^9}, 3.4801564226113997`*^9, 3.4801569619034*^9, 
   3.4801575602882*^9, 3.518532285430603*^9, 3.5396990847821627`*^9, 
   3.5920645376459723`*^9, 3.6436099629773216`*^9},
 CellLabel->"Out[107]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sampleLung3", "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Append", "[", 
       RowBox[{
        RowBox[{"{", "#", "}"}], ",", 
        RowBox[{"ErrorBar", "[", "30", " ", "]"}]}], "]"}], "&"}], ",", 
     "sampleLung1"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[108]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotLung2", "=", 
  RowBox[{"ErrorListPlot", "[", "sampleLung3", "]"}]}]], "Input",
 CellChangeTimes->{{3.4801571210546*^9, 3.480157137575*^9}},
 CellLabel->"In[109]:="],

Cell[BoxData[
 GraphicsBox[{{}, {{}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.019444444444444445`],
      AbsoluteThickness[1.6], 
     PointBox[{{1., 186.}, {5., 181.}, {30., 161.}, {70., 149.}, {120., 
      143.}, {250., 
      113.}}], {{LineBox[{{1., 216.}, {1., 156.}}], 
       LineBox[{Offset[{1.5, 0}, {1., 216.}], Offset[{-1.5, 0}, {1., 216.}]}],
        LineBox[{
        Offset[{1.5, 0}, {1., 156.}], Offset[{-1.5, 0}, {1., 156.}]}]}, {
       LineBox[{{5., 211.}, {5., 151.}}], 
       LineBox[{Offset[{1.5, 0}, {5., 211.}], Offset[{-1.5, 0}, {5., 211.}]}],
        LineBox[{
        Offset[{1.5, 0}, {5., 151.}], Offset[{-1.5, 0}, {5., 151.}]}]}, {
       LineBox[{{30., 191.}, {30., 131.}}], 
       LineBox[{
        Offset[{1.5, 0}, {30., 191.}], Offset[{-1.5, 0}, {30., 191.}]}], 
       LineBox[{
        Offset[{1.5, 0}, {30., 131.}], Offset[{-1.5, 0}, {30., 131.}]}]}, {
       LineBox[{{70., 179.}, {70., 119.}}], 
       LineBox[{
        Offset[{1.5, 0}, {70., 179.}], Offset[{-1.5, 0}, {70., 179.}]}], 
       LineBox[{
        Offset[{1.5, 0}, {70., 119.}], Offset[{-1.5, 0}, {70., 119.}]}]}, {
       LineBox[{{120., 173.}, {120., 113.}}], 
       LineBox[{
        Offset[{1.5, 0}, {120., 173.}], Offset[{-1.5, 0}, {120., 173.}]}], 
       LineBox[{
        Offset[{1.5, 0}, {120., 113.}], Offset[{-1.5, 0}, {120., 113.}]}]}, {
       LineBox[{{250., 143.}, {250., 83.}}], 
       LineBox[{
        Offset[{1.5, 0}, {250., 143.}], Offset[{-1.5, 0}, {250., 143.}]}], 
       LineBox[{
        Offset[{1.5, 0}, {250., 83.}], 
         Offset[{-1.5, 0}, {250., 83.}]}]}}}, {}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 109.35},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0, 250.}, {113., 186.}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{
  3.39858417307239*^9, 3.398592328338238*^9, 3.413801944277396*^9, 
   3.480094249910031*^9, 3.4800960422202*^9, 3.4800979583213997`*^9, 
   3.4801564229234*^9, 3.4801570952834*^9, {3.4801571295566*^9, 
   3.480157142177*^9}, 3.4801575610838003`*^9, 3.518532285477479*^9, 
   3.5396990848602886`*^9, 3.5920645380310106`*^9, 3.643609963055448*^9},
 CellLabel->"Out[109]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"PlotLung3", " ", "=", 
  RowBox[{"Plot", "[", 
   RowBox[{
    RowBox[{"inputAcute", " ", 
     RowBox[{"qLungU7", "[", "t", "]"}]}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"t", ",", " ", "1", ",", "300"}], "}"}], ",", 
    RowBox[{"PlotRange", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"0", ",", "100"}], "}"}]}], ",", 
    RowBox[{"PlotStyle", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"AbsoluteThickness", "[", "1", "]"}], ",", " ", 
       RowBox[{"AbsoluteDashing", "[", 
        RowBox[{"{", 
         RowBox[{"10", ",", "10"}], "}"}], "]"}]}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellLabel->"In[110]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1], Opacity[1.],
     AbsoluteDashing[{10, 10}], LineBox[CompressedData["
1:eJwV03881AkaB/DBUu0OhtVcJEcU0XJ3rLUW85kxI+VH5jsaIrOoRPkxvotI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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{0., 299.9999938979592}, {0, 100}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.398584173213637*^9, 3.3985923284322214`*^9, 
  3.4138019443555217`*^9, 3.480094250019231*^9, 3.4800960422514*^9, 
  3.480097958337*^9, 3.4801564234382*^9, 3.4801571674958*^9, 
  3.4801575628154*^9, 3.518532285524355*^9, 3.5396990848915396`*^9, 
  3.5920645382430315`*^9, 3.643609963102322*^9},
 CellLabel->"Out[110]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"fig6", "=", 
  RowBox[{"Show", "[", 
   RowBox[{"PlotLung1", ",", "PlotLung2", ",", "PlotLung3", ",", 
    RowBox[{"PlotRange", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"0", ",", "250"}], "}"}]}], ",", 
    RowBox[{"AxesLabel", "\[Rule]", 
     RowBox[{"{", 
      RowBox[{"\"\<days\>\"", ",", "\"\<BqU\>\""}], "}"}]}]}], 
   "]"}]}]], "Input",
 CellLabel->"In[111]:="],

Cell[BoxData[
 GraphicsBox[{{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwV0Hs8lIkeBvBxiWqlXHILKaLk0GVWjmgehbWR7FQavDPGMC+1g/GWVsnl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      "]]}}, {{}, {{}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.019444444444444445`], AbsoluteThickness[1.6], 
      PointBox[{{1., 186.}, {5., 181.}, {30., 161.}, {70., 149.}, {120., 
       143.}, {250., 
       113.}}], {{LineBox[{{1., 216.}, {1., 156.}}], 
        LineBox[{
         Offset[{1.5, 0}, {1., 216.}], Offset[{-1.5, 0}, {1., 216.}]}], 
        LineBox[{
         Offset[{1.5, 0}, {1., 156.}], Offset[{-1.5, 0}, {1., 156.}]}]}, {
        LineBox[{{5., 211.}, {5., 151.}}], 
        LineBox[{
         Offset[{1.5, 0}, {5., 211.}], Offset[{-1.5, 0}, {5., 211.}]}], 
        LineBox[{
         Offset[{1.5, 0}, {5., 151.}], Offset[{-1.5, 0}, {5., 151.}]}]}, {
        LineBox[{{30., 191.}, {30., 131.}}], 
        LineBox[{
         Offset[{1.5, 0}, {30., 191.}], Offset[{-1.5, 0}, {30., 191.}]}], 
        LineBox[{
         Offset[{1.5, 0}, {30., 131.}], Offset[{-1.5, 0}, {30., 131.}]}]}, {
        LineBox[{{70., 179.}, {70., 119.}}], 
        LineBox[{
         Offset[{1.5, 0}, {70., 179.}], Offset[{-1.5, 0}, {70., 179.}]}], 
        LineBox[{
         Offset[{1.5, 0}, {70., 119.}], Offset[{-1.5, 0}, {70., 119.}]}]}, {
        LineBox[{{120., 173.}, {120., 113.}}], 
        LineBox[{
         Offset[{1.5, 0}, {120., 173.}], Offset[{-1.5, 0}, {120., 173.}]}], 
        LineBox[{
         Offset[{1.5, 0}, {120., 113.}], Offset[{-1.5, 0}, {120., 113.}]}]}, {
        LineBox[{{250., 143.}, {250., 83.}}], 
        LineBox[{
         Offset[{1.5, 0}, {250., 143.}], Offset[{-1.5, 0}, {250., 143.}]}], 
        LineBox[{
         Offset[{1.5, 0}, {250., 83.}], 
          Offset[{-1.5, 0}, {250., 83.}]}]}}}, {}}, {}}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1], Opacity[
     1.], AbsoluteDashing[{10, 10}], LineBox[CompressedData["
1:eJwV03881AkaB/DBUu0OhtVcJEcU0XJ3rLUW85kxI+VH5jsaIrOoRPkxvotI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      "]]}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"days\"", TraditionalForm], 
    FormBox["\"BqU\"", TraditionalForm]},
  AxesOrigin->{0, 112.},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{0, 250},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3985841733078012`*^9, 3.3985923284635496`*^9, 
  3.413801944386772*^9, 3.480094250050431*^9, 3.4800960422826*^9, 
  3.4800979583682003`*^9, 3.4801564237346*^9, 3.4801571676518*^9, 
  3.4801575644533997`*^9, 3.518532285555606*^9, 3.53969908492279*^9, 
  3.592064538366044*^9, 3.6436099631179485`*^9},
 CellLabel->"Out[111]="]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Example 4 ",
 FontSize->12]], "Subsection"],

Cell[TextData[{
 "An operator has been exposed to an simple accidental intake by inhalation \
of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "60"], TraditionalForm]]],
 "Co. The cobalt form was metal and oxide. A program of in-vivo monitoring \
was carried out ten days after the event and continued up to 3 years (Table \
2). Urine samples were also taken (Table 2). Additional information: It is \
recommended to assume that the whole body and urine measurements  be \
approximated by a log-normal distribution with a geometric standard deviation \
of 1.07 Bq and  1.8 Bq"
}], "Text"],

Cell[TextData[{
 StyleBox["(Data from ICRP (Draft 2006): Draft guidance document: Bioassay \
data interpretation (Annex B) ",
  FontSize->10],
 StyleBox["http://www.icrp.org/news_guidance.asp",
  FontSize->10,
  FontVariations->{"Underline"->True},
  FontColor->RGBColor[0, 0, 1]],
 StyleBox[" ",
  FontSize->10],
 "[Accessed 15 june 2006]",
 StyleBox[")",
  FontSize->10]
}], "Text"],

Cell[CellGroupData[{

Cell["sol 1", "SubsubsectionIcon"],

Cell["\<\
This is a case where multiple data sets must be fitted to a nonlinear model. \
\>", "Text"],

Cell[TextData[{
 "The default parameter recommended by ICRP 78 for cobalt oxide values are: \
AMAD 5 \[Mu]m, absorption Type S, f1 value 0.05. If we applied the chi \
squared test (\[Chi]2) the goodness of the data fitted is very bad. For this \
reason we used the eqn (21) assuming that p (AMAD value in \[Micro]m), the \
absorption rates:{",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "pt"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "p"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "t"], TraditionalForm]]],
 "} and f1 are unknown. This is a case where multiple data sets must be \
fitted to a nonlinear model. To avoid a too long time of computation some \
restrictions about the parameters fitted were established. Also the number of \
step to find the minimum of eqn (21) was limited. The best fit obtained \
corresponds to 398.5 kBq with AMAD 5.5 \[Mu]m, {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "pt"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "p"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "t"], TraditionalForm]]],
 "} ={10, 90, 0.0007} and  f1 = 0.1. The committed effective dose, E(50) \
calculated using these values is: 4.5 mSv."
}], "Text"],

Cell[TextData[{
 "The method applied in ",
 StyleBox["ICRP (Draft 2006) ",
  FontSize->10],
 "is different. There is taken as AMAD 5 \[Mu]m, then is applied the eq. (19) \
several times: One set with with f1= 0.1  testing mixture of absorption Types \
S and M other repeating the procedure with f1 = 0.05.  In each test is \
obtained the Ji2 value. Finally is chosen the solution where the Ji2 is \
smallest one. The computation has been made using IMBA Professional. The \
solution reported is 404 kBq and 5 mSv "
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"sampleWBCo60", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"10", ",", "23900"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"14", ",", "29200"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"17", ",", "20100"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"20", ",", "18200"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"27", ",", "21600"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"40", ",", "19800"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"60", ",", "21600"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"80", ",", "17500"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"190", ",", "11600"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"370", ",", "8100"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"747", ",", "4800"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1010", ",", "2700"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[112]:="],

Cell["Table 1\tWhole body activity measurement", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"sampleWBCo60", ",", " ", 
   RowBox[{"TableHeadings", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Time of measurement\\n after intake in days\>\"", ",", 
        "\"\<Whole body\\n activity of 60Co (Bq)\>\""}], "}"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellLabel->"In[113]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Time of measurement\\n after intake in days\"\>",
       HoldForm], 
      TagBox["\<\"Whole body\\n activity of 60Co (Bq)\"\>",
       HoldForm]},
     {"10", "23900"},
     {"14", "29200"},
     {"17", "20100"},
     {"20", "18200"},
     {"27", "21600"},
     {"40", "19800"},
     {"60", "21600"},
     {"80", "17500"},
     {"190", "11600"},
     {"370", "8100"},
     {"747", "4800"},
     {"1010", "2700"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Time of measurement\n after intake in days", 
       "Whole body\n activity of 60Co (Bq)"}}]]]], "Output",
 CellChangeTimes->{3.39858417341766*^9, 3.398592328510542*^9, 
  3.4138020184964695`*^9, 3.480094250097231*^9, 3.4800960422981997`*^9, 
  3.4801564242494*^9, 3.4801575656546*^9, 3.518532285571231*^9, 
  3.5396990849540405`*^9, 3.592064538417049*^9, 3.643609963180447*^9},
 CellLabel->"Out[113]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sampleUriCo60", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"14", ",", "709"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"27", ",", "64"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"40", ",", "71"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"60", ",", "37"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"80", ",", "29"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"190", ",", "11"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"370", ",", "1.7"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[114]:="],

Cell["Table 2.- Urine activity measurement", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"sampleUriCo60", ",", " ", 
   RowBox[{"TableHeadings", "\[Rule]", " ", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Time of measurement\\n after intake in days\>\"", ",", 
        "\"\<Daily urinary excretion\\n rate of 60Co (Bq)\>\""}], "}"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[115]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Time of measurement\\n after intake in days\"\>",
       HoldForm], 
      TagBox["\<\"Daily urinary excretion\\n rate of 60Co (Bq)\"\>",
       HoldForm]},
     {"14", "709"},
     {"27", "64"},
     {"40", "71"},
     {"60", "37"},
     {"80", "29"},
     {"190", "11"},
     {"370", "1.7`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Time of measurement\n after intake in days", 
       "Daily urinary excretion\n rate of 60Co (Bq)"}}]]]], "Output",
 CellChangeTimes->{3.398584173496131*^9, 3.3985923285575333`*^9, 
  3.4138020185433445`*^9, 3.480094250112831*^9, 3.4800960423294*^9, 
  3.4801564244678*^9, 3.4801575665438004`*^9, 3.5185322856024814`*^9, 
  3.5396990850165415`*^9, 3.592064538476055*^9, 3.6436099632116976`*^9},
 CellLabel->"Out[115]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"sampleWBCo60L", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"10", ",", 
       RowBox[{"Log", "[", "23900", "]"}], ",", " ", 
       RowBox[{"Log", "[", "1.2", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"14", ",", 
       RowBox[{"Log", "[", "29200", "]"}], ",", " ", 
       RowBox[{"Log", "[", "1.2", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"17", ",", 
       RowBox[{"Log", "[", "20100", "]"}], ",", " ", 
       RowBox[{"Log", "[", "1.2", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"20", ",", 
       RowBox[{"Log", "[", "18200", "]"}], ",", " ", 
       RowBox[{"Log", "[", "1.2", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"27", ",", 
       RowBox[{"Log", "[", "21600", "]"}], ",", " ", 
       RowBox[{"Log", "[", "1.2", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"40", ",", 
       RowBox[{"Log", "[", "19800", "]"}], ",", " ", 
       RowBox[{"Log", "[", "1.2", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"60", ",", 
       RowBox[{"Log", "[", "21600", "]"}], ",", " ", 
       RowBox[{"Log", "[", "1.2", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"80", ",", 
       RowBox[{"Log", "[", "17500", "]"}], ",", " ", 
       RowBox[{"Log", "[", "1.2", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"190", ",", 
       RowBox[{"Log", "[", "11600", "]"}], ",", " ", 
       RowBox[{"Log", "[", "1.2", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"370", ",", 
       RowBox[{"Log", "[", "8100", "]"}], ",", " ", 
       RowBox[{"Log", "[", "1.2", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"747", ",", 
       RowBox[{"Log", "[", "4800", "]"}], ",", " ", 
       RowBox[{"Log", "[", "1.2", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"1010", ",", 
       RowBox[{"Log", "[", "2700", "]"}], ",", " ", 
       RowBox[{"Log", "[", "1.2", "]"}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[116]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"sampleUriCo60L", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"14", ",", 
       RowBox[{"Log", "[", "709", "]"}], ",", " ", 
       RowBox[{"Log", "[", "1.8", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"27", ",", 
       RowBox[{"Log", "[", "64", "]"}], ",", "  ", 
       RowBox[{"Log", "[", "1.8", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"40", ",", 
       RowBox[{"Log", "[", "71", "]"}], ",", "  ", 
       RowBox[{"Log", "[", "1.8", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"60", ",", 
       RowBox[{"Log", "[", "37", "]"}], ",", "  ", 
       RowBox[{"Log", "[", "1.8", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"80", ",", 
       RowBox[{"Log", "[", "29", "]"}], ",", "  ", 
       RowBox[{"Log", "[", "1.8", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"190", ",", 
       RowBox[{"Log", "[", "11", "]"}], ",", "  ", 
       RowBox[{"Log", "[", "1.8", "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"370", ",", 
       RowBox[{"Log", "[", "1.7", "]"}], ",", "  ", 
       RowBox[{"Log", "[", "1.8", "]"}]}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[117]:="],

Cell[TextData[{
 "The parameters to be fitted are Intake, AMAD p,  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "pt"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "p"], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "t"], TraditionalForm]]],
 "."
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fitType", "[", 
   RowBox[{
   "p_", ",", "f1_", ",", "s1_", ",", "s2_", ",", "s3_", ",", " ", "t_"}], 
   "]"}], ":=", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x1", ",", "x2"}], "}"}], ",", 
    RowBox[{
     RowBox[{
      RowBox[{"{", 
       RowBox[{"x1", ",", "x2"}], "}"}], " ", "=", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"qWholebody", "[", "t1", "]"}], ",", 
         RowBox[{"qDailyUrine", "[", "t1", "]"}]}], "}"}], "/.", 
       RowBox[{"BiokdataReport", "[", 
        RowBox[{
        "cobalt", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
         "\"\<Automatic\>\"", ",", "1", ",", "  ", 
         RowBox[{"AMADAdultW", "[", "p", "]"}], ",", 
         RowBox[{"{", 
          RowBox[{"s1", ",", "s2", ",", "s3"}], "}"}], ",", " ", "f1", ",", 
         "t1", ",", 
         RowBox[{
          RowBox[{"Log", "[", "2", "]"}], "/", 
          RowBox[{"(", 
           RowBox[{"5.27", "*", "365.24"}], ")"}]}]}], "]"}]}]}], ";", 
     RowBox[{"FindMinimum", "[", 
      RowBox[{
       RowBox[{"X2FitE", "[", 
        RowBox[{
         RowBox[{"{", "int", "}"}], ",", "sampleWBCo60L", " ", ",", 
         RowBox[{
          RowBox[{"Log", "[", 
           RowBox[{"int", " ", "x1"}], "]"}], "/.", 
          RowBox[{"t1", "\[Rule]", "t"}]}], ",", " ", "sampleUriCo60L", "  ", 
         ",", " ", 
         RowBox[{
          RowBox[{"Log", "[", 
           RowBox[{"int", " ", "x2"}], "]"}], "/.", 
          RowBox[{"t1", "\[Rule]", "t"}]}], ",", "  ", "t"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{"int", ",", " ", 
         RowBox[{"10", "^", "5"}], ",", " ", 
         RowBox[{"10", "^", "6"}]}], "}"}]}], "]"}]}]}], "]"}]}]], "Input",
 CellLabel->"In[118]:="],

Cell["The below calculation will take a long time (a few minutes).", "Text",
 CellChangeTimes->{{3.3985928424620457`*^9, 3.3985928564969893`*^9}, {
  3.5396992845672483`*^9, 3.539699292692404*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"todos", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"Flatten", "[", 
      RowBox[{"{", 
       RowBox[{"p", ",", "f1", ",", "s1", ",", "s2", ",", "s3", ",", 
        RowBox[{"fitType", "[", 
         RowBox[{"p", ",", "f1", ",", "s1", ",", "s2", ",", "s3", ",", "t"}], 
         "]"}]}], "}"}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", " ", "4.5", ",", "5.5", ",", " ", "0.5"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"f1", ",", "0.06", ",", "0.1", ",", "0.04"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s1", ",", "9", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s2", ",", "90", ",", "100", ",", "10"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"s3", ",", "0.0002", ",", "0.002", ",", "0.0005"}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellLabel->"In[119]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"todos1", " ", "=", 
   RowBox[{"Flatten", "[", 
    RowBox[{"todos", ",", "4"}], "]"}]}], ";", 
  RowBox[{"ji2", "=", 
   RowBox[{
    RowBox[{"Transpose", "[", "todos1", "]"}], "[", 
    RowBox[{"[", "6", "]"}], "]"}]}], ";", 
  RowBox[{"ps", "=", 
   RowBox[{"Position", "[", 
    RowBox[{"ji2", ",", 
     RowBox[{"Min", "[", "ji2", "]"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[120]:="],

Cell["The best fit obtained correspond to", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
   "amadp", ",", " ", "ff1", ",", "s1", ",", "s2", ",", "s3", ",", "min", ",",
     "inp"}], "}"}], " ", "=", " ", 
  RowBox[{
   RowBox[{"Extract", "[", 
    RowBox[{"todos1", ",", "ps"}], "]"}], "[", 
   RowBox[{"[", "1", "]"}], "]"}]}]], "Input",
 CellLabel->"In[121]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "5.5`", ",", "0.1`", ",", "10", ",", "90", ",", "0.0007`", ",", 
   "15.514118178939771`", ",", 
   RowBox[{"int", "\[Rule]", "398550.9996276666`"}]}], "}"}]], "Output",
 CellChangeTimes->{3.4800945888512306`*^9, 3.480096349899*^9, 
  3.4801568078845997`*^9, 3.480157961645*^9, 3.518532640656173*^9, 
  3.5396993168178673`*^9, 3.643610083836879*^9},
 CellLabel->"Out[121]="]
}, Open  ]],

Cell["\<\
Here are compared the \"experimental\" data with the fitted functions\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"I1", "=", 
   RowBox[{"int", "/.", "inp"}]}], ";"}]], "Input",
 CellLabel->"In[122]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"cobaltwb", "[", "t_", "]"}], ",", " ", 
     RowBox[{"cobaltURI", "[", "t_", "]"}]}], "}"}], "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"qWholebody", "[", "t", "]"}], ",", 
      RowBox[{"qDailyUrine", "[", "t", "]"}]}], "}"}], "/.", 
    RowBox[{"BiokdataReport", "[", " ", 
     RowBox[{
     "cobalt", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
      "\"\<Automatic\>\"", ",", "1", ",", 
      RowBox[{"AMADAdultW", "[", "amadp", "]"}], "  ", ",", 
      RowBox[{"{", 
       RowBox[{"s1", ",", "s2", ",", "s3"}], "}"}], ",", " ", "ff1", ",", "t",
       ",", 
      RowBox[{
       RowBox[{"Log", "[", "2", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"5.27", "*", "365.24"}], ")"}]}]}], "]"}]}]}], ";"}]], "Input",
 CellLabel->"In[123]:="],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"I1", " ", 
      RowBox[{"cobaltwb", "[", "t1", "]"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"t1", ",", " ", "1", ",", " ", "400"}], "}"}], ",", " ", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<days\>\"", ",", " ", "\"\<Bq\>\""}], "}"}]}], ",", " ", 
     RowBox[{"Epilog", " ", ":>", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", " ", 
          RowBox[{"Orange", ",", " ", 
           RowBox[{"PointSize", "[", ".02", "]"}], ",", " ", 
           RowBox[{"Point", "[", "##", "]"}]}], "}"}], " ", "&"}], ",", " ", 
        "sampleWBCo60"}], "]"}]}]}], "]"}], " "}],
  FormatType->StandardForm]], "Input",
 CellLabel->"In[124]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwVznk81AkDx3HJk6ODVGKTzbEVI8syuZqnL4Z1HyM63KzcR2j8qByNVo7k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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"days\"", TraditionalForm], 
    FormBox["\"Bq\"", TraditionalForm]},
  AxesOrigin->{0, 7000.},
  DisplayFunction->Identity,
  Epilog->{{
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{10, 23900}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{14, 29200}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{17, 20100}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{20, 18200}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{27, 21600}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{40, 19800}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{60, 21600}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{80, 17500}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{190, 11600}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{370, 8100}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{747, 4800}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{1010, 2700}]}},
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{1, 400}, {7796.868167247696, 25716.752473222514`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3985929292092776`*^9, 3.4138024139027195`*^9, 
  3.4800945924080305`*^9, 3.4800963532374*^9, 3.4801568113634*^9, 
  3.4801579672454*^9, 3.51853264489063*^9, 3.539699319317915*^9, 
  3.6436100851337557`*^9},
 CellLabel->"Out[124]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 StyleBox[
  RowBox[{" ", 
   RowBox[{"Plot", "[", 
    RowBox[{
     RowBox[{"I1", "  ", 
      RowBox[{"cobaltURI", "[", "t1", "]"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"t1", ",", " ", "1", ",", " ", "400"}], "}"}], ",", " ", 
     RowBox[{"AxesLabel", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"\"\<days\>\"", ",", " ", "\"\<Bq/day\>\""}], "}"}]}], ",", 
     " ", 
     RowBox[{"Epilog", " ", ":>", " ", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"{", " ", 
          RowBox[{"Orange", ",", " ", 
           RowBox[{"PointSize", "[", ".02", "]"}], ",", " ", 
           RowBox[{"Point", "[", "##", "]"}]}], "}"}], " ", "&"}], ",", " ", 
        "sampleUriCo60"}], "]"}]}]}], "]"}], " "}],
  FormatType->StandardForm]], "Input",
 CellLabel->"In[125]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwVz2k41AsDhnFFp6xRRrJli2rKUtax9BgzjK1hbIXKVA6SxhZ/HVs4slSX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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{
    FormBox["\"days\"", TraditionalForm], 
    FormBox["\"Bq/day\"", TraditionalForm]},
  AxesOrigin->{0, 4.},
  DisplayFunction->Identity,
  Epilog->{{
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{14, 709}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{27, 64}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{40, 71}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{60, 37}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{80, 29}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{190, 11}]}, {
     RGBColor[1, 0.5, 0], 
     PointSize[0.02], 
     PointBox[{370, 1.7}]}},
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{"DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None},
  PlotRange->{{1, 400}, {5.236015082464443, 50.54161813993005}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3985929294285736`*^9, 3.4138024532933445`*^9, 
  3.480094592517231*^9, 3.4800963533622*^9, 3.4801568115038*^9, 
  3.4801579674014*^9, 3.518532645062508*^9, 3.539699319442918*^9, 
  3.643610085180632*^9},
 CellLabel->"Out[125]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Doses ", "SubsubsectionFirst",
 CellChangeTimes->{{3.398593303641534*^9, 3.398593332870558*^9}, 
   3.4138025061058445`*^9}],

Cell[TextData[{
 "Then we can computed the equivalent doses using the ",
 StyleBox["Doses", "Input"],
 " package included in the new version of ",
 StyleBox["Biokmod", "Input"],
 ". . It can be used for computing,  over a period \[Tau], the acumulated \
disintegration ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["U", "s"], "(", "\[Tau]", ")"}], TraditionalForm]]],
 ", the committed effective doses ",
 Cell[BoxData[
  FormBox["e", TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "\[Tau]", ")"}], TraditionalForm]]],
 " and the equivalent doses ",
 Cell[BoxData[
  FormBox["H", TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "\[Tau]", ")"}], TraditionalForm]]],
 " . The SEE factors, require for computing ",
 Cell[BoxData[
  FormBox["e", TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "\[Tau]", ")"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["H", TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "\[Tau]", ")"}], TraditionalForm]]],
 ", are included for some selected isotopes, in the other cases the SEE \
factors can be introduced as input data (It can be obtained using DCAL \
(SEECAL). It can be downloaded at http://ordose.ornl.gov/downloads.html )."
}], "Text"],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellLabel->"In[126]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Biokmod`Doses`\>\"", "]"}]], "Input",
 CellLabel->"In[1]:="],

Cell[BoxData["\<\"Resptract 1.2  2005-05-16\"\>"], "Print",
 CellChangeTimes->{3.3985930331085896`*^9, 3.4138024706370945`*^9, 
  3.4138025359808445`*^9, 3.480665473767872*^9, 3.539699505805871*^9, 
  3.5920646301712236`*^9, 3.643610120680696*^9},
 CellLabel->"During evaluation of In[1]:="],

Cell[BoxData["\<\"SysModel, version 1.5.1   2013-11-12\"\>"], "Print",
 CellChangeTimes->{3.3985930331085896`*^9, 3.4138024706370945`*^9, 
  3.4138025359808445`*^9, 3.480665473767872*^9, 3.539699505805871*^9, 
  3.5920646301712236`*^9, 3.643610120680696*^9},
 CellLabel->"During evaluation of In[1]:="],

Cell[BoxData["\<\"Humorap 3.7b1 2015-06-15\"\>"], "Print",
 CellChangeTimes->{3.3985930331085896`*^9, 3.4138024706370945`*^9, 
  3.4138025359808445`*^9, 3.480665473767872*^9, 3.539699505805871*^9, 
  3.5920646301712236`*^9, 3.643610120711936*^9},
 CellLabel->"During evaluation of In[1]:="],

Cell[BoxData["\<\"Biokdata 1.2.2 2004-09-3\"\>"], "Print",
 CellChangeTimes->{3.3985930331085896`*^9, 3.4138024706370945`*^9, 
  3.4138025359808445`*^9, 3.480665473767872*^9, 3.539699505805871*^9, 
  3.5920646301712236`*^9, 3.6436101207588224`*^9},
 CellLabel->"During evaluation of In[1]:="],

Cell[BoxData["\<\" Doses 1.1   2011-07-11\"\>"], "Print",
 CellChangeTimes->{3.3985930331085896`*^9, 3.4138024706370945`*^9, 
  3.4138025359808445`*^9, 3.480665473767872*^9, 3.539699505805871*^9, 
  3.5920646301712236`*^9, 3.64361012107131*^9},
 CellLabel->"During evaluation of In[1]:="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "amadp", ",", " ", "ff1", ",", "s1", ",", "s2", ",", "s3", ",", "inp"}], 
    "}"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "5.5", ",", "  ", "0.1", ",", " ", "10", ",", " ", "90", ",", " ", 
     "0.0007", ",", " ", "398551"}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[2]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{"\"\<Co 60\>\"", ",", "\"\<Inhalation\>\"", ",", "inp", ",", 
   RowBox[{"AMADAdultW", "[", "amadp", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s1", ",", " ", "s2", ",", " ", "s3"}], "}"}], ",", "ff1", ",", 
   RowBox[{"50", "*", "365.25"}]}], "]"}]], "Input",
 CellLabel->"In[3]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox[
    StyleBox["\<\"\\nAccumulted disintegration, in Bq, as function of the \
time\\n\"\>",
     FontFamily->"Times",
     FontSize->12,
     FontWeight->"Bold"],
    StyleForm[#, FontFamily -> "Times", FontSize -> 12, FontWeight -> 
     "Bold"]& ], "\[InvisibleSpace]", 
   TagBox[
    TagBox[GridBox[{
       {
        TagBox["\<\"Compartment\"\>",
         HoldForm], 
        TagBox[
         RowBox[{"18262.5`", " ", "\<\"day\"\>"}],
         HoldForm]},
       {"\<\"AI\"\>", "1.4760354831193464`*^6"},
       {"\<\"bb1\"\>", "1349.2424093195727`"},
       {"\<\"bb2\"\>", "10178.302585497318`"},
       {"\<\"bbseq\"\>", "512.2457992363023`"},
       {"\<\"BB1\"\>", "390.7421108730792`"},
       {"\<\"BB2\"\>", "13944.477180272479`"},
       {"\<\"BBseq\"\>", "847.0898194449255`"},
       {"\<\"ET2\"\>", "371.23798924143`"},
       {"\<\"ET1\"\>", "29607.70237955229`"},
       {"\<\"ETseq\"\>", "7546.294242983589`"},
       {"\<\"LNth\"\>", "18869.495509578424`"},
       {"\<\"LNet\"\>", "7118.449257372645`"},
       {"\<\"ST\"\>", "1546.801746621267`"},
       {"\<\"SI\"\>", "5568.18552125692`"},
       {"\<\"B\"\>", "5171.06924453489`"},
       {"\<\"ULI\"\>", "19104.88327456838`"},
       {"\<\"LLI\"\>", "34377.27668259203`"},
       {"\<\"Other\"\>", "663196.391668358`"},
       {"\<\"Liver\"\>", "0.`"},
       {"\<\"UB_Content\"\>", "493.2666118388189`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[2.0999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     {None, OutputFormsDump`HeadedColumns}],
    Function[BoxForm`e$, 
     TableForm[
     BoxForm`e$, TableHeadings -> {None, {"Compartment", 18262.5 "day"}}]]], 
   "\[InvisibleSpace]", 
   TagBox[
    StyleBox["\<\"\\nDose accumulated, in Sv, as function of the time\\n\"\>",
     FontFamily->"Times",
     FontSize->12,
     FontWeight->"Bold"],
    StyleForm[#, FontFamily -> "Times", FontSize -> 12, FontWeight -> 
     "Bold"]& ], "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"\<\"Sv/Bq\"\>", 
       RowBox[{"18262.5`", " ", "\<\"day\"\>"}]},
      {"\<\"Testes\"\>", "0.0006471949991141813`"},
      {"\<\"Ovarius\"\>", "0.0012416685712395164`"},
      {"\<\"Red Marrow\"\>", "0.0018866439785832126`"},
      {"\<\"Colon\"\>", "0.0020344876355742557`"},
      {"\<\"Lungs\"\>", "0.02373583057224951`"},
      {"\<\"St Wall\"\>", "0.0019343290770839658`"},
      {"\<\"Bladder Wall\"\>", "0.0008606105190791268`"},
      {"\<\"Mama\"\>", "0.0029077818351623953`"},
      {"\<\"Liver\"\>", "0.0023275088209120066`"},
      {"\<\"Oesophagus\"\>", "0.003446119311465627`"},
      {"\<\"Thyroid\"\>", "0.0016215590004709129`"},
      {"\<\"Skin\"\>", "0.0009754084243855861`"},
      {"\<\"Bone Surface\"\>", "0.0016185817438510138`"},
      {"\<\"Muscle\"\>", "0.0016057141280610113`"},
      {"\<\"Brain\"\>", "0.0007291127761618344`"},
      {"\<\"Small intestine\"\>", "0.0013231225135026177`"},
      {"\<\"Kidneys\"\>", "0.0015072996902680128`"},
      {"\<\"Pancreas\"\>", "0.0023283069751611463`"},
      {"\<\"Spleen\"\>", "0.0023360271792699557`"},
      {"\<\"Thymus\"\>", "0.003446119311465627`"},
      {"\<\"Uterus\"\>", "0.0010171914225342977`"},
      {"\<\"Adrenals\"\>", "0.0028837632830632995`"},
      {"\<\"Extrathoracic airways\"\>", "0.020369756297647604`"},
      {"\<\"Effective, e(50)\"\>", "0.0044621555362132454`"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]]}],
  SequenceForm[
   StyleForm[
   "\nAccumulted disintegration, in Bq, as function of the time\n", 
    FontFamily -> "Times", FontSize -> 12, FontWeight -> "Bold"], 
   TableForm[{{"AI", 1.4760354831193464`*^6}, {"bb1", 1349.2424093195727`}, {
     "bb2", 10178.302585497318`}, {"bbseq", 512.2457992363023}, {
     "BB1", 390.7421108730792}, {"BB2", 13944.477180272479`}, {
     "BBseq", 847.0898194449255}, {"ET2", 371.23798924143}, {
     "ET1", 29607.70237955229}, {"ETseq", 7546.294242983589}, {
     "LNth", 18869.495509578424`}, {"LNet", 7118.449257372645}, {
     "ST", 1546.801746621267}, {"SI", 5568.18552125692}, {
     "B", 5171.06924453489}, {"ULI", 19104.88327456838}, {
     "LLI", 34377.27668259203}, {"Other", 663196.391668358}, {"Liver", 0.}, {
     "UB_Content", 493.2666118388189}}, 
    TableHeadings -> {None, {"Compartment", 18262.5 "day"}}], 
   StyleForm[
   "\nDose accumulated, in Sv, as function of the time\n", FontFamily -> 
    "Times", FontSize -> 12, FontWeight -> "Bold"], 
   TableForm[{{"Sv/Bq", 18262.5 "day"}, {"Testes", 0.0006471949991141813}, {
     "Ovarius", 0.0012416685712395164`}, {
     "Red Marrow", 0.0018866439785832126`}, {
     "Colon", 0.0020344876355742557`}, {"Lungs", 0.02373583057224951}, {
     "St Wall", 0.0019343290770839658`}, {
     "Bladder Wall", 0.0008606105190791268}, {
     "Mama", 0.0029077818351623953`}, {"Liver", 0.0023275088209120066`}, {
     "Oesophagus", 0.003446119311465627}, {
     "Thyroid", 0.0016215590004709129`}, {"Skin", 0.0009754084243855861}, {
     "Bone Surface", 0.0016185817438510138`}, {
     "Muscle", 0.0016057141280610113`}, {"Brain", 0.0007291127761618344}, {
     "Small intestine", 0.0013231225135026177`}, {
     "Kidneys", 0.0015072996902680128`}, {
     "Pancreas", 0.0023283069751611463`}, {
     "Spleen", 0.0023360271792699557`}, {"Thymus", 0.003446119311465627}, {
     "Uterus", 0.0010171914225342977`}, {
     "Adrenals", 0.0028837632830632995`}, {
     "Extrathoracic airways", 0.020369756297647604`}, {
     "Effective, e(50)", 0.0044621555362132454`}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.4138025060433445`*^9, 3.4138025436839695`*^9, 
  3.480665488346184*^9, 3.539699510259081*^9, 3.592064637056912*^9, 
  3.6436101224775743`*^9},
 CellLabel->"During evaluation of In[3]:="]
}, Open  ]],

Cell["\<\
The committed effective dose, E(50) calculated using these values is:  4.46 \
mSv\
\>", "MathCaption"]
}, Open  ]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conclusion", "Section"],

Cell["\<\
There are some good computer codes that can be applied in the interpretation \
of bioassay data. We have developed a new one, BIOKMOD, with some innovations \
that can be useful mainly for advanced studies. The standard version of \
BIOKMOD is available for free download at the author web \
side:http://diarium.usal.es/guillermo. Furthermore there is a web version \
(available at http://www3.enusa.es/webMathematica/Public/biokmod.html , \
sponsored by ENUSA Industrias Avanzadas. S.A) and therefore it can be used \
everywhere where an internet connection exists.\
\>", "Text",
 CellChangeTimes->{3.5920646838315887`*^9}],

Cell["\<\
BIOKMOD has been used in the evaluation of internal exposures using the \
bioassay data: Multiple constant and random intakes in occupational exposures \
taking into account periods without intake (weekends, holidays, etc.) has \
been described; an analytical method to evaluate the statistical \
uncertainties associated with the biokinetic model has been developed; non \
linear techniques have been applied to estimate the intakes using bioassay \
data.\
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Section"],

Cell[TextData[{
 "Ansoborlo, E. Berard, P. Eckermann, K. Berkovski, V. Birchall, A.. Fry, F. \
Guilmette, R. Miller, G.  Ishigure, N.  Lipsztein, J. and Nosske, D.  Review \
of methods and computer codes for interpretation of bioassay data. Radiat \
Prot Dosimetry. 105: 341-346; 2003.\nBertelli, L. Lipsztein J.L.  A \
mathematical simulation for the study of  radionuclide kinetics in the Human \
Body. Radiat Prot Dosimetry. 18-4: 409-214; 1987.\nBirchall, M. Puncher, A. \
C. James, J. W. Marsh, N. S. Jarvis, M. S. Peace, K. Davis and D. J. King. \
IMBA expert(r): Internal dosimetry made simple. Radiat Prot Dosimetry. 105: \
421- 425; 2003.\nDoerfel H. EULEP/EURADOS Feedback: 3rd European \
Intercomparison Exercise on Internal Dose Assessment. Proceedings of 3",
 StyleBox["rd",
  FontVariations->{"CompatibilityType"->"Superscript"}],
 " European ALARA Network Workshop. Munich 1999.\nEckerman K.F. at al. User`s \
Guide to the DCAL System. ORNL/TM-2001/190 August 2006\nFrench, CS. Skrable, \
KW. Tries, M. Medich, D. Lorenzen, W. ",
 StyleBox["Development and Implementation of an Internal Radiation Safety \
Program for Academic and Biomedical Institutions",
  FontSlant->"Italic"],
 ". Chapter 3 in: Belanger R, and Papin JP, ed. University Health Physics: \
Madison, WI;  Medical Physics Publishing; 2003.\nInternational Commission on \
Radiological Protection, Limits for Intakes of Radionuclides by Workers. ICRP \
Publication 30. Oxford: Pergamon Press; 1979.\nInternational Commission on \
Radiological Protection, Human Respiratory Tract Model for Radiological \
Protection ICRP Publication 66. Oxford: Pergamon Press; 1994.\nInternational \
Commission on Radiological Protection, Individual monitoring for internal \
exposure of workers. ICRP Publication 78. Oxford: Pergamon Press; 1997.\n\
International Commission on Radiological Protection. ICRP Database of Dose \
Coefficients: Workers and Members of the Public. Version 2.0.1 (CD-ROM), \
Oxford: Pergamon Press; 2001.\nInternational Commission on Radiological \
Protection. Draft guidance document: Bioassay data interpretation. \
http://www.icrp.org/news_guidance.asp [Accessed 15 June 2006]); 2006.\n\
Loevinger, R. Budinger, T. Watson, E. MIRD primer for absorbed dose \
calculations. New York: Society of Nuclear Medicine; 1988.\nLopez-Fidalgo, J. \
Sanchez, G. Statistical criteria to establish bioassay programs, health phys. \
Health Phys. 89(4): 333-338; 2005.\n",
 StyleBox["Lopez-Fidalgo, J.  Rodriguez-Diaz, JM. Sanchez, G. Santos-Martin, \
MT. ",
  FontFamily->"Times New Roman"],
 "Optimal designs for compartmental models with correlated observations. \
Journal of Applied Statistics: 32(10) 1075-1088; 2005.\nPotter Charles A. \
Intake Retention Fractions Developed from Models Used in the Determination of \
Dose Coefficients Developed for ICRP Publication 68.  Special Issue. Health \
Phys: 83(5); 2002.\nSanchez G, Lopez-Fidalgo, J. Mathematical techniques for \
solving analytically large compartmental systems, Health Phys: 85(2):184 \
-193; 2003.\nSanchez, G.  BIOKMOD: A Mathematica toolbox for modeling \
Biokinetic Systems. Mathematica in Education and Research 10(2): 50 - 70 ; \
2005.\nSkrable, KW.  French, C. Chabot, G. Major, A..  A general equation for \
the kinetics of linear first order phenomena and suggested applications. \
Health Physics 27: 155-157; 1974.\nSkrable KW, Chabot GE, French CS, La Bone \
TR. Intake retention functions and their applications to bioassay and the \
estimation of internal radiation doses. Health Phys 55:933-950; 1988.\n\
Skrable, KW.  French, CS. Chabot, GE. Tries, M. La Bone M. ",
 StyleBox["Variance Models for estimating intakes from repetitive bioassay \
measurements",
  FontSlant->"Italic"],
 ". Chapter 5 in: Both WE, ed. Practical applications of internal dosimetry: \
Madison, WI; Medical Physics Publishing; 2002."
}], "SmallText"]
}, Closed]]
}, Open  ]]
},
ScreenStyleEnvironment->"Brackets",
WindowToolbars->"EditBar",
WindowSize->{1658, 948},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
   Cell[
    TextData[
     StyleBox[
      CounterBox["Page"], "PageNumber"]], "Header", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, 
   Cell[
    TextData[
     StyleBox[
      RowBox[{"Printed", " ", "from", " ", "the", " ", 
        StyleBox["Mathematica", FontSlant -> "Italic"], " ", "Help", " ", 
        "Browser"}], "PageHeader"]], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}, {None, 
   Cell[
    TextData["Biokmod"], "Header"], 
   Cell[
    TextData[
     StyleBox[
      CounterBox["Page"], "PageNumber"]], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}},
PageFooters->{{None, 
   Cell[
    TextData[
     StyleBox[
      RowBox[{
       "\[Copyright]2013", " ", "Guillermo", " ", "Sanchez", " ", "and", " ", 
        "ENUSA", ".", " ", "All", " ", "rights", " ", "reserved", "."}], 
      "PageFooter"]], "Footer"], None}, {None, 
   Cell[
    TextData[
     StyleBox[
      RowBox[{
       "http", ":", "//", "diarium", ".", "usal", ".", "es", "/", 
        "guillermo"}], "PageFooter"]], "Footer"], None}},
PageHeaderLines->{True, True},
PageFooterLines->{True, True},
PrintingOptions->{"FacingPages"->True,
"FirstPageFace"->Right,
"FirstPageFooter"->True,
"FirstPageHeader"->True},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"10.0 for Microsoft Windows (64-bit) (December 4, 2014)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3643617131-9686839"->{
  Cell[215822, 4032, 343, 6, 148, "Print",
   CellTags->"Info3643617131-9686839"]},
 "Info3643617144-9686839"->{
  Cell[342478, 7085, 343, 6, 148, "Print",
   CellTags->"Info3643617144-9686839"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3643617131-9686839", 652375, 15175},
 {"Info3643617144-9686839", 652488, 15178}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 97, 2, 128, "Chapter"],
Cell[667, 26, 382, 9, 32, "Text"],
Cell[1052, 37, 628, 10, 41, "Commentary"],
Cell[CellGroupData[{
Cell[1705, 51, 57, 1, 37, "Input"],
Cell[1765, 54, 407, 7, 35, "Output"]
}, Open  ]],
Cell[2187, 64, 74, 0, 32, "Text"],
Cell[2264, 66, 857, 32, 111, "DefinitionBox"],
Cell[CellGroupData[{
Cell[3146, 102, 32, 0, 48, "Subsubsection"],
Cell[3181, 104, 1211, 19, 164, "Commentary"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4429, 128, 40, 0, 56, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[4494, 132, 105, 2, 37, "Input"],
Cell[4602, 136, 147, 2, 29, "Print"],
Cell[4752, 140, 158, 2, 29, "Print"],
Cell[4913, 144, 144, 2, 29, "Print"],
Cell[5060, 148, 146, 2, 29, "Print"],
Cell[5209, 152, 177, 3, 29, "Print"]
}, Open  ]],
Cell[5401, 158, 135, 3, 37, "Input",
 CellID->72157237]
}, Closed]],
Cell[CellGroupData[{
Cell[5573, 166, 31, 0, 52, "Section"],
Cell[5607, 168, 5113, 96, 603, "Text"],
Cell[10723, 266, 484, 8, 75, "Text"],
Cell[11210, 276, 689, 12, 75, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[11936, 293, 38, 0, 52, "Section"],
Cell[CellGroupData[{
Cell[11999, 297, 41, 0, 56, "Subsection"],
Cell[12043, 299, 335, 6, 54, "Text"],
Cell[12381, 307, 1972, 50, 165, "Text"],
Cell[14356, 359, 1463, 43, 97, "Text"],
Cell[15822, 404, 909, 13, 118, "Text"],
Cell[16734, 419, 80051, 991, 517, "Text"],
Cell[96788, 1412, 734, 11, 115, "Commentary"],
Cell[97525, 1425, 923, 19, 99, "Text"],
Cell[98451, 1446, 489, 22, 32, "Text"],
Cell[98943, 1470, 234, 8, 41, "NumberedEquation"],
Cell[99180, 1480, 250, 8, 32, "Text"],
Cell[99433, 1490, 706, 20, 45, "NumberedEquation"],
Cell[100142, 1512, 849, 29, 54, "Text"],
Cell[100994, 1543, 424, 15, 93, "NumberedEquation"],
Cell[101421, 1560, 603, 16, 54, "Text"],
Cell[102027, 1578, 424, 15, 93, "NumberedEquation"],
Cell[102454, 1595, 641, 15, 113, "Text"],
Cell[103098, 1612, 559, 19, 98, "NumberedEquation"],
Cell[103660, 1633, 1496, 43, 105, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[105193, 1681, 35, 0, 47, "Subsection"],
Cell[105231, 1683, 371, 15, 32, "Text"],
Cell[105605, 1700, 230, 7, 41, "NumberedEquation"],
Cell[105838, 1709, 72, 0, 56, "MathCaption"],
Cell[105913, 1711, 950, 30, 84, "DefinitionBox"],
Cell[106866, 1743, 435, 14, 41, "Commentary"],
Cell[CellGroupData[{
Cell[107326, 1761, 999, 25, 67, "Input"],
Cell[108328, 1788, 6541, 174, 209, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[114918, 1968, 36, 0, 47, "Subsection"],
Cell[114957, 1970, 802, 30, 32, "Text"],
Cell[115762, 2002, 922, 29, 91, "NumberedEquation"],
Cell[116687, 2033, 62, 0, 56, "MathCaption"],
Cell[116752, 2035, 782, 29, 57, "FramedBox"],
Cell[117537, 2066, 956, 34, 92, "MathCaption"],
Cell[118496, 2102, 274, 8, 37, "Input"],
Cell[CellGroupData[{
Cell[118795, 2114, 504, 14, 37, "Input"],
Cell[119302, 2130, 4224, 81, 345, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[123575, 2217, 39, 0, 47, "Subsection"],
Cell[123617, 2219, 286, 11, 62, "Text"],
Cell[123906, 2232, 473, 15, 91, "NumberedEquation"],
Cell[124382, 2249, 62, 0, 56, "MathCaption"],
Cell[124447, 2251, 685, 26, 57, "FramedBox"],
Cell[125135, 2279, 320, 10, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[125480, 2293, 604, 17, 37, "Input"],
Cell[126087, 2312, 52339, 870, 347, "Output"]
}, Open  ]],
Cell[178441, 3185, 869, 28, 79, "MathCaption"],
Cell[179313, 3215, 438, 7, 78, "MathCaption"],
Cell[CellGroupData[{
Cell[179776, 3226, 675, 21, 37, "Input"],
Cell[180454, 3249, 4451, 111, 151, "Output"]
}, Open  ]],
Cell[184920, 3363, 313, 11, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[185258, 3378, 298, 7, 37, "Input"],
Cell[185559, 3387, 26714, 501, 489, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[212322, 3894, 45, 0, 47, "Subsection"],
Cell[212370, 3896, 1215, 49, 32, "Text"],
Cell[213588, 3947, 917, 32, 79, "NumberedEquation"],
Cell[214508, 3981, 318, 9, 36, "Text"],
Cell[214829, 3992, 753, 26, 84, "NumberedEquation"],
Cell[215585, 4020, 111, 3, 57, "MathCaption"],
Cell[CellGroupData[{
Cell[215721, 4027, 98, 3, 37, "Input"],
Cell[215822, 4032, 343, 6, 148, "Print",
 CellTags->"Info3643617131-9686839"]
}, Open  ]],
Cell[216180, 4041, 408, 12, 56, "MathCaption"],
Cell[216591, 4055, 611, 19, 37, "Input"],
Cell[217205, 4076, 131, 3, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[217361, 4083, 724, 19, 37, "Input"],
Cell[218088, 4104, 14952, 263, 361, "Output"]
}, Open  ]],
Cell[233055, 4370, 45, 0, 56, "MathCaption"],
Cell[233103, 4372, 1110, 36, 80, "DefinitionBox"],
Cell[234216, 4410, 180, 6, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[234421, 4420, 279, 6, 37, "Input"],
Cell[234703, 4428, 365, 6, 35, "Output"]
}, Open  ]],
Cell[235083, 4437, 318, 11, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[235426, 4452, 250, 7, 37, "Input"],
Cell[235679, 4461, 365, 6, 35, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[236093, 4473, 47, 0, 47, "Subsection"],
Cell[236143, 4475, 1761, 69, 58, "Text"],
Cell[237907, 4546, 1055, 45, 32, "Text"],
Cell[238965, 4593, 162, 6, 32, "Text"],
Cell[239130, 4601, 895, 27, 58, "EquationNumber"],
Cell[240028, 4630, 93, 2, 32, "Text"],
Cell[240124, 4634, 1138, 40, 79, "NumberedEquation"],
Cell[241265, 4676, 243, 5, 33, "Text"],
Cell[241511, 4683, 459, 7, 90, "Commentary"],
Cell[241973, 4692, 72, 0, 56, "MathCaption"],
Cell[242048, 4694, 276, 8, 37, "Input"],
Cell[242327, 4704, 470, 20, 70, "MathCaption"],
Cell[242800, 4726, 175, 5, 37, "Input"],
Cell[242978, 4733, 439, 14, 37, "Input"],
Cell[243420, 4749, 92, 2, 56, "MathCaption"],
Cell[243515, 4753, 115, 3, 37, "Input"],
Cell[CellGroupData[{
Cell[243655, 4760, 127, 3, 37, "Input"],
Cell[243785, 4765, 350, 6, 55, "Output"]
}, Open  ]],
Cell[244150, 4774, 75, 0, 56, "MathCaption"],
Cell[244228, 4776, 4537, 127, 200, "Input"],
Cell[CellGroupData[{
Cell[248790, 4907, 119, 3, 37, "Input"],
Cell[248912, 4912, 336, 5, 35, "Output"]
}, Open  ]],
Cell[249263, 4920, 85, 2, 32, "Text"],
Cell[CellGroupData[{
Cell[249373, 4926, 125, 3, 37, "Input"],
Cell[249501, 4931, 326, 5, 35, "Output"]
}, Open  ]],
Cell[249842, 4939, 106, 3, 32, "Text"],
Cell[249951, 4944, 491, 14, 37, "Input"],
Cell[250445, 4960, 63, 0, 32, "Text"],
Cell[250511, 4962, 357, 10, 37, "Input"],
Cell[250871, 4974, 56, 0, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[250952, 4978, 695, 19, 65, "Input"],
Cell[251650, 4999, 90192, 2062, 359, "Output"]
}, Open  ]],
Cell[341857, 7064, 277, 5, 66, "Commentary"],
Cell[342137, 7071, 196, 4, 57, "MathCaption"],
Cell[CellGroupData[{
Cell[342358, 7079, 117, 4, 37, "Input"],
Cell[342478, 7085, 343, 6, 148, "Print",
 CellTags->"Info3643617144-9686839"]
}, Open  ]],
Cell[342836, 7094, 383, 11, 37, "Input"],
Cell[CellGroupData[{
Cell[343244, 7109, 599, 18, 37, "Input"],
Cell[343846, 7129, 969, 24, 134, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[344864, 7159, 37, 0, 47, "Subsection"],
Cell[344904, 7161, 1132, 33, 77, "Text"],
Cell[346039, 7196, 725, 24, 76, "NumberedEquation"],
Cell[346767, 7222, 2100, 74, 122, "Text"],
Cell[348870, 7298, 354, 10, 41, "Commentary"],
Cell[349227, 7310, 122, 3, 56, "MathCaption"],
Cell[349352, 7315, 607, 18, 65, "Input"],
Cell[349962, 7335, 1242, 36, 151, "Input"],
Cell[CellGroupData[{
Cell[351229, 7375, 87, 2, 37, "Input"],
Cell[351319, 7379, 27269, 458, 358, "Output"]
}, Open  ]],
Cell[378603, 7840, 296, 9, 37, "Input"],
Cell[378902, 7851, 38, 0, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[378965, 7855, 164, 5, 37, "Input"],
Cell[379132, 7862, 387, 7, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[379556, 7874, 229, 7, 37, "Input"],
Cell[379788, 7883, 568, 13, 35, "Output"]
}, Open  ]],
Cell[380371, 7899, 1108, 42, 62, "Text"],
Cell[381482, 7943, 94, 2, 32, "Text"],
Cell[CellGroupData[{
Cell[381601, 7949, 331, 9, 37, "Input"],
Cell[381935, 7960, 331, 5, 35, "Output"]
}, Open  ]],
Cell[382281, 7968, 308, 7, 37, "Input"],
Cell[382592, 7977, 887, 28, 58, "Text"],
Cell[383482, 8007, 562, 11, 90, "Commentary"],
Cell[384047, 8020, 694, 18, 65, "Input"],
Cell[384744, 8040, 518, 15, 64, "Input"],
Cell[385265, 8057, 109, 2, 56, "MathCaption"],
Cell[385377, 8061, 274, 8, 37, "Input"],
Cell[385654, 8071, 247, 8, 37, "Input"],
Cell[385904, 8081, 192, 4, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[386121, 8089, 1095, 26, 37, "Input"],
Cell[387219, 8117, 15637, 257, 350, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[402905, 8380, 37, 0, 47, "Subsection"],
Cell[402945, 8382, 415, 13, 32, "Text"],
Cell[403363, 8397, 391, 13, 46, "NumberedEquation"],
Cell[403757, 8412, 1313, 42, 85, "Text"],
Cell[405073, 8456, 328, 10, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[405426, 8470, 393, 11, 37, "Input"],
Cell[405822, 8483, 942, 22, 38, "Output"]
}, Open  ]],
Cell[406779, 8508, 93, 2, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[406897, 8514, 424, 11, 37, "Input"],
Cell[407324, 8527, 12543, 217, 319, "Output"]
}, Open  ]],
Cell[419882, 8747, 168, 6, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[420075, 8757, 115, 3, 37, "Input"],
Cell[420193, 8762, 335, 5, 38, "Output"]
}, Open  ]],
Cell[420543, 8770, 267, 9, 60, "MathCaption"],
Cell[CellGroupData[{
Cell[420835, 8783, 451, 12, 37, "Input"],
Cell[421289, 8797, 965, 22, 38, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[422291, 8824, 118, 3, 37, "Input"],
Cell[422412, 8829, 327, 5, 35, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[422800, 8841, 56, 0, 93, "Section"],
Cell[422859, 8843, 1320, 44, 119, "Text"],
Cell[424182, 8889, 686, 33, 53, "NumberedEquation"],
Cell[424871, 8924, 1250, 51, 109, "Text"],
Cell[426124, 8977, 701, 25, 63, "NumberedEquation"],
Cell[426828, 9004, 55, 0, 32, "Text"],
Cell[426886, 9006, 1098, 30, 109, "Text"],
Cell[427987, 9038, 111, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[428123, 9045, 265, 9, 45, "SubsubsectionIcon"],
Cell[428391, 9056, 596, 19, 58, "Text"],
Cell[428990, 9077, 327, 10, 37, "Input"],
Cell[429320, 9089, 237, 7, 32, "Text"],
Cell[429560, 9098, 675, 21, 37, "Input"],
Cell[CellGroupData[{
Cell[430260, 9123, 535, 14, 37, "Input"],
Cell[430798, 9139, 7917, 143, 360, "Output"]
}, Open  ]],
Cell[438730, 9285, 313, 5, 54, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[439080, 9295, 286, 10, 38, "SubsubsectionIcon"],
Cell[439369, 9307, 754, 26, 54, "Text"],
Cell[440126, 9335, 619, 26, 35, "Text"],
Cell[440748, 9363, 875, 24, 92, "Input"],
Cell[441626, 9389, 23, 0, 32, "Text"],
Cell[441652, 9391, 491, 14, 39, "Input"],
Cell[442146, 9407, 453, 13, 39, "Input"],
Cell[442602, 9422, 438, 16, 38, "Text"],
Cell[CellGroupData[{
Cell[443065, 9442, 107, 3, 37, "Input"],
Cell[443175, 9447, 6594, 176, 209, "Output"]
}, Open  ]],
Cell[449784, 9626, 616, 18, 37, "Input"],
Cell[CellGroupData[{
Cell[450425, 9648, 551, 15, 37, "Input"],
Cell[450979, 9665, 8022, 144, 360, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[459050, 9815, 283, 10, 35, "SubsubsectionIcon"],
Cell[459336, 9827, 1105, 29, 101, "Text"],
Cell[460444, 9858, 1050, 34, 68, "Text"],
Cell[461497, 9894, 574, 22, 33, "Text"],
Cell[462074, 9918, 388, 14, 37, "Input"],
Cell[CellGroupData[{
Cell[462487, 9936, 287, 9, 37, "Input"],
Cell[462777, 9947, 1889, 58, 63, "Output"]
}, Open  ]],
Cell[464681, 10008, 572, 19, 34, "Text"],
Cell[465256, 10029, 291, 10, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[465572, 10043, 96, 2, 37, "Input"],
Cell[465671, 10047, 1077, 28, 222, "Output"]
}, Open  ]],
Cell[466763, 10078, 50, 0, 32, "Text"],
Cell[466816, 10080, 1089, 27, 137, "Output"],
Cell[467908, 10109, 63, 0, 56, "MathCaption"],
Cell[467974, 10111, 1148, 33, 65, "Input"],
Cell[469125, 10146, 138, 5, 56, "MathCaption"],
Cell[469266, 10153, 1271, 37, 65, "Input"],
Cell[470540, 10192, 317, 10, 56, "MathCaption"],
Cell[470860, 10204, 999, 31, 37, "Input"],
Cell[471862, 10237, 524, 17, 80, "MathCaption"],
Cell[472389, 10256, 883, 28, 37, "Input"],
Cell[CellGroupData[{
Cell[473297, 10288, 429, 11, 37, "Input"],
Cell[473729, 10301, 20087, 421, 345, "Output"]
}, Open  ]],
Cell[493831, 10725, 96, 2, 32, "Text"],
Cell[CellGroupData[{
Cell[493952, 10731, 529, 17, 37, "Input"],
Cell[494484, 10750, 5345, 98, 348, "Output"]
}, Open  ]],
Cell[499844, 10851, 199, 4, 28, "SmallText"],
Cell[500046, 10857, 149, 4, 37, "Input"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[500244, 10867, 40, 0, 52, "Section"],
Cell[CellGroupData[{
Cell[500309, 10871, 44, 0, 33, "SubsubsectionIcon"],
Cell[500356, 10873, 1344, 33, 126, "Text"],
Cell[501703, 10908, 548, 10, 83, "Text"],
Cell[502254, 10920, 854, 32, 129, "NumberedEquation"],
Cell[503111, 10954, 540, 21, 86, "NumberedEquation"],
Cell[503654, 10977, 21, 0, 32, "Text"],
Cell[503678, 10979, 1178, 43, 103, "SmallText"],
Cell[504859, 11024, 75, 0, 32, "Text"],
Cell[504937, 11026, 614, 20, 54, "Text"],
Cell[505554, 11048, 815, 23, 37, "Input"],
Cell[CellGroupData[{
Cell[506394, 11075, 299, 8, 37, "Input"],
Cell[506696, 11085, 467, 9, 35, "Output"]
}, Open  ]],
Cell[507178, 11097, 128, 4, 62, "Text"],
Cell[507309, 11103, 1130, 40, 116, "NumberedEquation"],
Cell[508442, 11145, 355, 11, 32, "Text"],
Cell[CellGroupData[{
Cell[508822, 11160, 302, 8, 37, "Input"],
Cell[509127, 11170, 364, 6, 35, "Output"]
}, Open  ]],
Cell[509506, 11179, 508, 15, 54, "Text"],
Cell[510017, 11196, 1859, 67, 95, "NumberedEquation"],
Cell[511879, 11265, 103, 3, 62, "Text"],
Cell[511985, 11270, 1943, 69, 98, "NumberedEquation"],
Cell[513931, 11341, 75, 0, 32, "Text"],
Cell[514009, 11343, 337, 9, 32, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[514383, 11357, 50, 0, 25, "SubsubsectionIcon"],
Cell[514436, 11359, 917, 26, 75, "Text"],
Cell[515356, 11387, 313, 12, 43, "NumberedEquation"],
Cell[515672, 11401, 385, 16, 44, "Text"],
Cell[516060, 11419, 2729, 104, 101, "Text"],
Cell[518792, 11525, 644, 23, 54, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[519473, 11553, 34, 0, 39, "Subsubsection"],
Cell[519510, 11555, 237, 4, 54, "Text"],
Cell[519750, 11561, 145, 3, 56, "MathCaption"],
Cell[519898, 11566, 1685, 51, 92, "Input"],
Cell[CellGroupData[{
Cell[521608, 11621, 154, 4, 37, "Input"],
Cell[521765, 11627, 1372, 34, 351, "Output"]
}, Open  ]],
Cell[523152, 11664, 160, 3, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[523337, 11671, 382, 11, 37, "Input"],
Cell[523722, 11684, 1443, 35, 67, "Output"]
}, Open  ]],
Cell[525180, 11722, 334, 11, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[525539, 11737, 233, 7, 37, "Input"],
Cell[525775, 11746, 6603, 160, 190, "Output"]
}, Open  ]],
Cell[532393, 11909, 246, 4, 78, "MathCaption"],
Cell[532642, 11915, 140, 4, 37, "Input"],
Cell[532785, 11921, 123, 3, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[532933, 11928, 472, 14, 37, "Input"],
Cell[533408, 11944, 404, 7, 35, "Output"]
}, Open  ]],
Cell[533827, 11954, 55, 0, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[533907, 11958, 86, 2, 37, "Input"],
Cell[533996, 11962, 341, 5, 35, "Output"]
}, Open  ]],
Cell[534352, 11970, 64, 0, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[534441, 11974, 648, 19, 37, "Input"],
Cell[535092, 11995, 4511, 99, 341, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[539652, 12100, 66, 1, 39, "Subsection"],
Cell[539721, 12103, 1192, 37, 56, "Text"],
Cell[540916, 12142, 94, 2, 28, "SmallText"],
Cell[CellGroupData[{
Cell[541035, 12148, 692, 21, 37, "Input"],
Cell[541730, 12171, 773, 20, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[542540, 12196, 32, 0, 33, "SubsubsectionIcon"],
Cell[542575, 12198, 2093, 85, 56, "Text"],
Cell[544671, 12285, 323, 10, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[545019, 12299, 96, 2, 37, "Input"],
Cell[545118, 12303, 1058, 28, 199, "Output"]
}, Open  ]],
Cell[546191, 12334, 554, 15, 37, "Input"],
Cell[546748, 12351, 162, 5, 56, "MathCaption"],
Cell[546913, 12358, 484, 15, 37, "Input"],
Cell[547400, 12375, 238, 9, 56, "MathCaption"],
Cell[547641, 12386, 598, 18, 37, "Input"],
Cell[548242, 12406, 234, 10, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[548501, 12420, 303, 9, 37, "Input"],
Cell[548807, 12431, 472, 10, 35, "Output"]
}, Open  ]],
Cell[549294, 12444, 274, 5, 66, "Commentary"],
Cell[CellGroupData[{
Cell[549593, 12453, 928, 26, 65, "Input"],
Cell[550524, 12481, 13934, 255, 344, "Output"]
}, Open  ]],
Cell[564473, 12739, 887, 40, 81, "MathCaption"],
Cell[CellGroupData[{
Cell[565385, 12783, 456, 14, 37, "Input"],
Cell[565844, 12799, 472, 10, 35, "Output"]
}, Open  ]],
Cell[566331, 12812, 1071, 41, 58, "MathCaption"],
Cell[CellGroupData[{
Cell[567427, 12857, 221, 6, 37, "Input"],
Cell[567651, 12865, 469, 10, 35, "Output"]
}, Open  ]],
Cell[568135, 12878, 1772, 77, 56, "Text"],
Cell[569910, 12957, 872, 38, 60, "MathCaption"],
Cell[570785, 12997, 591, 22, 39, "Input"],
Cell[CellGroupData[{
Cell[571401, 13023, 299, 9, 37, "Input"],
Cell[571703, 13034, 469, 10, 35, "Output"]
}, Open  ]],
Cell[572187, 13047, 312, 7, 37, "Input"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[572548, 13060, 66, 1, 39, "Subsection"],
Cell[572617, 13063, 931, 27, 75, "Text"],
Cell[573551, 13092, 1196, 38, 58, "Text"],
Cell[CellGroupData[{
Cell[574772, 13134, 32, 0, 33, "SubsubsectionIcon"],
Cell[574807, 13136, 445, 7, 54, "Text"],
Cell[575255, 13145, 275, 8, 37, "Input"],
Cell[575533, 13155, 87, 1, 56, "MathCaption"],
Cell[575623, 13158, 89, 2, 37, "Input"],
Cell[CellGroupData[{
Cell[575737, 13164, 1027, 27, 92, "Input"],
Cell[576767, 13193, 751, 20, 35, "Output"]
}, Open  ]],
Cell[577533, 13216, 526, 17, 37, "Input"],
Cell[578062, 13235, 70, 0, 56, "MathCaption"],
Cell[578135, 13237, 210, 6, 37, "Input"],
Cell[578348, 13245, 75, 0, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[578448, 13249, 521, 15, 37, "Input"],
Cell[578972, 13266, 762, 20, 35, "Output"]
}, Open  ]],
Cell[579749, 13289, 134, 3, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[579908, 13296, 339, 9, 37, "Input"],
Cell[580250, 13307, 766, 20, 35, "Output"]
}, Open  ]],
Cell[581031, 13330, 107, 3, 37, "Input"],
Cell[581141, 13335, 340, 10, 37, "Input"],
Cell[CellGroupData[{
Cell[581506, 13349, 586, 18, 37, "Input"],
Cell[582095, 13369, 307, 6, 35, "Output"]
}, Open  ]],
Cell[582417, 13378, 83, 1, 56, "MathCaption"],
Cell[582503, 13381, 266, 9, 37, "Input"],
Cell[CellGroupData[{
Cell[582794, 13394, 65, 1, 37, "Input"],
Cell[582862, 13397, 828, 20, 35, "Output"]
}, Open  ]],
Cell[583705, 13420, 54, 0, 32, "Text"],
Cell[CellGroupData[{
Cell[583784, 13424, 301, 8, 37, "Input"],
Cell[584088, 13434, 537, 10, 35, "Output"]
}, Open  ]],
Cell[584640, 13447, 55, 0, 32, "Text"],
Cell[CellGroupData[{
Cell[584720, 13451, 302, 8, 37, "Input"],
Cell[585025, 13461, 533, 10, 35, "Output"]
}, Open  ]],
Cell[585573, 13474, 137, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[585735, 13481, 495, 13, 37, "Input"],
Cell[586233, 13496, 585, 13, 35, "Output"]
}, Open  ]],
Cell[586833, 13512, 205, 4, 41, "Commentary"],
Cell[587041, 13518, 277, 8, 37, "Input"],
Cell[CellGroupData[{
Cell[587343, 13530, 519, 15, 37, "Input"],
Cell[587865, 13547, 3423, 67, 356, "Output"]
}, Open  ]],
Cell[591303, 13617, 341, 11, 37, "Input"],
Cell[CellGroupData[{
Cell[591669, 13632, 193, 4, 37, "Input"],
Cell[591865, 13638, 2647, 61, 360, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[594549, 13704, 663, 19, 37, "Input"],
Cell[595215, 13725, 3343, 64, 369, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[598595, 13794, 397, 11, 37, "Input"],
Cell[598995, 13807, 7390, 142, 342, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[606446, 13956, 67, 1, 39, "Subsection"],
Cell[606516, 13959, 593, 12, 77, "Text"],
Cell[607112, 13973, 384, 13, 32, "Text"],
Cell[CellGroupData[{
Cell[607521, 13990, 34, 0, 33, "SubsubsectionIcon"],
Cell[607558, 13992, 101, 2, 32, "Text"],
Cell[607662, 13996, 1297, 35, 105, "Text"],
Cell[608962, 14033, 526, 10, 75, "Text"],
Cell[609491, 14045, 950, 29, 65, "Input"],
Cell[610444, 14076, 62, 0, 41, "Commentary"],
Cell[CellGroupData[{
Cell[610531, 14080, 394, 11, 37, "Input"],
Cell[610928, 14093, 1593, 45, 335, "Output"]
}, Open  ]],
Cell[612536, 14141, 592, 19, 37, "Input"],
Cell[613131, 14162, 58, 0, 41, "Commentary"],
Cell[CellGroupData[{
Cell[613214, 14166, 407, 11, 65, "Input"],
Cell[613624, 14179, 1490, 40, 230, "Output"]
}, Open  ]],
Cell[615129, 14222, 1995, 53, 92, "Input"],
Cell[617127, 14277, 1208, 33, 65, "Input"],
Cell[618338, 14312, 398, 18, 36, "Text"],
Cell[618739, 14332, 1798, 49, 92, "Input"],
Cell[620540, 14383, 197, 2, 32, "Text"],
Cell[620740, 14387, 861, 22, 65, "Input"],
Cell[621604, 14411, 430, 13, 37, "Input"],
Cell[622037, 14426, 51, 0, 32, "Text"],
Cell[CellGroupData[{
Cell[622113, 14430, 326, 10, 37, "Input"],
Cell[622442, 14442, 416, 9, 35, "Output"]
}, Open  ]],
Cell[622873, 14454, 93, 2, 32, "Text"],
Cell[622969, 14458, 122, 4, 37, "Input"],
Cell[623094, 14464, 866, 24, 65, "Input"],
Cell[CellGroupData[{
Cell[623985, 14492, 803, 22, 37, "Input"],
Cell[624791, 14516, 4490, 106, 349, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[629318, 14627, 821, 23, 65, "Input"],
Cell[630142, 14652, 4465, 98, 357, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[634656, 14756, 130, 2, 48, "SubsubsectionFirst"],
Cell[634789, 14760, 1255, 38, 76, "Text"],
Cell[636047, 14800, 77, 2, 37, "Input"],
Cell[CellGroupData[{
Cell[636149, 14806, 102, 2, 37, "Input"],
Cell[636254, 14810, 291, 4, 29, "Print"],
Cell[636548, 14816, 302, 4, 29, "Print"],
Cell[636853, 14822, 290, 4, 29, "Print"],
Cell[637146, 14828, 292, 4, 29, "Print"],
Cell[637441, 14834, 288, 4, 29, "Print"]
}, Open  ]],
Cell[637744, 14841, 357, 11, 37, "Input"],
Cell[CellGroupData[{
Cell[638126, 14856, 339, 7, 37, "Input"],
Cell[638468, 14865, 6672, 146, 1094, "Print"]
}, Open  ]],
Cell[645155, 15014, 112, 3, 56, "MathCaption"]
}, Open  ]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[645328, 15024, 29, 0, 93, "Section"],
Cell[645360, 15026, 634, 10, 75, "Text"],
Cell[645997, 15038, 480, 8, 75, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[646514, 15051, 29, 0, 52, "Section"],
Cell[646546, 15053, 3886, 58, 656, "SmallText"]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
