(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    269130,       7156]
NotebookOptionsPosition[    252969,       6659]
NotebookOutlinePosition[    255371,       6732]
CellTagsIndexPosition[    255141,       6725]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Internal doses ", "Chapter"],

Cell[TextData[{
 StyleBox["Author",
  FontWeight->"Bold"],
 ": Guillermo Sanchez: ",
 ButtonBox[" http://diarium.usal.es/guillermo",
  BaseStyle->"Hyperlink",
  ButtonData->{" http://diarium.usal.es/guillermo", None}]
}], "Text",
 CellChangeTimes->{{3.3992809464453416`*^9, 3.3992809874687996`*^9}, {
   3.5920621535253315`*^9, 3.592062165898821*^9}, 3.592062207859678*^9}],

Cell["Last updated: 2015-11-12", "Commentary",
 CellChangeTimes->{{3.39928025384801*^9, 3.399280259603493*^9}, {
  3.4228525171714554`*^9, 3.4228525382666454`*^9}, {3.422936332120079*^9, 
  3.422936340401223*^9}, {3.442218589593443*^9, 3.4422185944372244`*^9}, {
  3.479816247027495*^9, 3.4798162579804096`*^9}, {3.513395822423673*^9, 
  3.513395880159526*^9}, {3.518536578434902*^9, 3.518536584997528*^9}, {
  3.5193932942308636`*^9, 3.5193932955746393`*^9}, {3.5419932707941275`*^9, 
  3.541993276700528*^9}, {3.592062168534032*^9, 3.592062187680564*^9}, {
  3.6435962987319517`*^9, 3.6435963146695786`*^9}, {3.649664387887698*^9, 
  3.64966439945023*^9}, {3.6563207508365946`*^9, 3.6563207556491117`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["$Version"], "Input",
 CellLabel->"In[1]:="],

Cell[BoxData["\<\"10.2.0 for Microsoft Windows (64-bit) (July 28, \
2015)\"\>"], "Output",
 CellChangeTimes->{3.3992752647824697`*^9, 3.422852547121887*^9, 
  3.4422186266093054`*^9, 3.4798162427619514`*^9, 3.479963027849038*^9, 
  3.479963528528038*^9, 3.479963679586038*^9, 3.4802172397245297`*^9, 
  3.5185370893978376`*^9, 3.519392146146321*^9, 3.519392557185463*^9, 
  3.5193931048053517`*^9, 3.5193980304780483`*^9, 3.541993288872715*^9, 
  3.592062202728017*^9, 3.643596320700817*^9, 3.649664408872028*^9, 
  3.6563194953795137`*^9},
 CellLabel->"Out[1]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["Doses", "Input"],
 " is a package included in Biokmod. It can be used for computing,  over a \
period \[Tau], the accumulated disintegration ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["U", "s"], "(", "\[Tau]", ")"}], TraditionalForm]]],
 ", the committed effective doses ",
 Cell[BoxData[
  FormBox["e", TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "\[Tau]", ")"}], TraditionalForm]]],
 " and the equivalent doses ",
 Cell[BoxData[
  FormBox["H", TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "\[Tau]", ")"}], TraditionalForm]]],
 " . The SEE factors, require for computing ",
 Cell[BoxData[
  FormBox["e", TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "\[Tau]", ")"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox["H", TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "\[Tau]", ")"}], TraditionalForm]]],
 ", are included for some selected isotopes, in the other cases the SEE \
factors can be introduced as input data (It can be obtained using DCAL \
(SEECAL))."
}], "Text",
 CellChangeTimes->{3.4799637395530376`*^9}],

Cell["\<\
In this notebook is shown how obtain Dose Conversion Factors using Biokmod\
\>", "Text"],

Cell[CellGroupData[{

Cell["Introduction ", "SubsectionIcon"],

Cell[TextData[{
 "The committed equivalent dose ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "T"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "\[Tau]", ")"}], TraditionalForm]]],
 " is defined as the time integral of equivalent dose rate in a particular \
tissue or organ that will be receive by an individual following intake of \
radioactive material into the body, where \[Tau] is the integration time in \
years following the intake. Usually is taken  \[Tau] = 50 y for adult .  \n ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "T"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "\[Tau]", ")"}], TraditionalForm]]],
 " to organ or target tissue, T, as consequence of disintegration of a \
radionuclide in a source region, S,  is   given by (S and T can be the same \
compartment)"
}], "Text",
 CellChangeTimes->{3.479963771879038*^9}],

Cell[TextData[{
 "\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["H", "T"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "\[Tau]", ")"}], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["\[Sum]", "R"], 
    RowBox[{
     SubscriptBox["U", "s"], " ", 
     RowBox[{"(", "\[Tau]", ")"}], 
     RowBox[{"SEE", "(", 
      RowBox[{"T", "\[LeftArrow]", "S"}], ")"}]}]}], TraditionalForm]]]
}], "NumberedEquation"],

Cell["where:", "Text"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["U", "s"], "(", "\[Tau]", ")"}], TraditionalForm]]],
 " = Number of transformation (Bq S) in \[Tau] year in source region S \
following an acute intake. Usually  \[Tau] = 50 y for adult ."
}], "Text"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["U", "s"], "(", "\[Tau]", ")"}], TraditionalForm]]],
 " =",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubsuperscriptBox["\[Integral]", "0", "\[Tau]"], 
    RowBox[{
     RowBox[{"q", "(", "t", ")"}], 
     RowBox[{"\[DifferentialD]", "t"}]}]}], TraditionalForm]]],
 "\n"
}], "NumberedEquation"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   RowBox[{"SEE", "(", 
    RowBox[{"T", "\[LeftArrow]", "S"}], ")"}], TraditionalForm]]],
 " = Specific Effective Energy, equivalent dose in T per transformation in S \
following an acute intake expressed as (Sv/(Bq s))"
}], "Text"],

Cell[TextData[{
 "\n",
 Cell[BoxData[
  FormBox["SEE", TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"T", "\[LeftArrow]", "S"}], ")"}], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"1.6", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "13"}]]}], 
     SubscriptBox["m", "T"]], 
    RowBox[{
     UnderscriptBox["\[Sum]", "R"], 
     RowBox[{
      SubscriptBox["Y", "R"], 
      SubscriptBox["E", "R"], "  ", 
      SubscriptBox["w", 
       RowBox[{"R", " "}]], 
      SubscriptBox[
       RowBox[{"AF", "(", 
        RowBox[{"T", "\[LeftArrow]", "S"}], ")"}], "R"]}]}]}], 
   TraditionalForm]]]
}], "NumberedEquation"],

Cell[TextData[{
 "\t",
 Cell[BoxData[
  FormBox[
   SubscriptBox["Y", "R"], TraditionalForm]]],
 " = yield of radiation ",
 Cell[BoxData[
  FormBox["R", TraditionalForm]]],
 " per nuclear transformation ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"(", 
     RowBox[{"Bq", " ", "s"}], ")"}], 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 "\n\t",
 Cell[BoxData[
  FormBox[
   SubscriptBox["E", "R"], TraditionalForm]]],
 " = energy of radiation ",
 Cell[BoxData[
  FormBox["R", TraditionalForm]]],
 " (MeV/Transformation)\n\t",
 Cell[BoxData[
  FormBox[
   RowBox[{"1.6", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "13"}]]}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    FractionBox["J", "MeV"], ")"}], TraditionalForm]]],
 " is used for transform MeV in J\n\t",
 Cell[BoxData[
  FormBox[
   SubscriptBox["w", 
    RowBox[{"R", " "}]], TraditionalForm]]],
 "= radiation writhing factor for radiation R (see table 8 of ICRP 68, \
typical values are: 20 for alpha particles and 1 for photons and electrons)\n\
\t",
 Cell[BoxData[
  FormBox[
   SubscriptBox[
    RowBox[{"AF", "(", 
     RowBox[{"T", "\[LeftArrow]", "S"}], ")"}], "R"], TraditionalForm]]],
 "= absorbed fraction in T per transformation in S for radiation R\n\t",
 Cell[BoxData[
  FormBox[
   SubscriptBox["m", "T"], TraditionalForm]]],
 " = mass of target tissue, ",
 Cell[BoxData[
  FormBox[
   RowBox[{"T", " "}], TraditionalForm]]],
 "(kg).\nWhen a nuclei decay in other nuclei which itself is radioactive, the \
contribution of the decay product to the dose is evaluated using a similar \
set of equations for the decay products. It usually is assumed that these \
decay products adopted the biokinectic of their parents."
}], "Text",
 CellChangeTimes->{{3.479963824127038*^9, 3.4799638777150383`*^9}}],

Cell[CellGroupData[{

Cell["\<\
The committed effective dose computation (Taken from ICRP 68 and ICRP 2001):\
\>", "SubsubsectionIcon"],

Cell["\<\
The committed effective dose over a period \[Tau] ( 50 year for adult  is \
obtained as the sum of the weighted committed equivalent doses to organs or \
tissues.     \
\>", "Text"],

Cell[TextData[{
 "\n",
 Cell[BoxData[
  FormBox["e", TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "\[Tau]", ")"}], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["\[Sum]", "R"], 
    RowBox[{
     SubscriptBox["H", "T"], " ", 
     RowBox[{"(", "\[Tau]", ")"}], " ", 
     SubscriptBox["W", "T"]}]}], TraditionalForm]]]
}], "NumberedEquation"],

Cell["\<\
The committed (50-year) equivalent dose to organ or target tissue, T, is \
given by -- eq (1) -- the sum of the products of the number of nuclear \
transformations (Bq s) in 50 years in source regions S following an acute \
intake and the Specific Effective Energy , SEE(T<-S), where SEE is the \
equivalent dose in T per transformation in S expressed as (Sv/Bq s).\
\>", "Text"],

Cell["\<\
 When a nuclide forms a decay product which itself is radioactive, the \
contribution of the decay product to the dose is evaluated using a similar \
approach.  The identity of decay products, information on the types of \
radiations emitted by the radionuclide (ie, energies and intensities), and \
the half-lives of the radionuclides used in this report are those given in \
Publication 38.\
\>", "Text"],

Cell["\<\
The usual assumption in Publication 30 was that these radioactive decay \
products adopted the biokinetics of their parent; there were a few exceptions \
for decay products which were isotopes of iodine or noble gases.  The new \
ICRP model of the respiratory tract proposes that the rate at which the \
particle dissociates is determined by its matrix but the behaviour of \
dissociated material in the lung would be expected to depend on its elemental \
form.  This consideration would also be relevant to decay products entering \
the systemic circulation.  For the present implementation of the respiratory \
tract model, however, the absorption parameters of the parent are applied to \
all members of the decay chain.  In  ICRP 2001 (ICRPDose 2.0.1 CD-ROM) \
separate systemic biokinetics have been applied to the parent and its decay \
products for those elements where this is assumed in Publications 56, 67 and \
69.  This applies to intakes of lead, radium, tellurium, thorium and uranium. \
 For other elements, the ICRP 2001 treatment of decay products follows by \
that in Publication 30.\
\>", "Text"],

Cell["\<\
 The committed effective dose for the worker is then given by the sum of the \
products of the committed equivalent dose and the tissue weighting factors \
for the 12 tissues and organs named in Table 1, plus the products of the \
committed equivalent dose to the remainder tissues as defined above \
multiplied by the tissue weighting factor (0.05) assigned to these remainder \
tissues.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"tlabel", "=", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Gonads\>\"", ",", "\"\<Bone marrow (red) \>\"", ",", "\"\<Colon\>\"",
      ",", "\"\<Lung\>\"", ",", "\"\<Stomach\>\"", ",", "\"\<Bladder\>\"", 
     ",", "\"\<Breast\>\"", ",", "\"\<Liver\>\"", ",", "\"\<Oesophagus\>\"", 
     ",", "\"\<Thyroid\>\"", ",", "\"\<Skin\>\"", ",", "\"\<Bone surface\>\"",
      ",", "\"\<Remainder\>\""}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[2]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"wtf", " ", "=", 
   RowBox[{"{", 
    RowBox[{
    ".2", ",", ".12", ",", ".12", ",", ".12", ",", ".12", ",", ".05", ",", 
     ".05", ",", ".05", ",", ".05", ",", ".05", ",", ".01", ",", ".01", ",", 
     ".05"}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[3]:="],

Cell["Table 1.- Tissue weighting factors (*)", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TableForm", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"tlabel", ",", "wtf"}], "}"}], "]"}], ",", " ", 
    RowBox[{"TableHeadings", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"None", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<Organ or tissue\>\"", ",", "\"\<Weighting factor\>\""}], 
        "}"}]}], " ", "}"}]}]}], "]"}], " "}]], "Input",
 CellLabel->"In[4]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Organ or tissue\"\>",
       HoldForm], 
      TagBox["\<\"Weighting factor\"\>",
       HoldForm]},
     {"\<\"Gonads\"\>", "0.2`"},
     {"\<\"Bone marrow (red) \"\>", "0.12`"},
     {"\<\"Colon\"\>", "0.12`"},
     {"\<\"Lung\"\>", "0.12`"},
     {"\<\"Stomach\"\>", "0.12`"},
     {"\<\"Bladder\"\>", "0.05`"},
     {"\<\"Breast\"\>", "0.05`"},
     {"\<\"Liver\"\>", "0.05`"},
     {"\<\"Oesophagus\"\>", "0.05`"},
     {"\<\"Thyroid\"\>", "0.05`"},
     {"\<\"Skin\"\>", "0.01`"},
     {"\<\"Bone surface\"\>", "0.01`"},
     {"\<\"Remainder\"\>", "0.05`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Organ or tissue", "Weighting factor"}}]]]], "Output",
 CellChangeTimes->{3.399017434232931*^9, 3.3990175505602107`*^9, 
  3.4178379704214973`*^9, 3.479962642330038*^9, 3.479963528607038*^9, 
  3.479963679699038*^9, 3.4802172402870836`*^9, 3.518537089429088*^9, 
  3.5193921462400727`*^9, 3.519392557263589*^9, 3.519393104867853*^9, 
  3.51939803060305*^9, 3.541993288997718*^9, 3.5920622037580996`*^9, 
  3.6435963208102007`*^9, 3.6563194955357656`*^9},
 CellLabel->"Out[4]//TableForm="]
}, Open  ]],

Cell["\<\
(*) The values have been developed from a reference population of equal \
numbers of both sexes and a wide range of ages.  In the definition of \
effective dose they apply to workers, to the whole population, and to either \
sex.\
\>", "Text"],

Cell["\<\
The remainder tissues and organs of Publication 60 are given in Table 2.  To \
this list has been added the extrathoracic airways as defined in the ICRP 66 \
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"organremainder", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "\"\<Muscle\>\"", ",", "\"\<Brain\>\"", ",", "\"\<Small intestine\>\"", 
     ",", "\"\<Kidneys\>\"", ",", "\"\<Pancreas\>\"", ",", "\"\<Spleen\>\"", 
     ",", "\"\<Thymus\>\"", ",", "\"\<Uterus\>\"", ",", "\"\<Adrenals\>\"", 
     ",", "\"\<Extrathoracic airways\>\""}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[5]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"mass", " ", "=", 
   RowBox[{"{", 
    RowBox[{
    "28000", ",", "1400", ",", "640", ",", "310", ",", "100", ",", "180", ",",
      "20", ",", "80", ",", "14", ",", "15"}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[6]:="],

Cell["\<\
Table 2.- The remainder tissues and organs corresponding to the Remainder\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TableForm", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"organremainder", ",", "mass", ",", " ", 
       RowBox[{
        RowBox[{"mass", "/", 
         RowBox[{"Total", "[", "mass", "]"}]}], "//", "N"}]}], " ", "}"}], 
     "]"}], ",", " ", 
    RowBox[{"TableHeadings", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"None", ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<Organ or tissue\>\"", ",", "\"\<Mass(g)\>\"", ",", " ", 
         "\"\<Relative W. fac\>\""}], " ", "}"}]}], " ", "}"}]}]}], "]"}], 
  " "}]], "Input",
 CellLabel->"In[7]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Organ or tissue\"\>",
       HoldForm], 
      TagBox["\<\"Mass(g)\"\>",
       HoldForm], 
      TagBox["\<\"Relative W. fac\"\>",
       HoldForm]},
     {"\<\"Muscle\"\>", "28000", "0.9103026756396502`"},
     {"\<\"Brain\"\>", "1400", "0.045515133781982506`"},
     {"\<\"Small intestine\"\>", "640", "0.020806918300334862`"},
     {"\<\"Kidneys\"\>", "310", "0.010078351051724698`"},
     {"\<\"Pancreas\"\>", "100", "0.003251080984427322`"},
     {"\<\"Spleen\"\>", "180", "0.0058519457719691794`"},
     {"\<\"Thymus\"\>", "20", "0.0006502161968854644`"},
     {"\<\"Uterus\"\>", "80", "0.0026008647875418577`"},
     {"\<\"Adrenals\"\>", "14", "0.0004551513378198251`"},
     {"\<\"Extrathoracic airways\"\>", "15", "0.0004876621476640983`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Organ or tissue", "Mass(g)", "Relative W. fac"}}]]]], "Output",
 CellChangeTimes->{3.399017434295388*^9, 3.3990175506226683`*^9, 
  3.4178379704996896`*^9, 3.479962642385038*^9, 3.479963528660038*^9, 
  3.479963679759038*^9, 3.4802172404902287`*^9, 3.5185370894447136`*^9, 
  3.5193921462869487`*^9, 3.519392557310465*^9, 3.519393104930354*^9, 
  3.5193980306343007`*^9, 3.541993289153972*^9, 3.5920622046656723`*^9, 
  3.643596320857082*^9, 3.6563194956138897`*^9},
 CellLabel->"Out[7]//TableForm="]
}, Open  ]],

Cell["The ET mass has been taken from Table 5 of Publication 66.", "SmallText"],

Cell["\<\
The equivalent dose to remainder tissues is normally calculated as the \
mass-weighted mean dose to the ten organs and tissues listed in Table 2 . In \
this way it has been computed column 3-rd of Table 2.  Then the Tissue \
weighting factors including the remainder tissues and organs are the fiven in \
Table 3.\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"wtfexpanded", " ", "=", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Drop", "[", 
      RowBox[{"wtf", ",", 
       RowBox[{"-", "1"}]}], "]"}], " ", ",", " ", 
     RowBox[{"0.05", " ", 
      RowBox[{"mass", "/", 
       RowBox[{"Total", "[", "mass", "]"}]}]}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[8]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"tlabelexpanded", "=", " ", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"Drop", "[", 
      RowBox[{"tlabel", ",", 
       RowBox[{"-", "1"}]}], "]"}], " ", ",", "organremainder"}], " ", 
    "]"}]}], ";"}]], "Input",
 CellLabel->"In[9]:="],

Cell["\<\
Table 3.- Tissue weighting factors  including remainder organ or tissue\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"TableForm", "[", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"{", 
      RowBox[{"tlabelexpanded", ",", " ", "wtfexpanded"}], "}"}], "]"}], ",", 
    " ", 
    RowBox[{"TableHeadings", "\[Rule]", " ", 
     RowBox[{"{", 
      RowBox[{"None", ",", 
       RowBox[{"{", 
        RowBox[{"\"\<Organ or tissue\>\"", ",", "\"\<Weighting factor\>\""}], 
        "}"}]}], " ", "}"}]}]}], "]"}], " "}]], "Input",
 CellLabel->"In[10]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Organ or tissue\"\>",
       HoldForm], 
      TagBox["\<\"Weighting factor\"\>",
       HoldForm]},
     {"\<\"Gonads\"\>", "0.2`"},
     {"\<\"Bone marrow (red) \"\>", "0.12`"},
     {"\<\"Colon\"\>", "0.12`"},
     {"\<\"Lung\"\>", "0.12`"},
     {"\<\"Stomach\"\>", "0.12`"},
     {"\<\"Bladder\"\>", "0.05`"},
     {"\<\"Breast\"\>", "0.05`"},
     {"\<\"Liver\"\>", "0.05`"},
     {"\<\"Oesophagus\"\>", "0.05`"},
     {"\<\"Thyroid\"\>", "0.05`"},
     {"\<\"Skin\"\>", "0.01`"},
     {"\<\"Bone surface\"\>", "0.01`"},
     {"\<\"Muscle\"\>", "0.04551513378198251`"},
     {"\<\"Brain\"\>", "0.0022757566890991253`"},
     {"\<\"Small intestine\"\>", "0.0010403459150167432`"},
     {"\<\"Kidneys\"\>", "0.0005039175525862349`"},
     {"\<\"Pancreas\"\>", "0.0001625540492213661`"},
     {"\<\"Spleen\"\>", "0.000292597288598459`"},
     {"\<\"Thymus\"\>", "0.000032510809844273224`"},
     {"\<\"Uterus\"\>", "0.0001300432393770929`"},
     {"\<\"Adrenals\"\>", "0.000022757566890991258`"},
     {"\<\"Extrathoracic airways\"\>", "0.000024383107383204918`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Organ or tissue", "Weighting factor"}}]]]], "Output",
 CellChangeTimes->{3.3990174343578463`*^9, 3.3990175507007403`*^9, 
  3.4178379705622435`*^9, 3.479962642450038*^9, 3.4799635287080383`*^9, 
  3.479963679817038*^9, 3.48021724061524*^9, 3.518537089475964*^9, 
  3.519392146333824*^9, 3.5193925573729663`*^9, 3.51939310497723*^9, 
  3.5193980306655517`*^9, 3.54199328926335*^9, 3.5920622057345076`*^9, 
  3.643596320903943*^9, 3.656319495676388*^9},
 CellLabel->"Out[10]//TableForm="]
}, Open  ]],

Cell["\<\
In the exceptional case in which the most highly irradiated remainder tissue \
or organ receives the highest equivalent dose of all organs (not included in \
remainder), a weighting factor of 0.025 (half of remainder) is applied to \
that tissue or organ and 0.025 (half of remainder) to the mass-weighted \
equivalent dose in the rest of the remainder tissues and organs. \
\>", "Text"],

Cell[TextData[{
 "The dose coefficient ",
 Cell[BoxData[
  FormBox[
   RowBox[{"e", "(", "50", ")"}], TraditionalForm]]],
 " in Sv/Bq corresponds to the committed effective dose resulting from the \
intake of 1 Bq of that radionuclide   "
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Respiratory Tract Dose. Application U-234", "SubsubsectionIcon"],

Cell["\<\
The procedure for computing dose in the respiratory tract is described in \
ICRP 66. We are showing with an example for U-234 \
\>", "Text"],

Cell["We start obtained SSE using eq. ", "Text"],

Cell[TextData[{
 "\n",
 Cell[BoxData[
  FormBox["SEE", TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", 
    RowBox[{"T", "\[LeftArrow]", "S"}], ")"}], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"1.6", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "13"}]]}], 
     SubscriptBox["m", "T"]], 
    RowBox[{
     UnderscriptBox["\[Sum]", "R"], 
     RowBox[{
      SubscriptBox["Y", "R"], 
      SubscriptBox["E", "R"], "  ", 
      SubscriptBox["w", 
       RowBox[{"R", " "}]], 
      SubscriptBox[
       RowBox[{"AF", "(", 
        RowBox[{"T", "\[LeftArrow]", "S"}], ")"}], "R"]}]}]}], 
   TraditionalForm]]]
}], "NumberedEquation"],

Cell["\<\
The targets, sources, and mass (from ICRP 66) are the following:\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"target", ",", " ", "source", ",", " ", "mass"}], "}"}], "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
      "\"\<ET1\>\"", ",", "  ", "\"\<ET2\>\"", ",", " ", "\"\<LNet\>\"", ",", 
       "\"\<BBbas\>\"", ",", "\"\<BBsec\>\"", ",", "\"\<bb\>\"", ",", 
       "\"\<AI\>\"", ",", "\"\<LNth\>\""}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "\"\<ET1\>\"", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"\"\<ET2(surf)\>\"", ",", "\"\<ETseq\>\""}], "}"}], ",", " ", 
       RowBox[{"{", " ", "\"\<LNet\>\"", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<BB1(fast)\>\"", ",", "\"\<BB2(slow)\>\"", ",", "\"\<BBseq\>\""}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<BB1(fast)\>\"", ",", "\"\<BB2(slow)\>\"", ",", "\"\<BBseq\>\""}],
         "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<bb1(fast)\>\"", ",", "\"\<bb2(slow)\>\"", ",", "\"\<bbseq\>\"", 
         ",", "\"\<AI\>\""}], "}"}], ",", 
       RowBox[{"{", "\"\<AI\>\"", "}"}], ",", 
       RowBox[{"{", "\"\<LNth\>\"", "}"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"2.0", " ", 
        RowBox[{"10", "^", 
         RowBox[{"-", "5"}]}]}], ",", "0.00045", ",", " ", "0.015", ",", " ", 
       "0.000432", ",", " ", "0.000865", ",", " ", "0.00195", ",", " ", "1.1",
        ",", " ", "0.015"}], "}"}]}], " ", "}"}]}], ";"}]], "Input",
 CellLabel->"In[11]:="],

Cell[TextData[{
 "The U-234 emits a alpha particle per disintegration of 4.758 MeV. We can \
dropped the AF for gamma emissions because they are negligible. Also, the \
half-life of U-234 is to long 7.7 ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["10", "4"], TraditionalForm]]],
 " y compared with the human life, this mean that we don't need to be account \
the disintegration product of  U-234.  In summary, we only need computed the \
AF values for 4.758 MeV , they  (from Tabla H.1 of ICRP 66) are the following:"
}], "Text"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"afU234", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", "0", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", ".142"}], "}"}], ",", " ", 
      RowBox[{"{", "1", "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0", ",", "0", ",", "0.123`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.00965`", ",", "0.159`", ",", "0.0304`"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"0.238`", ",", "0.243`", ",", "0.114`", ",", "0.000034`"}], 
       "}"}], ",", 
      RowBox[{"{", "1", "}"}], ",", 
      RowBox[{"{", "1", "}"}]}], "}"}]}], ";"}]}]], "Input",
 CellLabel->"In[12]:="],

Cell[TextData[{
 "Now it is computed eq. (3) where it is applied ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["w", "R"], TraditionalForm]]],
 "= 20 (because they are alpha emissions) "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sseU234", " ", "=", 
  RowBox[{"afU234", "*", "4.758", "*", "20", "*", "1.6", "*", 
   RowBox[{
    SuperscriptBox["10", 
     RowBox[{"-", "13"}]], "/", "mass"}]}]}]], "Input",
 CellLabel->"In[13]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "0.`", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "4.804522666666666`*^-9"}], "}"}], ",", 
   RowBox[{"{", "1.01504`*^-9", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.`", ",", "0.`", ",", "4.335066666666666`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.698578497109827`*^-10", ",", "2.798694104046243`*^-9", ",", 
     "5.350962312138729`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "1.8583039999999997`*^-9", ",", "1.897344`*^-9", ",", "8.90112`*^-10", 
     ",", "2.6547199999999997`*^-13"}], "}"}], ",", 
   RowBox[{"{", "1.3841454545454544`*^-11", "}"}], ",", 
   RowBox[{"{", "1.01504`*^-9", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.3990174344046893`*^9, 3.399017550794427*^9, 
  3.4178379706560745`*^9, 3.479962642587038*^9, 3.4799635287550383`*^9, 
  3.479963679885038*^9, 3.4802172407246256`*^9, 3.5185370895072145`*^9, 
  3.5193921463807*^9, 3.5193925574510927`*^9, 3.519393105039731*^9, 
  3.519398030696802*^9, 3.5419932893571024`*^9, 3.592062207854677*^9, 
  3.643596320950819*^9, 3.656319495723284*^9},
 CellLabel->"Out[13]="]
}, Open  ]],

Cell["Here are summarized the data", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"Transpose", "[", 
    RowBox[{"{", 
     RowBox[{
     "target", ",", "mass", ",", " ", "source", ",", "afU234", ",", " ", 
      "sseU234"}], " ", "}"}], "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Target\>\"", ",", "\"\<mass\>\"", ",", "\"\<Source\>\"", ",", 
        "\"\<AF(T<-S)\>\"", ",", " ", "\"\<SSE\>\""}], "}"}]}], "}"}]}], ",", 
   " ", 
   RowBox[{"TableSpacing", "->", 
    RowBox[{"{", 
     RowBox[{"1", ",", "4"}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[14]:="],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"\<\"Target\"\>", "\<\"mass\"\>", "\<\"Source\"\>", "\<\"AF(T<-S)\"\>", \
"\<\"SSE\"\>"},
    {"\<\"ET1\"\>", "0.00002`", GridBox[{
       {"\<\"ET1\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {"0"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {"0.`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"\<\"ET2\"\>", "0.00045`", GridBox[{
       {"\<\"ET2(surf)\"\>"},
       {"\<\"ETseq\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {"0"},
       {"0.142`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {"0.`"},
       {"4.804522666666666`*^-9"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"\<\"LNet\"\>", "0.015`", GridBox[{
       {"\<\"LNet\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {"1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {"1.01504`*^-9"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"\<\"BBbas\"\>", "0.000432`", GridBox[{
       {"\<\"BB1(fast)\"\>"},
       {"\<\"BB2(slow)\"\>"},
       {"\<\"BBseq\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {"0"},
       {"0"},
       {"0.123`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {"0.`"},
       {"0.`"},
       {"4.335066666666666`*^-9"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"\<\"BBsec\"\>", "0.000865`", GridBox[{
       {"\<\"BB1(fast)\"\>"},
       {"\<\"BB2(slow)\"\>"},
       {"\<\"BBseq\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {"0.00965`"},
       {"0.159`"},
       {"0.0304`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {"1.698578497109827`*^-10"},
       {"2.798694104046243`*^-9"},
       {"5.350962312138729`*^-10"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"\<\"bb\"\>", "0.00195`", GridBox[{
       {"\<\"bb1(fast)\"\>"},
       {"\<\"bb2(slow)\"\>"},
       {"\<\"bbseq\"\>"},
       {"\<\"AI\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {"0.238`"},
       {"0.243`"},
       {"0.114`"},
       {"0.000034`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {"1.8583039999999997`*^-9"},
       {"1.897344`*^-9"},
       {"8.90112`*^-10"},
       {"2.6547199999999997`*^-13"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"\<\"AI\"\>", "1.1`", GridBox[{
       {"\<\"AI\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {"1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {"1.3841454545454544`*^-11"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"\<\"LNth\"\>", "0.015`", GridBox[{
       {"\<\"LNth\"\>"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {"1"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], GridBox[{
       {"1.01504`*^-9"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.8]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{"ET1", 0.00002, {"ET1"}, {0}, {0.}}, {
    "ET2", 0.00045, {"ET2(surf)", "ETseq"}, {0, 0.142}, {0., 
     4.804522666666666*^-9}}, {"LNet", 0.015, {"LNet"}, {1}, {1.01504*^-9}}, {
    "BBbas", 0.000432, {"BB1(fast)", "BB2(slow)", "BBseq"}, {0, 0, 0.123}, {
     0., 0., 4.335066666666666*^-9}}, {
    "BBsec", 0.000865, {"BB1(fast)", "BB2(slow)", "BBseq"}, {0.00965, 0.159, 
     0.0304}, {1.698578497109827*^-10, 2.798694104046243*^-9, 
     5.350962312138729*^-10}}, {
    "bb", 0.00195, {"bb1(fast)", "bb2(slow)", "bbseq", "AI"}, {0.238, 0.243, 
     0.114, 0.000034}, {1.8583039999999997`*^-9, 1.897344*^-9, 8.90112*^-10, 
     2.6547199999999997`*^-13}}, {
    "AI", 1.1, {"AI"}, {1}, {1.3841454545454544`*^-11}}, {
    "LNth", 0.015, {"LNth"}, {1}, {1.01504*^-9}}}, 
   TableHeadings -> {None, {"Target", "mass", "Source", "AF(T<-S)", "SSE"}}, 
   TableSpacing -> {1, 4}]]], "Output",
 CellChangeTimes->{3.39901743451399*^9, 3.399017550919342*^9, 
  3.417837970765544*^9, 3.479962642633038*^9, 3.4799635287880383`*^9, 
  3.479963679926038*^9, 3.480217240880891*^9, 3.5185370895540905`*^9, 
  3.519392146427576*^9, 3.51939255756047*^9, 3.5193931051022325`*^9, 
  3.519398030728053*^9, 3.5419932894196043`*^9, 3.5920622086834936`*^9, 
  3.643596320997698*^9, 3.6563194957857847`*^9},
 CellLabel->"Out[14]//TableForm="]
}, Open  ]],

Cell["\<\
Now we need apply eq. (2) to compute the disintegrations in compartments \
{\"ET1\", \"AI\", \"bb1\", \"bb2\", \"bbseq\", \"BB1\" \"BB2\", \"BBseq\", \
\"LNth \", \"ET2\", \"ETseq\", \"LNet\"}. It applied the Humorap function \
qRT[1,AMAD5,S, t,0] that compute the compartment retention for workers \
assuming  an intake AMAD 5 and class S for an acute intake \"1\" in t = 0. It \
can be as follow\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Biokmod`Resptract`\>\"", "]"}]], "Input",
 CellChangeTimes->{{3.3990175288405805`*^9, 3.399017536038819*^9}},
 CellLabel->"In[15]:="],

Cell[BoxData["\<\"Resptract 1.2  2005-05-16\"\>"], "Print",
 CellChangeTimes->{3.519398030899931*^9, 3.541993289607109*^9, 
  3.5920622092635403`*^9, 3.643596321122707*^9, 3.6563194959107723`*^9},
 CellLabel->"During evaluation of In[15]:="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"UsRT", "[", "t_", "]"}], " ", "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["q", "ET1"], ",", 
      SubscriptBox["q", "AI"], ",", 
      SubscriptBox["q", "bb1"], ",", " ", 
      SubscriptBox["q", "bb2"], ",", 
      SubscriptBox["q", "bbseq"], ",", 
      SubscriptBox["q", "BB1"], ",", 
      SubscriptBox["q", "BB2"], ",", 
      SubscriptBox["q", "BBseq"], ",", 
      SubscriptBox["q", "LNth"], ",", 
      SubscriptBox["q", "ET2"], ",", 
      SubscriptBox["q", "ETseq"], ",", 
      SubscriptBox["q", "LNet"]}], " ", "}"}], "=", 
    RowBox[{
     RowBox[{"Map", "[", 
      RowBox[{"Last", ",", 
       RowBox[{"RespiratoryTract", "[", 
        RowBox[{
         RowBox[{"3600", "*", "24"}], ",", "AMAD5", ",", "S", ",", " ", "t1", 
         ",", "0", ",", " ", 
         RowBox[{"IntakeType", "\[Rule]", " ", "\"\<Constant\>\""}]}], 
        "]"}]}], "]"}], "/.", 
     RowBox[{"t1", "\[Rule]", 
      RowBox[{"365.24", "t"}]}]}]}]}], ";"}]], "Input",
 CellLabel->"In[16]:="],

Cell["\<\
Even,  we can computed Us for different times. ex.. 30 days, 10 year and 50 \
years\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Transpose", "[", 
   RowBox[{"Join", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
       "\"\<qET1\>\"", ",", "\"\<qAI\>\"", ",", "\"\<qbb1\>\"", ",", 
        "\"\<qbb2\>\"", ",", "\"\<qbbseq\>\"", ",", "\"\<qBB1\>\"", ",", 
        "\"\<qBB2\>\"", ",", "\"\<qBBseq\>\"", ",", "\"\<qLNth\>\"", ",", 
        "\"\<qET2\>\"", ",", "\"\<qETseq\>\"", ",", "\"\<qLNet\>\""}], "}"}], 
      "}"}], ",", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"UsRT", "[", "#", "]"}], "&"}], ",", " ", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"30", "/", "365.24"}], ",", " ", "10", ",", " ", "50"}], 
        "}"}]}], "]"}]}], "]"}], "]"}], "//", "TableForm"}]], "Input",
 CellLabel->"In[17]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"qET1\"\>", "29263.64543999726`", "29263.64544`", "29263.64544`"},
    {"\<\"qAI\"\>", "126044.6382273836`", "3.680047640149734`*^6", 
     "4.621912199552285`*^6"},
    {"\<\"qbb1\"\>", "630.6056735380994`", "2255.7539284819873`", 
     "2323.13953664583`"},
    {"\<\"qbb2\"\>", "7475.573096346389`", "12571.418354066625`", 
     "12571.418354066625`"},
    {"\<\"qbbseq\"\>", "172.48359601952393`", "659.8429634502845`", 
     "659.8429634502846`"},
    {"\<\"qBB1\"\>", "249.40122441866583`", "589.9401302385168`", 
     "603.4178103972374`"},
    {"\<\"qBB2\"\>", "10096.457186009802`", "16978.870454933505`", 
     "16978.870454933505`"},
    {"\<\"qBBseq\"\>", "277.64639044999626`", "1062.1474812309868`", 
     "1062.1474812309868`"},
    {"\<\"qLNth\"\>", "74.97002862219233`", "93534.65666730073`", 
     "444601.8629545773`"},
    {"\<\"qET2\"\>", "372.27063710507383`", "408.39208890545416`", 
     "409.73986250663216`"},
    {"\<\"qETseq\"\>", "508.0300342047303`", "15368.624103423484`", 
     "15650.256445315263`"},
    {"\<\"qLNet\"\>", "7.654682024527574`", "37304.96323835419`", 
     "128781.77600813468`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.399017435919286*^9, 3.3990175521528797`*^9, 
  3.4178379734710045`*^9, 3.479962643370038*^9, 3.4799635294320383`*^9, 
  3.479963680582038*^9, 3.4802172419278665`*^9, 3.518537090147852*^9, 
  3.5193921468494596`*^9, 3.519392557997978*^9, 3.5193931055241156`*^9, 
  3.5193980311343107`*^9, 3.5419932898571153`*^9, 3.592062209971097*^9, 
  3.643596321278946*^9, 3.6563194960670195`*^9},
 CellLabel->"Out[17]//TableForm="]
}, Open  ]],

Cell[TextData[{
 "We will need the Us for at time of 50 y grouping the compartments as it \
shown (It can be observed that ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    SubscriptBox["q", "BB1"], ",", 
    SubscriptBox["q", "BB2"], ",", 
    SubscriptBox["q", "BBseq"]}], "}"}]]],
 "it is copy twice to be account BB bas and BB seq)"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"usU234", " ", "=", " ", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"UsRT", "[", "50", "]"}], ";", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         SubscriptBox["q", "ET1"], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["q", "ET2"], ",", 
          SubscriptBox["q", "ETseq"]}], "}"}], ",", 
        RowBox[{"{", 
         SubscriptBox["q", "LNet"], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["q", "BB1"], ",", 
          SubscriptBox["q", "BB2"], ",", 
          SubscriptBox["q", "BBseq"]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["q", "BB1"], ",", 
          SubscriptBox["q", "BB2"], ",", 
          SubscriptBox["q", "BBseq"]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          SubscriptBox["q", "bb1"], ",", " ", 
          SubscriptBox["q", "bb2"], ",", 
          SubscriptBox["q", "bbseq"], ",", " ", 
          SubscriptBox["q", "AI"]}], " ", "}"}], ",", 
        RowBox[{"{", " ", 
         SubscriptBox["q", "AI"], "}"}], ",", 
        RowBox[{"{", 
         SubscriptBox["q", "LNth"], "}"}]}], " ", "}"}], "/.", 
      RowBox[{"t", "\[Rule]", " ", "50"}]}]}], ")"}]}], ";"}]], "Input",
 CellLabel->"In[18]:="],

Cell[CellGroupData[{

Cell[BoxData["usU234"], "Input",
 CellLabel->"In[19]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "29263.64544`", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"409.73986250663216`", ",", "15650.256445315263`"}], "}"}], ",", 
   RowBox[{"{", "128781.77600813468`", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "603.4178103972374`", ",", "16978.870454933505`", ",", 
     "1062.1474812309868`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "603.4178103972374`", ",", "16978.870454933505`", ",", 
     "1062.1474812309868`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "2323.13953664583`", ",", "12571.418354066625`", ",", 
     "659.8429634502846`", ",", "4.621912199552285`*^6"}], "}"}], ",", 
   RowBox[{"{", "4.621912199552285`*^6", "}"}], ",", 
   RowBox[{"{", "444601.8629545773`", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.399017435950515*^9, 3.3990175521841087`*^9, 
  3.417837973533559*^9, 3.479962643431038*^9, 3.479963529474038*^9, 
  3.479963680647038*^9, 3.4802172420216255`*^9, 3.5185370901791024`*^9, 
  3.519392146896335*^9, 3.519392558044854*^9, 3.5193931055709915`*^9, 
  3.5193980311499357`*^9, 3.5419932899039917`*^9, 3.592062210272371*^9, 
  3.643596321310196*^9, 3.65631949609826*^9},
 CellLabel->"Out[19]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"doseEq", " ", "=", "  ", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Plus", "@@", "#"}], "&"}], ",", 
      RowBox[{"sseU234", "    ", "usU234"}]}], "]"}]}], " ", ";"}]}]], "Input",
 CellLabel->"In[20]:="],

Cell["\<\
Here is evaluated the weighted equivalent dose (wT are obtained from Table 10 \
of ICRP 66)\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"wT", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "0.001", ",", "0.999", ",", ".001", ",", ".1665", ",", ".1665", ",", 
     ".333", ",", ".333", ",", ".001"}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[21]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"doseH", " ", "=", " ", 
   RowBox[{"doseEq", " ", "wT"}]}], ";"}]], "Input",
 CellLabel->"In[22]:="],

Cell["\<\
Here is summed the dose for compartments of Extrathoracic (ET1, ET2 and LNet) \
and for  Lungs or thoracic region (BB, bb, AI, LNth).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"totalExtraThoracic", ",", "totalThoracic"}], "}"}], " ", "=", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"Plus", "@@", 
     RowBox[{"Drop", "[", 
      RowBox[{"doseH", ",", 
       RowBox[{"-", "5"}]}], "]"}]}], ",", 
    RowBox[{"Plus", "@@", 
     RowBox[{"Drop", "[", 
      RowBox[{"doseH", ",", "3"}], "]"}]}]}], "}"}]}]], "Input",
 CellLabel->"In[23]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.0000752475384727519`", ",", "0.00004052940720115908`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.3990174359973583`*^9, 3.3990175522309513`*^9, 
  3.4178379736899433`*^9, 3.479962643636038*^9, 3.479963529528038*^9, 
  3.479963680703038*^9, 3.480217242115384*^9, 3.518537090194728*^9, 
  3.519392146927586*^9, 3.51939255809173*^9, 3.5193931056334925`*^9, 
  3.5193980311811867`*^9, 3.54199329004462*^9, 3.59206221063365*^9, 
  3.643596321357071*^9, 3.65631949616076*^9},
 CellLabel->"Out[23]="]
}, Open  ]],

Cell["Finally here are summarized the data", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"Append", "[", 
    RowBox[{
     RowBox[{"Append", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{
         "target", ",", "sseU234", ",", "doseEq", ",", "wT", ",", "doseH"}], 
         "}"}], "]"}], ",", 
       RowBox[{"{", 
        RowBox[{
        "\"\<ExtraThoracic \>\"", ",", "\"\<tissues\>\"", ",", 
         "\"\<Total\>\"", ",", "\"\<(Sv/Bq)\>\"", ",", "totalExtraThoracic"}],
         "}"}]}], "]"}], ",", 
     RowBox[{"{", 
      RowBox[{
      "\"\<Thoracic \>\"", ",", "\"\<tissues\>\"", ",", "\"\<Total\>\"", ",", 
       "\"\<(Sv/Bq)\>\"", ",", "totalThoracic"}], "}"}]}], "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Target\>\"", ",", "\"\<SSE(T<-S)\>\"", ",", "\"\<DoseEq\>\"", 
        ",", "\"\<wT\>\"", ",", 
        "\"\<\!\(\*SubscriptBox[\(H\), \(T\)]\)(Sv)\>\""}], "}"}]}], "}"}]}], 
   ",", 
   RowBox[{"TableSpacing", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"1", ",", "1"}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[24]:="],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"\<\"Target\"\>", "\<\"SSE(T<-S)\"\>", "\<\"DoseEq\"\>", "\<\"wT\"\>", "\
\<\"\\!\\(\\*SubscriptBox[\\(H\\), \\(T\\)]\\)(Sv)\"\>"},
    {"\<\"ET1\"\>", GridBox[{
       {"0.`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "0.`", "0.001`", "0.`"},
    {"\<\"ET2\"\>", GridBox[{
       {"0.`"},
       {"4.804522666666666`*^-9"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "0.00007519201183066326`", 
     "0.999`", "0.0000751168198188326`"},
    {"\<\"LNet\"\>", GridBox[{
       {"1.01504`*^-9"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "0.00013071865391929704`", 
     "0.001`", "1.3071865391929704`*^-7"},
    {"\<\"BBbas\"\>", GridBox[{
       {"0.`"},
       {"0.`"},
       {"4.335066666666666`*^-9"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "4.6044801409684095`*^-6", 
     "0.1665`", "7.666459434712402`*^-7"},
    {"\<\"BBsec\"\>", GridBox[{
       {"1.698578497109827`*^-10"},
       {"2.798694104046243`*^-9"},
       {"5.350962312138729`*^-10"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "0.00004818951100153875`", 
     "0.1665`", "8.023553581756201`*^-6"},
    {"\<\"bb\"\>", GridBox[{
       {"1.8583039999999997`*^-9"},
       {"1.897344`*^-9"},
       {"8.90112`*^-10"},
       {"2.6547199999999997`*^-13"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "0.000029983727094407483`", 
     "0.333`", "9.984581122437692`*^-6"},
    {"\<\"AI\"\>", GridBox[{
       {"1.3841454545454544`*^-11"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "0.00006397398762318478`", 
     "0.333`", "0.00002130333787852053`"},
    {"\<\"LNth\"\>", GridBox[{
       {"1.01504`*^-9"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}], "0.0004512886749734142`", 
     "0.001`", "4.512886749734142`*^-7"},
    {"\<\"ExtraThoracic \"\>", "\<\"tissues\"\>", "\<\"Total\"\>", \
"\<\"(Sv/Bq)\"\>", "0.0000752475384727519`"},
    {"\<\"Thoracic \"\>", "\<\"tissues\"\>", "\<\"Total\"\>", \
"\<\"(Sv/Bq)\"\>", "0.00004052940720115908`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[0.7]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{"ET1", {0.}, 0., 0.001, 0.}, {
    "ET2", {0., 4.804522666666666*^-9}, 0.00007519201183066326, 0.999, 
     0.0000751168198188326}, {
    "LNet", {1.01504*^-9}, 0.00013071865391929704`, 0.001, 
     1.3071865391929704`*^-7}, {
    "BBbas", {0., 0., 4.335066666666666*^-9}, 4.6044801409684095`*^-6, 0.1665,
      7.666459434712402*^-7}, {
    "BBsec", {1.698578497109827*^-10, 2.798694104046243*^-9, 
     5.350962312138729*^-10}, 0.00004818951100153875, 0.1665, 
     8.023553581756201*^-6}, {
    "bb", {1.8583039999999997`*^-9, 1.897344*^-9, 8.90112*^-10, 
     2.6547199999999997`*^-13}, 0.000029983727094407483`, 0.333, 
     9.984581122437692*^-6}, {
    "AI", {1.3841454545454544`*^-11}, 0.00006397398762318478, 0.333, 
     0.00002130333787852053}, {
    "LNth", {1.01504*^-9}, 0.0004512886749734142, 0.001, 
     4.512886749734142*^-7}, {
    "ExtraThoracic ", "tissues", "Total", "(Sv/Bq)", 0.0000752475384727519}, {
    "Thoracic ", "tissues", "Total", "(Sv/Bq)", 0.00004052940720115908}}, 
   TableHeadings -> {
    None, {"Target", "SSE(T<-S)", "DoseEq", "wT", 
      "\!\(\*SubscriptBox[\(H\), \(T\)]\)(Sv)"}}, 
   TableSpacing -> {1, 1}]]], "Output",
 CellChangeTimes->{3.399017436028587*^9, 3.399017552277795*^9, 
  3.417837973799413*^9, 3.479962643669038*^9, 3.479963529581038*^9, 
  3.479963680746038*^9, 3.4802172421935167`*^9, 3.518537090241604*^9, 
  3.5193921469744616`*^9, 3.5193925581698565`*^9, 3.5193931056803684`*^9, 
  3.5193980312280626`*^9, 3.541993290122747*^9, 3.592062210874919*^9, 
  3.643596321388327*^9, 3.656319496192011*^9},
 CellLabel->"Out[24]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "target", ",", " ", "source", ",", " ", "mass", ",", "sseU234", ",", "UsRT",
    ",", " ", "usU234", ",", "  ", "doseEq", ",", " ", "totalExtraThoracic", 
   ",", " ", "totalThoracic"}], " ", "]"}]], "Input",
 CellLabel->"In[25]:="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Loading the package", "SubsectionIcon"],

Cell[TextData[{
 StyleBox["Dose ", "Input"],
 "package computes the acumulated disintegration ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["U", "s"], "(", "\[Tau]", ")"}], TraditionalForm]]],
 " and the committed effective dose ",
 Cell[BoxData[
  FormBox["e", TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "\[Tau]", ")"}], TraditionalForm]]],
 " and the equivalent doses ",
 Cell[BoxData[
  FormBox["H", TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   RowBox[{"(", "\[Tau]", ")"}], TraditionalForm]]],
 " over a period \[Tau], in day, this period is chosen by the user althought \
it is recomended to apply 50*365.25 days. ",
 Cell[BoxData[
  FormBox[
   RowBox[{"H", 
    FormBox[
     RowBox[{"(", "\[Tau]", ")"}],
     TraditionalForm], "  "}], TraditionalForm]]],
 "ans ",
 Cell[BoxData[
  FormBox[
   RowBox[{"e", "(", "\[Tau]", ")"}], TraditionalForm]]],
 " for a specific isotope can be evaluated following two different ways: a) \
Directelly chosen the isotope symbol (this option is only available for some \
selected isotopes)  or b) Given as input data the ",
 Cell[BoxData[
  FormBox[
   RowBox[{"SEE", "(", 
    RowBox[{"T", "\[LeftArrow]", "S"}], ")"}], TraditionalForm]]],
 " factors and the corresponding decay constant value. In the las case, to \
use  the SEE factors given by DCAL-SEECAL is encouregement recommended."
}], "Text"],

Cell["\<\
The package is loaded (Note that Doses autoload others Biokmod package)\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Biokmod`Doses`\>\"", "]"}]], "Input",
 CellLabel->"In[26]:="],

Cell[BoxData["\<\"SysModel, version 1.5.1   2013-11-12\"\>"], "Print",
 CellChangeTimes->{3.5193980312593126`*^9, 3.541993290232125*^9, 
  3.5920622114187126`*^9, 3.643596321482074*^9, 3.656319496285763*^9},
 CellLabel->"During evaluation of In[26]:="],

Cell[BoxData["\<\"Humorap 3.7 2015-06-15\"\>"], "Print",
 CellChangeTimes->{3.5193980312593126`*^9, 3.541993290232125*^9, 
  3.5920622114187126`*^9, 3.643596321482074*^9, 3.656319496285763*^9},
 CellLabel->"During evaluation of In[26]:="],

Cell[BoxData["\<\"Biokdata 1.2.2 2004-09-3\"\>"], "Print",
 CellChangeTimes->{3.5193980312593126`*^9, 3.541993290232125*^9, 
  3.5920622114187126`*^9, 3.643596321482074*^9, 3.656319496332647*^9},
 CellLabel->"During evaluation of In[26]:="],

Cell[BoxData[
 RowBox[{
  StyleBox[
   RowBox[{"DisintegrationReport", "::", "shdw"}], "MessageName"], 
  RowBox[{
  ":", " "}], "\<\"Symbol \[NoBreak]\\!\\(\\\"DisintegrationReport\\\"\\)\
\[NoBreak] appears in multiple contexts \[NoBreak]\\!\\({\\\"Biokmod`Doses`\\\
\", \\\"Global`\\\"}\\)\[NoBreak]; definitions in context \
\[NoBreak]\\!\\(\\\"Biokmod`Doses`\\\"\\)\[NoBreak] may shadow or be shadowed \
by other definitions. \\!\\(\\*ButtonBox[\\\"\[RightSkeleton]\\\", \
ButtonStyle->\\\"Link\\\", ButtonFrame->None, \
ButtonData:>\\\"paclet:ref/message/General/shdw\\\", ButtonNote -> \
\\\"Biokmod`Doses`DisintegrationReport::shdw\\\"]\\)\"\>"}]], "Message", "MSG",
 CellChangeTimes->{3.656319496488885*^9},
 CellLabel->"During evaluation of In[26]:="],

Cell[BoxData["\<\" Doses 1.2   2015-08-27\"\>"], "Print",
 CellChangeTimes->{3.5193980312593126`*^9, 3.541993290232125*^9, 
  3.5920622114187126`*^9, 3.643596321482074*^9, 3.6563194969107714`*^9},
 CellLabel->"During evaluation of In[26]:="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "spell1"}], "]"}], ";", 
  RowBox[{"Off", "[", 
   RowBox[{"General", "::", "spell"}], "]"}], ";"}]], "Input",
 CellLabel->"In[27]:="],

Cell["\<\
The function helps available by Doses can be obtained as usual.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "\"\<Biokmod`Doses`*\>\""}]], "Input",
 CellLabel->"In[28]:="],

Cell[BoxData[
 DynamicModuleBox[{Typeset`open$$ = True}, 
  PaneSelectorBox[{False->
   RowBox[{
    OpenerBox[Dynamic[Typeset`open$$],
     ImageSize->Small], 
    StyleBox["Biokmod`Doses`", "InfoHeading"]}], True->GridBox[{
     {
      RowBox[{
       OpenerBox[Dynamic[Typeset`open$$],
        ImageSize->Small], 
       StyleBox["Biokmod`Doses`", "InfoHeading"]}]},
     {GridBox[{
        {
         ButtonBox["CommittedDose",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-7ef140d5-6fbe-4373-ace8-3bb4f82f0c5d", {
            "CommittedDose", "Biokmod`Doses`"}},
          ButtonNote->"Biokmod`Doses`"], 
         ButtonBox["DoseEnrichedUranium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-7ef140d5-6fbe-4373-ace8-3bb4f82f0c5d", {
            "DoseEnrichedUranium", "Biokmod`Doses`"}},
          ButtonNote->"Biokmod`Doses`"], 
         ButtonBox["elementsymbol",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-7ef140d5-6fbe-4373-ace8-3bb4f82f0c5d", {
            "elementsymbol", "Biokmod`Doses`"}},
          ButtonNote->"Biokmod`Doses`"], 
         ButtonBox["ExportSEE",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-7ef140d5-6fbe-4373-ace8-3bb4f82f0c5d", {
            "ExportSEE", "Biokmod`Doses`"}},
          ButtonNote->"Biokmod`Doses`"], 
         ButtonBox["see",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-7ef140d5-6fbe-4373-ace8-3bb4f82f0c5d", {
            "see", "Biokmod`Doses`"}},
          ButtonNote->"Biokmod`Doses`"]},
        {
         ButtonBox["Decayconst",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-7ef140d5-6fbe-4373-ace8-3bb4f82f0c5d", {
            "Decayconst", "Biokmod`Doses`"}},
          ButtonNote->"Biokmod`Doses`"], 
         ButtonBox["dosefactor",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-7ef140d5-6fbe-4373-ace8-3bb4f82f0c5d", {
            "dosefactor", "Biokmod`Doses`"}},
          ButtonNote->"Biokmod`Doses`"], 
         ButtonBox["elname",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-7ef140d5-6fbe-4373-ace8-3bb4f82f0c5d", {
            "elname", "Biokmod`Doses`"}},
          ButtonNote->"Biokmod`Doses`"], 
         ButtonBox["ImportSEE",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-7ef140d5-6fbe-4373-ace8-3bb4f82f0c5d", {
            "ImportSEE", "Biokmod`Doses`"}},
          ButtonNote->"Biokmod`Doses`"], 
         ButtonBox["targetCompartments",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-7ef140d5-6fbe-4373-ace8-3bb4f82f0c5d", {
            "targetCompartments", "Biokmod`Doses`"}},
          ButtonNote->"Biokmod`Doses`"]},
        {
         ButtonBox["DisintegrationReport",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-7ef140d5-6fbe-4373-ace8-3bb4f82f0c5d", {
            "DisintegrationReport", "Biokmod`Doses`"}},
          ButtonNote->"Biokmod`Doses`"], 
         ButtonBox["doseslabel",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-7ef140d5-6fbe-4373-ace8-3bb4f82f0c5d", {
            "doseslabel", "Biokmod`Doses`"}},
          ButtonNote->"Biokmod`Doses`"], 
         ButtonBox["EnrichedU",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-7ef140d5-6fbe-4373-ace8-3bb4f82f0c5d", {
            "EnrichedU", "Biokmod`Doses`"}},
          ButtonNote->"Biokmod`Doses`"], 
         ButtonBox["isotopesymbol",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-7ef140d5-6fbe-4373-ace8-3bb4f82f0c5d", {
            "isotopesymbol", "Biokmod`Doses`"}},
          ButtonNote->"Biokmod`Doses`"], ""},
        {
         ButtonBox["Disintegrations",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-7ef140d5-6fbe-4373-ace8-3bb4f82f0c5d", {
            "Disintegrations", "Biokmod`Doses`"}},
          ButtonNote->"Biokmod`Doses`"], 
         ButtonBox["elementname",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-7ef140d5-6fbe-4373-ace8-3bb4f82f0c5d", {
            "elementname", "Biokmod`Doses`"}},
          ButtonNote->"Biokmod`Doses`"], 
         ButtonBox["esym",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-7ef140d5-6fbe-4373-ace8-3bb4f82f0c5d", {
            "esym", "Biokmod`Doses`"}},
          ButtonNote->"Biokmod`Doses`"], 
         ButtonBox["label",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-7ef140d5-6fbe-4373-ace8-3bb4f82f0c5d", {
            "label", "Biokmod`Doses`"}},
          ButtonNote->"Biokmod`Doses`"], ""}
       },
       DefaultBaseStyle->"InfoGrid",
       GridBoxItemSize->{"Columns" -> {{
            Scaled[0.19]}}}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}]}, 
   Dynamic[Typeset`open$$],
   ImageSize->Automatic]]], "Print", "InfoCell",
 CellChangeTimes->{3.6563195015982466`*^9}]
}, Open  ]],

Cell[TextData[{
 "The name of the elements and the corresponding symbol and viceversa can be \
shown using ",
 StyleBox["elname", "Input"],
 " and ",
 StyleBox["esym", "Input"]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"elname", "[", "cobalt", "]"}]], "Input",
 CellLabel->"In[29]:="],

Cell[BoxData["\<\"Co\"\>"], "Output",
 CellChangeTimes->{3.3990168213941364`*^9, 3.417838098016019*^9, 
  3.479963688844038*^9, 3.4802172475534067`*^9, 3.5185370935541673`*^9, 
  3.5193921472557173`*^9, 3.519392558669866*^9, 3.5193931061335025`*^9, 
  3.51939803422812*^9, 3.541993291919668*^9, 3.5920622157628098`*^9, 
  3.643596322138339*^9, 3.6563195017701206`*^9},
 CellLabel->"Out[29]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"esym", "[", "\"\<Co\>\"", "]"}]], "Input",
 CellLabel->"In[30]:="],

Cell[BoxData["cobalt"], "Output",
 CellChangeTimes->{3.3990168214254*^9, 3.4178380980472956`*^9, 
  3.4799636889250383`*^9, 3.480217247584659*^9, 3.5185370935854177`*^9, 
  3.5193921472869678`*^9, 3.5193925587948685`*^9, 3.519393106164753*^9, 
  3.5193980342593703`*^9, 3.541993291966544*^9, 3.5920622159078217`*^9, 
  3.6435963221539574`*^9, 3.6563195017857533`*^9},
 CellLabel->"Out[30]="]
}, Open  ]],

Cell[TextData[{
 "Here are shown of elements availAble by ",
 StyleBox["Doses", "Input"],
 StyleBox[".", "Text"]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Sort", "[", 
  RowBox[{"Transpose", "[", 
   RowBox[{"{", 
    RowBox[{"elementname", ",", 
     RowBox[{"Evaluate", "[", 
      RowBox[{"Map", "[", 
       RowBox[{"elname", ",", "elementname"}], "]"}], "]"}]}], "}"}], "]"}], 
  "]"}]], "Input",
 CellLabel->"In[31]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"actinium", ",", "\<\"Ac\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"aluminium", ",", "\<\"Al\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"americium", ",", "\<\"Am\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"antimony", ",", "\<\"Sb\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"arsenic", ",", "\<\"As\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"astatine", ",", "\<\"At\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"barium", ",", "\<\"Ba\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"berkelium", ",", "\<\"Bk\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"beryllium", ",", "\<\"Be\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"bismuth", ",", "\<\"Bi\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"bromine", ",", "\<\"Br\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cadmium", ",", "\<\"Cd\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"caesium", ",", "\<\"Cs\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"calcium", ",", "\<\"Ca\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"californium", ",", "\<\"Cf\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cerium", ",", "\<\"Ce\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"chlorine", ",", "\<\"Cl\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"chromium", ",", "\<\"Cr\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"cobalt", ",", "\<\"Co\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"copper", ",", "\<\"Cu\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"curium", ",", "\<\"Cm\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"dysprosium", ",", "\<\"Dy\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"einsteinium", ",", "\<\"Es\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"erbium", ",", "\<\"Er\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"europium", ",", "\<\"Eu\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"fermium", ",", "\<\"Fm\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"gadolinium", ",", "\<\"Gd\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"gallium", ",", "\<\"Ga\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"germanium", ",", "\<\"Ge\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"gold", ",", "\<\"Au\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"hafnium", ",", "\<\"Hf\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"holmium", ",", "\<\"Ho\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"indium", ",", "\<\"In\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"iodine", ",", "\<\"I\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"iridium", ",", "\<\"Ir\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"iron", ",", "\<\"Fe\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"lanthanum", ",", "\<\"La\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"lead", ",", "\<\"Pb\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"lutetium", ",", "\<\"Lu\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"magnesium", ",", "\<\"Mg\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"manganese", ",", "\<\"Mn\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"mendelevium", ",", "\<\"Md\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"mercuryinorg", ",", "\<\"Hg\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"mercuryorg", ",", "\<\"Hg\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"molybdenum", ",", "\<\"Mo\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"neodymium", ",", "\<\"Nd\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"neptunium", ",", "\<\"Np\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"nickel", ",", "\<\"Ni\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"niobium", ",", "\<\"Nb\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"osmium", ",", "\<\"Os\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"palladium", ",", "\<\"Pd\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"phosphorus", ",", "\<\"P\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"platinum", ",", "\<\"Pt\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"plutonium", ",", "\<\"Pu\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"polonium", ",", "\<\"Po\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"potassium", ",", "\<\"K\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"praseodymium", ",", "\<\"Pr\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"promethium", ",", "\<\"Pm\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"protactinium", ",", "\<\"Pa\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"radium", ",", "\<\"Ra\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"rhenium", ",", "\<\"Re\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"rhodium", ",", "\<\"Rh\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"rubidium", ",", "\<\"Rb\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ruthenium", ",", "\<\"Ru\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"samarium", ",", "\<\"Sm\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"scandium", ",", "\<\"Sc\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"selenium", ",", "\<\"Se\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"silicon", ",", "\<\"Si\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"silver", ",", "\<\"Ag\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"sodium", ",", "\<\"Na\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"strontium", ",", "\<\"Sr\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"sulfur", ",", "\<\"S\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"tantalum", ",", "\<\"Ta\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"technetium", ",", "\<\"Tc\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"tellurium", ",", "\<\"Te\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"terbium", ",", "\<\"Tb\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"thallium", ",", "\<\"Tl\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"thorium", ",", "\<\"Th\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"thulium", ",", "\<\"Tm\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"tin", ",", "\<\"Sn\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"titanium", ",", "\<\"Ti\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"tungsten", ",", "\<\"W\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"uranium", ",", "\<\"U\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"vanadium", ",", "\<\"V\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"ytterbium", ",", "\<\"Yb\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"yttrium", ",", "\<\"Y\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"zinc", ",", "\<\"Zn\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"zirconium", ",", "\<\"Zr\"\>"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.399016821456663*^9, 3.4178380980785723`*^9, 
  3.479963689086038*^9, 3.4802172476471653`*^9, 3.5185370936791697`*^9, 
  3.519392147318218*^9, 3.5193925588729954`*^9, 3.519393106211629*^9, 
  3.5193980343062468`*^9, 3.541993292029046*^9, 3.592062216175343*^9, 
  3.6435963221852036`*^9, 3.656319501817004*^9},
 CellLabel->"Out[31]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["Doses", "Input"],
 " includes the disintegration constants (",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["day", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 ") and the SEE factor (Bq/Sv) for some isotopes "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "isotopesymbol"}]], "Input",
 CellLabel->"In[32]:="],

Cell[BoxData[
 StyleBox["\<\"Symbol of isotopes whose disintegration constans, in day^-1 \
and see \\nfactors are included in the present version of Doses\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6563195018794947`*^9},
 CellTags->"Info-c74cd3e3-9188-4da4-8d2d-d49dbca22874"]
}, Open  ]],

Cell[TextData[{
 "Here are shown the decay constant included in Biokmod (in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["d", 
    RowBox[{
     RowBox[{"-", "1"}], ")"}]], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "MathCaption",
 CellChangeTimes->{{3.656319545098361*^9, 3.656319670410746*^9}, {
  3.656319777176817*^9, 3.6563197846455936`*^9}, {3.656319980927556*^9, 
  3.6563199891619606`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Thread", "[", 
   RowBox[{"isotopesymbol", "->", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Decayconst", "[", "#", "]"}], "&"}], ",", "isotopesymbol"}], 
     "]"}]}], "]"}], "//", "N"}]], "Input",
 CellChangeTimes->{{3.65631987103653*^9, 3.6563198720365076`*^9}},
 CellLabel->"In[89]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"\<\"U 234\"\>", "\[Rule]", "7.777596532354274`*^-9"}], ",", 
   RowBox[{"\<\"U 235\"\>", "\[Rule]", "2.69564425269097`*^-12"}], ",", 
   RowBox[{"\<\"U 238\"\>", "\[Rule]", "4.2454889348868965`*^-13"}], ",", 
   RowBox[{"\<\"Pu 239\"\>", "\[Rule]", "7.874413086698934`*^-8"}], ",", 
   RowBox[{"\<\"Co 60\"\>", "\[Rule]", "0.00036010124362323404`"}], ",", 
   RowBox[{"\<\"Cs 137\"\>", "\[Rule]", "0.00006325778512981477`"}], ",", 
   RowBox[{"\<\"I 125\"\>", "\[Rule]", "0.011533230957736194`"}], ",", 
   RowBox[{"\<\"I 131\"\>", "\[Rule]", "0.08664339756999316`"}], ",", 
   RowBox[{"\<\"Sr 90\"\>", "\[Rule]", "0.00006521421147403585`"}], ",", 
   RowBox[{"\<\"Sr 89\"\>", "\[Rule]", "0.013725686743761293`"}], ",", 
   RowBox[{"\<\"Y 90\"\>", "\[Rule]", "0.25993019270997947`"}], ",", 
   RowBox[{"\<\"Th 232\"\>", "\[Rule]", "0.`"}], ",", 
   RowBox[{"\<\"Ra 226\"\>", "\[Rule]", "1.1860834711840268`*^-6"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399016822081927*^9, 3.417838098594643*^9, 
  3.479963690470038*^9, 3.4802172478190565`*^9, 3.5185370938822985`*^9, 
  3.5193921475838485`*^9, 3.519392559201126*^9, 3.519393106633512*^9, 
  3.519398034509375*^9, 3.541993292716563*^9, 3.592062216927903*^9, 
  3.6435963223414555`*^9, 3.6563195019107533`*^9, 3.6563198728646183`*^9},
 CellLabel->"Out[89]="]
}, Open  ]],

Cell[TextData[{
 "Other decay constants can be obtained using the Mathematica function ",
 Cell[BoxData[
  ButtonBox[Cell["IsotopeData"],
   BaseStyle->Dynamic[
     If[
      CurrentValue["MouseOver"], {
      "Link", FontColor -> RGBColor[0.854902, 0.396078, 0.145098]}, {"Link"}]],
   ButtonData->"paclet:ref/IsotopeData"]]],
 ". The decay lifetime ",
 Cell[BoxData[
  FormBox["\[Tau]", TraditionalForm]], "InlineMath"],
 " in seconds for any isotopes are available using:  "
}], "MathCaption",
 CellChangeTimes->{{3.6563197710205164`*^9, 3.6563198351614027`*^9}, {
  3.65631990948977*^9, 3.6563200023495083`*^9}, {3.6563201336156096`*^9, 
  3.656320134256238*^9}, {3.656320179943903*^9, 3.6563202396628675`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"IsotopeData", "[", 
  RowBox[{"\"\<U235\>\"", ",", "\"\<Lifetime\>\""}], "]"}]], "Input",
 CellLabel->"In[92]:="],

Cell[BoxData[
 TemplateBox[{"3.21`3.*^16","\"s\"","seconds","\"Seconds\""},
  "Quantity"]], "Output",
 CellChangeTimes->{3.656320251084784*^9},
 CellLabel->"Out[92]="]
}, Open  ]],

Cell[TextData[{
 "It can be converted to other units, for instance the decay constant in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["d", 
    RowBox[{"-", "1"}]], TraditionalForm]],
  FormatType->"TraditionalForm"]
}], "MathCaption",
 CellChangeTimes->{{3.6563202575222826`*^9, 3.656320316163144*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"1", "/", 
  RowBox[{"QuantityMagnitude", "[", 
   RowBox[{"UnitConvert", "[", 
    RowBox[{
     RowBox[{"IsotopeData", "[", 
      RowBox[{"\"\<U235\>\"", ",", "\"\<Lifetime\>\""}], "]"}], ",", 
     "\"\<Days\>\""}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.6563200862091866`*^9, 3.6563201055217037`*^9}, {
  3.6563203240225487`*^9, 3.656320338850726*^9}},
 CellLabel->"In[93]:=",
 CellID->150092720],

Cell[BoxData["2.69158878504672897196261682`3.*^-12"], "Output",
 CellChangeTimes->{3.6563201066467037`*^9, 3.656320339756934*^9},
 ImageSize->{74, 17},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"Out[93]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["New functions ",
 FontColor->RGBColor[0, 0, 1]]], "SubsectionIcon",
 CellChangeTimes->{{3.6496642301849623`*^9, 3.6496642478255515`*^9}, {
  3.649664347965965*^9, 3.6496643565753207`*^9}, {3.6563205229607687`*^9, 
  3.656320532101428*^9}}],

Cell["\<\
At present version of Biokmod`Doses`\[CloseCurlyDoubleQuote] has been \
included the following funtions:\
\>", "Text",
 CellChangeTimes->{{3.649664595637291*^9, 3.64966472390267*^9}, {
  3.649664803699376*^9, 3.6496648734023542`*^9}, {3.656320566554676*^9, 
  3.6563206193673673`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "EnrichedU"}]], "Input",
 CellChangeTimes->{3.649664313934787*^9},
 CellLabel->"In[55]:="],

Cell[BoxData[
 StyleBox["\<\"EnrichedU[enr, actU] where enr (% wt U235) and act (activity \
in Bq, by default it assumed 100 Bq) returns the isotopic composition for \
standard uranium (no reprocessed)\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6563195218171763`*^9},
 CellTags->"Info-9c7d9f7e-df35-4cf3-b463-4742e3852c45"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "DoseEnrichedUranium"}]], "Input",
 CellChangeTimes->{3.649664326997258*^9},
 CellLabel->"In[57]:="],

Cell[BoxData[
 StyleBox["\<\"DoseEnrichedUranium[totalintake, enriched, amad, fs] assuming \
an totalintake, in Bq, by inhalation of uranium oxide enriched (% wt U235), \
of radioactive aerosols of AMAD amad with a fraction fs of type S and the \
rest type M returns efective dose. The isotopic composition for standard \
uranium (no reprocessed) is used\"\>", "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.6563195218796744`*^9},
 CellTags->"Info-7148e4c2-c689-4073-ab16-66c8599c2771"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Example: A worker has been exposed by inhalation of a 25 000 Bq at uranium \
oxide (89% S and 11% M) enriched 3.7% wt U235, AMAD 5.\
\>", "SubsubsectionIcon",
 CellChangeTimes->{{3.649664595637291*^9, 3.64966472390267*^9}, {
  3.649664803699376*^9, 3.6496648734023542`*^9}, {3.6563206443518343`*^9, 
  3.656320649539352*^9}}],

Cell["The isotopic uranium composition is :", "Text",
 CellChangeTimes->{{3.6496647288557367`*^9, 3.649664765199459*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"EnrichedU", "[", "3.7", "]"}], " "}]], "Input",
 CellChangeTimes->{{3.516513734879484*^9, 3.5165137527702236`*^9}, {
   3.5181646022518253`*^9, 3.5181646412066956`*^9}, {3.5183219983394623`*^9, 
   3.518322003558112*^9}, {3.643948076945075*^9, 3.6439481759604015`*^9}, {
   3.643948220132248*^9, 3.6439482216791286`*^9}, {3.643949941504244*^9, 
   3.6439499463792343`*^9}, 3.643951818424743*^9, {3.643951848956091*^9, 
   3.6439518511904745`*^9}, {3.6439520629880514`*^9, 3.643952064347401*^9}, {
   3.643952477408459*^9, 3.6439524806271043`*^9}},
 CellLabel->"In[56]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"U234\"\>", ",", "0.031412686216000005`", ",", 
     "82.94359883826236`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"U235\"\>", ",", "3.7`", ",", "3.380106436963569`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"U238\"\>", ",", "96.268587313784`", ",", 
     "13.67629472477406`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.5165137536764793`*^9, {3.518164608392725*^9, 3.5181646421911144`*^9}, {
   3.518322004417471*^9, 3.5183220094173746`*^9}, 3.5183238582357297`*^9, {
   3.643948084007497*^9, 3.6439481767728534`*^9}, 3.6439482226165867`*^9, 
   3.643949951004192*^9, {3.643951526968348*^9, 3.6439515401092024`*^9}, 
   3.643951575875408*^9, 3.643951625016836*^9, {3.6439516982680154`*^9, 
   3.643951723486879*^9}, {3.6439518270653353`*^9, 3.6439518521279197`*^9}, 
   3.6439518877530355`*^9, {3.6439519334719515`*^9, 3.6439519579407825`*^9}, {
   3.6439519981440296`*^9, 3.6439520082065763`*^9}, 3.64395206539431*^9, {
   3.643952149753907*^9, 3.643952174066499*^9}, 3.643952296816894*^9, 
   3.643952332457652*^9, 3.6439524814707747`*^9, 3.644029886089327*^9, 
   3.6440299214800572`*^9, 3.649661559762968*^9, 3.6563195218171763`*^9},
 CellLabel->"Out[56]="]
}, Open  ]],

Cell["The efective dose, in mSv, is: ", "Text",
 CellChangeTimes->{{3.649664789699356*^9, 3.649664800855632*^9}, {
  3.6496648879335747`*^9, 3.649664900574171*^9}, {3.6496649736990175`*^9, 
  3.6496649753865137`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoseEnrichedUranium", "[", 
  RowBox[{"24763", ",", " ", "4", ",", " ", "AMAD5", ",", "0.89"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.644030304512591*^9, 3.6440303353564873`*^9}, {
  3.6440304171692595`*^9, 3.64403042376303*^9}, {3.644030809858008*^9, 
  3.6440308136237016`*^9}, {3.649664278200486*^9, 3.649664279200486*^9}},
 CellLabel->"In[58]:="],

Cell[BoxData["131.3032516858395`"], "Output",
 CellChangeTimes->{3.6440304625131035`*^9, 3.644030545497766*^9, 
  3.644030895186416*^9, 3.644030978858568*^9, 3.6496615964191427`*^9, 
  3.64966343943659*^9, 3.656319556629592*^9},
 CellLabel->"Out[58]="]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Disintegrations", "SubsectionIcon"],

Cell[TextData[{
 StyleBox["Doses", "Input"],
 " includes some function for computing the acumulated disintegration during \
a time \[Tau]."
}], "Text"],

Cell["\<\
The disintegrations can be evaluate in the  RT (respiratory tract) , GI \
(gastrointestinal tract) and the systemic compartments . All these \
compartment are usually called: Source compartments\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"label", "[", "\"\<RT\>\"", "]"}]], "Input",
 CellLabel->"In[34]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"AI\"\>", ",", "\<\"bb1\"\>", ",", "\<\"bb2\"\>", 
   ",", "\<\"bbseq\"\>", ",", "\<\"BB1\"\>", ",", "\<\"BB2\"\>", 
   ",", "\<\"BBseq\"\>", ",", "\<\"ET2\"\>", ",", "\<\"ET1\"\>", 
   ",", "\<\"ETseq\"\>", ",", "\<\"LNth\"\>", ",", "\<\"LNet\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399016850953492*^9, 3.4178380986259203`*^9, 
  3.479963690525038*^9, 3.48021724785031*^9, 3.5185370939135494`*^9, 
  3.5193921476307244`*^9, 3.519392559248002*^9, 3.5193931066960135`*^9, 
  3.519398034540626*^9, 3.541993292825941*^9, 3.592062217161672*^9, 
  3.643596322372706*^9, 3.6563195019107533`*^9},
 CellLabel->"Out[34]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"label", "[", "\"\<GI\>\"", "]"}]}]], "Input",
 CellLabel->"In[35]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"ST\"\>", ",", "\<\"SI\"\>", ",", "\<\"B\"\>", 
   ",", "\<\"ULI\"\>", ",", "\<\"LLI\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.3990168510160184`*^9, 3.417838098657197*^9, 
  3.479963690580038*^9, 3.4802172478815627`*^9, 3.5185370939291744`*^9, 
  3.519392147661975*^9, 3.519392559279253*^9, 3.5193931067585144`*^9, 
  3.5193980345875015`*^9, 3.541993292888443*^9, 3.592062217322935*^9, 
  3.6435963223883286`*^9, 3.6563195019107533`*^9},
 CellLabel->"Out[35]="]
}, Open  ]],

Cell["\<\
 The systemic compartments are specific for each element. Here they are shown \
the systemic compartments for uranium\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"label", "[", "\"\<U\>\"", "]"}]], "Input",
 CellLabel->"In[36]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"Soft Tissues\"\>", ",", "\<\"UB_Content\"\>", 
   ",", "\<\"Kydneys\"\>", ",", "\<\"Liver\"\>", ",", "\<\"TrabSurface\"\>", 
   ",", "\<\"CorticalSurf\"\>", ",", "\<\"Trab. Vol.\"\>", 
   ",", "\<\"Cort. Vol\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.39901685103165*^9, 3.4178380986884737`*^9, 
  3.479963690902038*^9, 3.4802172479284425`*^9, 3.5185370939604254`*^9, 
  3.519392147693226*^9, 3.5193925593105035`*^9, 3.5193931068053904`*^9, 
  3.5193980346187525`*^9, 3.5419932929509444`*^9, 3.5920622175517035`*^9, 
  3.6435963224195795`*^9, 3.656319501926369*^9},
 CellLabel->"Out[36]="]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"Disintegrations", "[", 
   StyleBox[
    RowBox[{"element", 
     StyleBox[",", "Text"], 
     StyleBox[" ", "Text"], 
     StyleBox["\"\<IntakeWay\>\"", "Text"], ",", " ", 
     StyleBox["Intake", "Text"], 
     StyleBox[",", "Text"], 
     StyleBox[" ", "Text"], "IFD", " ", ",", " ", "FRA", ",", " ", "f1", ",", 
     " ", "\[Tau]", ",", " ", "\[Lambda]", ",", " ", "options"}],
    FontWeight->"Plain",
    FontSlant->"Italic"], 
   StyleBox["]", "Text"]}]], "Input"],
 " \ngives for element the accumulated disintegrations in the source \
compartments defined with  Intake, IFD , FRA, f1, t, \[Lambda]. \n\nIf \
\"IntakeWay\"  is \"Injection\" or \"Ingestion\"  IFD and FRA are \
unnecessary, then \n\n",
 Cell[BoxData[
  RowBox[{"Disintegrations", "[", 
   StyleBox[
    RowBox[{"element", 
     StyleBox[",", "Text"], 
     StyleBox[" ", "Text"], 
     StyleBox["\"\<IntakeWay\>\"", "Text"], ",", " ", 
     StyleBox["Intake", "Text"], 
     StyleBox[",", "Text"], 
     StyleBox[" ", "Text"], "f1", ",", " ", "t", ",", " ", "\[Lambda]", ",", 
     " ", "options"}],
    FontWeight->"Plain",
    FontSlant->"Italic"], 
   StyleBox["]", "Text"]}]], "Input"],
 " \n"
}], "DefinitionBox",
 CellChangeTimes->{3.4799639514140377`*^9}],

Cell[TextData[{
 StyleBox["element",
  FontWeight->"Bold"],
 " write the symbol of the element using double quotes (ex: ",
 StyleBox["\"U\"", "MR"],
 ") \n\n",
 StyleBox["IntakeWay ",
  FontWeight->"Bold"],
 "write \"Injection\" or \"Ingestion\" or \"Inhalation\" (To use double \
quotes)\n\n",
 StyleBox["Intake",
  FontWeight->"Bold"],
 ".- Quantity intake in Bq. If we are interested in to obtain the dose \
conversion factor (DCF)  write 1.\n"
}], "Text",
 CellChangeTimes->{{3.479963959606038*^9, 3.479963969643038*^9}}],

Cell[TextData[{
 StyleBox["IFD",
  FontWeight->"Bold"],
 ": (only by Inhalation) write AMADAdultW[x] (for adult worker), being x the \
AMAD value which you wish . Then the program will select the appropriated \
Initial fractional Deposition (IFD) values. If you wish, you  can be directly \
written the IFD values with this pattern ",
 Cell[BoxData[
  RowBox[{"{", "AI"}]]],
 ", ",
 Cell[BoxData[
  SubscriptBox["bb", 
   RowBox[{"fast", "+", "seq"}]]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["bb", "slow"], ","}]]],
 " ",
 Cell[BoxData[
  SubscriptBox["BB", 
   RowBox[{"fast", "+", "seq"}]]]],
 " ",
 Cell[BoxData[
  RowBox[{",", " ", 
   SubscriptBox["BB", "slow"], ",", " "}]]],
 " ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["ET", "2"], ",", " ", 
    SubscriptBox["ET", "1"]}], "}"}]]],
 " (i.e: {0.12, 0.011, 0.011, 0.0039, 0.004, 0.11, 0.089}). ",
 StyleBox["IFD",
  FontSlant->"Italic"],
 " for normal adult (female and male), Child (10 y old) or Infant (1 y old) \
can be obtained applied  ",
 StyleBox["AMADAdultP[x], ", "Input",
  FontWeight->"Bold"],
 "  ",
 StyleBox["AMADyr10[x], AMADyr1[x].", "Input",
  FontWeight->"Bold"],
 "  \n\n",
 StyleBox["FRA",
  FontWeight->"Bold"],
 " (only by Inhalation) .",
 StyleBox["FRA: Fractional rate of absorption",
  FontSlant->"Italic"],
 "  of material into the blood. Write: F or M or S, then the program will \
select the appropriate fractional rate of absorption: type F:{100, 0, 0};  \
type M: {10, 90, 0.005};  type S: {0.1, 100, 0.0001}. If you wish, you  can \
be directly written the FRA values with this pattern {",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    SubscriptBox["s", "p"], ",", 
    SubscriptBox["s", "pt"], ",", 
    SubscriptBox["s", "t"]}], "Input"]]],
 "} (i.e.: {10, 90, 0.005}) \n\n",
 StyleBox["f1",
  FontWeight->"Bold"],
 ": fraction from GI to Blood. By default are given the included in ICRPs, \
but you can change this value.\n"
}], "Text"],

Cell[TextData[{
 StyleBox["\[Tau]",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontSlant->"Italic"],
 "  in days. If ",
 StyleBox["Disintegrations", "Input"],
 " is used to obtain DCF then should be introduced ",
 StyleBox["\[Tau]",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox["  =",
  FontSlant->"Italic"],
 " 50\[Times]365.25 days.\n\n",
 StyleBox["\[Lambda]",
  FontFamily->"Times New Roman Greek",
  FontWeight->"Bold"],
 " is the radioactive decay constant, in day",
 StyleBox["-1",
  FontVariations->{"CompatibilityType"->"Superscript"}],
 ". If you know the half-life T, as ",
 StyleBox["\[Lambda]",
  FontFamily->"Times New Roman Greek",
  FontWeight->"Bold"],
 " = Log[t]/T you can write: Log[2]/T, ex.: For T = 8.2 year, then write: \
Log[2]/(365.25*8.2) . The decay constant for isotopes included in ",
 StyleBox["isotopesymbol", "Input"],
 " can be obtained using ",
 StyleBox["Decayconst[", "Input"],
 StyleBox["isotope", "Input",
  FontWeight->"Plain",
  FontSlant->"Italic"],
 StyleBox["] \n\n", "Input"],
 StyleBox["Options",
  FontWeight->"Bold"],
 ": ",
 StyleBox["DisintegrationReport\[Rule] \"True\"", "Input"],
 " gives the solution in table format."
}], "Text",
 CellChangeTimes->{3.479963979076038*^9}],

Cell[CellGroupData[{

Cell["Examples", "SubsubsectionIcon"],

Cell[TextData[{
 "Here it  is obtained for Co 60 the accumulated disintegration in different \
compartments and organ as function of the time assuming an acute intake \"1 \
Bq\"  by injection at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "=", "0"}], TraditionalForm]]],
 "."
}], "MathCaption",
 CellChangeTimes->{
  3.479963707261038*^9, {3.479963993563038*^9, 3.479964009845038*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Disintegrations", "[", 
   RowBox[{
   "\"\<Co\>\"", ",", "\"\<Injection\>\"", ",", "1", ",", "1", ",", "t", " ", 
    ",", " ", 
    RowBox[{"Decayconst", "[", "\"\<Co 60\>\"", "]"}]}], "]"}], "//", 
  "Chop"}]], "Input",
 CellLabel->"In[37]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"ST\"\>", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"SI\"\>", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"B\"\>", ",", 
     RowBox[{"62308.24069374401`", "\[VeryThinSpace]", "-", 
      RowBox[{"62308.24069374401`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "1.3866544623635135`"}], " ", "t"}]]}]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"ULI\"\>", ",", 
     RowBox[{"6625.654883136971`", "\[VeryThinSpace]", "+", 
      RowBox[{"10997.961184472415`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "1.8003601012436232`"}], " ", "t"}]]}], "-", 
      RowBox[{"14073.16757914125`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "1.3866544623635135`"}], " ", "t"}]]}], "-", 
      RowBox[{"2390.6125455307224`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.11588463133694744`"}], " ", "t"}]]}], "-", 
      RowBox[{"674.9057044349211`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.011912554252955655`"}], " ", "t"}]]}], "-", 
      RowBox[{"484.9302385024937`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0012265352193231657`"}], " ", "t"}]]}]}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"LLI\"\>", ",", 
     RowBox[{"11921.885703778273`", "\[VeryThinSpace]", "-", 
      RowBox[{"24745.412665062933`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "1.8003601012436232`"}], " ", "t"}]]}], "+", 
      RowBox[{"65576.16209829245`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "1.3866544623635135`"}], " ", "t"}]]}], "-", 
      RowBox[{"45784.82887611435`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "1.0003601012436232`"}], " ", "t"}]]}], "-", 
      RowBox[{"4865.146324984384`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.11588463133694744`"}], " ", "t"}]]}], "-", 
      RowBox[{"1229.0285627005835`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.011912554252955655`"}], " ", "t"}]]}], "-", 
      RowBox[{"873.6313732084742`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0012265352193231657`"}], " ", "t"}]]}]}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Other\"\>", ",", 
     RowBox[{"7.991113339726498`*^6", "+", 
      RowBox[{"32909.6925687663`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "1.3866544623635135`"}], " ", "t"}]]}], "-", 
      RowBox[{"244004.43190906805`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.11588463133694744`"}], " ", "t"}]]}], "-", 
      RowBox[{"731380.0933880407`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.011912554252955655`"}], " ", "t"}]]}], "-", 
      RowBox[{"7.048638506998155`*^6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0012265352193231657`"}], " ", "t"}]]}]}]}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"UB_Content\"\>", ",", 
     RowBox[{"5964.103374684699`", "\[VeryThinSpace]", "+", 
      RowBox[{"400.59009239057366`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "12.000360101243624`"}], " ", "t"}]]}], "-", 
      RowBox[{"3291.3003144167437`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "1.3866544623635135`"}], " ", "t"}]]}], "-", 
      RowBox[{"2033.036225045587`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.11588463133694744`"}], " ", "t"}]]}], "-", 
      RowBox[{"604.0982938694`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.011912554252955655`"}], " ", "t"}]]}], "-", 
      RowBox[{"436.258633743542`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0012265352193231657`"}], " ", "t"}]]}]}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399016851688177*^9, 3.4178380990325212`*^9, 
  3.479963691903038*^9, 3.480217248991044*^9, 3.518537094116678*^9, 
  3.5193921478651037`*^9, 3.5193925594980073`*^9, 3.5193931069928937`*^9, 
  3.519398034790631*^9, 3.5419932930603223`*^9, 3.5920622178929806`*^9, 
  3.6435963224820814`*^9, 3.6563195020201187`*^9},
 CellLabel->"Out[37]="]
}, Open  ]],

Cell["\<\
It can be obtained the accumulated disintegration for different times (in \
days after the acute intake by inhalation happened)\
\>", "MathCaption",
 CellChangeTimes->{{3.479964040890038*^9, 3.479964061061038*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Disintegrations", "[", 
   RowBox[{"\"\<Co\>\"", ",", "\"\<Inhalation\>\"", ",", "1", ",", 
    RowBox[{"AMADAdultW", "[", "5", "]"}], ",", "F", ",", "1", ",", 
    RowBox[{"{", 
     RowBox[{"1.0", ",", " ", "10", ",", " ", "100", ",", " ", 
      RowBox[{"365.35", "*", "50"}]}], "}"}], " ", ",", " ", 
    RowBox[{"Decayconst", "[", "\"\<Co 60\>\"", "]"}], ",", " ", 
    RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<True\>\""}]}], 
   "]"}]}]], "Input",
 CellLabel->"In[38]:="],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"\<\"Compartment\"\>", 
     RowBox[{"1.`", " ", "\<\"day\"\>"}], 
     RowBox[{"10", " ", "\<\"day\"\>"}], 
     RowBox[{"100", " ", "\<\"day\"\>"}], 
     RowBox[{"18267.5`", " ", "\<\"day\"\>"}]},
    {"\<\"AI\"\>", "45.95209252682688`", "45.95209252682688`", 
     "45.95209252682688`", "45.95209252682688`"},
    {"\<\"bb1\"\>", "5.567286041243797`", "5.567286041243797`", 
     "5.567286041243797`", "5.567286041243797`"},
    {"\<\"bb2\"\>", "3.786626376398407`", "3.786626376398407`", 
     "3.786626376398407`", "3.786626376398407`"},
    {"\<\"bbseq\"\>", "0.06670379949883856`", "0.06670379949883856`", 
     "0.06670379949883856`", "0.06670379949883856`"},
    {"\<\"BB1\"\>", "9.299908513865073`", "9.299908513865073`", 
     "9.299908513865073`", "9.299908513865073`"},
    {"\<\"BB2\"\>", "5.114191326335532`", "5.114191326335532`", 
     "5.114191326335532`", "5.114191326335532`"},
    {"\<\"BBseq\"\>", "0.10737293045569654`", "0.10737293045569654`", 
     "0.10737293045569654`", "0.10737293045569654`"},
    {"\<\"ET2\"\>", "172.70408919960573`", "172.70408919960573`", 
     "172.70408919960573`", "172.70408919960573`"},
    {"\<\"ET1\"\>", "18495.36767368914`", "29251.788042884255`", 
     "29253.111358220056`", "29253.111358220056`"},
    {"\<\"ETseq\"\>", "0.17232245624011064`", "0.17232245624011064`", 
     "0.17232245624011064`", "0.17232245624011064`"},
    {"\<\"LNth\"\>", "0.000018326708507987455`", "0.000018326708507987455`", 
     "0.000018326708507987455`", "0.000018326708507987455`"},
    {"\<\"LNet\"\>", "1.7232183570636828`*^-6", "1.7232183570636828`*^-6", 
     "1.7232183570636828`*^-6", "1.7232183570636828`*^-6"},
    {"\<\"ST\"\>", "719.5895747549422`", "719.5895747858245`", 
     "719.5895747858245`", "719.5895747858245`"},
    {"\<\"SI\"\>", "0.`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
    {"\<\"B\"\>", "22220.93046714775`", "29962.16536156339`", 
     "29962.194796592194`", "29962.194796592194`"},
    {"\<\"ULI\"\>", "770.2814252984967`", "2305.7839436312793`", 
     "2881.157720941263`", "3186.0819700664783`"},
    {"\<\"LLI\"\>", "441.9287705378265`", "4055.8949036802687`", 
     "5181.6199311075925`", "5732.883127775722`"},
    {"\<\"Other\"\>", "8948.182243231684`", "145219.83081571944`", 
     "737480.0879778131`", "3.842690658928214`*^6"},
    {"\<\"Liver\"\>", "0.`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
    {"\<\"UB_Content\"\>", "1089.382178391641`", "2095.1331063156094`", 
     "2594.0907846596137`", "2867.9613660618206`"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{
    "AI", 45.95209252682688, 45.95209252682688, 45.95209252682688, 
     45.95209252682688}, {
    "bb1", 5.567286041243797, 5.567286041243797, 5.567286041243797, 
     5.567286041243797}, {
    "bb2", 3.786626376398407, 3.786626376398407, 3.786626376398407, 
     3.786626376398407}, {
    "bbseq", 0.06670379949883856, 0.06670379949883856, 0.06670379949883856, 
     0.06670379949883856}, {
    "BB1", 9.299908513865073, 9.299908513865073, 9.299908513865073, 
     9.299908513865073}, {
    "BB2", 5.114191326335532, 5.114191326335532, 5.114191326335532, 
     5.114191326335532}, {
    "BBseq", 0.10737293045569654`, 0.10737293045569654`, 0.10737293045569654`,
      0.10737293045569654`}, {
    "ET2", 172.70408919960573`, 172.70408919960573`, 172.70408919960573`, 
     172.70408919960573`}, {
    "ET1", 18495.36767368914, 29251.788042884255`, 29253.111358220056`, 
     29253.111358220056`}, {
    "ETseq", 0.17232245624011064`, 0.17232245624011064`, 0.17232245624011064`,
      0.17232245624011064`}, {
    "LNth", 0.000018326708507987455`, 0.000018326708507987455`, 
     0.000018326708507987455`, 0.000018326708507987455`}, {
    "LNet", 1.7232183570636828`*^-6, 1.7232183570636828`*^-6, 
     1.7232183570636828`*^-6, 1.7232183570636828`*^-6}, {
    "ST", 719.5895747549422, 719.5895747858245, 719.5895747858245, 
     719.5895747858245}, {"SI", 0.}, {
    "B", 22220.93046714775, 29962.16536156339, 29962.194796592194`, 
     29962.194796592194`}, {
    "ULI", 770.2814252984967, 2305.7839436312793`, 2881.157720941263, 
     3186.0819700664783`}, {
    "LLI", 441.9287705378265, 4055.8949036802687`, 5181.6199311075925`, 
     5732.883127775722}, {
    "Other", 8948.182243231684, 145219.83081571944`, 737480.0879778131, 
     3.842690658928214*^6}, {"Liver", 0.}, {
    "UB_Content", 1089.382178391641, 2095.1331063156094`, 2594.0907846596137`,
      2867.9613660618206`}}, 
   TableHeadings -> {
    None, {"Compartment", 1. "day", 10 "day", 100 "day", 18267.5 
      "day"}}]]], "Output",
 CellChangeTimes->{3.3990168540172853`*^9, 3.4178381012062726`*^9, 
  3.4799636937890377`*^9, 3.48021725128814*^9, 3.5185370958510866`*^9, 
  3.5193921497245145`*^9, 3.5193925611074133`*^9, 3.5193931087898035`*^9, 
  3.5193980365719147`*^9, 3.5419932939822206`*^9, 3.592062219986898*^9, 
  3.643596323153961*^9, 3.6563195025513673`*^9},
 CellLabel->"Out[38]//TableForm="]
}, Open  ]],

Cell["The solution can be rounded as follow", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"nround", "[", "x_", "]"}], ":=", 
   RowBox[{"MapAll", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"If", "[", 
       RowBox[{
        RowBox[{"NumberQ", "[", "#", "]"}], ",", 
        RowBox[{"Round", "[", "#", "]"}], ",", "#"}], "]"}], "&"}], ",", 
     "x"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[39]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DisintegrationLabel", "[", 
    RowBox[{"dis_", ",", "tafter_"}], "]"}], ":=", 
   RowBox[{"TableForm", "[", 
    RowBox[{
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"Flatten", "[", "#", "]"}], "&"}], ",", 
       RowBox[{"nround", "[", "dis", "]"}]}], "]"}], ",", 
     RowBox[{"TableHeadings", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", 
        RowBox[{"Flatten", "[", 
         RowBox[{"{", 
          RowBox[{"\"\<Compartment\>\"", ",", 
           RowBox[{"tafter", "\"\<day\>\""}]}], "}"}], "]"}]}], "}"}]}]}], 
    "]"}]}], ";"}]], "Input",
 CellLabel->"In[40]:="],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"dis", " ", "=", " ", 
    RowBox[{"Disintegrations", "[", 
     RowBox[{"\"\<Co\>\"", ",", "\"\<Ingestion\>\"", ",", "1", ",", "1", ",", 
      RowBox[{"{", 
       RowBox[{"1.0", ",", " ", "10", ",", " ", "100", ",", " ", 
        RowBox[{"365.35", "*", "50"}]}], "}"}], " ", ",", " ", 
      RowBox[{"Decayconst", "[", "\"\<Co 60\>\"", "]"}]}], "]"}]}], 
   ";"}]}]], "Input",
 CellLabel->"In[41]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DisintegrationLabel", "[", 
  RowBox[{"dis", ",", 
   RowBox[{"{", 
    RowBox[{"1.0", ",", " ", "10", ",", " ", "100", ",", " ", 
     RowBox[{"365.35", "*", "50"}]}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[42]:="],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"\<\"Compartment\"\>", 
     RowBox[{"1.`", " ", "\<\"day\"\>"}], 
     RowBox[{"10", " ", "\<\"day\"\>"}], 
     RowBox[{"100", " ", "\<\"day\"\>"}], 
     RowBox[{"18267.5`", " ", "\<\"day\"\>"}]},
    {"\<\"ST\"\>", "3600", "3600", "3600", "3600"},
    {"\<\"SI\"\>", "0", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
    {"\<\"B\"\>", "45781", "62307", "62307", "62307"},
    {"\<\"ULI\"\>", "1567", "4793", "5991", "6626"},
    {"\<\"LLI\"\>", "883", "8431", "10775", "11922"},
    {"\<\"Other\"\>", "18046", "301523", "1533422", "7990993"},
    {"\<\"Liver\"\>", "0", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
    {"\<\"UB_Content\"\>", "2239", "4355", "5394", "5964"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{"ST", 3600, 3600, 3600, 3600}, {"SI", 0}, {
    "B", 45781, 62307, 62307, 62307}, {"ULI", 1567, 4793, 5991, 6626}, {
    "LLI", 883, 8431, 10775, 11922}, {
    "Other", 18046, 301523, 1533422, 7990993}, {"Liver", 0}, {
    "UB_Content", 2239, 4355, 5394, 5964}}, 
   TableHeadings -> {
    None, {"Compartment", 1. "day", 10 "day", 100 "day", 18267.5 
      "day"}}]]], "Output",
 CellChangeTimes->{3.3990168544862337`*^9, 3.4178381016754274`*^9, 
  3.479963695037038*^9, 3.4802172518038144`*^9, 3.5185370962260933`*^9, 
  3.5193921500838966`*^9, 3.51939256148242*^9, 3.51939310916481*^9, 
  3.5193980369469223`*^9, 3.5419932942478523`*^9, 3.5920622209419746`*^9, 
  3.6435963234195924`*^9, 3.65631950272325*^9},
 CellLabel->"Out[42]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"DisintegrationLabel1", "[", "dis_", "]"}], ":=", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Flatten", "[", "#", "]"}], "&"}], ",", 
     RowBox[{"nround", "[", "dis", "]"}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[43]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DisintegrationLabel1", "[", "dis", "]"}]], "Input",
 CellLabel->"In[44]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"ST\"\>", ",", "3600", ",", "3600", ",", "3600", ",", 
     "3600"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"SI\"\>", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"B\"\>", ",", "45781", ",", "62307", ",", "62307", ",", 
     "62307"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"ULI\"\>", ",", "1567", ",", "4793", ",", "5991", ",", 
     "6626"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"LLI\"\>", ",", "883", ",", "8431", ",", "10775", ",", 
     "11922"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Other\"\>", ",", "18046", ",", "301523", ",", "1533422", ",",
      "7990993"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"UB_Content\"\>", ",", "2239", ",", "4355", ",", "5394", ",", 
     "5964"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.3990168545331287`*^9, 3.4178381017223434`*^9, 
  3.479963698526038*^9, 3.4802172518350673`*^9, 3.5185370962729692`*^9, 
  3.5193921501463976`*^9, 3.519392561513671*^9, 3.5193931092273116`*^9, 
  3.5193980370094233`*^9, 3.541993294310354*^9, 3.592062221174493*^9, 
  3.6435963234508376`*^9, 3.6563195027544928`*^9},
 CellLabel->"Out[44]="]
}, Open  ]]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Committed Doses", "SubsectionIcon"],

Cell[TextData[{
 StyleBox["Doses", "Input"],
 " includes some function for computing the Committed Doses ."
}], "Text",
 CellChangeTimes->{3.479964067540038*^9}],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"CommittedDose", "[", 
   RowBox[{
    StyleBox["\"\<Isotope\>\"", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[",", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["\"\<IntakeWay\>\"", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[",",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["Intake", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[",", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["IFD",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[",",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["FRA",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[",",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["f1",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[",",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontWeight->"Plain",
     FontSlant->"Italic"], "\[Tau]", 
    StyleBox[",",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["  ",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["options",
     FontWeight->"Plain",
     FontSlant->"Italic"]}], 
   StyleBox["]", "Text"]}]], "Input"],
 " \ngives for isotope \"X a\" the committed equivalent dose and the \
committed effective dose, in Sv,  accumulated during a time t, in days, after \
an acute ",
 StyleBox["Intake",
  FontSlant->"Italic"],
 " in Bq at t=0.  (Note: ",
 Cell[BoxData[
  FormBox[
   StyleBox[
    RowBox[{" ", 
     RowBox[{"IFD", " ", ",", " ", "FRA", ",", " ", "f1", " "}]}],
    FontSlant->"Italic"], TraditionalForm]]],
 "has been previously defined)  \n\nIf \"IntakeWay\"  is \"Injection\" or \
\"Ingestion\"  IFD and FRA are unnecessary, then \n\n",
 Cell[BoxData[
  RowBox[{"CommittedDose", "[", 
   RowBox[{
    StyleBox["\"\<Isotope\>\"", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[",", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["\"\<IntakeWay\>\"", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[",",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["Intake", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[",", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["f1",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[",",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontWeight->"Plain",
     FontSlant->"Italic"], "\[Tau]", 
    StyleBox[",",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["  ",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["options",
     FontWeight->"Plain",
     FontSlant->"Italic"]}], 
   StyleBox["]", "Text"]}]], "Input"],
 " \n\n",
 StyleBox["Options:",
  FontSlant->"Italic"],
 " ",
 StyleBox["DisintegrationReport\[Rule] \"True\"", "Input"],
 "  (option by default) gives the accumulated disintegrations and the \
committed doses formatted as a table; ",
 StyleBox["DisintegrationReport\[Rule] \"False\" ", "Input"],
 " gives the committed doses. This last option can be used to export the \
solution to a file formatted for using by other program such as an \
spreadsheet as EXCEL. "
}], "DefinitionBox",
 CellChangeTimes->{3.479964080726038*^9}],

Cell[TextData[{
 "The previous functions can only be used for some isotopes whose the SEE \
factors has been included in ",
 StyleBox["Biokmod", "Input"]
}], "MathCaption",
 CellChangeTimes->{{3.479964089195038*^9, 3.4799640983030376`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["isotopesymbol"], "Input",
 CellLabel->"In[45]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"U 234\"\>", ",", "\<\"U 235\"\>", ",", "\<\"U 238\"\>", 
   ",", "\<\"Pu 239\"\>", ",", "\<\"Co 60\"\>", ",", "\<\"Cs 137\"\>", 
   ",", "\<\"I 125\"\>", ",", "\<\"I 131\"\>", ",", "\<\"Sr 90\"\>", 
   ",", "\<\"Sr 89\"\>", ",", "\<\"Y 90\"\>", ",", "\<\"Th 232\"\>", 
   ",", "\<\"Ra 226\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.399016866037986*^9, 3.41783810175362*^9, 
  3.479963698693038*^9, 3.4802172518350673`*^9, 3.51853709630422*^9, 
  3.5193921501776485`*^9, 3.5193925615449214`*^9, 3.5193931092741876`*^9, 
  3.519398037056299*^9, 3.54199329435723*^9, 3.5920622214907684`*^9, 
  3.6435963234508376`*^9, 3.6563195027544928`*^9},
 CellLabel->"Out[45]="]
}, Open  ]],

Cell[TextData[{
 "For the rest of isotopes SEE factors and the decay constant must be \
introduced as input data. It is recommended to use  DCAL (SEECAL) program (it \
can be downloaded at ",
 ButtonBox["http://ordose.ornl.gov/downloads.html",
  BaseStyle->"Hyperlink",
  ButtonData:>{
    URL["http://ordose.ornl.gov/downloads.html"], None}],
 "). In this case can be used the following function to import the see \
factors previously obtained other program such as DCAL."
}], "Text",
 CellChangeTimes->{3.479964113994038*^9}],

Cell[TextData[{
 StyleBox["ImportSEE[", "Input"],
 StyleBox["file, \"ext\"", "Input",
  FontWeight->"Plain",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["]", "Input"],
 " imports the see factors from the folder \
..\\\\AddOns\\\\Applications\\\\Biokmod\\\\Data\\\\file.ext being \"ext\" the \
file extension.It can be used \"csv\" or \"xls\" "
}], "DefinitionBox",
 CellChangeTimes->{{3.3990173207006283`*^9, 3.399017324276326*^9}, {
  3.3990173734460716`*^9, 3.399017381971534*^9}}],

Cell["\<\
If it is used DCAL (module SEECAL) it should be chosen as intake pathway \
inhalation (as it will shown later they can be also applicable for ingestion \
and injection).In the out file \"isotope.SEE\" (\"isotope\" means the \
identification of isotope by DCAL.e.g.:I125HT),generated by DCAL-SEECAL must \
be eliminated the unnecessary data and texts and formatted as it is shown in \
\"AddOns\\\\Applications\\\\Biokmod\\\\Data\\\\isotope.txt\" or \"isotope.csv\
\" or \"isotope.xls\".Isotope.txt has basically the same format that the \
included in file \"isotope.SEE\" generated by DCAL (SEECAL).If you prefer a \
csv o xls format import \"isotope.txt\" using EXCEL and then the information \
should be rearranged put in a table where the heading titles represents the \
source compartments an the left side the source compartments and save as a \
\"isotope.csv\" or \"isotope.xls\" (.i.e.:see the examples included in \
\"\\...\\Data\\isotope.txt\",\"isotope.csv\" or \"isotope.xls\").\
\>", "Commentary",
 CellChangeTimes->{{3.479964131029038*^9, 3.4799641524580383`*^9}}],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"CommittedDose", "[", 
   RowBox[{
    StyleBox["element",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[",", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["\"\<IntakeWay\>\"", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[",",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["Intake", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[",", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ", "Text",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["IFD",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[",",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["FRA",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[",",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["f1",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[",",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontWeight->"Plain",
     FontSlant->"Italic"], "\[Tau]", 
    StyleBox[",",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["\[Lambda]",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[",",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["see",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[",",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox[" ",
     FontWeight->"Plain",
     FontSlant->"Italic"], 
    StyleBox["options",
     FontWeight->"Plain",
     FontSlant->"Italic"]}], 
   StyleBox["]", "Text"]}]], "Input"],
 " \ngives for isotope of the element \"X\" with disintegration constant \
\[Lambda] and ",
 StyleBox["see",
  FontSlant->"Italic"],
 " factors the committed equivalent dose and the committed effective dose , \
in Sv, accumulated during a time t, in days, after an acute ",
 StyleBox["Intake",
  FontSlant->"Italic"],
 " in Bq at ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", "=", "0"}], TraditionalForm]]],
 ".  \n\nIf \"IntakeWay\"  is \"Injection\" or \"Ingestion\"  IFD and FRA are \
unnecessary, then \n\n",
 Cell[BoxData[
  RowBox[{"CommittedDose", "[", 
   StyleBox[
    RowBox[{"element", 
     StyleBox[",", "Text"], 
     StyleBox[" ", "Text"], 
     StyleBox["\"\<IntakeWay\>\"", "Text"], ",", " ", 
     StyleBox["Intake", "Text"], 
     StyleBox[",", "Text"], 
     StyleBox[" ", "Text"], "f1", ",", " ", "\[Tau]", ",", " ", "\[Lambda]", 
     ",", " ", "see", ",", " ", "options"}],
    FontWeight->"Plain",
    FontSlant->"Italic"], 
   StyleBox["]", "Text"]}]], "Input"],
 " "
}], "DefinitionBox",
 CellChangeTimes->{3.4799641714330378`*^9}],

Cell[CellGroupData[{

Cell["Uranium", "SubsubsectionIcon"],

Cell["U 234", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<U 234\>\"", ",", "\"\<Inhalation\>\"", ",", "1", ",", "AMAD5", ",", 
   "S", ",", "0.002", ",", 
   RowBox[{"50", "*", "365.25"}]}], "]"}]], "Input",
 CellLabel->"In[46]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox[
    StyleBox["\<\"\\nAccumulted disintegration, in Bq, as function of the \
time\\n\"\>",
     FontFamily->"Times",
     FontSize->12,
     FontWeight->"Bold"],
    StyleForm[#, FontFamily -> "Times", FontSize -> 12, FontWeight -> 
     "Bold"]& ], "\[InvisibleSpace]", 
   TagBox[
    TagBox[GridBox[{
       {
        TagBox["\<\"Compartment\"\>",
         HoldForm], 
        TagBox[
         RowBox[{"18262.5`", " ", "\<\"day\"\>"}],
         HoldForm]},
       {"\<\"AI\"\>", "4.621831487017342`*^6"},
       {"\<\"bb1\"\>", "2323.127261326559`"},
       {"\<\"bb2\"\>", "12571.415105715627`"},
       {"\<\"bbseq\"\>", "659.8424553326731`"},
       {"\<\"BB1\"\>", "603.4153451457594`"},
       {"\<\"BB2\"\>", "16978.866067733168`"},
       {"\<\"BBseq\"\>", "1062.1466633154055`"},
       {"\<\"ET2\"\>", "409.7396146337317`"},
       {"\<\"ET1\"\>", "29263.645212399177`"},
       {"\<\"ETseq\"\>", "15650.145790319068`"},
       {"\<\"LNth\"\>", "444580.1228394519`"},
       {"\<\"LNet\"\>", "128775.97672531777`"},
       {"\<\"ST\"\>", "1707.2483923198868`"},
       {"\<\"SI\"\>", "6815.33555046994`"},
       {"\<\"B\"\>", "51.46042281487568`"},
       {"\<\"ULI\"\>", "22719.588006048794`"},
       {"\<\"LLI\"\>", "40895.30057207151`"},
       {"\<\"Soft Tissues\"\>", "35240.48896545493`"},
       {"\<\"UB_Content\"\>", "46.70880135402965`"},
       {"\<\"Kydneys\"\>", "1898.8353648550183`"},
       {"\<\"Liver\"\>", "4289.513922363638`"},
       {"\<\"TrabSurface\"\>", "771.040250280922`"},
       {"\<\"CorticalSurf\"\>", "613.8925281047296`"},
       {"\<\"Trab. Vol.\"\>", "29727.808615247683`"},
       {"\<\"Cort. Vol\"\>", "96706.84900058876`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[2.0999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     {None, OutputFormsDump`HeadedColumns}],
    Function[BoxForm`e$, 
     TableForm[
     BoxForm`e$, TableHeadings -> {None, {"Compartment", 18262.5 "day"}}]]], 
   "\[InvisibleSpace]", 
   TagBox[
    StyleBox["\<\"\\nDose accumulated, in Sv, as function of the time\\n\"\>",
     FontFamily->"Times",
     FontSize->12,
     FontWeight->"Bold"],
    StyleForm[#, FontFamily -> "Times", FontSize -> 12, FontWeight -> 
     "Bold"]& ], "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"\<\"Sv/Bq\"\>", 
       RowBox[{"18262.5`", " ", "\<\"day\"\>"}]},
      {"\<\"Testes\"\>", "8.927433895853276`*^-9"},
      {"\<\"Ovarius\"\>", "8.928383329366694`*^-9"},
      {"\<\"Red Marrow\"\>", "2.797768674854026`*^-8"},
      {"\<\"Colon\"\>", "2.356249598192798`*^-8"},
      {"\<\"Lungs\"\>", "0.00004111321494373307`"},
      {"\<\"St Wall\"\>", "9.456851758664235`*^-9"},
      {"\<\"Bladder Wall\"\>", "8.95760470307338`*^-9"},
      {"\<\"Mama\"\>", "8.930581659643654`*^-9"},
      {"\<\"Liver\"\>", "3.699396672691428`*^-8"},
      {"\<\"Oesophagus\"\>", "8.929583591925596`*^-9"},
      {"\<\"Thyroid\"\>", "8.927900344867`*^-9"},
      {"\<\"Skin\"\>", "8.927875657860255`*^-9"},
      {"\<\"Bone Surface\"\>", "2.703242723135893`*^-7"},
      {"\<\"Muscle\"\>", "8.93545218661701`*^-9"},
      {"\<\"Brain\"\>", "8.927562528007386`*^-9"},
      {"\<\"Small intestine\"\>", "1.0243542848359105`*^-8"},
      {"\<\"Kidneys\"\>", "9.495374244606916`*^-8"},
      {"\<\"Pancreas\"\>", "8.928706767929694`*^-9"},
      {"\<\"Spleen\"\>", "8.930527187906956`*^-9"},
      {"\<\"Thymus\"\>", "8.929583591925596`*^-9"},
      {"\<\"Uterus\"\>", "8.92750172962444`*^-9"},
      {"\<\"Adrenals\"\>", "8.930568943600606`*^-9"},
      {"\<\"Extrathoracic airways\"\>", "0.00007526937619842556`"},
      {"\<\"Effective, e(50)\"\>", "6.831100762132214`*^-6"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]]}],
  SequenceForm[
   StyleForm[
   "\nAccumulted disintegration, in Bq, as function of the time\n", 
    FontFamily -> "Times", FontSize -> 12, FontWeight -> "Bold"], 
   TableForm[{{"AI", 4.621831487017342*^6}, {"bb1", 2323.127261326559}, {
     "bb2", 12571.415105715627`}, {"bbseq", 659.8424553326731}, {
     "BB1", 603.4153451457594}, {"BB2", 16978.866067733168`}, {
     "BBseq", 1062.1466633154055`}, {"ET2", 409.7396146337317}, {
     "ET1", 29263.645212399177`}, {"ETseq", 15650.145790319068`}, {
     "LNth", 444580.1228394519}, {"LNet", 128775.97672531777`}, {
     "ST", 1707.2483923198868`}, {"SI", 6815.33555046994}, {
     "B", 51.46042281487568}, {"ULI", 22719.588006048794`}, {
     "LLI", 40895.30057207151}, {"Soft Tissues", 35240.48896545493}, {
     "UB_Content", 46.70880135402965}, {"Kydneys", 1898.8353648550183`}, {
     "Liver", 4289.513922363638}, {"TrabSurface", 771.040250280922}, {
     "CorticalSurf", 613.8925281047296}, {
     "Trab. Vol.", 29727.808615247683`}, {"Cort. Vol", 96706.84900058876}}, 
    TableHeadings -> {None, {"Compartment", 18262.5 "day"}}], 
   StyleForm[
   "\nDose accumulated, in Sv, as function of the time\n", FontFamily -> 
    "Times", FontSize -> 12, FontWeight -> "Bold"], 
   TableForm[{{"Sv/Bq", 18262.5 "day"}, {"Testes", 8.927433895853276*^-9}, {
     "Ovarius", 8.928383329366694*^-9}, {
     "Red Marrow", 2.797768674854026*^-8}, {"Colon", 2.356249598192798*^-8}, {
     "Lungs", 0.00004111321494373307}, {"St Wall", 9.456851758664235*^-9}, {
     "Bladder Wall", 8.95760470307338*^-9}, {"Mama", 8.930581659643654*^-9}, {
     "Liver", 3.699396672691428*^-8}, {"Oesophagus", 8.929583591925596*^-9}, {
     "Thyroid", 8.927900344867*^-9}, {"Skin", 8.927875657860255*^-9}, {
     "Bone Surface", 2.703242723135893*^-7}, {
     "Muscle", 8.93545218661701*^-9}, {"Brain", 8.927562528007386*^-9}, {
     "Small intestine", 1.0243542848359105`*^-8}, {
     "Kidneys", 9.495374244606916*^-8}, {"Pancreas", 8.928706767929694*^-9}, {
     "Spleen", 8.930527187906956*^-9}, {"Thymus", 8.929583591925596*^-9}, {
     "Uterus", 8.92750172962444*^-9}, {"Adrenals", 8.930568943600606*^-9}, {
     "Extrathoracic airways", 0.00007526937619842556}, {
     "Effective, e(50)", 6.831100762132214*^-6}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.3990168948782883`*^9, 3.4178381305128217`*^9, 
  3.479963715924038*^9, 3.4802172788845387`*^9, 3.5185371122576513`*^9, 
  3.519392168959259*^9, 3.5193925781546154`*^9, 3.51939312738391*^9, 
  3.5193980536503677`*^9, 3.5419933037480955`*^9, 3.5920622582424583`*^9, 
  3.64359632891963*^9, 3.656319508051365*^9},
 CellLabel->"During evaluation of In[46]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<U 234\>\"", ",", "\"\<Ingestion\>\"", ",", "1", ",", "0.002", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[47]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "2.757623503482544`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "2.759572757550012`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "8.111687897832557`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "3.3615715555648114`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "2.7576184543205068`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "3.870100352078343`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "2.766869830775228`*^-9"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "2.757613688316469`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "1.0753456285483432`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "2.757613349799273`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "2.7576118442034997`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "2.7576302277648154`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "7.855185746475918`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "2.7577042614814235`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "2.7576355471643436`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "5.532704138113785`*^-9"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "2.8645651680439144`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "2.757648270537995`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "2.757629905328904`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "2.757613349799273`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "2.7577348174940775`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "2.7576342794896835`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "2.7576118442034993`*^-9"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "8.411099311525008`*^-9"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.3990168987705564`*^9, 3.417838135266926*^9, 
  3.479963719218038*^9, 3.480217282634899*^9, 3.5185371150545797`*^9, 
  3.5193921719280663`*^9, 3.5193925810140452`*^9, 3.519393130040211*^9, 
  3.51939805660355*^9, 3.5419933053731375`*^9, 3.59206226138896*^9, 
  3.6435963299196386`*^9, 3.6563195090044746`*^9},
 CellLabel->"Out[47]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<U 234\>\"", ",", "\"\<Injection\>\"", ",", "1", ",", "0.002", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[48]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "1.378820982105434`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "1.3788229572545215`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "4.055822193342148`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "1.3790290296340067`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "1.3788249771201771`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "1.3788219729040693`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "1.3834027771429135`*^-6"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "1.3788231249734599`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "5.376727320216949`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "1.378823078352649`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "1.378822490145345`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "1.3788261402649705`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "0.000039275982989604576`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "1.3788281268518939`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "1.3788343571073242`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "1.3788243732679714`*^-6"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "0.00001432281957333504`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "1.3788229379169158`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "1.3788234424920213`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "1.378823078352649`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "1.3788217117672424`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "1.3788301989960429`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "1.378822490145345`*^-6"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "2.2857063147790757`*^-6"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.399016900427506*^9, 3.4178381383789873`*^9, 
  3.479963720148038*^9, 3.480217284150669*^9, 3.518537116070225*^9, 
  3.519392173037462*^9, 3.5193925820765657`*^9, 3.5193931311183567`*^9, 
  3.51939805766607*^9, 3.5419933059981537`*^9, 3.592062262605307*^9, 
  3.643596330247766*^9, 3.656319509316987*^9},
 CellLabel->"Out[48]="]
}, Open  ]],

Cell["U 238", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<U 238\>\"", ",", "\"\<Inhalation\>\"", ",", "1", ",", "AMAD5", ",", 
   "S", ",", "0.002", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[49]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "1.568505089528855`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "4.300528893009535`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "1.7963421698240223`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "3.4480339195396234`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "0.00003419385473950617`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "9.260830710916979`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "8.237372361988259`*^-9"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "8.446298584518919`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "3.317625112590076`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "8.501502280941333`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "8.277616363941905`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "8.227844253765914`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "2.414953878703918`*^-7"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "8.303137025808415`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "8.194995379447057`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "1.0576909166676267`*^-8"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "8.472476614752663`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "8.363274062436487`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "8.365407083998444`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "8.501502280941333`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "8.1901417396679`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "8.434293730669712`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "0.00006490626574485171`"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "5.739389463282713`*^-6"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.3990169277359114`*^9, 3.4178381648549676`*^9, 
  3.4799637351780376`*^9, 3.4802173085117345`*^9, 3.518537132586167*^9, 
  3.5193921915378175`*^9, 3.5193925997331543`*^9, 3.519393149806216*^9, 
  3.519398076010172*^9, 3.541993315514022*^9, 3.592062296955555*^9, 
  3.643596335607184*^9, 3.656319514332832*^9},
 CellLabel->"Out[49]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<U 238\>\"", ",", "\"\<Ingestion\>\"", ",", "1", ",", "0.002", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[50]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "6.9166520666915726`*^-12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "4.413729047591852`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "5.017373489290568`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "5.7954773097578734`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "2.5257454125425054`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "4.534139781736915`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "2.552431481597547`*^-9"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "2.525100387614516`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "9.579935660871417`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "2.525229909049573`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "2.525240778055737`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "2.526159482453501`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "7.013950809389784`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "2.5292335098861507`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "2.5255656759321662`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "7.545866540244265`*^-9"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "2.5539252866485564`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "2.5293759765105527`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "2.528156458431213`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "2.525229909049573`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "2.5409156968013114`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "2.5278402212362867`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "2.5252407780557372`*^-9"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "1.0267992961266812`*^-8"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.3990169316281796`*^9, 3.417838168748954*^9, 
  3.479963737467038*^9, 3.480217312246134*^9, 3.5185371356331005`*^9, 
  3.519392194069116*^9, 3.5193926026082096`*^9, 3.519393152165636*^9, 
  3.5193980808227644`*^9, 3.541993317139064*^9, 3.592062300063304*^9, 
  3.6435963365446916`*^9, 3.6563195152547207`*^9},
 CellLabel->"Out[50]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<U 238\>\"", ",", "\"\<Injection\>\"", ",", "1", ",", "0.002", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[51]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "1.937346106728409`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "2.2759812745853602`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "2.505670448534555`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "1.2630269788151755`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "1.2626324759421591`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "1.2624875626729522`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "1.2706899377210234`*^-6"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "1.2624020512153773`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "4.788533843326695`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "1.262511973851438`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "1.2626074948341312`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "1.2624452835544424`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "0.00003506752623163533`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "1.2626224942500114`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "1.2627928571958309`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "1.2626645027638825`*^-6"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "0.000012767512888012907`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "1.2627169112309588`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "1.2625758549081143`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "1.262511973851438`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "1.262572105066123`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "1.2630331678022503`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "1.2626074948341314`*^-6"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "1.6802791556778003`*^-6"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.3990169332851295`*^9, 3.417838170437912*^9, 
  3.479963738384038*^9, 3.4802173138086433`*^9, 3.518537136617494*^9, 
  3.519392195116011*^9, 3.5193926036863556`*^9, 3.5193931530875287`*^9, 
  3.519398081885285*^9, 3.5419933177640796`*^9, 3.592062301369658*^9, 
  3.643596336888443*^9, 3.6563195155672035`*^9},
 CellLabel->"Out[51]="]
}, Open  ]],

Cell["U 235", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<U 235\>\"", ",", "\"\<Inhalation\>\"", ",", "1", ",", "AMAD5", ",", 
   "S", ",", "0.002", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[52]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "3.3558449080222375`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "1.844320186565684`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "1.8674804849541343`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "2.5403551833004493`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "0.00003641715777311801`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "9.9263328257698`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "8.587875461695961`*^-9"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "1.0062025281410814`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "3.567464143965207`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "1.0455987874995153`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "9.108839296665862`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "8.791381409973596`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "2.5177095970860227`*^-7"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "9.254791646939627`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "8.604278130751452`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "1.0198474151543985`*^-8"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "8.847708792308873`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "9.64747708998188`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "9.627008347761362`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "1.0455987874995153`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "8.59036382982982`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "1.0114214543748503`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "0.00006916751046631867`"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "6.112315398799253`*^-6"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.399016960624798*^9, 3.417838198008588*^9, 
  3.4799637532160378`*^9, 3.4802173383713007`*^9, 3.518537153305314*^9, 
  3.5193922134288626`*^9, 3.519392621608575*^9, 3.519393170322235*^9, 
  3.5193981001356354`*^9, 3.5419933271080685`*^9, 3.592062338748898*^9, 
  3.643596342216612*^9, 3.6563195205828037`*^9},
 CellLabel->"Out[52]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<U 235\>\"", ",", "\"\<Ingestion\>\"", ",", "1", ",", "0.002", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[53]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "2.4366900341764278`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "2.3717514436112983`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "5.066644077249864`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "3.806814786391394`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "2.6323383213697706`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "3.951120369938029`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "2.7089251241204483`*^-9"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "2.6277475067034185`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "9.979702379468591`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "2.6295984509243557`*^-9"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "2.6296322131636894`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "2.6337573070485687`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "7.288439951759916`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "2.6534602207555722`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "2.6314072563537923`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "5.984200679832647`*^-9"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "2.6582275053336657`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "2.6546057432149527`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "2.6479307304760926`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "2.6295984509243557`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "2.726556892623681`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "2.6448321895765785`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "2.6296322131636894`*^-9"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "7.945739171674262`*^-9"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.399016964517066*^9, 3.417838202277898*^9, 
  3.479963755525038*^9, 3.4802173422307005`*^9, 3.5185371559303646`*^9, 
  3.51939221639767*^9, 3.5193926243898783`*^9, 3.5193931730254116`*^9, 
  3.5193981030263157`*^9, 3.5419933287643614`*^9, 3.5920623417566385`*^9, 
  3.643596343138505*^9, 3.6563195214421763`*^9},
 CellLabel->"Out[53]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<U 235\>\"", ",", "\"\<Injection\>\"", ",", "1", ",", "0.002", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[54]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "3.3677238216648086`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "5.261739557789352`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "2.5151254137614903`*^-6"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "1.3153752891569575`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "1.3149784320129346`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "1.314270015205849`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "1.3193947886911778`*^-6"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "1.3132575907831121`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "4.981667721764971`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "1.3143471013094113`*^-6"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "1.314771169719398`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "1.3134898993530083`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "0.00003642793766991907`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "1.3149511238280727`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "1.3157141917922795`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "1.3151742766435002`*^-6"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "0.000013277976243007625`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "1.3154307479677893`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "1.3146446167707302`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "1.3143471013094113`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "1.3147281040947599`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "1.316976560941805`*^-6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "1.314771169719398`*^-6"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "1.737586127373763`*^-6"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.3990169661740155`*^9, 3.417838203966856*^9, 
  3.4799637564720383`*^9, 3.48021734369946*^9, 3.518537157024136*^9, 
  3.5193922175539417`*^9, 3.5193926254680233`*^9, 3.5193931739473047`*^9, 
  3.519398104088836*^9, 3.5419933294050026`*^9, 3.5920623428679776`*^9, 
  3.6435963434822435`*^9, 3.6563195217546735`*^9},
 CellLabel->"Out[54]="]
}, Open  ]],

Cell["\<\
Example: A worker has been exposed by inhalation of a 25 000 Bq at uranium \
oxide (89% S and 11% M) enriched 3.7% wt U235, AMAD 5.\
\>", "Text",
 CellChangeTimes->{{3.649664595637291*^9, 3.64966472390267*^9}, {
  3.649664803699376*^9, 3.6496648734023542`*^9}, {3.6563206443518343`*^9, 
  3.656320649539352*^9}}],

Cell["The efective dose, in mSv, is: ", "Text",
 CellChangeTimes->{{3.649664789699356*^9, 3.649664800855632*^9}, {
  3.6496648879335747`*^9, 3.649664900574171*^9}, {3.6496649736990175`*^9, 
  3.6496649753865137`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DoseEnrichedUranium", "[", 
  RowBox[{"24763", ",", " ", "4", ",", " ", "AMAD5", ",", "0.89"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.644030304512591*^9, 3.6440303353564873`*^9}, {
  3.6440304171692595`*^9, 3.64403042376303*^9}, {3.644030809858008*^9, 
  3.6440308136237016`*^9}, {3.649664278200486*^9, 3.649664279200486*^9}},
 CellLabel->"In[58]:="],

Cell[BoxData["131.3032516858395`"], "Output",
 CellChangeTimes->{3.6440304625131035`*^9, 3.644030545497766*^9, 
  3.644030895186416*^9, 3.644030978858568*^9, 3.6496615964191427`*^9, 
  3.64966343943659*^9, 3.656319556629592*^9},
 CellLabel->"Out[58]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Cobalt", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<Co 60\>\"", ",", "\"\<Inhalation\>\"", ",", "1", ",", "AMAD5", ",", 
   "M", ",", "0.1", ",", 
   RowBox[{"50", "*", "365.25"}]}], "]"}]], "Input",
 CellLabel->"In[59]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox[
    StyleBox["\<\"\\nAccumulted disintegration, in Bq, as function of the \
time\\n\"\>",
     FontFamily->"Times",
     FontSize->12,
     FontWeight->"Bold"],
    StyleForm[#, FontFamily -> "Times", FontSize -> 12, FontWeight -> 
     "Bold"]& ], "\[InvisibleSpace]", 
   TagBox[
    TagBox[GridBox[{
       {
        TagBox["\<\"Compartment\"\>",
         HoldForm], 
        TagBox[
         RowBox[{"18262.5`", " ", "\<\"day\"\>"}],
         HoldForm]},
       {"\<\"AI\"\>", "514610.1927251526`"},
       {"\<\"bb1\"\>", "941.6177232828709`"},
       {"\<\"bb2\"\>", "9641.665531978095`"},
       {"\<\"bbseq\"\>", "390.9067028123808`"},
       {"\<\"BB1\"\>", "308.9621872884685`"},
       {"\<\"BB2\"\>", "13021.966609224979`"},
       {"\<\"BBseq\"\>", "629.2414904561806`"},
       {"\<\"ET2\"\>", "361.99890668821433`"},
       {"\<\"ET1\"\>", "29253.111358220056`"},
       {"\<\"ETseq\"\>", "2438.6588288085745`"},
       {"\<\"LNth\"\>", "2184.816205232886`"},
       {"\<\"LNet\"\>", "454.96185508478584`"},
       {"\<\"ST\"\>", "1508.3061469125905`"},
       {"\<\"SI\"\>", "5429.608847550564`"},
       {"\<\"B\"\>", "6325.408883564334`"},
       {"\<\"ULI\"\>", "18767.17529304653`"},
       {"\<\"LLI\"\>", "33768.75419887387`"},
       {"\<\"Other\"\>", "811241.9599240777`"},
       {"\<\"Liver\"\>", "0.`"},
       {"\<\"UB_Content\"\>", "604.9923810486695`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[2.0999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     {None, OutputFormsDump`HeadedColumns}],
    Function[BoxForm`e$, 
     TableForm[
     BoxForm`e$, TableHeadings -> {None, {"Compartment", 18262.5 "day"}}]]], 
   "\[InvisibleSpace]", 
   TagBox[
    StyleBox["\<\"\\nDose accumulated, in Sv, as function of the time\\n\"\>",
     FontFamily->"Times",
     FontSize->12,
     FontWeight->"Bold"],
    StyleForm[#, FontFamily -> "Times", FontSize -> 12, FontWeight -> 
     "Bold"]& ], "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"\<\"Sv/Bq\"\>", 
       RowBox[{"18262.5`", " ", "\<\"day\"\>"}]},
      {"\<\"Testes\"\>", "1.9045003540875253`*^-9"},
      {"\<\"Ovarius\"\>", "3.2887380806238204`*^-9"},
      {"\<\"Red Marrow\"\>", "3.1121293945639323`*^-9"},
      {"\<\"Colon\"\>", "5.088060952825363`*^-9"},
      {"\<\"Lungs\"\>", "3.342157306308704`*^-8"},
      {"\<\"St Wall\"\>", "3.2294523289699977`*^-9"},
      {"\<\"Bladder Wall\"\>", "2.436875796460571`*^-9"},
      {"\<\"Mama\"\>", "3.582246108950271`*^-9"},
      {"\<\"Liver\"\>", "2.9460608645689273`*^-9"},
      {"\<\"Oesophagus\"\>", "4.421840527397164`*^-9"},
      {"\<\"Thyroid\"\>", "2.8382503703418965`*^-9"},
      {"\<\"Skin\"\>", "1.8006458781882133`*^-9"},
      {"\<\"Bone Surface\"\>", "2.9548657292268748`*^-9"},
      {"\<\"Muscle\"\>", "2.7764992456277386`*^-9"},
      {"\<\"Brain\"\>", "1.7789014332675676`*^-9"},
      {"\<\"Small intestine\"\>", "3.2659619137250704`*^-9"},
      {"\<\"Kidneys\"\>", "2.798121371135108`*^-9"},
      {"\<\"Pancreas\"\>", "3.662023441399242`*^-9"},
      {"\<\"Spleen\"\>", "3.5569340151237543`*^-9"},
      {"\<\"Thymus\"\>", "4.421840527397164`*^-9"},
      {"\<\"Uterus\"\>", "2.7791142577288928`*^-9"},
      {"\<\"Adrenals\"\>", "4.038344697161045`*^-9"},
      {"\<\"Extrathoracic airways\"\>", "3.042690967610935`*^-8"},
      {"\<\"Effective, e(50)\"\>", "7.036915651185687`*^-9"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]]}],
  SequenceForm[
   StyleForm[
   "\nAccumulted disintegration, in Bq, as function of the time\n", 
    FontFamily -> "Times", FontSize -> 12, FontWeight -> "Bold"], 
   TableForm[{{"AI", 514610.1927251526}, {"bb1", 941.6177232828709}, {
     "bb2", 9641.665531978095}, {"bbseq", 390.9067028123808}, {
     "BB1", 308.9621872884685}, {"BB2", 13021.966609224979`}, {
     "BBseq", 629.2414904561806}, {"ET2", 361.99890668821433`}, {
     "ET1", 29253.111358220056`}, {"ETseq", 2438.6588288085745`}, {
     "LNth", 2184.816205232886}, {"LNet", 454.96185508478584`}, {
     "ST", 1508.3061469125905`}, {"SI", 5429.608847550564}, {
     "B", 6325.408883564334}, {"ULI", 18767.17529304653}, {
     "LLI", 33768.75419887387}, {"Other", 811241.9599240777}, {"Liver", 0.}, {
     "UB_Content", 604.9923810486695}}, 
    TableHeadings -> {None, {"Compartment", 18262.5 "day"}}], 
   StyleForm[
   "\nDose accumulated, in Sv, as function of the time\n", FontFamily -> 
    "Times", FontSize -> 12, FontWeight -> "Bold"], 
   TableForm[{{"Sv/Bq", 18262.5 "day"}, {"Testes", 1.9045003540875253`*^-9}, {
     "Ovarius", 3.2887380806238204`*^-9}, {
     "Red Marrow", 3.1121293945639323`*^-9}, {
     "Colon", 5.088060952825363*^-9}, {"Lungs", 3.342157306308704*^-8}, {
     "St Wall", 3.2294523289699977`*^-9}, {
     "Bladder Wall", 2.436875796460571*^-9}, {
     "Mama", 3.582246108950271*^-9}, {"Liver", 2.9460608645689273`*^-9}, {
     "Oesophagus", 4.421840527397164*^-9}, {
     "Thyroid", 2.8382503703418965`*^-9}, {"Skin", 1.8006458781882133`*^-9}, {
     "Bone Surface", 2.9548657292268748`*^-9}, {
     "Muscle", 2.7764992456277386`*^-9}, {"Brain", 1.7789014332675676`*^-9}, {
     "Small intestine", 3.2659619137250704`*^-9}, {
     "Kidneys", 2.798121371135108*^-9}, {"Pancreas", 3.662023441399242*^-9}, {
     "Spleen", 3.5569340151237543`*^-9}, {"Thymus", 4.421840527397164*^-9}, {
     "Uterus", 2.7791142577288928`*^-9}, {
     "Adrenals", 4.038344697161045*^-9}, {
     "Extrathoracic airways", 3.042690967610935*^-8}, {
     "Effective, e(50)", 7.036915651185687*^-9}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.5193922229134197`*^9, 3.5193926300462365`*^9, 
  3.519393178025508*^9, 3.5193981088233023`*^9, 3.5419933318738155`*^9, 
  3.592062347823374*^9, 3.643596344919756*^9, 3.6563195579889603`*^9},
 CellLabel->"During evaluation of In[59]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<Co 60\>\"", ",", "\"\<Ingestion\>\"", ",", "1", ",", "0.1", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[60]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "1.982722605815954`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "4.454262580146926`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "2.210204639892849`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "8.767555399672547`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "1.696720835731329`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "2.55291653407312`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "2.7577422278891515`*^-9"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "1.3718829058162608`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "1.333139189934523`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "1.8134615362209924`*^-9"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "1.8758871788741183`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "1.3360957702414043`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "2.1701830335015437`*^-9"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "1.9885540869497024`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "1.5078124936489852`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "4.256036018877935`*^-9"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "2.207859407391042`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "2.369018867311288`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "2.1762866553784945`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "1.8134615362209924`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "3.2166036753462365`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "2.116043531538724`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "1.8758871788741183`*^-9"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "3.3118823186334256`*^-9"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5193922233509283`*^9, 3.5193926306087475`*^9, 
  3.5193931785567675`*^9, 3.5193981093545623`*^9, 3.5419933322332*^9, 
  3.5920623484584246`*^9, 3.643596345107257*^9, 3.6563195581764507`*^9},
 CellLabel->"Out[60]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<Co 60\>\"", ",", "\"\<Injection\>\"", ",", "1", ",", "0.1", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[61]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "1.7605182197364695`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "2.191033852738845`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "1.7982523736639715`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "2.0664050638909373`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "1.6487216241148166`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "1.8059205810092384`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "2.058840198165647`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "1.3374014743713892`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "1.1208345621960632`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "1.7877765871026778`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "1.8689052685207653`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "1.229194965217336`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "1.9902977643514176`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "1.7201738435943807`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "1.5064481184799848`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "2.096577058129579`*^-8"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "1.8994439576003433`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "2.0894874364090292`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "1.9569894086906717`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "1.7877765871026778`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "2.2354430503746516`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "1.9733063214632993`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "1.868905268520765`*^-8"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "1.8563643843381116`*^-8"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.519392223491556*^9, 3.5193926307650003`*^9, 
  3.5193931787286463`*^9, 3.5193981095264406`*^9, 3.541993332358203*^9, 
  3.5920623486621914`*^9, 3.643596345185383*^9, 3.6563195582389507`*^9},
 CellLabel->"Out[61]="]
}, Open  ]],

Cell["\<\
Here they are applied no standard values for computing the doses\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "amadp", ",", " ", "ff1", ",", "s1", ",", "s2", ",", "s3", ",", "inp"}], 
    "}"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "5.5", ",", "  ", "0.1", ",", " ", "10", ",", " ", "90", ",", " ", 
     "0.0007", ",", " ", "398551"}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[62]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{"\"\<Co 60\>\"", ",", "\"\<Inhalation\>\"", ",", "inp", ",", 
   RowBox[{"AMADAdultW", "[", "amadp", "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"s1", ",", " ", "s2", ",", " ", "s3"}], "}"}], ",", "ff1", ",", 
   RowBox[{"50", "*", "365.25"}]}], "]"}]], "Input",
 CellLabel->"In[63]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox[
    StyleBox["\<\"\\nAccumulted disintegration, in Bq, as function of the \
time\\n\"\>",
     FontFamily->"Times",
     FontSize->12,
     FontWeight->"Bold"],
    StyleForm[#, FontFamily -> "Times", FontSize -> 12, FontWeight -> 
     "Bold"]& ], "\[InvisibleSpace]", 
   TagBox[
    TagBox[GridBox[{
       {
        TagBox["\<\"Compartment\"\>",
         HoldForm], 
        TagBox[
         RowBox[{"18262.5`", " ", "\<\"day\"\>"}],
         HoldForm]},
       {"\<\"AI\"\>", "1.4760354831193464`*^6"},
       {"\<\"bb1\"\>", "1349.2424093195727`"},
       {"\<\"bb2\"\>", "10178.302585497318`"},
       {"\<\"bbseq\"\>", "512.2457992363023`"},
       {"\<\"BB1\"\>", "390.7421108730792`"},
       {"\<\"BB2\"\>", "13944.477180272479`"},
       {"\<\"BBseq\"\>", "847.0898194449255`"},
       {"\<\"ET2\"\>", "371.23798924143`"},
       {"\<\"ET1\"\>", "29607.70237955229`"},
       {"\<\"ETseq\"\>", "7546.294242983589`"},
       {"\<\"LNth\"\>", "18869.495509578424`"},
       {"\<\"LNet\"\>", "7118.449257372645`"},
       {"\<\"ST\"\>", "1546.801746621267`"},
       {"\<\"SI\"\>", "5568.18552125692`"},
       {"\<\"B\"\>", "5171.06924453489`"},
       {"\<\"ULI\"\>", "19104.88327456838`"},
       {"\<\"LLI\"\>", "34377.27668259203`"},
       {"\<\"Other\"\>", "663196.391668358`"},
       {"\<\"Liver\"\>", "0.`"},
       {"\<\"UB_Content\"\>", "493.2666118388189`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[2.0999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     {None, OutputFormsDump`HeadedColumns}],
    Function[BoxForm`e$, 
     TableForm[
     BoxForm`e$, TableHeadings -> {None, {"Compartment", 18262.5 "day"}}]]], 
   "\[InvisibleSpace]", 
   TagBox[
    StyleBox["\<\"\\nDose accumulated, in Sv, as function of the time\\n\"\>",
     FontFamily->"Times",
     FontSize->12,
     FontWeight->"Bold"],
    StyleForm[#, FontFamily -> "Times", FontSize -> 12, FontWeight -> 
     "Bold"]& ], "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"\<\"Sv/Bq\"\>", 
       RowBox[{"18262.5`", " ", "\<\"day\"\>"}]},
      {"\<\"Testes\"\>", "0.0006471949991141813`"},
      {"\<\"Ovarius\"\>", "0.0012416685712395164`"},
      {"\<\"Red Marrow\"\>", "0.0018866439785832126`"},
      {"\<\"Colon\"\>", "0.0020344876355742557`"},
      {"\<\"Lungs\"\>", "0.02373583057224951`"},
      {"\<\"St Wall\"\>", "0.0019343290770839658`"},
      {"\<\"Bladder Wall\"\>", "0.0008606105190791268`"},
      {"\<\"Mama\"\>", "0.0029077818351623953`"},
      {"\<\"Liver\"\>", "0.0023275088209120066`"},
      {"\<\"Oesophagus\"\>", "0.003446119311465627`"},
      {"\<\"Thyroid\"\>", "0.0016215590004709129`"},
      {"\<\"Skin\"\>", "0.0009754084243855861`"},
      {"\<\"Bone Surface\"\>", "0.0016185817438510138`"},
      {"\<\"Muscle\"\>", "0.0016057141280610113`"},
      {"\<\"Brain\"\>", "0.0007291127761618344`"},
      {"\<\"Small intestine\"\>", "0.0013231225135026177`"},
      {"\<\"Kidneys\"\>", "0.0015072996902680128`"},
      {"\<\"Pancreas\"\>", "0.0023283069751611463`"},
      {"\<\"Spleen\"\>", "0.0023360271792699557`"},
      {"\<\"Thymus\"\>", "0.003446119311465627`"},
      {"\<\"Uterus\"\>", "0.0010171914225342977`"},
      {"\<\"Adrenals\"\>", "0.0028837632830632995`"},
      {"\<\"Extrathoracic airways\"\>", "0.020369756297647604`"},
      {"\<\"Effective, e(50)\"\>", "0.0044621555362132454`"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]]}],
  SequenceForm[
   StyleForm[
   "\nAccumulted disintegration, in Bq, as function of the time\n", 
    FontFamily -> "Times", FontSize -> 12, FontWeight -> "Bold"], 
   TableForm[{{"AI", 1.4760354831193464`*^6}, {"bb1", 1349.2424093195727`}, {
     "bb2", 10178.302585497318`}, {"bbseq", 512.2457992363023}, {
     "BB1", 390.7421108730792}, {"BB2", 13944.477180272479`}, {
     "BBseq", 847.0898194449255}, {"ET2", 371.23798924143}, {
     "ET1", 29607.70237955229}, {"ETseq", 7546.294242983589}, {
     "LNth", 18869.495509578424`}, {"LNet", 7118.449257372645}, {
     "ST", 1546.801746621267}, {"SI", 5568.18552125692}, {
     "B", 5171.06924453489}, {"ULI", 19104.88327456838}, {
     "LLI", 34377.27668259203}, {"Other", 663196.391668358}, {"Liver", 0.}, {
     "UB_Content", 493.2666118388189}}, 
    TableHeadings -> {None, {"Compartment", 18262.5 "day"}}], 
   StyleForm[
   "\nDose accumulated, in Sv, as function of the time\n", FontFamily -> 
    "Times", FontSize -> 12, FontWeight -> "Bold"], 
   TableForm[{{"Sv/Bq", 18262.5 "day"}, {"Testes", 0.0006471949991141813}, {
     "Ovarius", 0.0012416685712395164`}, {
     "Red Marrow", 0.0018866439785832126`}, {
     "Colon", 0.0020344876355742557`}, {"Lungs", 0.02373583057224951}, {
     "St Wall", 0.0019343290770839658`}, {
     "Bladder Wall", 0.0008606105190791268}, {
     "Mama", 0.0029077818351623953`}, {"Liver", 0.0023275088209120066`}, {
     "Oesophagus", 0.003446119311465627}, {
     "Thyroid", 0.0016215590004709129`}, {"Skin", 0.0009754084243855861}, {
     "Bone Surface", 0.0016185817438510138`}, {
     "Muscle", 0.0016057141280610113`}, {"Brain", 0.0007291127761618344}, {
     "Small intestine", 0.0013231225135026177`}, {
     "Kidneys", 0.0015072996902680128`}, {
     "Pancreas", 0.0023283069751611463`}, {
     "Spleen", 0.0023360271792699557`}, {"Thymus", 0.003446119311465627}, {
     "Uterus", 0.0010171914225342977`}, {
     "Adrenals", 0.0028837632830632995`}, {
     "Extrathoracic airways", 0.020369756297647604`}, {
     "Effective, e(50)", 0.0044621555362132454`}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.5193922283197737`*^9, 3.5193926352025857`*^9, 
  3.519393182791224*^9, 3.5193981142140303`*^9, 3.541993334842642*^9, 
  3.592062353610087*^9, 3.6435963465603933`*^9, 3.6563195595670743`*^9},
 CellLabel->"During evaluation of In[63]:="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Caesium", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<Cs 137\>\"", ",", "\"\<Inhalation\>\"", ",", "1", ",", "AMAD5", ",", 
   "F", ",", "1", ",", 
   RowBox[{"50", "*", "365.25"}]}], "]"}]], "Input",
 CellLabel->"In[64]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox[
    StyleBox["\<\"\\nAccumulted disintegration, in Bq, as function of the \
time\\n\"\>",
     FontFamily->"Times",
     FontSize->12,
     FontWeight->"Bold"],
    StyleForm[#, FontFamily -> "Times", FontSize -> 12, FontWeight -> 
     "Bold"]& ], "\[InvisibleSpace]", 
   TagBox[
    TagBox[GridBox[{
       {
        TagBox["\<\"Compartment\"\>",
         HoldForm], 
        TagBox[
         RowBox[{"18262.5`", " ", "\<\"day\"\>"}],
         HoldForm]},
       {"\<\"AI\"\>", "45.95222892350486`"},
       {"\<\"bb1\"\>", "5.567302252153501`"},
       {"\<\"bb2\"\>", "3.7866376133729034`"},
       {"\<\"bbseq\"\>", "0.0667039974847801`"},
       {"\<\"BB1\"\>", "9.299933908177156`"},
       {"\<\"BB2\"\>", "5.114206502915365`"},
       {"\<\"BBseq\"\>", "0.10737324915314546`"},
       {"\<\"ET2\"\>", "172.70434680191198`"},
       {"\<\"ET1\"\>", "29261.7944036971`"},
       {"\<\"ETseq\"\>", "0.17232296776261072`"},
       {"\<\"LNth\"\>", "0.000018326817306180132`"},
       {"\<\"LNet\"\>", "1.72322858754681`*^-6"},
       {"\<\"ST\"\>", "719.5995483298996`"},
       {"\<\"SI\"\>", "0.`"},
       {"\<\"B\"\>", "14984.743104788742`"},
       {"\<\"ULI\"\>", "4574.7362307512185`"},
       {"\<\"LLI\"\>", "8234.004350474206`"},
       {"\<\"Body_Tis\"\>", "5.888221804750575`*^6"},
       {"\<\"UB_Content\"\>", "2744.9237311949382`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[2.0999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     {None, OutputFormsDump`HeadedColumns}],
    Function[BoxForm`e$, 
     TableForm[
     BoxForm`e$, TableHeadings -> {None, {"Compartment", 18262.5 "day"}}]]], 
   "\[InvisibleSpace]", 
   TagBox[
    StyleBox["\<\"\\nDose accumulated, in Sv, as function of the time\\n\"\>",
     FontFamily->"Times",
     FontSize->12,
     FontWeight->"Bold"],
    StyleForm[#, FontFamily -> "Times", FontSize -> 12, FontWeight -> 
     "Bold"]& ], "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"\<\"Sv/Bq\"\>", 
       RowBox[{"18262.5`", " ", "\<\"day\"\>"}]},
      {"\<\"Testes\"\>", "9.660702392689749`*^-9"},
      {"\<\"Ovarius\"\>", "1.1359005751854088`*^-8"},
      {"\<\"Red Marrow\"\>", "1.0218716662351861`*^-8"},
      {"\<\"Colon\"\>", "1.1766428823698513`*^-8"},
      {"\<\"Lungs\"\>", "9.821866250062207`*^-9"},
      {"\<\"St Wall\"\>", "1.0233252520821967`*^-8"},
      {"\<\"Bladder Wall\"\>", "1.116475583834612`*^-8"},
      {"\<\"Mama\"\>", "8.342337944074519`*^-9"},
      {"\<\"Liver\"\>", "1.0645837827285867`*^-8"},
      {"\<\"Oesophagus\"\>", "1.0220214704663135`*^-8"},
      {"\<\"Thyroid\"\>", "1.0188048691077364`*^-8"},
      {"\<\"Skin\"\>", "7.869441243777946`*^-9"},
      {"\<\"Bone Surface\"\>", "1.0842645485121978`*^-8"},
      {"\<\"Muscle\"\>", "9.663037711794574`*^-9"},
      {"\<\"Brain\"\>", "8.927098910690778`*^-9"},
      {"\<\"Small intestine\"\>", "1.1063981472907337`*^-8"},
      {"\<\"Kidneys\"\>", "1.0552989567272336`*^-8"},
      {"\<\"Pancreas\"\>", "1.1448307631111434`*^-8"},
      {"\<\"Spleen\"\>", "1.0561414956290664`*^-8"},
      {"\<\"Thymus\"\>", "1.0220214704663135`*^-8"},
      {"\<\"Uterus\"\>", "1.148994633916907`*^-8"},
      {"\<\"Adrenals\"\>", "1.1097293419325183`*^-8"},
      {"\<\"Extrathoracic airways\"\>", "2.1721550152949526`*^-8"},
      {"\<\"Effective, e(50)\"\>", "1.0816964691017395`*^-8"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]]}],
  SequenceForm[
   StyleForm[
   "\nAccumulted disintegration, in Bq, as function of the time\n", 
    FontFamily -> "Times", FontSize -> 12, FontWeight -> "Bold"], 
   TableForm[{{"AI", 45.95222892350486}, {"bb1", 5.567302252153501}, {
     "bb2", 3.7866376133729034`}, {"bbseq", 0.0667039974847801}, {
     "BB1", 9.299933908177156}, {"BB2", 5.114206502915365}, {
     "BBseq", 0.10737324915314546`}, {"ET2", 172.70434680191198`}, {
     "ET1", 29261.7944036971}, {"ETseq", 0.17232296776261072`}, {
     "LNth", 0.000018326817306180132`}, {"LNet", 1.72322858754681*^-6}, {
     "ST", 719.5995483298996}, {"SI", 0.}, {"B", 14984.743104788742`}, {
     "ULI", 4574.7362307512185`}, {"LLI", 8234.004350474206}, {
     "Body_Tis", 5.888221804750575*^6}, {"UB_Content", 2744.9237311949382`}}, 
    TableHeadings -> {None, {"Compartment", 18262.5 "day"}}], 
   StyleForm[
   "\nDose accumulated, in Sv, as function of the time\n", FontFamily -> 
    "Times", FontSize -> 12, FontWeight -> "Bold"], 
   TableForm[{{"Sv/Bq", 18262.5 "day"}, {"Testes", 9.660702392689749*^-9}, {
     "Ovarius", 1.1359005751854088`*^-8}, {
     "Red Marrow", 1.0218716662351861`*^-8}, {
     "Colon", 1.1766428823698513`*^-8}, {"Lungs", 9.821866250062207*^-9}, {
     "St Wall", 1.0233252520821967`*^-8}, {
     "Bladder Wall", 1.116475583834612*^-8}, {
     "Mama", 8.342337944074519*^-9}, {"Liver", 1.0645837827285867`*^-8}, {
     "Oesophagus", 1.0220214704663135`*^-8}, {
     "Thyroid", 1.0188048691077364`*^-8}, {"Skin", 7.869441243777946*^-9}, {
     "Bone Surface", 1.0842645485121978`*^-8}, {
     "Muscle", 9.663037711794574*^-9}, {"Brain", 8.927098910690778*^-9}, {
     "Small intestine", 1.1063981472907337`*^-8}, {
     "Kidneys", 1.0552989567272336`*^-8}, {
     "Pancreas", 1.1448307631111434`*^-8}, {
     "Spleen", 1.0561414956290664`*^-8}, {
     "Thymus", 1.0220214704663135`*^-8}, {"Uterus", 1.148994633916907*^-8}, {
     "Adrenals", 1.1097293419325183`*^-8}, {
     "Extrathoracic airways", 2.1721550152949526`*^-8}, {
     "Effective, e(50)", 1.0816964691017395`*^-8}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.519392230007306*^9, 3.5193926369213686`*^9, 
  3.5193931851975203`*^9, 3.519398115698434*^9, 3.5419933357332897`*^9, 
  3.5920623553689775`*^9, 3.643596347076023*^9, 3.656319560067081*^9},
 CellLabel->"During evaluation of In[64]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{"\"\<Cs 137\>\"", ",", "\"\<Ingestion\>\"", ",", "1", ",", "1", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[65]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "2.0089844515312025`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "2.3622024676992498`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "2.120932563314904`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "2.447078437293962`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "2.0321071869004095`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "2.1553448128669372`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "2.3217703591443612`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "1.732863348747931`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "2.213381651597747`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "2.1173737553833975`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "2.1110410338945194`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "1.6338636166986472`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "2.2496045258242488`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "2.0036423164329796`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "1.8488206877970756`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "2.301039454255969`*^-8"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "2.1945245712675547`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "2.381988755540222`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "2.1968528736984347`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "2.1173737553833975`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "2.3894202518372828`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "2.307527666559325`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "2.1110410338945197`*^-8"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "2.1871686797506426`*^-8"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.519392230319812*^9, 3.5193926383745213`*^9, 
  3.5193931854319*^9, 3.5193981159953146`*^9, 3.5419933359207945`*^9, 
  3.592062355699004*^9, 3.6435963471854095`*^9, 3.6563195601608205`*^9},
 CellLabel->"Out[65]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{"\"\<Cs 137\>\"", ",", "\"\<Injection\>\"", ",", "1", ",", "1", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[66]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "2.0089644181738356`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "2.362009923453081`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "2.1206847315437627`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "2.4465528616988656`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "2.0317854542085836`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "2.1078045737975754`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "2.3216929623296284`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "1.7326621005268606`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "2.2129642946984554`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "2.11722687263216`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "2.1110251272918687`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "1.6337360479399262`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "2.249458059999071`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "2.0033485527151286`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "1.8488206353255146`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "2.30050153399994`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "2.1938073674658835`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "2.378677633845583`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "2.1948032440335662`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "2.11722687263216`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "2.3892550709301433`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "2.3066896926045425`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "2.1110251272918687`*^-8"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "2.181232770019782`*^-8"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5193922304760647`*^9, 3.519392638499524*^9, 
  3.519393185572528*^9, 3.5193981161515675`*^9, 3.5419933360457973`*^9, 
  3.5920623558602667`*^9, 3.6435963472322755`*^9, 3.6563195602076964`*^9},
 CellLabel->"Out[66]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Iodine", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<I 125\>\"", ",", "\"\<Inhalation\>\"", ",", "1", ",", "AMAD5", ",", 
   "F", ",", "1", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[67]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "1.1383686446054008`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "1.4102902329238959`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "1.6419007440988805`*^-11"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "2.2000840278984073`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "2.045497701647974`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "1.8913605050704804`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "7.112951506825017`*^-11"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "1.05749946822635`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "1.2793235044947022`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "2.454297154202274`*^-11"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "1.4901549692092375`*^-7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "1.769818192573228`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "8.372229863140219`*^-11"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "6.840215237099127`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "1.717694889410887`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "1.297305860684984`*^-11"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "1.2471417794674884`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "1.3481091159893653`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "1.300358198598632`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "2.454297154202274`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "1.4564266404435682`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "1.3024659409763244`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "1.8309416456679298`*^-9"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "7.473122102062`*^-9"}], "}"}]}],
   "}"}]], "Output",
 CellChangeTimes->{3.519392232241724*^9, 3.5193926402651825`*^9, 
  3.5193931868694277`*^9, 3.5193981178391*^9, 3.541993337030198*^9, 
  3.592062357837925*^9, 3.6435963477479043`*^9, 3.656319560707706*^9},
 CellLabel->"Out[67]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{"\"\<I 125\>\"", ",", "\"\<Ingestion\>\"", ",", "1", ",", "1", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[68]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "2.3667852214117603`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "2.932371041966643`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "3.346818231913519`*^-11"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "4.585944020457385`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "4.134867423456694`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "6.221899879475716`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "1.478859183582078`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "2.1948471416787077`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "2.6625981563211507`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "4.9949325899320854`*^-11"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "3.098178843142877`*^-7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "3.605027725142988`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "1.690861143907265`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "1.3740823214392907`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "3.533521225539677`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "2.7046299741388492`*^-11"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "2.6007973672371288`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "2.9459508934449344`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "2.758769283257778`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "4.9949325899320854`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "3.028296537551061`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "2.7140306556241708`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "3.52275753156732`*^-11"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "1.5539473933692828`*^-8"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5193922325229793`*^9, 3.519392640593314*^9, 
  3.5193931870256805`*^9, 3.5193981181672316`*^9, 3.541993337233328*^9, 
  3.59206235827171*^9, 3.6435963478729134`*^9, 3.656319560832694*^9},
 CellLabel->"Out[68]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{"\"\<I 125\>\"", ",", "\"\<Injection\>\"", ",", "1", ",", "1", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[69]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "2.3679193431030397`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "2.933376276653594`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "3.3456919897322244`*^-11"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "4.568029705772277`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "4.126454039330973`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "2.3044898214886594`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "1.4795616900703683`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "2.1943135583039752`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "2.6563176712998996`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "4.997019243231585`*^-11"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "3.099667676629506`*^-7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "3.6040975658667514`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "1.6907862894111601`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "1.3732295584714067`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "3.5352191763868187`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "2.6932540875618733`*^-11"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "2.58839958376696`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "2.7013785739470102`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "2.663579013395629`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "4.997019243231585`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "3.0293424693586335`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "2.7028464865568072`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "3.524446866723438`*^-11"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "1.5542182556034073`*^-8"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5193922326011057`*^9, 3.519392640733942*^9, 
  3.5193931871194324`*^9, 3.5193981183234844`*^9, 3.5419933373427057`*^9, 
  3.5920623585454817`*^9, 3.64359634793542*^9, 3.656319560879568*^9},
 CellLabel->"Out[69]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<I 131\>\"", ",", "\"\<Inhalation\>\"", ",", "1", ",", "AMAD5", ",", 
   "F", ",", "1", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[70]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "1.9391052675365147`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "2.3273543527788103`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "5.495551574536398`*^-11"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "2.7798485145422915`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "8.070331705619769`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "7.329613492948719`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "3.673380429950428`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "3.113598961301702`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "2.411670467254654`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "8.587526797892022`*^-11"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "2.092317537416127`*^-7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "3.702275445725657`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "7.28535344387648`*^-11"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "7.017467463062272`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "8.113965070116097`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "2.1306059231759653`*^-11"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "2.1866712563298665`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "2.6920489005015494`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "2.459249509336738`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "8.587526797892022`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "2.773321479972389`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "2.4521317684594702`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "4.809971284444288`*^-9"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "1.0524722520969951`*^-8"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.519392234444891*^9, 3.5193926424058485`*^9, 
  3.5193931884475827`*^9, 3.519398119761012*^9, 3.5419933382646046`*^9, 
  3.5920623605031385`*^9, 3.6435963484666696`*^9, 3.656319561379568*^9},
 CellLabel->"Out[70]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{"\"\<I 131\>\"", ",", "\"\<Ingestion\>\"", ",", "1", ",", "1", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[71]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "4.02751453993774`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "4.856382700322849`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "1.012750257794275`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "5.855095427020453`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "1.037747591827928`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "3.0355936254118226`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "7.627522641727494`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "5.913464970986216`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "4.8875413656044956`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "1.5365159478934316`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "4.343870110559297`*^-7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "6.901868073979604`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "1.3239766611204062`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "1.2726095345752917`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "1.4477560592427787`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "4.518865236449011`*^-11"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "4.578954511775793`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "6.097005255336217`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "5.357114268502698`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "1.5365159478934316`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "5.777019687913045`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "5.073077982862361`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", 
     "1.4825374016654376`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "2.18565920930527`*^-8"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.519392235429285*^9, 3.5193926425933523`*^9, 
  3.5193931891819715`*^9, 3.519398120042268*^9, 3.5419933384677343`*^9, 
  3.592062360941923*^9, 3.6435963485760355`*^9, 3.656319561473317*^9},
 CellLabel->"Out[71]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{"\"\<I 131\>\"", ",", "\"\<Injection\>\"", ",", "1", ",", "1", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[72]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "4.035376437583719`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "4.808862929366892`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "1.0078492295953377`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "5.6909634703910884`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "1.0304564075436106`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "4.286325481346393`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "7.652527558257562`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "5.869113416673678`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "4.758162081841203`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "1.5373181879828683`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "4.359551530320266`*^-7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "6.884736794792583`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "1.3224204042963762`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "1.2669258351526244`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "1.4528563755688552`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "4.3410309796676666`*^-11"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "4.336537185784947`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "4.925976307433117`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "4.6326942093941495`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "1.5373181879828683`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "5.743551546812647`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "4.801340512552938`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", 
     "1.4873232915614948`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "2.1903284360859655`*^-8"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5193922357886667`*^9, 3.519392642671479*^9, 
  3.5193931894319763`*^9, 3.5193981202141457`*^9, 3.541993338561487*^9, 
  3.5920623611519403`*^9, 3.643596348622911*^9, 3.656319561520196*^9},
 CellLabel->"Out[72]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Plutonium ", "SubsubsectionIcon"],

Cell["\<\
The committed 50 y dose for Pu 239 (Adult Worker, AMAD5, type S, and f1= \
0.00001) can be obtained as follow\
\>", "Text",
 CellChangeTimes->{3.4799642157880383`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<Pu 239\>\"", ",", "\"\<Inhalation\>\"", ",", "1", ",", "AMAD5", ",", 
   "S", ",", "0.00001", ",", 
   RowBox[{"50", "*", "365.25"}]}], "]"}]], "Input",
 CellLabel->"In[73]:="],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox[
    StyleBox["\<\"\\nAccumulted disintegration, in Bq, as function of the \
time\\n\"\>",
     FontFamily->"Times",
     FontSize->12,
     FontWeight->"Bold"],
    StyleForm[#, FontFamily -> "Times", FontSize -> 12, FontWeight -> 
     "Bold"]& ], "\[InvisibleSpace]", 
   TagBox[
    TagBox[GridBox[{
       {
        TagBox["\<\"Compartment\"\>",
         HoldForm], 
        TagBox[
         RowBox[{"18262.5`", " ", "\<\"day\"\>"}],
         HoldForm]},
       {"\<\"AI\"\>", "4.621057533443436`*^6"},
       {"\<\"bb1\"\>", "2323.013385820359`"},
       {"\<\"bb2\"\>", "12571.385466275093`"},
       {"\<\"bbseq\"\>", "659.8378190591619`"},
       {"\<\"BB1\"\>", "603.3924770835878`"},
       {"\<\"BB2\"\>", "16978.82603691031`"},
       {"\<\"BBseq\"\>", "1062.1392003181393`"},
       {"\<\"ET2\"\>", "409.7373155299591`"},
       {"\<\"ET1\"\>", "29263.643135659855`"},
       {"\<\"ETseq\"\>", "15649.136192996824`"},
       {"\<\"LNth\"\>", "444319.16549080267`"},
       {"\<\"LNet\"\>", "128710.4412140681`"},
       {"\<\"ST\"\>", "1707.238807674493`"},
       {"\<\"SI\"\>", "6829.171594359857`"},
       {"\<\"B\"\>", "1865.5477698966013`"},
       {"\<\"ULI\"\>", "22770.622001577718`"},
       {"\<\"LLI\"\>", "40991.10992150358`"},
       {"\<\"Liver\"\>", "2.0708488525685966`*^6"},
       {"\<\"C_Bone-S\"\>", "1.901466135729771`*^6"},
       {"\<\"T_Bone-S\"\>", "662506.6013397882`"},
       {"\<\"UB_Content\"\>", "1.321058264292136`"},
       {"\<\"Kidneys\"\>", "5612.74719010225`"},
       {"\<\"Testes\"\>", "1821.1727856453494`"},
       {"\<\"Ovaries\"\>", "1821.1727856453494`"},
       {"\<\"Other\"\>", "555640.7886952944`"},
       {"\<\"C_Bone-V\"\>", "433605.2318299762`"},
       {"\<\"R_Marrow\"\>", "87621.4157254888`"},
       {"\<\"T_Bone-V\"\>", "305869.407145935`"}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxDividers->{
       "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
        "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[2.0999999999999996`]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.4]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}],
     {None, OutputFormsDump`HeadedColumns}],
    Function[BoxForm`e$, 
     TableForm[
     BoxForm`e$, TableHeadings -> {None, {"Compartment", 18262.5 "day"}}]]], 
   "\[InvisibleSpace]", 
   TagBox[
    StyleBox["\<\"\\nDose accumulated, in Sv, as function of the time\\n\"\>",
     FontFamily->"Times",
     FontSize->12,
     FontWeight->"Bold"],
    StyleForm[#, FontFamily -> "Times", FontSize -> 12, FontWeight -> 
     "Bold"]& ], "\[InvisibleSpace]", 
   TagBox[GridBox[{
      {"\<\"Sv/Bq\"\>", 
       RowBox[{"18262.5`", " ", "\<\"day\"\>"}]},
      {"\<\"Testes\"\>", "8.733431545448511`*^-7"},
      {"\<\"Ovarius\"\>", "2.7777444465826195`*^-6"},
      {"\<\"Red Marrow\"\>", "4.79078879801751`*^-6"},
      {"\<\"Colon\"\>", "1.7238651894909824`*^-7"},
      {"\<\"Lungs\"\>", "0.000046927828731444464`"},
      {"\<\"St Wall\"\>", "1.572135236748418`*^-7"},
      {"\<\"Bladder Wall\"\>", "1.5664630548551593`*^-7"},
      {"\<\"Mama\"\>", "1.566472992596556`*^-7"},
      {"\<\"Liver\"\>", "0.000019300769661236614`"},
      {"\<\"Oesophagus\"\>", "1.566466679573406`*^-7"},
      {"\<\"Thyroid\"\>", "1.566457100087378`*^-7"},
      {"\<\"Skin\"\>", "1.5664605403247325`*^-7"},
      {"\<\"Bone Surface\"\>", "0.00009041784981228968`"},
      {"\<\"Muscle\"\>", "1.566500666500185`*^-7"},
      {"\<\"Brain\"\>", "1.5664645006942698`*^-7"},
      {"\<\"Small intestine\"\>", "1.5806396331163849`*^-7"},
      {"\<\"Kidneys\"\>", "3.0421799126757186`*^-7"},
      {"\<\"Pancreas\"\>", "1.5664697885752362`*^-7"},
      {"\<\"Spleen\"\>", "1.5664713147076422`*^-7"},
      {"\<\"Thymus\"\>", "1.566466679573406`*^-7"},
      {"\<\"Uterus\"\>", "1.5664547175482727`*^-7"},
      {"\<\"Adrenals\"\>", "1.56649654908071`*^-7"},
      {"\<\"Extrathoracic airways\"\>", "0.0000793272540413401`"},
      {"\<\"Effective, e(50)\"\>", "8.71328645504691`*^-6"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    Function[BoxForm`e$, 
     TableForm[BoxForm`e$]]]}],
  SequenceForm[
   StyleForm[
   "\nAccumulted disintegration, in Bq, as function of the time\n", 
    FontFamily -> "Times", FontSize -> 12, FontWeight -> "Bold"], 
   TableForm[{{"AI", 4.621057533443436*^6}, {"bb1", 2323.013385820359}, {
     "bb2", 12571.385466275093`}, {"bbseq", 659.8378190591619}, {
     "BB1", 603.3924770835878}, {"BB2", 16978.82603691031}, {
     "BBseq", 1062.1392003181393`}, {"ET2", 409.7373155299591}, {
     "ET1", 29263.643135659855`}, {"ETseq", 15649.136192996824`}, {
     "LNth", 444319.16549080267`}, {"LNet", 128710.4412140681}, {
     "ST", 1707.238807674493}, {"SI", 6829.171594359857}, {
     "B", 1865.5477698966013`}, {"ULI", 22770.622001577718`}, {
     "LLI", 40991.10992150358}, {"Liver", 2.0708488525685966`*^6}, {
     "C_Bone-S", 1.901466135729771*^6}, {"T_Bone-S", 662506.6013397882}, {
     "UB_Content", 1.321058264292136}, {"Kidneys", 5612.74719010225}, {
     "Testes", 1821.1727856453494`}, {"Ovaries", 1821.1727856453494`}, {
     "Other", 555640.7886952944}, {"C_Bone-V", 433605.2318299762}, {
     "R_Marrow", 87621.4157254888}, {"T_Bone-V", 305869.407145935}}, 
    TableHeadings -> {None, {"Compartment", 18262.5 "day"}}], 
   StyleForm[
   "\nDose accumulated, in Sv, as function of the time\n", FontFamily -> 
    "Times", FontSize -> 12, FontWeight -> "Bold"], 
   TableForm[{{"Sv/Bq", 18262.5 "day"}, {"Testes", 8.733431545448511*^-7}, {
     "Ovarius", 2.7777444465826195`*^-6}, {
     "Red Marrow", 4.79078879801751*^-6}, {
     "Colon", 1.7238651894909824`*^-7}, {"Lungs", 0.000046927828731444464`}, {
     "St Wall", 1.572135236748418*^-7}, {
     "Bladder Wall", 1.5664630548551593`*^-7}, {
     "Mama", 1.566472992596556*^-7}, {"Liver", 0.000019300769661236614`}, {
     "Oesophagus", 1.566466679573406*^-7}, {
     "Thyroid", 1.566457100087378*^-7}, {"Skin", 1.5664605403247325`*^-7}, {
     "Bone Surface", 0.00009041784981228968}, {
     "Muscle", 1.566500666500185*^-7}, {"Brain", 1.5664645006942698`*^-7}, {
     "Small intestine", 1.5806396331163849`*^-7}, {
     "Kidneys", 3.0421799126757186`*^-7}, {
     "Pancreas", 1.5664697885752362`*^-7}, {
     "Spleen", 1.5664713147076422`*^-7}, {"Thymus", 1.566466679573406*^-7}, {
     "Uterus", 1.5664547175482727`*^-7}, {"Adrenals", 1.56649654908071*^-7}, {
     "Extrathoracic airways", 0.0000793272540413401}, {
     "Effective, e(50)", 8.71328645504691*^-6}}]],
  Editable->False]], "Print",
 CellChangeTimes->{3.399017016531866*^9, 3.4178382569638543`*^9, 
  3.479963784793038*^9, 3.4802173900591316`*^9, 3.518537191915431*^9, 
  3.5193922550390368`*^9, 3.519392661249961*^9, 3.5193932040416317`*^9, 
  3.519398138995756*^9, 3.5419933487648735`*^9, 3.5920623986336884`*^9, 
  3.643596354247954*^9, 3.656319567223301*^9},
 CellLabel->"During evaluation of In[73]:="]
}, Open  ]],

Cell["\<\
Here it is obtained the committed doses by injection formatted as a list.\
\>", "Text",
 CellChangeTimes->{{3.479964221875038*^9, 3.479964224259038*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<Pu 239\>\"", ",", "\"\<Injection\>\"", ",", "1", ",", "0.00001", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], " ", 
  "]"}]], "Input",
 CellLabel->"In[74]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "0.00022010180838602712`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "0.0007000611395671191`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "0.0008365179827137227`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "0.000029073827539668502`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "0.000029069420914481294`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "0.00002906914735781377`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "0.000029070638341582116`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "0.000029069146711756885`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "0.0034602276508505273`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "0.000029069144185875427`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "0.00002906912268744654`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "0.000029069187320124106`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "0.016363943279035113`"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "0.000029069297319736142`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "0.000029069297339636056`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "0.00002906940305644523`"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "0.00006770488237036684`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "0.0000290692767230366`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "0.000029069134008463806`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "0.000029069144185875427`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "0.000029069115477513184`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "0.0000290695802370122`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", 
     "0.000029069122687446535`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "0.000595088212268895`"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5193922562109337`*^9, 3.5193926622343545`*^9, 
  3.5193932052604055`*^9, 3.51939814021453*^9, 3.541993349499267*^9, 
  3.5920624000800543`*^9, 3.6435963546542077`*^9, 3.6563195676139345`*^9},
 CellLabel->"Out[74]="]
}, Open  ]],

Cell["\<\
Here is an example where the SSE factors are imported, from the DCAL output \
file. SEE factors and the decay constant are given as  input data.\
\>", "Text",
 CellChangeTimes->{3.479964229147038*^9}],

Cell[BoxData[
 RowBox[{
  RowBox[{"pu239see", "=", " ", 
   RowBox[{"ImportSEE", "[", 
    RowBox[{"PU239ADULT", ",", "\"\<csv\>\""}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.399017231135552*^9, 3.3990172333378167`*^9}},
 CellLabel->"In[75]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CommittedDose", "[", 
   RowBox[{
   "\"\<Pu\>\"", ",", "\"\<Inhalation\>\"", ",", "1", ",", "AMAD5", ",", "S", 
    ",", "0.00001", ",", 
    RowBox[{"50", "*", "365.25"}], ",", " ", 
    RowBox[{
     RowBox[{"Log", "[", "2", "]"}], "/", "8802525"}], ",", "pu239see", ",", 
    " ", 
    RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], " ", 
   "]"}], "//", "TableForm"}]], "Input",
 CellLabel->"In[76]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"Sv/Bq\"\>", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]},
    {"\<\"Testes\"\>", "8.733431545448511`*^-7"},
    {"\<\"Ovarius\"\>", "2.7777444465826195`*^-6"},
    {"\<\"Red Marrow\"\>", "4.79078879801751`*^-6"},
    {"\<\"Colon\"\>", "1.7238651894909824`*^-7"},
    {"\<\"Lungs\"\>", "0.000046927828731444464`"},
    {"\<\"St Wall\"\>", "1.572135236748418`*^-7"},
    {"\<\"Bladder Wall\"\>", "1.5664630548551593`*^-7"},
    {"\<\"Mama\"\>", "1.566472992596556`*^-7"},
    {"\<\"Liver\"\>", "0.000019300769661236614`"},
    {"\<\"Oesophagus\"\>", "1.566466679573406`*^-7"},
    {"\<\"Thyroid\"\>", "1.566457100087378`*^-7"},
    {"\<\"Skin\"\>", "1.5664605403247325`*^-7"},
    {"\<\"Bone Surface\"\>", "0.00009041784981228968`"},
    {"\<\"Muscle\"\>", "1.566500666500185`*^-7"},
    {"\<\"Brain\"\>", "1.5664645006942698`*^-7"},
    {"\<\"Small intestine\"\>", "1.5806396331163849`*^-7"},
    {"\<\"Kidneys\"\>", "3.0421799126757186`*^-7"},
    {"\<\"Pancreas\"\>", "1.5664697885752362`*^-7"},
    {"\<\"Spleen\"\>", "1.5664713147076422`*^-7"},
    {"\<\"Thymus\"\>", "1.566466679573406`*^-7"},
    {"\<\"Uterus\"\>", "1.5664547175482727`*^-7"},
    {"\<\"Adrenals\"\>", "1.56649654908071`*^-7"},
    {"\<\"Extrathoracic airways\"\>", "0.0000793272540413401`"},
    {"\<\"Effective, e(50)\"\>", "8.71328645504691`*^-6"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.399017048160138*^9, 3.399017266293696*^9, 
  3.417838288202827*^9, 3.479963801535038*^9, 3.48021741793431*^9, 
  3.51853721166581*^9, 3.519392274914418*^9, 3.519392681469099*^9, 
  3.5193932232763767`*^9, 3.519398159480525*^9, 3.541993359655777*^9, 
  3.5920624371330185`*^9, 3.6435963603573785`*^9, 3.656319573082672*^9},
 CellLabel->"Out[76]//TableForm="]
}, Open  ]],

Cell["\<\
The see factors for respiratory tract compartments are not necessary when the \
intake way is ingestion or injection. In this case these factor should be \
dropped  in the see file generated by DCAL-SEECAL. They are always included \
in the first 12 columns. It can be done Map[Drop[#,12]&, see ]\
\>", "Text",
 CellChangeTimes->{{3.4799642329790382`*^9, 3.479964240243038*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<Pu\>\"", ",", "\"\<Ingestion\>\"", ",", "1", ",", "0.00001", ",", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{
    RowBox[{"Log", "[", "2", "]"}], "/", "8802525"}], ",", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"Drop", "[", 
       RowBox[{"#", ",", "12"}], "]"}], "&"}], ",", "pu239see"}], " ", "]"}], 
   ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], " ", 
  "]"}]], "Input",
 CellLabel->"In[77]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "2.2010085827057867`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "7.001520899709334`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "8.365168683181471`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "3.346857801305547`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "2.906919720477281`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "1.4862934093438863`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "2.907538244903711`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "2.906886349479903`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "3.460202474633629`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "2.9068846381362706`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "2.9068796117489877`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "2.9069419941300777`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "1.6363807835286354`*^-7"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "2.907302120958615`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "2.906896615478379`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "3.280806261945484`*^-9"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "6.770559679015167`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "2.907076846860098`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "2.906964809231266`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "2.9068846381362706`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "2.9074980326576044`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "2.9069647127780646`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "2.906879611748988`*^-10"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "1.0078963681301242`*^-8"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.399017050565449*^9, 3.399017284286669*^9, 
  3.41783829032814*^9, 3.4799638029800377`*^9, 3.480217420496826*^9, 
  3.518537213009586*^9, 3.519392276273819*^9, 3.5193926836878915`*^9, 
  3.5193932243076463`*^9, 3.5193981608086753`*^9, 3.5419933604214215`*^9, 
  3.592062438680642*^9, 3.643596360951132*^9, 3.6563195735045457`*^9},
 CellLabel->"Out[77]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Strontium ", "SubsubsectionIcon"],

Cell["Sr 89", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<Sr 89\>\"", ",", "\"\<Inhalation\>\"", ",", "1", ",", "AMAD5", ",", 
   "S", ",", "0.01", ",", " ", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[78]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "3.239571747620134`*^-12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "3.276179391300704`*^-12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "7.911698862591039`*^-11"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "7.90477295991814`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "3.812626412592442`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "2.9591015325783876`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "1.1084812253455551`*^-11"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "3.276819375618202`*^-12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "3.2708157444930943`*^-12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "3.285212344333188`*^-12"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "3.2537102298027023`*^-12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "3.2464212702799416`*^-12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "9.856499363724608`*^-11"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "3.2579295859977905`*^-12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "3.2411405925131378`*^-12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "7.258579632291598`*^-10"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "3.254153507160375`*^-12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "3.2672442941632155`*^-12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "3.266293796163277`*^-12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "3.285212344333188`*^-12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "3.2541098950462824`*^-12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "3.2756392005549343`*^-12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "6.086846535363323`*^-9"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "5.572672576609408`*^-9"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.399017065231596*^9, 3.4178383049396653`*^9, 
  3.4799638109400377`*^9, 3.48021743362191*^9, 3.5185372236504154`*^9, 
  3.5193922863521376`*^9, 3.5193926951256113`*^9, 3.5193932341672106`*^9, 
  3.519398171262001*^9, 3.5419933657340574`*^9, 3.59206244940775*^9, 
  3.643596364029281*^9, 3.656319576285777*^9},
 CellLabel->"Out[78]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<Sr 89\>\"", ",", "\"\<Ingestion\>\"", ",", "1", ",", "0.3", ",", " ", 
   RowBox[{"50", "*", "365.25"}], ",", " ", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[79]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Sv/Bq\"\>", ",", 
     RowBox[{"18262.5`", " ", "\<\"day\"\>"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "1.9574174042791496`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "1.9582305622084356`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "4.784605113268112`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "1.3960646270567286`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "1.9574830080936454`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "8.682074477757992`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "6.701846457788692`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "1.9573080785016087`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "1.9574823625590777`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "1.9574306624512516`*^-10"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "1.957441801238555`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "1.9573331530657928`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "5.961592917401892`*^-9"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "1.957534635497874`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "1.9575026542217718`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "1.3705914141744826`*^-9"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "1.9576292977365537`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "1.957586103799137`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "1.9574925359490612`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "1.9574306624512516`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "1.9577632495232192`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "1.9577230651960427`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "1.957441801238555`*^-10"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "2.561510153593422`*^-9"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.399017067964904*^9, 3.4178383070806055`*^9, 
  3.479963812225038*^9, 3.4802174358406744`*^9, 3.518537225166069*^9, 
  3.519392287883417*^9, 3.519392697563158*^9, 3.519393235667239*^9, 
  3.5193981728089056`*^9, 3.5419933666247053`*^9, 3.5920624512078943`*^9, 
  3.6435963645917854`*^9, 3.656319576754525*^9},
 CellLabel->"Out[79]="]
}, Open  ]],

Cell["\<\
Sr 90. It is a special case where the descent Y 90 is radioactive.\
\>", "Text",
 CellChangeTimes->{{3.3990171091050863`*^9, 3.3990171320336313`*^9}, 
   3.479964251794038*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{
  "\"\<Sr 90\>\"", ",", "\"\<Ingestion\>\"", ",", "1", ",", "0.01", ",", 
   RowBox[{"50", "*", "365.24"}], ",", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[80]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "2.212896028204219`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "2.212956229655634`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "5.966996018210962`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "1.4839579329352702`*^-8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "2.2129021761682405`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "2.594404470195191`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "4.942228081848596`*^-11"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "2.2129018836390035`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "2.2128994242810086`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "2.2129005820503126`*^-11"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "2.2128976871110452`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "2.212910297494688`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "1.3612678839404182`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "2.212914257039719`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "2.212929270475585`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "7.179812199895553`*^-10"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "2.212899468299666`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "2.212896987336531`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "2.212898214358331`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "2.2129005820503126`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "2.2128965696791017`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "2.2129094971035224`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", 
     "2.2128976871110452`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "2.6800786640715806`*^-9"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.3990170798821244`*^9, 3.4178383193792906`*^9, 
  3.479963820719038*^9, 3.480217450372018*^9, 3.518537231525566*^9, 
  3.5193922932741456`*^9, 3.519392703703901*^9, 3.5193932429173784`*^9, 
  3.519398179949668*^9, 3.5419933732342496`*^9, 3.592062513501627*^9, 
  3.6435963694824505`*^9, 3.6563195815045137`*^9},
 CellLabel->"Out[80]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose", "[", 
  RowBox[{"\"\<Sr 90\>\"", ",", "\"\<Inhalation\>\"", ",", "1", ",", 
   RowBox[{"AMADAdultW", "[", "5", "]"}], ",", " ", "S", ",", "0.01", ",", 
   RowBox[{"50", "*", "365.24"}], ",", 
   RowBox[{"DisintegrationReport", "\[Rule]", " ", "\"\<False\>\""}]}], 
  "]"}]], "Input",
 CellLabel->"In[81]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"Testes\"\>", ",", "2.3375661052465033`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Ovarius\"\>", ",", "2.3376031555476898`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Red Marrow\"\>", ",", "6.024594015809244`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Colon\"\>", ",", "8.222384898577085`*^-9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Lungs\"\>", ",", "6.25242048871531`*^-7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"St Wall\"\>", ",", "1.9451447397810393`*^-10"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bladder Wall\"\>", ",", "5.492041550619708`*^-11"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Mama\"\>", ",", "2.3377271238284358`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Liver\"\>", ",", "2.3380800492376278`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Oesophagus\"\>", ",", "2.337603421280643`*^-11"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thyroid\"\>", ",", "2.3375686031630733`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Skin\"\>", ",", "2.3375962832332833`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Bone Surface\"\>", ",", "1.3577711522421468`*^-8"}], "}"}], 
   ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Muscle\"\>", ",", "2.338264832212435`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Brain\"\>", ",", "2.3375992002335506`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Small intestine\"\>", ",", "4.92103544986994`*^-10"}], "}"}],
    ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Kidneys\"\>", ",", "2.3375706454411137`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Pancreas\"\>", ",", "2.3375895117897842`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Spleen\"\>", ",", "2.3377569860151437`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thymus\"\>", ",", "2.337603421280643`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Uterus\"\>", ",", "2.3375665819694304`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Adrenals\"\>", ",", "2.3377360304535288`*^-11"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Extrathoracic airways\"\>", ",", "9.102652966106331`*^-8"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Effective, e(50)\"\>", ",", "7.691400833027974`*^-8"}], 
    "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.39901712922223*^9, 3.417838368386503*^9, 
  3.479963856260038*^9, 3.480217510513027*^9, 3.5185372611042595`*^9, 
  3.5193923208059244`*^9, 3.5193927324075766`*^9, 3.519393275652382*^9, 
  3.5193982123877907`*^9, 3.5419934400640855`*^9, 3.592062906703081*^9, 
  3.6435964956084394`*^9, 3.6563197388328724`*^9},
 CellLabel->"Out[81]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Computing the equivalent dose step by step", \
"Subsubsection"]], "SubsubsectionIcon",
 CellChangeTimes->{{3.4801816581*^9, 3.4801816926071997`*^9}, {
  3.4801817246496*^9, 3.4801817450388002`*^9}}],

Cell["\<\
Here is computed the equivalent doses step by step  assuming an inhalation of \
Cobalt 60 with the following characteristic\
\>", "MathCaption",
 CellChangeTimes->{{3.4801815421140003`*^9, 3.4801815508812*^9}, {
  3.480181749594*^9, 3.480181826502*^9}, {3.480216977296459*^9, 
  3.4802170034674764`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "I1", ",", "amadp", ",", " ", "ff1", ",", "s1", ",", "s2", ",", "s3"}], 
    "}"}], " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
    "398551", ",", " ", "5.5", ",", "  ", "0.1", ",", " ", "10", ",", " ", 
     "90", ",", " ", "0.0007"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.4801818927396*^9, 3.4801819014756002`*^9}},
 CellLabel->"In[82]:="],

Cell["Doses = Intake*Us*DCF", "Text",
 CellChangeTimes->{{3.480217022750577*^9, 3.4802170535191555`*^9}}],

Cell["Us", "Text",
 CellChangeTimes->{{3.4802170724115944`*^9, 3.480217072645992*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"CobaltUs", "[", 
    RowBox[{
    "amadx_", ",", " ", "typem_", ",", " ", "ff1_", ",", "lambda_", ",", " ", 
     "t1_"}], "]"}], ":=", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        SubscriptBox["q", "AI"], "[", "t", "]"}], ",", 
       RowBox[{
        SubscriptBox["q", "bb1"], "[", "t", "]"}], ",", " ", 
       RowBox[{
        SubscriptBox["q", "bb2"], "[", "t", "]"}], ",", 
       RowBox[{
        SubscriptBox["q", "bbseq"], "[", "t", "]"}], ",", 
       RowBox[{
        SubscriptBox["q", "BB1"], "[", "t", "]"}], ",", " ", 
       RowBox[{
        SubscriptBox["q", "BB2"], "[", "t", "]"}], ",", " ", 
       RowBox[{
        SubscriptBox["q", "BBseq"], "[", "t", "]"}], ",", 
       RowBox[{
        SubscriptBox["q", "ET2"], "[", "t", "]"}], ",", 
       RowBox[{
        SubscriptBox["q", "ET1"], "[", "t", "]"}], ",", "  ", 
       RowBox[{
        SubscriptBox["q", "ETseq"], "[", "t", "]"}], ",", " ", 
       RowBox[{
        SubscriptBox["q", "LNth"], "[", "t", "]"}], ",", " ", 
       RowBox[{
        SubscriptBox["q", "LNet"], "[", "t", "]"}], ",", 
       RowBox[{"qST", "[", "t", "]"}], ",", 
       RowBox[{"qSI", "[", "t", "]"}], ",", 
       RowBox[{"qB", "[", "t", "]"}], ",", 
       RowBox[{"qULI", "[", "t", "]"}], ",", " ", 
       RowBox[{"qLLI", "[", "t", "]"}], ",", 
       RowBox[{
        RowBox[{
         SubscriptBox["q", "2"], "[", "t", "]"}], "+", " ", 
        RowBox[{
         SubscriptBox["q", "3"], "[", "t", "]"}], "+", 
        RowBox[{
         SubscriptBox["q", "4"], "[", "t", "]"}]}], " ", ",", " ", "0", ",", 
       " ", 
       RowBox[{
        SubscriptBox["q", "5"], "[", "t", "]"}]}], " ", "}"}], "/.", 
     RowBox[{"BiokdataReport", "[", 
      RowBox[{
      "cobalt", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
       "\"\<Disintegrations\>\"", ",", " ", "1", ",", " ", "amadx", ",", " ", 
       "typem", ",", " ", "ff1", ",", "t", ",", "lambda"}], "]"}]}], "/.", 
    RowBox[{"t", "->", " ", 
     RowBox[{"t1", "*", "365"}]}]}]}], ";"}]], "Input",
 CellLabel->"In[83]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"UsCo60e", " ", "=", 
   RowBox[{"CobaltUs", "[", " ", 
    RowBox[{
     RowBox[{"AMADAdultW", "[", "amadp", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"s1", ",", "s2", ",", "s3"}], "}"}], ",", " ", "ff1", ",", 
     RowBox[{
      RowBox[{"Log", "[", "2", "]"}], "/", 
      RowBox[{"(", 
       RowBox[{"5.27", "*", "365"}], ")"}]}], " ", ",", " ", "50"}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[84]:="],

Cell["DCF.- They are downloaded ", "Text",
 CellChangeTimes->{{3.480217084490879*^9, 3.480217098054681*^9}, {
  3.480217162545246*^9, 3.480217200877051*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"seecalCo60", "=", 
   RowBox[{"ImportSEE", "[", 
    RowBox[{"CO60ADULT", ",", " ", "\"\<csv\>\""}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{
  3.4801795725984*^9, {3.4801803323964*^9, 3.4801803342684*^9}},
 CellLabel->"In[85]:="],

Cell["\<\
Finally it is computed the CommittedDose1 (CommittedDose included in the \
package is similar) \
\>", "Text",
 CellChangeTimes->{{3.480217111743495*^9, 3.4802171389179783`*^9}, {
  3.5193982224817343`*^9, 3.519398387750532*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"CommittedDose1", "[", 
   RowBox[{"intake_", ",", "us_", ",", " ", "seecal_"}], "]"}], ":=", "\n", 
  "  ", 
  RowBox[{"Module", "[", 
   RowBox[{
    RowBox[{"{", "sidelavel", "}"}], ",", "\n", "    ", 
    RowBox[{
     RowBox[{"sidelavel", " ", "=", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Testes\>\"", ",", "\"\<Ovarius\>\"", ",", "\"\<Red Marrow\>\"", 
        ",", "\"\<Colon\>\"", ",", "\"\<Lungs\>\"", ",", "\"\<St Wall\>\"", 
        ",", "\n", "        ", "\"\<Bladder Wall\>\"", ",", "\"\<Mama\>\"", 
        ",", "\"\<Liver\>\"", ",", "\"\<Oesophagus\>\"", ",", 
        "\"\<Thyroid\>\"", ",", "\"\<Skin\>\"", ",", "\n", "        ", 
        "\"\<Bone Surface\>\"", ",", "\"\<Muscle\>\"", ",", "\"\<Brain\>\"", 
        ",", "\"\<Small intestine\>\"", ",", "\"\<Kidneys\>\"", ",", "\n", 
        "        ", "\"\<Pancreas\>\"", ",", "\"\<Spleen\>\"", ",", 
        "\"\<Thymus\>\"", ",", "\"\<Uterus\>\"", ",", "\"\<Adrenals\>\"", ",",
         "\n", "        ", "\"\<Extrathoracic airways\>\"", ",", " ", 
        "\"\<Effective, e(50)\>\""}], "}"}]}], ";", "\n", "    ", 
     RowBox[{"TableForm", "[", 
      RowBox[{
       RowBox[{"Transpose", "[", 
        RowBox[{"{", 
         RowBox[{"sidelavel", " ", ",", 
          RowBox[{"intake", "*", 
           RowBox[{"dosefactor", "[", 
            RowBox[{"us", ",", " ", "seecal"}], "]"}]}]}], " ", "}"}], " ", 
        "]"}], ",", " ", "\n", "      ", 
       RowBox[{"TableHeadings", "\[Rule]", " ", 
        RowBox[{"{", 
         RowBox[{"None", ",", " ", 
          RowBox[{"{", 
           RowBox[{"\"\<Organ\>\"", ",", " ", "\"\<Sv/Bq\>\""}], " ", "}"}]}],
          "}"}]}]}], "]"}]}]}], "]"}]}]], "Input",
 CellChangeTimes->{3.4801804132200003`*^9, 3.480215873433586*^9},
 CellLabel->"In[86]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CommittedDose1", "[", 
  RowBox[{"I1", ",", "UsCo60e", ",", "seecalCo60"}], "]"}]], "Input",
 CellChangeTimes->{
  3.4801795211963997`*^9, {3.4801802924916*^9, 3.4801802972808*^9}, 
   3.4801804180092*^9},
 CellLabel->"In[87]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Organ\"\>",
       HoldForm], 
      TagBox["\<\"Sv/Bq\"\>",
       HoldForm]},
     {"\<\"Testes\"\>", "0.0006470747728017828`"},
     {"\<\"Ovarius\"\>", "0.0012415059209341616`"},
     {"\<\"Red Marrow\"\>", "0.0018863611025469467`"},
     {"\<\"Colon\"\>", "0.0020343233171116817`"},
     {"\<\"Lungs\"\>", "0.023733565476456355`"},
     {"\<\"St Wall\"\>", "0.0019340458371692106`"},
     {"\<\"Bladder Wall\"\>", "0.0008604716497422247`"},
     {"\<\"Mama\"\>", "0.002907361554137617`"},
     {"\<\"Liver\"\>", "0.0023271755547621484`"},
     {"\<\"Oesophagus\"\>", "0.0034456186631889527`"},
     {"\<\"Thyroid\"\>", "0.0016213022504020919`"},
     {"\<\"Skin\"\>", "0.000975253519704434`"},
     {"\<\"Bone Surface\"\>", "0.0016183259138705336`"},
     {"\<\"Muscle\"\>", "0.0016054682219773847`"},
     {"\<\"Brain\"\>", "0.0007289843608563277`"},
     {"\<\"Small intestine\"\>", "0.0013229481362209497`"},
     {"\<\"Kidneys\"\>", "0.0015070622023193665`"},
     {"\<\"Pancreas\"\>", "0.0023279538235642`"},
     {"\<\"Spleen\"\>", "0.0023356743935886944`"},
     {"\<\"Thymus\"\>", "0.0034456186631889527`"},
     {"\<\"Uterus\"\>", "0.001017028767593227`"},
     {"\<\"Adrenals\"\>", "0.002883334472093411`"},
     {"\<\"Extrathoracic airways\"\>", "0.020367814896399224`"},
     {"\<\"Effective, e(50)\"\>", "0.004461664903544442`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, TableHeadings -> {None, {"Organ", "Sv/Bq"}}]]]], "Output",
 CellChangeTimes->{3.4801803005880003`*^9, 3.4801804246703997`*^9, 
  3.4801805907948*^9, 3.480216027256899*^9, 3.4802175164818153`*^9, 
  3.5185372665418634`*^9, 3.5193923255560155`*^9, 3.519392737267045*^9, 
  3.5193932801212177`*^9, 3.5193982169660034`*^9, 3.5419934426735272`*^9, 
  3.5920629117522345`*^9, 3.64359649704595*^9, 3.656319740364127*^9},
 CellLabel->"Out[87]//TableForm="]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Brackets",
WindowToolbars->"EditBar",
WindowSize->{1664, 948},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingStartingPageNumber->1,
PageHeaders->{{
   Cell[
    TextData[
     StyleBox[
      CounterBox["Page"], "PageNumber"]], "Header", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], 
   Cell[
    TextData["Biokmod"], "Header"], None}, {
   Cell[
    TextData[
     StyleBox[
      RowBox[{"Printed", " ", "from", " ", "the", " ", 
        StyleBox["Mathematica", FontSlant -> "Italic"], " ", "Help", " ", 
        "Browser"}], "PageHeader"]], "Header", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, 
   Cell[
    TextData[
     StyleBox[
      CounterBox["Page"], "PageNumber"]], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}},
PageFooters->{{None, 
   Cell[
    TextData[
     StyleBox[
      RowBox[{
       "\[Copyright]2013", " ", "Guillermo", " ", "S\[AAcute]nchez", " ", 
        "and", " ", "ENUSA", ".", " ", "All", " ", "rights", " ", "reserved", 
        "."}], "PageFooter"]], "Footer"], None}, {None, 
   Cell[
    TextData[{
     "http", ":", "//", "diarium", ".", "usal", ".", "es", "/", "guillermo"}],
     "Footer"], None}},
PageHeaderLines->{True, True},
PageFooterLines->{True, True},
PrintingOptions->{"FacingPages"->True,
"FirstPageFace"->Right,
"FirstPageFooter"->True,
"FirstPageHeader"->True},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"10.2 for Microsoft Windows (64-bit) (July 29, 2015)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info-c74cd3e3-9188-4da4-8d2d-d49dbca22874"->{
  Cell[79943, 2263, 295, 5, 90, "Print",
   CellTags->"Info-c74cd3e3-9188-4da4-8d2d-d49dbca22874"]},
 "Info-9c7d9f7e-df35-4cf3-b463-4742e3852c45"->{
  Cell[85250, 2412, 339, 5, 60, "Print",
   CellTags->"Info-9c7d9f7e-df35-4cf3-b463-4742e3852c45"]},
 "Info-7148e4c2-c689-4073-ab16-66c8599c2771"->{
  Cell[85757, 2427, 492, 7, 90, "Print",
   CellTags->"Info-7148e4c2-c689-4073-ab16-66c8599c2771"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info-c74cd3e3-9188-4da4-8d2d-d49dbca22874", 254719, 6713},
 {"Info-9c7d9f7e-df35-4cf3-b463-4742e3852c45", 254868, 6716},
 {"Info-7148e4c2-c689-4073-ab16-66c8599c2771", 255017, 6719}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 34, 0, 128, "Chapter"],
Cell[604, 24, 373, 9, 32, "Text"],
Cell[980, 35, 708, 9, 41, "Commentary"],
Cell[CellGroupData[{
Cell[1713, 48, 57, 1, 37, "Input"],
Cell[1773, 51, 563, 9, 35, "Output"]
}, Open  ]],
Cell[2351, 63, 1134, 36, 55, "Text"],
Cell[3488, 101, 98, 2, 32, "Text"],
Cell[CellGroupData[{
Cell[3611, 107, 39, 0, 56, "SubsectionIcon"],
Cell[3653, 109, 883, 22, 83, "Text"],
Cell[4539, 133, 461, 18, 65, "NumberedEquation"],
Cell[5003, 153, 22, 0, 32, "Text"],
Cell[5028, 155, 271, 7, 32, "Text"],
Cell[5302, 164, 365, 14, 68, "NumberedEquation"],
Cell[5670, 180, 275, 7, 32, "Text"],
Cell[5948, 189, 706, 28, 87, "NumberedEquation"],
Cell[6657, 219, 1820, 59, 244, "Text"],
Cell[CellGroupData[{
Cell[8502, 282, 113, 2, 33, "SubsubsectionIcon"],
Cell[8618, 286, 191, 4, 32, "Text"],
Cell[8812, 292, 397, 16, 65, "NumberedEquation"],
Cell[9212, 310, 389, 6, 54, "Text"],
Cell[9604, 318, 416, 7, 54, "Text"],
Cell[10023, 327, 1125, 16, 140, "Text"],
Cell[11151, 345, 412, 7, 54, "Text"],
Cell[11566, 354, 474, 10, 65, "Input"],
Cell[12043, 366, 298, 8, 37, "Input"],
Cell[12344, 376, 54, 0, 32, "Text"],
Cell[CellGroupData[{
Cell[12423, 380, 450, 13, 37, "Input"],
Cell[12876, 395, 1816, 47, 330, "Output"]
}, Open  ]],
Cell[14707, 445, 253, 5, 54, "Text"],
Cell[14963, 452, 180, 3, 32, "Text"],
Cell[15146, 457, 423, 9, 65, "Input"],
Cell[15572, 468, 257, 7, 37, "Input"],
Cell[15832, 477, 97, 2, 32, "Text"],
Cell[CellGroupData[{
Cell[15954, 483, 634, 19, 65, "Input"],
Cell[16591, 504, 2016, 46, 267, "Output"]
}, Open  ]],
Cell[18622, 553, 79, 0, 28, "SmallText"],
Cell[18704, 555, 337, 6, 54, "Text"],
Cell[19044, 563, 357, 11, 37, "Input"],
Cell[19404, 576, 282, 9, 37, "Input"],
Cell[19689, 587, 95, 2, 32, "Text"],
Cell[CellGroupData[{
Cell[19809, 593, 477, 14, 37, "Input"],
Cell[20289, 609, 2319, 56, 522, "Output"]
}, Open  ]],
Cell[22623, 668, 397, 6, 54, "Text"],
Cell[23023, 676, 250, 7, 32, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[23310, 688, 70, 0, 33, "SubsubsectionIcon"],
Cell[23383, 690, 150, 3, 32, "Text"],
Cell[23536, 695, 48, 0, 32, "Text"],
Cell[23587, 697, 706, 28, 87, "NumberedEquation"],
Cell[24296, 727, 88, 2, 32, "Text"],
Cell[24387, 731, 1526, 39, 92, "Input"],
Cell[25916, 772, 532, 10, 77, "Text"],
Cell[26451, 784, 666, 19, 37, "Input"],
Cell[27120, 805, 196, 6, 32, "Text"],
Cell[CellGroupData[{
Cell[27341, 815, 225, 6, 39, "Input"],
Cell[27569, 823, 1139, 25, 67, "Output"]
}, Open  ]],
Cell[28723, 851, 44, 0, 32, "Text"],
Cell[CellGroupData[{
Cell[28792, 855, 650, 19, 65, "Input"],
Cell[29445, 876, 13732, 356, 408, "Output"]
}, Open  ]],
Cell[43192, 1235, 421, 7, 54, "Text"],
Cell[CellGroupData[{
Cell[43638, 1246, 175, 3, 37, "Input"],
Cell[43816, 1251, 241, 3, 29, "Print"]
}, Open  ]],
Cell[44072, 1257, 1056, 30, 66, "Input"],
Cell[45131, 1289, 107, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[45263, 1296, 786, 21, 65, "Input"],
Cell[46052, 1319, 2081, 44, 286, "Output"]
}, Open  ]],
Cell[48148, 1366, 348, 10, 35, "Text"],
Cell[48499, 1378, 1309, 38, 66, "Input"],
Cell[CellGroupData[{
Cell[49833, 1420, 56, 1, 37, "Input"],
Cell[49892, 1423, 1199, 27, 64, "Output"]
}, Open  ]],
Cell[51106, 1453, 284, 9, 37, "Input"],
Cell[51393, 1464, 115, 3, 32, "Text"],
Cell[51511, 1469, 245, 7, 37, "Input"],
Cell[51759, 1478, 135, 4, 37, "Input"],
Cell[51897, 1484, 157, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[52079, 1491, 412, 13, 37, "Input"],
Cell[52494, 1506, 536, 10, 35, "Output"]
}, Open  ]],
Cell[53045, 1519, 52, 0, 32, "Text"],
Cell[CellGroupData[{
Cell[53122, 1523, 1170, 33, 119, "Input"],
Cell[54295, 1558, 7026, 167, 458, "Output"]
}, Open  ]],
Cell[61336, 1728, 283, 6, 37, "Input"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[61668, 1740, 45, 0, 37, "SubsectionIcon"],
Cell[61716, 1742, 1380, 40, 76, "Text"],
Cell[63099, 1784, 102, 2, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[63226, 1790, 103, 2, 37, "Input"],
Cell[63332, 1794, 252, 3, 29, "Print"],
Cell[63587, 1799, 238, 3, 29, "Print"],
Cell[63828, 1804, 240, 3, 29, "Print"],
Cell[64071, 1809, 761, 14, 62, "Message"],
Cell[64835, 1825, 241, 3, 29, "Print"]
}, Open  ]],
Cell[65091, 1831, 209, 6, 37, "Input"],
Cell[65303, 1839, 94, 2, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[65422, 1845, 90, 2, 37, "Input"],
Cell[65515, 1849, 5359, 151, 177, "Print"]
}, Open  ]],
Cell[70889, 2003, 195, 6, 57, "MathCaption"],
Cell[CellGroupData[{
Cell[71109, 2013, 88, 2, 37, "Input"],
Cell[71200, 2017, 392, 6, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71629, 2028, 90, 2, 37, "Input"],
Cell[71722, 2032, 391, 6, 35, "Output"]
}, Open  ]],
Cell[72128, 2041, 131, 4, 57, "MathCaption"],
Cell[CellGroupData[{
Cell[72284, 2049, 294, 9, 37, "Input"],
Cell[72581, 2060, 6983, 184, 286, "Output"]
}, Open  ]],
Cell[79579, 2247, 256, 8, 59, "MathCaption"],
Cell[CellGroupData[{
Cell[79860, 2259, 80, 2, 37, "Input"],
Cell[79943, 2263, 295, 5, 90, "Print",
 CellTags->"Info-c74cd3e3-9188-4da4-8d2d-d49dbca22874"]
}, Open  ]],
Cell[80253, 2271, 413, 11, 58, "MathCaption"],
Cell[CellGroupData[{
Cell[80691, 2286, 351, 10, 37, "Input"],
Cell[81045, 2298, 1365, 22, 67, "Output"]
}, Open  ]],
Cell[82425, 2323, 716, 16, 57, "MathCaption"],
Cell[CellGroupData[{
Cell[83166, 2343, 137, 3, 37, "Input"],
Cell[83306, 2348, 167, 4, 49, "Output"]
}, Open  ]],
Cell[83488, 2355, 305, 8, 58, "MathCaption"],
Cell[CellGroupData[{
Cell[83818, 2367, 433, 11, 37, "Input",
 CellID->150092720],
Cell[84254, 2380, 240, 5, 38, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[84543, 2391, 263, 4, 37, "SubsectionIcon"],
Cell[84809, 2397, 295, 6, 32, "Text"],
Cell[CellGroupData[{
Cell[85129, 2407, 118, 3, 37, "Input"],
Cell[85250, 2412, 339, 5, 60, "Print",
 CellTags->"Info-9c7d9f7e-df35-4cf3-b463-4742e3852c45"]
}, Open  ]],
Cell[CellGroupData[{
Cell[85626, 2422, 128, 3, 37, "Input"],
Cell[85757, 2427, 492, 7, 90, "Print",
 CellTags->"Info-7148e4c2-c689-4073-ab16-66c8599c2771"]
}, Open  ]],
Cell[CellGroupData[{
Cell[86286, 2439, 335, 6, 33, "SubsubsectionIcon"],
Cell[86624, 2447, 121, 1, 32, "Text"],
Cell[CellGroupData[{
Cell[86770, 2452, 606, 10, 37, "Input"],
Cell[87379, 2464, 1264, 24, 35, "Output"]
}, Open  ]],
Cell[88658, 2491, 217, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[88900, 2498, 378, 7, 37, "Input"],
Cell[89281, 2507, 252, 4, 35, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[89594, 2518, 41, 0, 37, "SubsectionIcon"],
Cell[89638, 2520, 151, 4, 33, "Text"],
Cell[89792, 2526, 218, 4, 32, "Text"],
Cell[CellGroupData[{
Cell[90035, 2534, 91, 2, 37, "Input"],
Cell[90129, 2538, 666, 12, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[90832, 2555, 109, 3, 37, "Input"],
Cell[90944, 2560, 509, 9, 35, "Output"]
}, Open  ]],
Cell[91468, 2572, 141, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[91634, 2579, 90, 2, 37, "Input"],
Cell[91727, 2583, 636, 11, 35, "Output"]
}, Open  ]],
Cell[92378, 2597, 1278, 35, 188, "DefinitionBox"],
Cell[93659, 2634, 525, 15, 181, "Text"],
Cell[94187, 2651, 1951, 62, 255, "Text"],
Cell[96141, 2715, 1257, 40, 194, "Text"],
Cell[CellGroupData[{
Cell[97423, 2759, 37, 0, 33, "SubsubsectionIcon"],
Cell[97463, 2761, 386, 10, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[97874, 2775, 281, 8, 37, "Input"],
Cell[98158, 2785, 4812, 117, 151, "Output"]
}, Open  ]],
Cell[102985, 2905, 224, 4, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[103234, 2913, 529, 11, 65, "Input"],
Cell[103766, 2926, 5347, 101, 483, "Output"]
}, Open  ]],
Cell[109128, 3030, 53, 0, 32, "Text"],
Cell[109184, 3032, 362, 12, 37, "Input"],
Cell[109549, 3046, 666, 20, 65, "Input"],
Cell[110218, 3068, 454, 11, 37, "Input"],
Cell[CellGroupData[{
Cell[110697, 3083, 242, 6, 37, "Input"],
Cell[110942, 3091, 1880, 39, 221, "Output"]
}, Open  ]],
Cell[112837, 3133, 296, 9, 37, "Input"],
Cell[CellGroupData[{
Cell[113158, 3146, 99, 2, 37, "Input"],
Cell[113260, 3150, 1274, 30, 61, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[114595, 3187, 41, 0, 37, "SubsectionIcon"],
Cell[114639, 3189, 161, 4, 33, "Text"],
Cell[114803, 3195, 4168, 146, 258, "DefinitionBox"],
Cell[118974, 3343, 240, 5, 57, "MathCaption"],
Cell[CellGroupData[{
Cell[119239, 3352, 63, 1, 37, "Input"],
Cell[119305, 3355, 711, 12, 35, "Output"]
}, Open  ]],
Cell[120031, 3370, 527, 11, 54, "Text"],
Cell[120561, 3383, 517, 12, 58, "DefinitionBox"],
Cell[121081, 3397, 1086, 15, 139, "Commentary"],
Cell[122170, 3414, 3295, 119, 188, "DefinitionBox"],
Cell[CellGroupData[{
Cell[125490, 3537, 36, 0, 33, "SubsubsectionIcon"],
Cell[125529, 3539, 21, 0, 32, "Text"],
Cell[CellGroupData[{
Cell[125575, 3543, 237, 6, 37, "Input"],
Cell[125815, 3551, 7326, 152, 1302, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[133178, 3708, 292, 7, 37, "Input"],
Cell[133473, 3717, 2840, 64, 179, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[136350, 3786, 292, 7, 37, "Input"],
Cell[136645, 3795, 2843, 64, 179, "Output"]
}, Open  ]],
Cell[139503, 3862, 21, 0, 32, "Text"],
Cell[CellGroupData[{
Cell[139549, 3866, 321, 8, 37, "Input"],
Cell[139873, 3876, 2839, 65, 179, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[142749, 3946, 292, 7, 37, "Input"],
Cell[143044, 3955, 2842, 64, 179, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[145923, 4024, 292, 7, 37, "Input"],
Cell[146218, 4033, 2849, 64, 179, "Output"]
}, Open  ]],
Cell[149082, 4100, 21, 0, 32, "Text"],
Cell[CellGroupData[{
Cell[149128, 4104, 321, 8, 37, "Input"],
Cell[149452, 4114, 2847, 66, 179, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[152336, 4185, 292, 7, 37, "Input"],
Cell[152631, 4194, 2854, 65, 179, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[155522, 4264, 292, 7, 37, "Input"],
Cell[155817, 4273, 2861, 66, 179, "Output"]
}, Open  ]],
Cell[158693, 4342, 322, 6, 32, "Text"],
Cell[159018, 4350, 217, 3, 32, "Text"],
Cell[CellGroupData[{
Cell[159260, 4357, 378, 7, 37, "Input"],
Cell[159641, 4366, 252, 4, 35, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[159942, 4376, 35, 0, 33, "SubsubsectionIcon"],
Cell[CellGroupData[{
Cell[160002, 4380, 235, 6, 37, "Input"],
Cell[160240, 4388, 6754, 145, 1200, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[167031, 4538, 290, 7, 37, "Input"],
Cell[167324, 4547, 2727, 63, 179, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[170088, 4615, 290, 7, 37, "Input"],
Cell[170381, 4624, 2738, 64, 179, "Output"]
}, Open  ]],
Cell[173134, 4691, 88, 2, 32, "Text"],
Cell[173225, 4695, 358, 11, 37, "Input"],
Cell[CellGroupData[{
Cell[173608, 4710, 340, 7, 37, "Input"],
Cell[173951, 4719, 6721, 146, 1094, "Print"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[180721, 4871, 36, 0, 25, "SubsubsectionIcon"],
Cell[CellGroupData[{
Cell[180782, 4875, 234, 6, 184, "Input"],
Cell[181019, 4883, 6721, 144, 70, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[187777, 5032, 286, 6, 184, "Input"],
Cell[188066, 5040, 2730, 63, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[190833, 5108, 286, 6, 184, "Input"],
Cell[191122, 5116, 2731, 63, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[193902, 5185, 35, 0, 25, "SubsubsectionIcon"],
Cell[CellGroupData[{
Cell[193962, 5189, 317, 8, 123, "Input"],
Cell[194282, 5199, 2741, 64, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[197060, 5268, 285, 6, 123, "Input"],
Cell[197348, 5276, 2749, 64, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[200134, 5345, 285, 6, 123, "Input"],
Cell[200422, 5353, 2755, 64, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[203214, 5422, 317, 8, 123, "Input"],
Cell[203534, 5432, 2748, 64, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[206319, 5501, 285, 6, 123, "Input"],
Cell[206607, 5509, 2747, 64, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[209391, 5578, 285, 6, 123, "Input"],
Cell[209679, 5586, 2753, 64, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[212481, 5656, 39, 0, 25, "SubsubsectionIcon"],
Cell[212523, 5658, 177, 4, 108, "Text"],
Cell[CellGroupData[{
Cell[212725, 5666, 240, 6, 123, "Input"],
Cell[212968, 5674, 7611, 159, 70, "Print"]
}, Open  ]],
Cell[220594, 5836, 163, 3, 162, "Text"],
Cell[CellGroupData[{
Cell[220782, 5843, 300, 7, 123, "Input"],
Cell[221085, 5852, 2745, 63, 70, "Output"]
}, Open  ]],
Cell[223845, 5918, 210, 4, 108, "Text"],
Cell[224058, 5924, 252, 6, 123, "Input"],
Cell[CellGroupData[{
Cell[224335, 5934, 464, 12, 123, "Input"],
Cell[224802, 5948, 2218, 46, 70, "Output"]
}, Open  ]],
Cell[227035, 5997, 388, 6, 181, "Text"],
Cell[CellGroupData[{
Cell[227448, 6007, 540, 15, 123, "Input"],
Cell[227991, 6024, 2879, 65, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[230919, 6095, 39, 0, 25, "SubsubsectionIcon"],
Cell[230961, 6097, 21, 0, 108, "Text"],
Cell[CellGroupData[{
Cell[231007, 6101, 325, 8, 123, "Input"],
Cell[231335, 6111, 2867, 66, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[234239, 6182, 295, 7, 123, "Input"],
Cell[234537, 6191, 2868, 65, 70, "Output"]
}, Open  ]],
Cell[237420, 6259, 186, 4, 108, "Text"],
Cell[CellGroupData[{
Cell[237631, 6267, 286, 7, 123, "Input"],
Cell[237920, 6276, 2755, 62, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[240712, 6343, 347, 7, 123, "Input"],
Cell[241062, 6352, 2750, 62, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[243861, 6420, 222, 3, 25, "SubsubsectionIcon"],
Cell[244086, 6425, 314, 6, 189, "MathCaption"],
Cell[244403, 6433, 423, 12, 123, "Input"],
Cell[244829, 6447, 105, 1, 108, "Text"],
Cell[244937, 6450, 86, 1, 108, "Text"],
Cell[245026, 6453, 2140, 57, 405, "Input"],
Cell[247169, 6512, 449, 13, 123, "Input"],
Cell[247621, 6527, 157, 2, 108, "Text"],
Cell[247781, 6531, 270, 7, 123, "Input"],
Cell[248054, 6540, 238, 5, 108, "Text"],
Cell[248295, 6547, 1817, 39, 856, "Input"],
Cell[CellGroupData[{
Cell[250137, 6590, 253, 6, 123, "Input"],
Cell[250393, 6598, 2524, 55, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
