(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    437987,       9451]
NotebookOptionsPosition[    423653,       9020]
NotebookOutlinePosition[    428081,       9148]
CellTagsIndexPosition[    427789,       9139]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Solving the ICRP 66 compartmental models ", "Chapter"],

Cell[TextData[{
 "Author : Guillermo S\[AAcute]nchez  (",
 ButtonBox["http://diarium.usal.es/guillermo",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://diarium.usal.es/guillermo"], None},
  ButtonNote->"http://diarium.usal.es/guillermo"],
 ") "
}], "Text",
 CellChangeTimes->{{3.4779023566657305`*^9, 3.4779024333879175`*^9}, {
  3.587475201974296*^9, 3.5874752531748085`*^9}}],

Cell["Last update:  \t  2015-11-17 ", "Commentary",
 CellChangeTimes->{{3.39928025384801*^9, 3.399280259603493*^9}, {
   3.4228525171714554`*^9, 3.4228525382666454`*^9}, {3.422936332120079*^9, 
   3.422936340401223*^9}, {3.442218589593443*^9, 3.4422185944372244`*^9}, {
   3.479816247027495*^9, 3.4798162579804096`*^9}, {3.513395822423673*^9, 
   3.513395880159526*^9}, 3.5185325242008123`*^9, {3.5874741322941694`*^9, 
   3.5874741421380215`*^9}, 3.5874751966857605`*^9, {3.591671808847712*^9, 
   3.591671811960023*^9}, {3.5922014955413866`*^9, 3.59220149675821*^9}, {
   3.6436097653677073`*^9, 3.643609772352092*^9}, {3.6506055199973793`*^9, 
   3.6506055239350047`*^9}, {3.656752467764387*^9, 3.6567524731394367`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["$Version"], "Input",
 CellLabel->"In[1]:="],

Cell[BoxData[
 FormBox["\<\"10.2.0 for Microsoft Windows (64-bit) (July 28, 2015)\"\>", 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.3992752647824697`*^9, 3.422852547121887*^9, 
  3.4422186266093054`*^9, 3.4798162427619514`*^9, 3.513395883425235*^9, 
  3.513395935395315*^9, 3.5185327468300867`*^9, 3.587474148580987*^9, 
  3.587475619482329*^9, 3.587475966100147*^9, 3.6436090728197327`*^9, 
  3.6436095810861216`*^9, 3.65060551368467*^9},
 CellLabel->"Out[1]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Initialization", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Biokmod`Resptract`\>\"", "]"}]], "Input",
 CellTags->"Introduction",
 CellLabel->"In[2]:="],

Cell[BoxData[
 FormBox["\<\"Resptract 1.2  2005-05-16\"\>", TraditionalForm]], "Print",
 CellChangeTimes->{3.650605513840938*^9},
 CellTags->"Introduction",
 CellLabel->"During evaluation of In[2]:="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The respiratory tract model (ICRP 66)", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["RT model description", "SubsubsectionIcon"],

Cell[TextData[{
 "ICRP 66 describes the compartmental model of the human respiratory tract \
(RT) applied to the intake of radioactive aerosols by inhalation (Fig.1). The \
respiratory tract is represented by five regions (fig. 1). The extrathoracic \
(ET) airways are divided into ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["ET", "1"], TraditionalForm]]],
 "(nasal passage) and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["ET", "2"], TraditionalForm]]],
 " (posterior nasal and oral passages, the pharynx and the larynx) and the \
thoracic region is divided into BB (Bronchial), bronchiolar (bb), and \
alveolar-interstitial (AI: AI1, AI2, and AI3). ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["LN", "ET"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["LN", "TH"], TraditionalForm]]],
 " represent extrathoracic and thoracic airways. "
}], "Text"],

Cell[TextData[{
 "In this model the material is deposited in the respiratory tract: in \
compartments labeled \[OpenCurlyDoubleQuote]Particles in Initial State\
\[CloseCurlyDoubleQuote] (PIS) and in ET1. From each PIS compartment the \
material is transferred into the body fluids,at a absorption rate sp.It is \
also simultaneously transferred from PIS (at a rate spt) to a corresponding \
compartment labeled \[OpenCurlyDoubleQuote]Particles in Transformed State\
\[CloseCurlyDoubleQuote] (PTS). The flow goes from 1, in PIS, to 1, in PTS, \
from 2, in PIS,to 2, in PTS,and so on. We can consider that each compartment \
1-13 in PIS has a mirror compartment 1-13 in PTS. In each compartment in PTS \
the isotope is dissolved at a constant rate ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "p"], TraditionalForm]]],
 " into the body fluids (usually the blood). For instance: the total transfer \
rate for AI2 in PIS will be ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     SubscriptBox["K", "AI2"],
     TraditionalForm], "=", 
    RowBox[{
     FormBox[
      SubscriptBox["k", 
       RowBox[{"2", ",", "4"}]],
      TraditionalForm], "+", 
     FormBox[
      SubscriptBox["s", "pt"],
      TraditionalForm], "+", 
     FormBox[
      SubscriptBox["s", "p"],
      TraditionalForm]}]}], TraditionalForm]]],
 ", and for AI2, in PTS, ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FormBox[
     SubscriptBox["K", "AI2"],
     TraditionalForm], "=", 
    RowBox[{
     FormBox[
      SubscriptBox["k", 
       RowBox[{"2", ",", "4"}]],
      TraditionalForm], "+", 
     FormBox[
      SubscriptBox["s", "t"],
      TraditionalForm]}]}], TraditionalForm]]],
 ".This general model of RT is common to any element.\nThe initial deposition \
factor of inhaled aerosols are functions of AMAD (Activity Median Diameter) \
and AMTD  (Activity Median Thermodynamic Diameter).  Reference values for \
regional deposition are given in ICRP 66.  The transfer compartment  \
represents the body fluid (usually the blood). "
}], "Text"],

Cell[TextData[{
 "The values of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "p"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "pt"], TraditionalForm]]],
 ",  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["s", "t"], TraditionalForm]]],
 " depend on absorption, they ",
 "are related with the chemical form of the element",
 ". ICRP 66 consider tree type of compounds: Type F (fast absorption), type M \
(moderate absorption) and type S (Slow absorption). Default absorption rates, \
taken from Tabla 30 of ICRP 66, are given in table 1 "
}], "Text"],

Cell[TextData[{
 StyleBox["Table1",
  FontWeight->"Bold"],
 ".- Absorption parameters values for metabolism F, M and S (ICRP 66) "
}], "Text"],

Cell[TextData[Cell[BoxData[GridBox[{
   {
    StyleBox[
     RowBox[{
      StyleBox["Default",
       FontWeight->"Bold"], 
      StyleBox[" ",
       FontWeight->"Bold"], 
      StyleBox["absorption",
       FontWeight->"Bold"], 
      StyleBox[" ",
       FontWeight->"Bold"], 
      StyleBox["parameters",
       FontWeight->"Bold"], " "}],
     FontSlant->"Plain",
     FontVariations->{"CompatibilityType"->0}], "s", 
    StyleBox["F",
     FontWeight->"Bold"], 
    StyleBox["M",
     FontWeight->"Bold"], 
    StyleBox["S",
     FontWeight->"Bold"]},
   {
    StyleBox[
     RowBox[{"Initial", " ", "disolution", " ", "rate", " ", 
      RowBox[{"(", 
       FormBox[
        SuperscriptBox["d", 
         RowBox[{"-", "1"}]],
        TraditionalForm], ")"}]}],
     FontFamily->"Times New Roman"], 
    SubscriptBox["s", "p"], "100", "10", "0.1"},
   {
    StyleBox[
     RowBox[{"Transformation", " ", "rate", " ", 
      RowBox[{"(", 
       FormBox[
        SuperscriptBox["d", 
         RowBox[{"-", "1"}]],
        TraditionalForm], ")"}]}],
     FontFamily->"Times New Roman"], 
    FormBox[
     SubscriptBox["s", "pt"],
     TraditionalForm], "0", "90", "100"},
   {
    StyleBox[
     RowBox[{"Transformation", " ", "rate", " ", 
      RowBox[{"(", 
       FormBox[
        SuperscriptBox["d", 
         RowBox[{"-", "1"}]],
        TraditionalForm], ")"}]}],
     FontFamily->"Times New Roman"], 
    FormBox[
     SubscriptBox["s", "t"],
     TraditionalForm], "0", "0.005", "0.0001"}
  },
  GridBoxDividers->{
   "Columns" -> {False, {True}, False}, "ColumnsIndexed" -> {}, 
    "Rows" -> {False, {True}, False}, "RowsIndexed" -> {}}]]]], "Commentary"],

Cell[TextData[{
 StyleBox["Table 2",
  FontWeight->"Bold"],
 ".- Respiratory Tract model: Compartments numbering and rate transfer \
coefficients values (ICRP 66) "
}], "Text"],

Cell["\<\
k[i,j]-> K value means transfer coeffs. from compartment i to compartment j.
k[i,0]-> K value means transfer coeffs. from compartment i to out the system \
or Environment(0).
This notation has little differences with ICRP 66. Compartment 14 here \
represents the transfer compartment or Blood (in place of  ET1). 
Lungs include the compartments 1 to 10\
\>", "Commentary"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"AI1\"\>", "1", "\<\"bb1\"\>", "4", "\<\"k[1,4]->\"\>", "0.02`"},
    {"\<\"AI2\"\>", "2", "\<\"bb1\"\>", "4", "\<\"k[2,4]->\"\>", "0.001`"},
    {"\<\"AI3\"\>", "3", "\<\"bb1\"\>", "4", "\<\"k[3,4]->\"\>", "0.0001`"},
    {"\<\"AI3\"\>", "3", "\<\"\\!\\(LN\\_TH\\)\"\>", 
     "10", "\<\"k[3,10]->\"\>", "0.00002`"},
    {"\<\"bb1\"\>", "4", "\<\"BB1\"\>", "7", "\<\"k[4,7]->\"\>", "2"},
    {"\<\"bb2\"\>", "5", "\<\"BB1\"\>", "7", "\<\"k[5,9]->\"\>", "0.03`"},
    {"\<\"bbseq\"\>", "6", "\<\"\\!\\(LN\\_TH\\)\"\>", 
     "10", "\<\"k[6,10]->\"\>", "0.01`"},
    {"\<\"BB1\"\>", "7", "\<\"ET2\"\>", "11", "\<\"k[7,11]->\"\>", "10"},
    {"\<\"BB2\"\>", "8", "\<\"ET2\"\>", "11", "\<\"k[8,11]->\"\>", "0.03`"},
    {"\<\"BBseq\"\>", "9", "\<\"LN-TH\"\>", "10", "\<\"k[9,10]->\"\>", 
     "0.01`"},
    {"\<\"LN-TH\"\>", "10", "\<\"Blood\"\>", 
     "14", "\<\"k[10,14]->\"\>", "\<\"\\!\\(s\\_p\\)\"\>"},
    {"\<\"ET2\"\>", "11", "\<\"Gitract\"\>", "15", "\<\"k[11,15]->\"\>", 
     "100"},
    {"\<\"ETseq\"\>", "12", "\<\"\\!\\(LN\\_ET\\)\"\>", 
     "13", "\<\"k[12,13]->\"\>", "0.001`"},
    {"\<\"\\!\\(LN\\_ET\\)\"\>", "13", "\<\"Blood\"\>", 
     "14", "\<\"k[13,14]->\"\>", "\<\"\\!\\(s\\_p\\)\"\>"},
    {"\<\"Blood\"\>", "14", "\<\"Env\"\>", "0", "\<\"k[14,0]->\"\>", "0"},
    {"\<\"GItract(ST)\"\>", "15", "\<\"Env\"\>", "0", "\<\"k[15,0]->\"\>", "0"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@000Bc80@0006`0000;0000000000T200020`00
^0400000002@D@00N7P00215CDH00040b2`108l9000<0000000000000000000080<005P200100@00
l0000000000000000000003R1020Z@<0AP0002`0000P0000ADe6:`500@0L00004000004@`=/10000
H000060000160000G00005000015CDH[8T0400`0000000007T0100`000000000940100`000000000
8D0700`000000000<4020100000400000020?`A0000<0000000001P0000<0000000001T0000<0000
oooo01@0000<00003@000180000<00000P00024000080000500000`0000=0000<00000`0000?0020
AP0002P0000L0000AdA9@`80000:0000ooooo`/200040`00000004H0000`K@0096d004E=AR/Z@000
900001P00000080o000000000000080o00000000000Q@0D030000000000U@000400000@000000000
;40002@0000H0000iM02?`0008000020@F15?ooo;d40002024001Fa/001PK0000A30f`8000020000
>6`00=O=aYX00:L02@2V0_d2H0000000Q5L000402@000a`f000=02d0000000D000090P0000050000
0@;oool01@0000@13@0000D000020@800005000030;d0_l10`0001h01@0000/22@2W00D0000<0_@2
o`450000104=0000;@000?L000<D0000002000000800082000000800P0200020P030`<00`=c00:K:
l03ono00X:2T0820P03o00000?l00?oo00000?l0o`3o003oo`3oool0100003@2000@00009PH?01H0
ooooo`00Y`0000T0002V0P00o@8000L0003l0P00oooo0000100002d10@080000nP80004000000002
100002d10P0700006`A80?d19P360@L0003l0P00oooo0000100002d10`040000l04100P0003j0P00
0000000000040000;@4100@0003`0@801`000?`2003oool000040000;@4200P0003j0P000@000?oo
o`840000;@4400L0000K14<0mP4/0=T1100002d10`040000l04200@0000]0@4010000?0110030000
7P0700005PA20?<1;@3L0A`0003k0_?o00000000T04000000000045bJF5/0000kP8:hjF7kGN^Qneg
d6O_Mnh22^<000X0100002d10P0L0000n`;go`0000000901000000000211LVUQK0000?X32SBUQneg
[XO]Mm1WkgOj0`Xd000:00@0000]0@@0100002d10P040000;@4400@0000]0@801@0000810@0000X0
000b2Rl0g0420000AE@900L0100002d110090000<PXe0>`10@00035D1@0400009`7oo`<0000N00D0
00010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0
100002d10`070000o0800?ooo`0000@0000]0@D020000?X20001000000000P@0000]0@H01`0001/4
A`2F0RL0@P840000;@4300@0003`0@D0100002d10@040000l04600<0000N00L0000F14H0T`8X04D2
100002d10P040000;@4200D000040@d0000500000P4100006000038:;P180P/00015KWIYLVm^KFE^
M00900L01@0300@01`0700/01`0700@0100002L1ool300007P0500000@;oool01@0000T2000000L0
000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`20030`<00
00040000;@4500P0003j0P000@00000000840000;@4600L0000K1;`1I`:K0A<2100002d10`040000
l04500@0000]0@4010000?011P0300007P0700005PBk0F@2W04F0Q`0003k0_?o00000000_0800000
0000845bJF5/0000?0@:6ZF7kGN^Qnegd6O_Mc`42QX000X0100002d11@040000;@4500D000040@d0
000500000P4100004`00038:X`4T0PP00017BB1DLV5SM0X0100400P01@0800L0100400009`7oo`<0
000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P0000050000
0@;oool0100002d10`070000o0800?ooo`0000@0000]0@H020000?X200010000oooo0P@0000]0@L0
1`0001/4/P7B0I/1/0440000;@4300@0003`0@H0100002d10@040000l04700<0000N00L0000F1;41
c`6L0K<1100002d10P040000;@4400@0000]0@80100002d110040000;@4200D000040@d000050000
0P4100002@00038:WP6c0@40001cE0L0100002d1100:0000<PZT0KX10P00071d1@0300@0000W0Ooo
0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D0
00010_ooo`040000;@4300L0003l0P00oooo0000100002d11P080000nP800040003oool2100002d1
1`0700006`BC0C`1O04J0@@0000]0@<010000?011P040000;@4100@0003`0@L00`0001h01`0001H4
TP4i0Gd17@440000;@4200@0000]0@@0100002d10P040000;@4400@0000]0@801@0000@13@0000D0
00020@4000090000<PYo0Ad10@0007=d1`040000;@4400T0000b2XD190410000L7@500@0000W0Ooo
0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D0
00010_ooo`040000;@430100000V1Pl05P3ooooo000;0@00L04001T1002K0@0020000?X200010000
000000@0000]0@H01`000?`2003oool000040000;@470180000T0`L0306?0@l1S`4?0G41505a0A@1
S`4G0Hl14@6I0@@0000]0@4010000?011P040000;@4300@0003`0@L0200002H63`060?ooool10100
000V1Pl05P3ooooo002T0000E@000942001f0@0020000?X200010000000000@0000]0@H01`000?`2
003oool000040000;@4700L0000K17<1SP9I0:P0100002d10@040000l04600@0000]0@<010000?01
1`0800009PH?00H0ooooo`400`0001h01`0001H4LP6:0UX0[00L0000n`;]o`000000090100000000
0211LVUQK0000:`32RJUQneg[XO]Mm1WkgN/0`XV000:00@0000]0@H01@0000@13@0000D000020@40
00090000<P[307L20@0005003@090000<P[K07/20@0004T01P090000<P[c07L20@0005<03@040000
9`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00
000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@L020000?X20001000000000P@0
000]0@P01`0001/4J05X0TH1_`440000;@4300@0003`0@L0100002d10@040000l04800L0003l0P00
oooo0000100002d11`080000nP80004000000002100002d1200700006`AX0Nh0_`3100@0000]0@<0
10000?011`040000;@4100@0003`0@P0400002H63`0F0?ooool00>`0001A0@00_P4005h100080000
nP80004000000000100002d11`070000o0810000000000@0000]0@P0200002D30P2l0EL1m@1G0@P0
003j0PD00@00000000040000;@4900@0003`0@L01`000?`20000000000040000;@4700X0000T0`<0
n01B0Nh0F07h05d1100002d10@040000;@4300@0003`0@L0200002H63`060?ooool100L0003l0P00
oooo0000100002d11`080000nP80004000000002100002d12P0700006`@V0FP2106n0@@0000]0@<0
10000?011`040000;@4100@0003`0@X01`000?`2003oool000040000;@4700P0003j0P000@000000
00840000;@4:00L0000K1>00I`:n0<01100002d10`040000l04700@0000]0@4010000?012P0@0000
9PH?01H0ooooo`00m04004D1003g0@00JP4000P0003j0P000@00000000040000;@4700@0000]0@P0
200002D30P3e0DH1m@5X0@@0000]0@4010000?011`040000;@4300P0000V1Pl01P3ooooo0@0@0000
9PH?01H0ooooo`00;08004H1000_0P00JP4000P0003j0P000@00000000040000;@4700@0000]0@P0
200002D30P0]0TL1;@9X0@@0000]0@4010000?011`040000;@4300P0000V1Pl01P3ooooo0@070000
o0800?ooo`0000@0000]0@L020000?X20001000000000P@0000]0@X01`0001/4SP1X0V`0_P440000
;@4300@0003`0@L0100002d10@040000l04:00L0003l0P00oooo0000100002d11`080000nP800040
003oool2100002d12P0700006`AQ0N`1C@7@0@@0000]0@<010000?011`040000;@4100@0003`0@X0
0`0001h01`0001H4H07Y0Dh1d`440000;@4200@0000]0@@0100002d10P040000;@4400@0000]0@80
1@0000@13@0000D000020@40000:0000<PY@0M<10P0004592@0300@0000]0@@02@00038:EP7O0@40
000cB@D0100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1
ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000;@4700P0003j0P00
0@000?ooo`840000;@4:00L0000K16418@9=0@H2100002d10`040000l04700@0000]0@4010000?01
2P0300007P0700005PAP0Ah2CP490P@0000]0@80100002d110040000;@4200@0000]0@@0100002d1
0P050000104=00001@0000810@0000X0000b2U012@820000@DT900<0100002d110090000<PYF0AD2
0@0003991@0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P040000
9`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@L020000?X2
00010000oooo0P@0000]0@X01`0001/4H`5G0Tl1?P840000;@4300@0003`0@L0100002d10@040000
l04:00<0000N00L0000F1681E09@0D42100002d10P040000;@4400@0000]0@80100002d110040000
;@4200D000040@d0000500000P4100002P00038:DP510P800011B@T00`040000;@4400T0000b2UP1
C@810000<DT500@0000W0Ooo0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0
000W0Ooo1@0000T2000000D000010_ooo`040000;@4300L0003l0P00oooo0000100002d11`080000
nP800040003oool2100002d12P0700006`@N0B<22P470P@0000]0@<010000?011`040000;@4100@0
003`0@X00`0001h01`0001H47@4P0P/12P840000;@4200@0000]0@@0100002d10P040000;@4400@0
000]0@801@0000@13@0000D000020@40000:0000<PX=0@X20P00069R1`0700@0000]0@@02@00038:
4`4H0P40000aHPD0100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0
100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000;@4700P0
003j0P000@000?ooo`840000;@4:00L0000K1=T08@;500@2100002d10`040000l04700@0000]0@40
10000?012P0300007P0700005PCH01h2aP070P@0000]0@80100002d110040000;@4200@0000]0@@0
100002d10P050000104=00001@0000810@0000X0000b2/P01`820000@T8900T0100002d110090000
<P[>01T20@0003521@0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a40
6P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@L0
20000?X200010000oooo0P@0000]0@X01`0001/4Q`0S0W001P840000;@4300@0003`0@L0100002d1
0@040000l04:00<0000N00L0000F18H0809a00T2100002d10P040000;@4400@0000]0@80100002d1
10040000;@4200D000040@d0000500000P4100002P00038:L`090P800015E0T01`040000;@4400T0
000b2WT06@810000<U@500@0000W0Ooo0`0001h01@000042oooo00D000090P00000700005PB<0@d3
4@0J00@0000W0Ooo1@0000T2000000D000010_ooo`040000;@4300L0003l0P00oooo0000100002d1
1`080000nP80004000000002100002d12P0700006`CQ09l1_`1a0@@0000]0@<010000?011`040000
;@4100@0003`0@X01`000?`2003oool000040000;@4700P0003j0P000@00000000840000;@4:00L0
000K12D1W`430G41100002d10`040000l04700@0000]0@4010000?012P070000o0800?ooo`0000@0
000]0@L020000?X20001000000000P@0000]0@X01`0001/4h@1;0Kl040440000;@4300@0003`0@L0
100002d10@040000l04:00L0003l0P00oooo0000100002d11`080000nP80004000000002100002d1
2P0700006`@U0D/10`4@0@@0000]0@<010000?011`040000;@4100@0003`0@X0400002H63`0F0?oo
ool008P1003M0000``4000@100080000nP80004000000000100002d11`040000;@4800P0000U0`80
R@420K/1h@040000;@4900@0003`0@L01`000?`20000000000040000;@4700X0000T0`<0^`7Y0<81
gP2f0N00100002d10@040000;@4300@0003`0@L0200002H63`060?ooool10100000V1Pl05P3ooooo
00270@00RP000<81002o000020000?X200010000000000@0000]0@L0100002d1200800009@<208P1
_@2k0I00100002d12@040000l04700L0003l0P0000000000100002d11`0:000090<30;d1U`300H`0
]@6?00@0000]0@40100002d10`040000l04700P0000V1Pl01P3ooooo0@0@00009PH?01H0ooooo`00
kP000</0000?0@00f00000P0003j0P000@00000000040000;@4700@0000]0@P0200002D30P0=0M40
m`3A00@0000]0@T010000?011`070000o0800000000000@0000]0@L02P0002@30`3j0<`0l03B0?X0
e`040000;@4100@0000]0@<010000?011`0800009PH?00H0ooooo`40400002H63`0F0?ooool00>d0
000>0@003P4001/100080000nP80004000000000100002d11`040000;@4800P0000U0`80304D0OH0
50440000;@4900@0003`0@L01`000?`20000000000040000;@4700X0000T0`<0n@0?0Nh0507i01X1
100002d10@040000;@4300@0003`0@L0200002H63`060?ooool100L0003l0P00oooo0000100002d1
1`080000nP80004000000002100002d12P0700006`B<0?00JP3200@0000]0@<010000?011`040000
;@4100@0003`0@X01`000?`2003oool000040000;@4700P0003j0P000@00000000840000;@4:00L0
000K18`0B@5Z0101100002d10`040000l04700@0000]0@4010000?012P070000o0800?ooo`0000@0
000]0@L020000?X200010000oooo0P@0000]0@X01`0001/4Q@130Fh06P440000;@4300@0003`0@L0
100002d10@040000l04:00<0000N00L0000F18@0@05_01d1100002d10P040000;@4400@0000]0@80
100002d110040000;@4200D000040@d0000500000P4100002P00038:L@0M0@800015E0T01`040000
;@4400`0000b2WL0;@430000LfEaN0D01@0500@0000W0Ooo0`0001h01@000042oooo00D000090P00
000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D000010_ooo`040000;@4300L0003l0P00
oooo0000100002d11`080000nP800040003oool2100002d12P0700006`CK0401a00G0@@0000]0@<0
10000?011`040000;@4100@0003`0@X00`0001h01`0001H4fP0m0LD06P440000;@4200@0000]0@@0
100002d10P040000;@4400@0000]0@801@0000@13@0000D000020@40000:0000<P[701X10P000492
2@0900@0000]0@@03000038:c@0/0@<0001cIG5i1@0500D0100002L1ool300007P0500000@;oool0
1@0000T2000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<0
1`000?`2003oool000040000;@4700P0003j0P000@000?ooo`840000;@4:00L0000K11l1?P480AD1
100002d10`040000l04700@0000]0@4010000?012P0300007P0700005P@N0C/12@4H0@@0000]0@80
100002d110040000;@4200@0000]0@@0100002d10P050000104=00001@0000810@0000X0000b2P/1
60420000HV8700L0100002d1100<0000<PXA0BH10`0007=ULGX500D01@0400009`7oo`<0000N00D0
00010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0
100002d10`070000o0800?ooo`0000@0000]0@L020000?X200010000oooo0P@0000]0@X01`0001/4
7@7/00H1``040000;@4300@0003`0@L0100002d10@040000l04:00<0000N00L0000F11`1j@070LH0
100002d10P040000;@4400@0000]0@80100002d110040000;@4200D000040@d0000500000P410000
2P00038:2@760080001<CPL02@040000;@4400X0000b2Pl1eP020000E4P500L0100002L1ool30000
7P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042
oooo00@0000]0@<01`000?`2003oool000040000;@4700P0003j0P000@000?ooo`840000;@4:00L0
000K18H0k@1_0<@0100002d10`040000l04700@0000]0@4010000?012P0300007P0700005PB50>X0
L03700@0000]0@80100002d110040000;@4200@0000]0@@0100002d10P050000104=00001@000081
0@0000X0000b2W80a`020000C4h700T0100002d1100:0000<PYh0=L00P0004ED1P0500@0000W0Ooo
0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D0
00010_ooo`040000;@430100000V1Pl05P3ooooo003^0000M@0000l10022000020000?X200010000
000000@0000]0@L0100002d1200800009@<200d1N`3g07/0100002d12@040000l04700L0003l0P00
00000000100002d11`0:000090<30?X0MP3`07`0nP2100@0000]0@40100002d10`040000l04700P0
000V1Pl01P3ooooo0@070000o0800?ooo`0000@0000]0@L020000?X200010000oooo0P@0000]0@X0
1`0001/4f@2C0LD0MP440000;@4300@0003`0@L0100002d10@040000l04:00<0000N00L0000F1=P0
T07607T1100002d10P040000;@4400@0000]0@80100002d110040000;@4200D000040@d000050000
0P4100002P00038:b01i0@800012@PT02@040000;@4400T0000b2/h0R`410000<T8500@0000W0Ooo
0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D0
00010_ooo`040000;@4300L0003l0P00oooo0000100002d11`080000nP800040003oool2100002d1
2P0700006`@L0ID1205i0@@0000]0@<010000?011`040000;@4100@0003`0@X00`0001h01`0001H4
6`6B0@T1O0440000;@4200@0000]0@@0100002d10P040000;@4400@0000]0@801@0000@13@0000D0
00020@40000:0000<PX;0G`10P00069R1`0700@0000]0@@02@00038:4@6:0@40000bHPD0100002L1
ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@800000
1@000042oooo00@0000]0@<01`000?`2003oool000040000;@4700P0003j0P000@00000000840000
;@4:00L0000K16L1kP1I0ML0100002d10`040000l04700@0000]0@4010000?012P0300007P070000
5PAV0N/0FP7J01`0003k0_Go00000000T04000000000845bJF5/0000B`@:7ZF7kGN^Qnegd6O_Md/4
2Qh000X0100002d11`040000;@4700D000040@d0000500000P4100002P00038:FP7J0080000a<0H0
1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D0
00090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X020000?X200010000
00000P@0000]0@/01`0001/4I`5X0UX1G@840000;@4300@0003`0@X0100002d10@040000l04;00<0
000N00L0000F16H1I@9K0F02100002d11`040000;@4700@0000]0@L01@0000@13@0000D000020@40
00090000<PYK0F020@00034`1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4
S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0
000]0@X020000?X20001000000000P@0000]0@/01`0001/4I`4^0UX18`840000;@4300@0003`0@X0
100002d10@040000l04;00<0000N00L0000F16H1:`9K0BH2100002d11`040000;@4700@0000]0@L0
1@0000@13@0000D000020@4000090000<PYK0BH20@00038`1P0400009`7oo`<0000N00D000010_oo
o`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d1
0`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4I`7e0EX1
jP440000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F16H1lP5K0Nd1100002d1
1`040000;@4700@0000]0@L01@0000@13@0000D000020@4000090000<PYK0Nd10@0003<`1P040000
9`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00
000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0
000]0@/01`0001/49@5W0QP1G0840000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0
000F12@1I08I0El2100002d11`040000;@4700@0000]0@L01@0000@13@0000D000020@4000090000
<PXI0El20@0003@`1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a40
6P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X0
20000?X20001000000000P@0000]0@/01`0001/4g`1V0]80F`840000;@4300@0003`0@X0100002d1
0@040000l04;00<0000N00L0000F1=h0H`;C05h2100002d11`040000;@4700@0000]0@L01@0000@1
3@0000D000020@4000090000<P[C05h20@0003L`1P0400009`7oo`<0000N00D000010_ooo`050000
2@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d10`070000
o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4h@2O0M40T@440000
;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1>00W07B09@1100002d11`040000
;@4700D000040@d0000500000P4100002@00038:dP2D0@40000h<0H0100002L1ool300007P050000
0@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0
000]0@<01`000?`2003oool000040000;@4:00P0003j0P000@00000000840000;@4;00L0000K12D1
W`4G0I<1100002d10`040000l04:00@0000]0@4010000?012`0300007P0700005P@T0I`1606F0@@0
000]0@L0100002d11`050000104=00001@0000810@0000T0000b2QP1UP410000=C0600@0000W0Ooo
0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D0
00010_ooo`040000;@4300L0003l0P00oooo0000100002d12P080000nP80004000000002100002d1
2`0700006`CP04X1d00n0@@0000]0@<010000?012P040000;@4100@0003`0@/00`0001h01`0001H4
g`170M40@@440000;@4700@0000]0@L01@0000@13@0000D000020@4000090000<P[A04410@0003T`
1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D0
00090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X020000?X200010000
00000P@0000]0@/01`0001/49@5;0A@1?`440000;@4300@0003`0@X0100002d10@040000l04;00<0
000N00L0000F12@1B04E0D81100002d11`040000;@4700D000040@d0000500000P4100002@00038:
5@520@40000f<0H0100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0
100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0
003j0P000@00000000840000;@4;00L0000K1900D`6203`1100002d10`040000l04:00@0000]0@40
10000?012`0300007P0700005PB?0501P`0o0@@0000]0@L0100002d11`050000104=00001@000081
0@0000X0000b2X<0?`420000<C8600H0100002L1ool300007P0500000@;oool01@0000T2000000L0
000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool0
00040000;@4:00P0003j0P000@00000000840000;@4;00L0000K1900m`230>40100002d10`040000
l04:00@0000]0@4010000?012`0300007P0700005PB?0?@0Q03T00@0000]0@L0100002d11`050000
104=00001@0000810@0000X0000b2X@0i0020000<C<600H0100002L1ool300007P0500000@;oool0
1@0000T2000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<0
1`000?`2003oool000040000;@4:00P0003j0P000@00000000840000;@4;00L0000K18d0I`9o0502
100002d10`040000l04:00@0000]0@4010000?012`0300007P0700005PB<06@2P01C0P@0000]0@L0
100002d11`050000104=00001@0000810@0000X0000b2X00D`820000<C4600H0100002L1ool30000
7P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042
oooo00@0000]0@<0400002H63`0F0?ooool00:h0001J0000L`8005h000080000nP80004000000000
100002d12P040000;@4800P0000U0`80[`1L0742F`040000;@4100@0003`0@X0100002d10`080000
9PH?00H0ooooo`40400002H63`0F0?ooool000d2002<00006P800<0000080000nP80004000000000
100002d12P040000;@4800P0000U0`804`:n01<2U@040000;@4900@0003`0@X01`000?`200000000
00040000;@4:00X0000T0`<06@:H01@2SP0>0YP0100002d10@040000;@4300@0003`0@X0200002H6
3`060?ooool10100000V1Pl05P3ooooo000;0P00gP0001P200070@0020000?X200010000000000@0
000]0@X0100002d1200800009@<201421@4A0^L0100002d12@040000l04:00L0003l0P0000000000
100002d12P0:000090<301L2jP0B0^0030;Z00@0000]0@40100002d10`040000l04:00P0000V1Pl0
1P3ooooo0@0@00009PH?01H0ooooo`00e@400281003R0@00B@4000P0003j0P000@00000000040000
;@4:00@0000]0@P0200002D30P3K0DL1f`4[0@@0000]0@T010000?012P070000o0800000000000@0
000]0@X02P0002@30`3Q0Bh1g04T0MH1;P440000;@4100@0000]0@<010000?012P0800009PH?00H0
ooooo`40400002H63`0F0?ooool000X2000R0@005`8004T100080000nP80004000000000100002d1
2P040000;@4800P0000U0`8040970A02:`440000;@4900@0003`0@X01`000?`20000000000040000
;@4:00X0000T0`<05P8^0A02904;0Rh1100002d10@040000;@4300@0003`0@X0200002H63`060?oo
ool10100000V1Pl05P3ooooo00130P008P40050200190@0020000?X200010000000000@0000]0@X0
100002d1200800009@<204T2A`590R/1100002d12@040000l04:00L0003l0P0000000000100002d1
2P0:000090<304l2;P5:0R@1A08^0@@0000]0@40100002d10`040000l04:00P0000V1Pl01P3ooooo
0@0@00009PH?01H0ooooo`00X`000=l1002@0P0000<000P0003j0P000@00000000040000;@4:00L0
003l0P00oooo0000100002d12`0700006`Cm0Xd2h`6W00@0000]0@4010000?012P040000;@4300@0
003`0@/0200002H63`060?ooool100<0000N00L0000F1?`2R@;T0J/0100002d11P050000104=0000
1@0000810@0000T0000b2Td2MP810000D00=00T0000b2VD2M`810000E00<00T0000b2Wd2MP810000
D`0=00@0000W0Ooo0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo
1@0000T2000000D000010_ooo`040000;@4300L0003l0P00oooo0000100002d12P080000nP800040
00000002100002d12`0700006`Cb0VL2d0:n0@@0000]0@<010000?012P040000;@4100@0003`0@/0
1`000?`2003oool000040000;@4:00P0003j0P000@00000000840000;@4;00L0000K1?82k@190/00
100002d10`040000l04:00@0000]0@4010000?012`0@00009PH?01H0ooooo`00j`000=/2002m0@00
j08000P0003j0P000@00000000040000;@4:00@0000]0@P0200002D30P2k0N42m03Q0P@0000]0@T0
10000?012P070000o0800000000000@0000]0@X02P0002@30`3g0=`2k03R0_L0i`840000;@4100@0
000]0@<010000?012P0800009PH?00H0ooooo`401`000?`2003oool000040000;@4:00P0003j0P00
0@00000000840000;@4;00L0000K1;02I`:>0[d1100002d10`040000l04:00@0000]0@4010000?01
2`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4JP9V0TP2
_`440000;@4300@0003`0@X0100002d10@040000l04;0100000V1Pl05P3ooooo003c0@00c`800?H1
003d0P0020000?X200010000000000@0000]0@X0100002d1200800009@<20?@1d0;d0O82100002d1
0@040000l04:00@0000]0@<0200002H63`060?ooool10100000V1Pl05P3ooooo000[0P00d08002h2
003d0P0020000?X200010000000000@0000]0@X0100002d1200800009@<202`2d@8/0_82100002d1
0@040000l04:00@0000]0@<0200002H63`060?ooool100L0003l0P00oooo0000100002d12P080000
nP80004000000002100002d12`0700006`@H0VL2mP6m0@@0000]0@<010000?012P040000;@4100@0
003`0@/01`000?`2003oool000040000;@4:00P0003j0P000@000?ooo`840000;@4;00L0000K1>/2
j`7G0/l1100002d10`040000l04:00@0000]0@4010000?012`0300007P0700005PCZ0^P1f0;B0@@0
000]0@80100002d110040000;@4200@0000]0@@0100002d10P050000104=00001@0000810@0000X0
000b2]X2dP420000@DT900<0100002d110090000<P[P0]h10@0003=91@0400009`7oo`<0000N00D0
00010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0
100002d10`070000o0800?ooo`0000@0000]0@X020000?X200010000oooo0P@0000]0@/01`0001/4
j`8P0]L21@840000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1>X27@;H0PP2
100002d10P040000;@4400@0000]0@80100002d110040000;@4200D000040@d0000500000P410000
2P00038:fP880P800011B@T00`040000;@4400T0000b2^0250810000<TT500@0000W0Ooo0`0001h0
1@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D000010_oo
o`040000;@4300L0003l0P00oooo0000100002d12P080000nP800040003oool2100002d12`070000
6`C]0UH2f@8m0P@0000]0@<010000?012P040000;@4100@0003`0@/00`0001h01`0001H4k09C0]X2
@0840000;@4200@0000]0@@0100002d10P040000;@4400@0000]0@801@0000@13@0000D000020@40
000:0000<P[L0T020P0004592@0300@0000]0@@02@00038:hP9<0P40000aB@D0100002L1ool30000
7P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042
oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0003j0P000@000?ooo`840000;@4;00L0
000K1:P28P:D0PH2100002d10`040000l04:00@0000]0@4010000?012`0300007P0700005PBW0Ql2
U@890P@0000]0@80100002d110040000;@4200@0000]0@@0100002d10P050000104=00001@000081
0@0000X0000b2YL22@820000HV8700L0100002d110090000<PZM0QL20@00035R1@0400009`7oo`<0
000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P0000050000
0@;oool0100002d10`070000o0800?ooo`0000@0000]0@X020000?X200010000oooo0P@0000]0@/0
1`0001/4H`8P0Tl20`840000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1682
7@9@0PH2100002d10P040000;@4400@0000]0@80100002d110040000;@4200D000040@d000050000
0P4100002P00038:DP860P800012@PT02@040000;@4400T0000b2UP260810000<D8500@0000W0Ooo
0`0001h01@000042oooo00D000090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D0
00010_ooo`040000;@4300L0003l0P00oooo0000100002d12P080000nP800040003oool2100002d1
2`0700006`@A0R82nP450P@0000]0@<010000?012P040000;@4100@0003`0@/00`0001h01`0001H4
408O0_/120840000;@4200@0000]0@@0100002d10P040000;@4400@0000]0@801@0000@13@0000D0
00020@40000:0000<P[m0@P20P0004ED2@0700@0000]0@@02@00038:0`8H0P40000bE0D0100002L1
ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@800000
1@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0003j0P000@00000000840000
;@4;00L0000K16/2WP590W01100002d10`040000l04:00@0000]0@4010000?012`070000o0800?oo
o`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4[`:N0Hd2L0440000;@4300@0
003`0@X0100002d10@040000l04;00L0003l0P00oooo0000100002d12P080000nP80004000000002
100002d12`0700006`A[0TX1B@8?0@@0000]0@<010000?012P040000;@4100@0003`0@/01`000?`2
003oool000040000;@4:00P0003j0P000@00000000840000;@4;00L0000K1:l2BP6=0Pl1100002d1
0`040000l04:00@0000]0@4010000?012`0@00009PH?01H0ooooo`00Q`4006L200320@00SP8000P0
003j0P000@00000000040000;@4:00@0000]0@P0200002D30P280H`2^P5[0P@0000]0@T010000?01
2P070000o0800000000000@0000]0@X02P0002@30`2j0G<2`05X0[D1JP840000;@4100@0000]0@<0
10000?012P0800009PH?00H0ooooo`40400002H63`0F0?ooool008H1000D0P00`@4004T200080000
nP80004000000000100002d12P040000;@4800P0000U0`80Q`570[X16P840000;@4900@0003`0@X0
1`000?`20000000000040000;@4:00X0000T0`<0_04Q0/015P:d0AT2100002d10@040000;@4300@0
003`0@X0200002H63`060?ooool10100000V1Pl05P3ooooo003]0000E@8000h1001R0P0020000?X2
00010000000000@0000]0@X0100002d1200800009@<200`1F`;f05/2100002d12@040000l04:00L0
003l0P0000000000100002d12P0:000090<30?T0EP;^05`2n@1Q0P@0000]0@40100002d10`040000
l04:00P0000V1Pl01P3ooooo0@0@00009PH?01H0ooooo`00k00009P2000=0@00Y@8000P0003j0P00
0@00000000040000;@4:00@0000]0@P0200002D30P0;0Ih2m@2N0P@0000]0@T010000?012P070000
o0800000000000@0000]0@X02P0002@30`3h09T2kP2N0_P0Y0840000;@4100@0000]0@<010000?01
2P0800009PH?00H0ooooo`401`000?`2003oool000040000;@4:00P0003j0P000@00000000840000
;@4;00L0000K11H2k`3d0L40100002d10`040000l04:00@0000]0@4010000?012`070000o0800?oo
o`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/45P980O@13`440000;@4300@0
003`0@X0100002d10@040000l04;00L0003l0P00oooo0000100002d12P080000nP800040003oool2
100002d12`0700006`@?0T81n04I0@@0000]0@<010000?012P040000;@4100@0003`0@/00`0001h0
1`0001H43P8o0OT170440000;@4200@0000]0@@0100002d10P040000;@4400@0000]0@801@0000@1
3@0000D000020@40000:0000<P[k0A`10P0004ED2@0700@0000]0@@03000038:0@8/0@<0001cIG6/
1@0500D0100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1
ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0003j0P00
0@000?ooo`840000;@4;00L0000K16D2?`5>0QH1100002d10`040000l04:00@0000]0@4010000?01
2`0300007P0700005PAT0S`1C`8I0@@0000]0@80100002d110040000;@4200@0000]0@@0100002d1
0P050000104=00001@0000810@0000X0000b2U426@420000@T8900T0100002d1100<0000<PYG0R/1
0`0007=ULJd500D01@0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a40
6P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X0
20000?X200010000oooo0P@0000]0@/01`0001/4Z@8m0I8250440000;@4300@0003`0@X0100002d1
0@040000l04;00<0000N00L0000F1:P2>P6C0QL1100002d10P040000;@4400@0000]0@80100002d1
10040000;@4200D000040@d0000500000P4100002P00038:U@8G0@80001RHPL01`040000;@4400`0
000b2Y/29@430000LfEa[PD01@0500@0000W0Ooo0`0001h01@000042oooo00D000090P0000070000
5PB<0@d34@0J00@0000W0Ooo1@0000T2000000D000010_ooo`040000;@4300L0003l0P00oooo0000
100002d12P080000nP800040003oool2100002d12`0700006`BW0^/0T0;200@0000]0@<010000?01
2P040000;@4100@0003`0@/00`0001h01`0001H4YP;X0942a@040000;@4200@0000]0@@0100002d1
0P040000;@4400@0000]0@801@0000@13@0000D000020@40000:0000<PZC0/D00P0004a>1`0900@0
000]0@@02P00038:V@;E0080001DB0D01`0400009`7oo`<0000N00D000010_ooo`0500002@800000
1`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?oo
o`0000@0000]0@X020000?X200010000oooo0P@0000]0@/01`0001/440;/0?T1``040000;@4300@0
003`0@X0100002d10@040000l04;00<0000N00L0000F10l2j@3j0LH0100002d10P040000;@4400@0
000]0@80100002d110040000;@4200D000040@d0000500000P4100002P00038:o0760080001<CPL0
2@040000;@4400X0000b2P82eP020000AE@600D0100002L1ool300007P0500000@;oool01@0000T2
000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<0400002H6
3`0F0?ooool00>d0003o0@003P4000`200080000nP80004000000000100002d12P040000;@4800P0
000U0`8030450_H01@840000;@4900@0003`0@X01`000?`20000000000040000;@4:00X0000T0`<0
n@000^h01P;i00/2100002d10@040000;@4300@0003`0@X0200002H63`060?ooool100L0003l0P00
oooo0000100002d12P080000nP800040003oool2100002d12`0700006`AT0Y81D09e0@@0000]0@<0
10000?012P040000;@4100@0003`0@/00`0001h01`0001H4H`:?0E42N0440000;@4200@0000]0@@0
100002d10P040000;@4400@0000]0@801@0000@13@0000D000020@40000:0000<PYC0WP10P000492
2@0900@0000]0@@02@00038:F@::0@40000b@PD0100002L1ool300007P0500000@;oool01@0000T2
000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2
003oool000040000;@4:00P0003j0P000@000?ooo`840000;@4;00L0000K1:H2U06B0WP1100002d1
0`040000l04:00@0000]0@4010000?012`0300007P0700005PBU0Y41T`9k0@@0000]0@80100002d1
10040000;@4200@0000]0@@0100002d10P050000104=00001@0000810@0000X0000b2YD2N`420000
HV8700L0100002d110090000<PZK0XT10@00039R1@0400009`7oo`<0000N00D000010_ooo`050000
2@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d10`070000
o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4l@;]0><2eP040000
;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1?02jP3T0]T0100002d11`040000
;@4700D000040@d0000500000P4100002P00038:i0;I0080000a<0H01P0400009`7oo`<0000N00D0
00010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0
100002d10`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4
l@9W0^@2G0840000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1?02I0;U0Ul2
100002d11`040000;@4700@0000]0@L01@0000@13@0000D000020@4000090000<P[U0Ul20@00034`
1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D0
00090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X020000?X200010000
00000P@0000]0@/01`0001/4l@8]0^@28P840000;@4300@0003`0@X0100002d10@040000l04;00<0
000N00L0000F1?02:P;U0RD2100002d11`040000;@4700@0000]0@L01@0000@13@0000D000020@40
00090000<P[U0RD20@00038`1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4
S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0
000]0@X020000?X20001000000000P@0000]0@/01`0001/4l@;d0N@2j@440000;@4300@0003`0@X0
100002d10@040000l04;00<0000N00L0000F1?02l@7U0^`1100002d11`040000;@4700@0000]0@L0
1@0000@13@0000D000020@4000090000<P[U0^`10@0003<`1P0400009`7oo`<0000N00D000010_oo
o`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d1
0`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4[`9V0Z82
F`840000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1:h2H`:S0Uh2100002d1
1`040000;@4700@0000]0@L01@0000@13@0000D000020@4000090000<PZS0Uh20@0003@`1P040000
9`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00
000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0
000]0@/01`0001/4JP9V0Ud2F`840000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0
000F16T2H`9N0Uh2100002d11`040000;@4700@0000]0@L01@0000@13@0000D000020@4000090000
<PYN0Uh20@0003L`1P0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4S04=0a40
6P0400009`7oo`D000090P00000500000@;oool0100002d10`070000o0800?ooo`0000@0000]0@X0
20000?X20001000000000P@0000]0@/01`0001/4J`:N0E`2TP440000;@4300@0003`0@X0100002d1
0@040000l04;00<0000N00L0000F16X2V`5M0YD1100002d11`040000;@4700D000040@d000050000
0P4100002@00038:G@:E0@40000h<0H0100002L1ool300007P0500000@;oool01@0000T2000000L0
000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool0
00040000;@4:00P0003j0P000@00000000840000;@4;00L0000K1:l2WP6P0Y41100002d10`040000
l04:00@0000]0@4010000?012`0300007P0700005PB^0Y/1X@:D0@@0000]0@L0100002d11`050000
104=00001@0000810@0000T0000b2Z42U0410000=C0600@0000W0Ooo0`0001h01@000042oooo00D0
00090P00000700005PB<0@d34@0J00@0000W0Ooo1@0000T2000000D000010_ooo`040000;@4300L0
003l0P00oooo0000100002d12P080000nP80004000000002100002d12`0700006`A[0TT1G@8l0@@0
000]0@<010000?012P040000;@4100@0003`0@/00`0001h01`0001H4JP960Eh2?`440000;@4700@0
000]0@L01@0000@13@0000D000020@4000090000<PYN0Sl10@0003T`1P0400009`7oo`<0000N00D0
00010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P00000500000@;oool0
100002d10`070000o0800?ooo`0000@0000]0@X020000?X20001000000000P@0000]0@/01`0001/4
[`9:0J02?@440000;@4300@0003`0@X0100002d10@040000l04;00<0000N00L0000F1:h2A`6Q0T01
100002d11`040000;@4700D000040@d0000500000P4100002@00038:X@900@40000f<0H0100002L1
ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@800000
1@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0003j0P000@00000000840000
;@4;00L0000K11X2DP4<0S/1100002d10`040000l04:00@0000]0@4010000?012`0300007P070000
5P@I0Tl13@8n0@@0000]0@L0100002d11`050000104=00001@0000810@0000X0000b2Pd2?P420000
<C8600H0100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1
ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0003j0P00
0@00000000840000;@4;00L0000K11X2mP0=0^00100002d10`040000l04:00@0000]0@4010000?01
2`0300007P0700005P@I0_<03P;S00@0000]0@L0100002d11`050000104=00001@0000810@0000X0
000b2Ph2h`020000<C<600H0100002L1ool300007P0500000@;oool01@0000T2000000L0000F18`1
3@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<01`000?`2003oool000040000
;@4:00P0003j0P000@00000000840000;@4;00L0000K11L2IP890Tl2100002d10`040000l04:00@0
000]0@4010000?012`0300007P0700005P@F0V<22P9B0P@0000]0@L0100002d11`050000104=0000
1@0000810@0000X0000b2PX2DP820000<C4600H0100002L1ool300007P0500000@;oool01@0000T2
000000L0000F18`13@<A01X0100002L1ool500002@8000001@000042oooo00@0000]0@<0400002H6
3`0F0?ooool00:d0003T0@00LP800>P100080000nP80004000000000100002d12P040000;@4800P0
000U0`80[P3V0G02i@440000;@4100@0003`0@X0100002d10`0800009PH?00H0ooooo`40400002H6
3`0F0?ooool000`2000F0P006@8004X200080000nP80004000000000100002d12P040000;@4800P0
000U0`804P980Q827`840000;@4900@0003`0@X01`000?`20000000000040000;@4:00X0000T0`<0
608R0Q82608=0R82100002d10@040000;@4300@0003`0@X0200002H63`060?ooool10100000V1Pl0
5P3ooooo000:0P00J08001L2002A0P0020000?X200010000000000@0000]0@X0100002d120080000
9@<20102S`8@0W42100002d12@040000l04:00L0003l0P0000000000100002d12P0:000090<301H2
M08@0VX22`9d0P@0000]0@40100002d10`040000l04:00P0000V1Pl01P3ooooo0@0@00009PH?01H0
ooooo`00e0400:`2003Q0@00d`8000P0003j0P000@00000000040000;@4:00@0000]0@P0200002D3
0P3J0M42fP6e0P@0000]0@T010000?012P070000o0800000000000@0000]0@X02P0002@30`3P0KP2
fP6^0]D1^0840000;@4100@0000]0@<010000?012P0800009PH?00H0ooooo`40400002H63`0F0?oo
ool000T2002/0P005P800=<200080000nP80004000000000100002d12P040000;@4800P0000U0`80
3`;A0Pl2]@840000;@4900@0003`0@X01`000?`20000000000040000;@4:00X0000T0`<05@:h0Q02
[P8:0[P2100002d10@040000;@4300@0003`0@X0200002H63`060?ooool10100000V1Pl05P3ooooo
00120P00[08004l2003C0P0020000?X200010000000000@0000]0@X0100002d1200800009@<204P2
d@980[D2100002d12@040000l04:00L0003l0P0000000000100002d12P0:000090<304h2^0980Zh2
@`:h0P@0000]0@40100002d10`040000l04:00P0000V1Pl01P3ooooo0@070000o0800?ooo`0000@0
000]0@X020000?X200010000oooo0P@0000]0@/01`0001/4f`4k0L@16@440000;@4300@0003`0@X0
100002d10@040000l04;00<0000N00L0000F1=X1>0750A`1100002d10P040000;@4400@0000]0@80
100002d110040000;@4200D000040@d0000500000P4100002@00038:a`4L0@40001c00L0100002d1
10090000<P[=0B<10@0007@00`0400009`7oo`<0000N00D000010_ooo`0500002@8000001`0001H4
S04=0a406P0400009`7oo`D000090P00000500000@;oool0100002d10`0@00009PH?01H0ooooo`00
2@400;X1000G0@00iP4000P0003j0P000@00000000040000;@4:00L0003l0P00oooo0000100002d1
2`0B000090<700X1a@4=0LD13@7T0A81i04B0LD15@750@l1^`440000;@4100@0003`0@X0100002d1
0`040000l04;00P0000V1Pl01P3ooooo0@0@00009PH?01H0ooooo`00V`400701002]0@00i`4000@0
000]0@T01`000?`2003oool000040000;@4:0180000T0`L0W0780J01b06P0G41Y`5a0JL1b06[0LP1
X`7U0@@0000]0@40100002d10`040000l04:00@0000]0@T01`000?`20000000000040000;@4:00D0
00060@80000L000090<<09`1b06L0LP1W0780I`1c06M0L`1W@7<0Id1b06L0LP1W0790J01b@6P0LP1
X0780A00000T0`H0X0750J01a@6Q0LD1X@710J01`@6P0L41400002@31P2P0Kh1X06n0J41_P6Q0KX1
X06j0J01^P4@000090<60:01]`6P0KL1X@6g0J41/`6P0K<1X06c0A00000T0`H0X06`0J01/06Q0K01
X@6/0J01[06P0J`1400002@31P2P0JT1X06Y0J41Z@6Q0JD1X06U0J01Y@4@000090<60:01XP6P0J81
X@6R0J41WP6P0Ih1X06N0A00000T0`H0X06K0J01V`6Q0I/1X@6G0J01U`6P0IL1400002@31P2P0I@1
X06D0J41U06Q0I01X06@0J01T04@000090<60:01S@6P0Hd1X@6=0J41R@6P0HT1X0690A00000T0`H0
X0660J01QP6Q0HH1X@620J01PP6P0H81400002@31P2P0Gl1X05o0J41O`6Q0G/1X05k0J01N`4@0000
90<60:01N06P0GP1X@5h0J41M06P0G@1X05d0A00000T0`H0X05a0J01L@6P0G81Y05b0J@1L@6T0G41
400002@31P2X0G41Y`5a0JL1L@6W0GD1Y`5e0JP1M@4@000090<60:P1N06W0GL1Y`5h0JL1O06W0G`1
Z05l0A00000T0`H0Z05o0JL1OP6W0Gl1Y`630JL1P`6X0H<1400002@31P2X0HH1Y`650JL1QP6W0HX1
Y`6:0JP1RP4@000090<60:P1S@6W0H`1Y`6=0JL1T@6W0I41Z06A0A00000T0`H0Z06D0JL1T`6W0I@1
Y`6H0JL1V06X0IP1400002@31P2X0I/1Y`6J0JL1V`6W0Il1Y`6O0JP1W`4@000090<60:P1XP6W0J41
Y`6R0JL1YP6W0JH1Z06V0A00000T0`H0Z06Y0JL1Z06W0JT1Y`6]0JL1[@6X0Jd1400002@31P2X0K01
Y`6_0JL1/06W0K@1Y`6d0JP1]04@000090<60:P1]`6W0KH1Y`6g0JL1^`6W0K/1Z06k0A00000T0`H0
Z06n0JL1_@6W0Kh1Y`720JL1`P6X0L816P0002@32`2X0LD1Y`740JL1a@6W0LP1Y`790JP1b@6X0LP1
Z0780JL1b06W0LP1Z0780A00000T0`H0[0780J/1b06[0LP1Z@7<0JX1c06Z0L`1400002@31P2Z0Ll1
Z@7>0JT1c`6X0M<1Z07C0JT1d`4@000090<60:P1e@6W0MD1Y`7E0JH1f@6V0MX1Y`7I0A00000T0`H0
YP7L0JD1g06U0M`1Y07P0J@1h@6U0N017P0002@33@2T0N<1Y07R0J<1h`6S0ND1X`7U0J@1i@6S0N<1
X`7S0J81h`6S0ND1X`7U0J<1i@6T0ND1400002@31P2Q0N01XP7Q0J81h06Q0M`1X@7L0J01g04@0000
90<60:01f@6P0MX1X@7I0J01eP6O0MD1W`7F0A00000T0`H0WP7C0Il1d`6O0M<1WP7?0Ih1cP6M0Ll1
1@0000H10@0000@0000]0@40100002d10`040000l04:00P0000V1Pl01P3ooooo0@0@00009PH?01H0
ooooo`00n`40034000140P00?P0000P0003j0P000@00000000040000;@4:00@0000]0@P0200002D3
0P3l0CL0>P8g00@0000]0@T010000?012P070000o0800000000000@0000]0@X02P0002@30`0h0Sd0
@P8h03P2<P040000;@4100@0000]0@<010000?012P0800009PH?00H0ooooo`40400002H63`0F0?oo
ool003L2002j0@00P08000T200080000nP80004000000000100002d12P040000;@4800h0000U0`D0
IP870Wh21`9n0]P1?@;H0Cd2``440000;@4900@0003`0@X01`000?`20000000000040000;@4:00X0
000T0`<0@`;60Ch2_04h0/H1100002d10@040000;@4300@0003`0@X0200002H63`060?ooool10100
000V1Pl05P3ooooo002U0@008P000<L10012000020000?X200010000000000@0000]0@X01`000?`2
003oool000040000;@4;01H0000T0`T0a@4h0;/1;`2k0C@0/04d0;018`2V0B<0YP4l0;/1?02k0D00
100002d10@040000l04:00@0000]0@<010000?012`0800009PH?00H0ooooo`40400002H63`0F0?oo
ool009@1000R0000[P4005`000080000nP80004000000000100002d12P070000o0800?ooo`0000@0
000]0@/04P0002@31`2E0D`0V`5<09/18`2V0B<0YP5<0:`1C02P0EX0100002d10@040000l04:00@0
000]0@<010000?012`0800009PH?00H0ooooo`40400002H63`0F0?ooool006D2001l0000X`800;81
00080000nP80004000000000100002d12P040000;@4800`0000U0`@0I`9m0:42O@2Q0Z/1KP:[0@@0
000]0@T010000?012P070000o0800000000000@0000]0@X02P0002@30`1a0ZH1IP:/0G42/@440000
;@4100@0000]0@<010000?012P0800009PH?00H0ooooo`401`000?`20030`<0000040000;@4:00P0
003j0P000@00000000840000;@4;00L0000K1;`1>`6K0NL0100002d10`040000l04:00@0000]0@40
10000?012`0300007P0700005PBk0CP1W07Z00@0000]0@D0100002d11@050000104=00001@000081
0@0001T0000b2Z<1kP0<0000@VmTNB1VK7EYI7<P2@0800P01`0400@0100800@0200600@0100002L1
ool300007P0500000@;oool01@0000T2000000L0000F18`13@<A01X0100002L1ool500002@800000
1@000042oooo00@0000]0@<01`000?`2003oool000040000;@4:00P0003j0P000@000?ooo`840000
;@4;00L0000K12<0_0490981100002d10`040000l04:00@0000]0@4010000?012`0300007P070000
5P@R0;P12P2F0A`0003k0_3o00000000_08000000000845bJF5/0000>@<::ZF7kGN^Qnegd6O_McT3
2RX000X0100002d12P0L0000n`;`o`0000000901000000000211LVUQK0000:d32TbUQneg[XO]Mm1W
kgN]0`Y<000:00@0000]0@/070000?/2l?l00000002@0@400000000P@G9YHF`0002J0`ZPYHO]Mjj7
kGO@InmgVP<:X0002P040000;@4<00@0000]0@/0100002d12P040000;@4;00@0000]0@X01@0000@1
3@0000D000020@4000090000<PX;09H10@0006802P040000;@4;00T0000b2P/0X0410000:00500@0
000]0@`02@00038:2P2U0@40001d00@0100002d12`090000<PX;0:`10@0002T01@0400009`7oo`<0
000N00D000010_ooo`0500002@8000001`0001H4S04=0a406P0400009`7oo`D000090P0000050000
0@;oool0100002d10`0800009PH?00H0ooooo`401@0000T2000000D000010_ooo`040000;@4300@0
000W0Ooo0`000000240122@0000H00000A30f`400003000000000000000000006T00@2`0000P0000
0@000080000002M3000@@@20od<003e400000>P3j0<Q000020000680000<00000@00024000080000
HP0000`0000100004@0000`0000800002P000100002W00002@0000T0000@0000o`400?@2000<0000
400000/0000000002`000100003o0@000`<00240000800009@0000`0000700209@0000`000000020
5P0000`000000000600000`0000000006@0000`0003oool0500000`0000=0000DP00070100010000
400000L00000000000000;`2000000001`828U<0N@1c07@0I@1]0000000000000000000000000000
000000000000000000000000000000000000000000000780K`1c06l0IP1d0200C`1V06H0J@1S06D0
801H0000000hKLEg00000=l>8@lI0;01000@0640K00P06<0K`1^0200AP1b06l0KP1d0500H@1W06D0
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000I7H02000000U0000
30000040000H000030000000000I000030000?ooo`0D0000300000d0000B000030000080000:0000
40000000000000002@000100003o0@00m0800240000800002P000100002W00002@0000T0000@0000
o`400?@2000D0000300000d0000W00006000008000000000oooo0000000U000030000080000V0000
700000<0000000000@000000000000009@0000`000030000:`0001P000360@009P000?`100170000
9`0001P00004000000000?ooo`0000009@0000`000040000:00000`0000200009P0001`000020000
0000000000000000000002D0000<00000P0002P0000<00000`0002L0000H00000`000000003oool0
000002D0000<00000`0002H0000L00001@0000000001000000000?ooo`0U0000300000D0000[0000
60000=T1000/0000m@400480000U0000300000@0000X0000300000<0000U000030000080000X0000
300000D0000Q0000200001h0000H0000g04002d0003c0@00@P000580001`0@001@000??oool00000
00000000002@0@00000000L000110780J@1Q06`00000000000000000000000000000000000000000
00000000000000000000000000000000000C0:A:bc3O3R4?23dm0Q/4001XcQ<00000090Fm7N8aC`2
CQKdMdP75@1Z5_Agi`h`0I35?0:@aC`2K`1c06l0IP1d0200C`1V06H0J@1S06D0801H0000000hKLEg
00000=l>8@lI0;01000@0640K00P06<0K`1^0200AP0001<00000090Fm7OhT_T6CQKdMoP85@1Z5_Ag
G9?i1/80_`L0ToT60000000000000000000000@0000P00000000000000000000000100005@2/cA<0
00000:3>4`05T?Igb=GeMooooomZ5_Agbf3UM`005@000000gV3UMfAf00P000009@0000`000050000
DP00070100030000moooo`000000000000000901000000001`008440LP1Y0640K000000000000000
000000000000000000000000000000000000000000000000000000000000024?6@2`0@00401Q06`0
801S06l0KP0P04H0000C0000002@5_Agn9;i1ThFm7Oh21D0JQKdMebCn@K20;l709?i1P0000000000
00000000000400008000000000000000000000000@0001D0[<dC0000002PcQ<01I3fM`00mGOooooo
JQKdMl]PiGL001D000000=iPiGMTMP080000002Cn@H0000000000000000000001000020000000000
0000000000000040000E0:c=4`000000X<hC00F@mWO8eOEgooooofXFm7O;H>Eg000E0000003NH>Eg
I7H02000000U0000300000<0000U0000300000D0000U0000300000<0000U0000300000D0000B0000
30000040001D0000F0000401000W0000C`4003H000010000000P@[</8d;L0@00;`000080001<0000
0000000000000000oooooooooom@0000A@1D00T0000700009@0000`000030000E00005@0001@0@00
;@0005@1000h00000@00000084:c;2=2k04003D000010000C00000000000000000000?oooooooooo
D0000340000500008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001X0000A00003@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000
300000@0000W0000600000H000000000oooo0000000U0000300000H0000V0000700000L000000000
0@000000000000009@0000`000070000:`0001P000120P009`0009D2001600009@0000`000040000
:00000`0000600009@0000`000020000:00000`0000700008@0000P0000N0000600004D2000X0000
T`8004H0000U0000300000D0000U0000300000D0000D0000300000d0000B000030000040001D0000
T0000:`1000V0000lP4003D000010000000P@[</8d980P00;P0000/0001<00000000000000000000
oooooooooomT0000A@1^07H0J@1b06l0KP1]06D0KP1d00002@0000L0000500000`0000@000070000
1`0000/0000700001`0000@0000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000
000001h0000H00006P000140000=0`00S0400280000<0000oooooaP0000<0000000001T0000<0000
oooo02D0000<0000100002L0000H00001`0000000030`<00000002D0000<00001`0002H0000L0000
1P0000000001000000000000000U0000300000H0000[0000600001<2002K0@00IP800;/1000U0000
300000@0000X0000300000L0000U000030000080000X0000300000H0000Q0000200001h0000H0000
5P8009`1001T0P00^`400580001`0@001P000??oool0000000000000002l0P00000000L002110780
J@1Q06`0000000000000000000000000000000000000000000000000000000000000000000000000
000C0:A:bc3O3R4?23dm0Q/4001XcQ<00000090Fm7L0DCD2CQKdMdP75@1Z5_Agi`h`1`QA=@88DCD2
0000002Cn@H00000000004D0KP1f06T0LP1_06h0K@1U06h0M000000000000040000E0:c=4`000000
X<hC00F@mWL001<00000090Fm7L`YC`2CQKdMmP75@1Z5_AgYP>o1cRU?08hYC`20000000000000000
000000@0000P00000000000000000000YAl100005@2/cA<0YAo4MjDOa7O4l?eo0>3mO`0000000000
000000000032?LAg0P0006Af00P000009@0000`0000600009@0000`000060000500000`0000=0000
4P0000`000010000E00007`000280@00XP400;T1002a0@000@00000084:c;2=290800:<100080000
C00000000000000000000?ooooooooooG00004L0B@0P05@0LP1Q06<0M00:0000100000@000080000
1@0000P00007000010000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P00007000000000?ooo`0000009@0000`0000700009P0001`000080000
0000004000000000oooo02D0000<0000200002/0000H0000/04009/1003A0@00/@4002D0000<0000
100002P0000<00001`0002D0000<00000P0002P0000<000020000240000800007P0001P0002c0@00
W0400<l1002a0@009@0000`0000500009@0000`0000300009@0000`0000500009@0000`000030000
9@0000`000050000500000`0000=00004P0000`000010000E00005@0000G0@00W@4001d1002/0@00
0@00000084:c;2=2/`4009h100010000C00000000000000000000?ooooooooooD00007<000070000
9@0000`000030000E00005P0000N0@00X`4002D1002^0@000@00000084:c;2=2^P400:@100020000
C00000000000000000000?ooooooooooD0000700M00500000`000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`000000
9@0000`0000800009P0001`0000700000000004000000000oooo02D0000<00001`0002/0000H0000
6P4007`1000k0@00TP4002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<0000
1`000240000800007P0001P0000M0@00O@4003T1002B0@009@0000`0000500009@0000`000030000
9@0000`0000500009@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000
E00005@000210000O@4008L0002<0@000@00000084:c;2=27@4007l100010000C000000000000000
00000?ooooooooooD00007<0000700009@0000`000030000E00005@000280000Q04008`0002?0@00
0@00000084:c;2=2904008D100010000C00000000000000000000?ooooooooooD000070000050000
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A0000
3@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000300000@0000V0000
700000L0000000000@000000000000009@0000`0000700009`0001P00008000000000?ooo`000000
9@0000`000080000EP0003P0001`0000K`4007/0002H0@001`0000`1S`4?0Hl13`5a0A@1L@4D0Hl1
5`6?0A41V@4U000030000080000X0000300000L0000U0000300000@0000X0000300000P0000V0000
700000P0000000000@000000000000009@0000`0000800009`0001P00007000000000?ooo`000000
9@0000`000070000:`0001P0002X0000F@0008d2001b0@009@0000`000020000:00000`000080000
9@0000`000040000:00000`0000700008@0000P0000N000060000:`0001J0000RP800781001B0000
L04000L0003]oooo0000000000000000T04000000007000P@@1b06T0H@1/00000000000000000000
000000000000000000000000000000000000000000000000000000004`2TB//`g`hQ3`Pm?@8K1000
J<hC0000002@5_AgF;dl0ThFm7M81aD0JQKdMd0=40IP_C`2H;dl0SRU?08hYC`200000000001`07@0
801D0780H@1S07@00000000000000000YAl100005@2/cA<0YAo4MjDOa7O4l?eo000C0000002@5_Ag
h=_i1ThFm7L821D0JQKdM`L000000000j=_i1P000000000000000000000400008000000000000000
YAo4MjDO0@0001D0[<dC0000002PcQ<01I3fMlSEmGOoooooJQKdMl]PiGL001D000000=iPiGMTMP08
000002D0000<00001`0001@0000<00003@000180000<00000@0005@0001D0000f`400;h0003W0@00
d`00004000000212/b`S@WL2003300000@0004`00000000000000000003ooooooooooe00001@0000
3@0005@0001D0000g`400=H0003T0@00j`00004000000212/b`S@W/2003K00000@0004`000000000
00000000003ooooooooooe00001900001P0005@0001D0000f`400>l0003W0@001040004000000212
/b`S@WL2003c00000@0004`00000000000000000003ooooooooooe00001C00003@000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009`0001P000080000
00000?ooo`0000009@0000`0000800009P0001`0000900000000004000000000000002D0000<0000
2@0002/0000H0000_`4004H1001W0P00I`4002D0000<0000100002P0000<0000200002D0000<0000
0P0002P0000<00002@0002L0000H00002@000000003oool0000002D0000<00002@0002H0000L0000
200000000001000000000000000U0000300000P0000[000060000<40002o0000k@0006L1000U0000
300000@0000X0000300000T0000U000030000080000X0000300000P0000V0000700000P000000000
0@000000000000009@0000`0000800009@0000`000050020E`0002@0001I0000E@400201001E0@00
0P000;`1E`7e05L19@0000`000080020:00000`0000800009`0001P0000800000000000000000000
9@0000`000080000EP0002P0001B0000D04005`0001K0@000`000?P0DP7^05P1n01M0BD0000<0000
0P0002D0000<0000100002P0000<0000200002L0000H000020000000003oool0000002D0000<0000
200002H0000L00002@0000000001000000000000000U0000300000T0000[000060000;h100040@00
I`8002D1000U0000300000@0000X0000300000P0000U000030000080000X0000300000T0000W0000
600000T000000000oooo0000000U0000300000T0000V0000700000P0000000000@00000000000000
9@0000`000080000:`0001P000300@00_P0006H2003O00009@0000`000040000:00000`000090000
9@0000`000020000:00000`0000800009P0001`0000800000000004000000000000002D0000<0000
200002D0000<00001@00P5L0000T0000F@4004<1001I0@00IP400080003e0DH1m@5X0BD0000<0000
0P0002P0000<0000200002D0000<0000100002H0000L0000200000000001000000000000000U0000
300000P0000U0000300000D0081G00009000094100140@00T@4006H100020000;@970Bd2J04U0000
30000080000X0000300000P0000U0000300000@0000W0000600000P000000000oooo0000000U0000
300000P0000V0000700000T0000000000@000000000000009@0000`000090000:`0001P0002n0@00
K00006L2002=00009@0000`000040000:00000`0000800009@0000`000020000:00000`000090000
9`0001P00009000000000?ooo`0000009@0000`0000900009P0001`0000800000000004000000000
oooo02D0000<0000200002/0000H0000d04004d1003[0@00H04002D0000<0000100002P0000<0000
2@0002D0000<00000P0002P0000<000020000240000800007P0001P0003C0@00CP400>T1001P0@00
9@0000`0000500009@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000
500000`0000=00004P0000`000010000E00005P0000g0@00CP400481001M0@000@00000084:c;2=2
d`40050100020000C00000000000000000000?ooooooooooD0000440B@0900000`0002D0000<0000
0`0005@0001D0000@`4005@100170@00G@40004000000212/b`S@]l1001F0@000@0004`000000000
00000000003ooooooooooe00000c00001@000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`0000009@0000`000080000
9P0001`0000900000000004000000000oooo02D0000<00002@0002/0000H00001P8004d1000P0P00
H04002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<00002@00024000080000
7P0001P000090P00CP4001h2001P0@009@0000`0000500009@0000`0000300009@0000`000050000
9@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000E00005P0001]0@00
CP4007P1001M0@000@00000084:c;2=22@80050100020000C00000000000000000000?oooooooooo
D0000440B@0900000`0002D0000<00000`0005@0001D0000N@4005@1001m0@00G@40004000000212
/b`S@QD2001F0@000@0004`00000000000000000003ooooooooooe00000b00001@000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009`0001P000090000
00000?ooo`0000009@0000`0000900009P0001`0000800000000004000000000oooo02D0000<0000
200002/0000H0000?P8004l1001F0P00HP4002D0000<0000100002P0000<00002@0002D0000<0000
0P0002P0000<000020000240000800007P0001P000110P00D04005@2001R0@009@0000`000050000
9@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000500000`0000=0000
4P0000`000010000E00005P0002U0@00D0400;01001O0@000@00000084:c;2=2@@80058100020000
C00000000000000000000?ooooooooooD0000440B@0900000`0002D0000<00000`0005@0001D0000
/@4005H1002e0@00G`40004000000212/b`S@Td2001H0@000@0004`00000000000000000003ooooo
oooooe00000a00001@000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P00008000000000?ooo`0000009@0000`0000800009P0001`000090000
0000004000000000oooo02D0000<00002@0002/0000H00001`8000X1000R0P007@4002D0000<0000
100002P0000<0000200002D0000<00000P0002P0000<00002@000240000800007P0001P0000:0P00
2`400202000M0@009@0000`0000500009@0000`0000300009@0000`0000500009@0000`000030000
9@0000`000050000500000`0000=00004P0000`000010000E00005P0001^0@002@4007/1000H0@00
0@00000084:c;2=22P8000d100020000C00000000000000000000?ooooooooooD0000680HP070000
1`0002D0000<00000`0005@0001D0000O04000l100200@006040004000000212/b`S@QP2000C0@00
0@0004`00000000000000000003ooooooooooe00000a00001@000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P00009000000000?ooo`000000
9@0000`0000900009P0001`0000800000000004000000000oooo02D0000<0000200002/0000H0000
10800<D0000P0P00f00002D0000<0000100002P0000<00002@0002D0000<00000P0002P0000<0000
20000240000800007P0001P000070P00aP0001h2003H00009@0000`0000500009@0000`000030000
9@0000`0000500009@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000
E00005P0001[0@00``0007`1003B00000@00000084:c;2=21`800<P000020000C000000000000000
00000?ooooooooooD0000480@P0900002@0002D0000<00000`0005@0001D0000O@400<T000210@00
dP00004000000212/b`S@QT2003>00000@0004`00000000000000000003ooooooooooe00000a0000
1@000280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000040000
9`0001P00008000000000?ooo`0000009@0000`0000800009P0001`0000900000000004000000000
oooo02D0000<00002@0002/0000H00001P800700000R0P00QP0002D0000<0000100002P0000<0000
200002D0000<00000P0002P0000<00002@000240000800007P0001P000090P00L@00020200260000
9@0000`0000500009@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000
500000`0000=00004P0000`000010000E00005P0001]0@00K00007`1001k00000@00000084:c;2=2
2@8007<000020000C00000000000000000000?ooooooooooD00004D0E00900001`0002D0000<0000
0`0005@0001D0000O@40078000210@00O@00004000000212/b`S@QT2001i00000@0004`000000000
00000000003ooooooooooe00000b00001@000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P00009000000000?ooo`0000009@0000`000090000
9P0001`0000800000000004000000000000002D0000<0000200002/0000H0000L@400;l0002N0@00
h00002D0000<0000100002P0000<00002@0002D0000<00000P0002P0000<0000200002L0000H0000
20000000003oool0000002D0000<0000200002H0000L00002@0000000001000000000000000U0000
300000T0000[00006000074100030@00WP4002@1000U0000300000@0000X0000300000P0000U0000
30000080000X0000300000T0000W0000600000T000000000oooo0000000U0000300000T0000V0000
700000P0000000000@000000000000009@0000`000080000:`0001P0000@0@00_`0004X1003P0000
9@0000`000040000:00000`0000900009@0000`000020000:00000`0000800009`0001P000080000
00000?ooo`0000009@0000`0000800009P0001`0000900000000004000000000000002D0000<0000
2@0002/0000H0000404000<1001:0@00904002D0000<0000100002P0000<0000200002D0000<0000
0P0002P0000<00002@0002H0000L00002@0000000001000000000000000U0000300000T0000U0000
300000D0081G000090000>d0003L00007`400?h000020000R@420K/1h@0U0000300000P0080X0000
300000T0000W0000600000T00000000000000000000U0000300000T0001F0000:00001X1003I0000
9P400>@000030000^`7Y0<81gP2f0N009@0000`0000200009@0000`000040000:00000`000090000
9P0001`0000900000000004000000000000002D0000<00002@0002D0000<00001@00P5L0000T0000
k00008X0000O0@00^000008000280Kd0^`6@02D0000<00002000P2P0000<00002@0002L0000H0000
2@00000000000000000002D0000<00002@0005H0000X00006@4008H0000T0@00T@0000<0002m0IL0
`06<0;D1S`0U000030000080000U0000300000@0000X0000300000T0000V0000700000T000000000
0@000000000000009@0000`0000900009@0000`000050020E`0002@0001K0000c0000740003<0000
0P0000d1d@3g0=409@0000`000080020:00000`0000900009`0001P0000900000000000000000000
9@0000`000090000EP0002P0001D0000a`0005h0003B00000`000?X0c03`0=80nP3G02D0000<0000
0P0002D0000<0000100002P0000<00002@0002H0000L00002@0000000001000000000000000U0000
300000T0000U0000300000D0081G0000900005X0000@0@00L000010100020000304D0OH0504U0000
300000P0080X0000300000T0000W0000600000T00000000000000000000U0000300000T0001F0000
:0000580000;0@00G@0001H100030000n@0?0Nh0507i01X19@0000`0000200009@0000`000040000
:00000`0000900009`0001P00009000000000?ooo`0000009@0000`0000900009P0001`000080000
0000004000000000000002D0000<0000200002/0000H0000`P0006X0003_0000R`0002D0000<0000
100002P0000<00002@0002D0000<00000P0002P0000<0000200002L0000H000020000000003oool0
000002D0000<0000200002H0000L00002@0000000001000000000000000U0000300000T0000[0000
60000101001Z0000B04008/0000U0000300000@0000X0000300000P0000U000030000080000X0000
300000T0000W0000600000T000000000oooo0000000U0000300000T0000V0000700000P000000000
0@000000003oool09@0000`000080000:`0001P0000J0@00KP000481002400009@0000`000040000
:00000`0000900009@0000`000020000:00000`0000800008@0000P0000N0000600001d1001_0000
@04008@0000U0000300000D0000U0000300000<0000U0000300000D0000U0000300000<0000U0000
300000D0000D0000300000d0000B000030000040001D0000F0000840001Z0000T00007T000010000
000P@[</8d8M0@00L@000080001<00000000000000000000oooooooooom@0000A@1D00T000070000
9@0000`000030000E0000600002A0000L00009l0001k00000@00000084:c;2=2;@4007L000030000
C00000000000000000000?ooooooooooE00007<0I@1a00001@0000D0000500008P0000`0003ooooo
8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R0000
30000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000600000P000000000
oooo0000000U0000300000P0000V0000700000T0000000000@000000003oool09@0000`000090000
:`0001P0000G0@00a00003l1003J00009@0000`000040000:00000`0000800009@0000`000020000
:00000`0000900008@0000P0000N0000600001X100350000?@400=X0000U0000300000D0000U0000
300000<0000U0000300000D0000U0000300000<0000U0000300000D0000D0000300000d0000B0000
30000040001D0000F00007h000320000S`000=4000010000000P@[</8d8J0@00a`000080001<0000
0000000000000000oooooooooom@0000@P1200T0000900009@0000`000030000E0000600002@0000
b00009h0003C00000@00000084:c;2=2;0400<d000030000C00000000000000000000?oooooooooo
E00007<0I@1a00001@0000D0000500008P0000`0003ooooo8@0000P0000I000030000?ooo`0H0000
30000000000N0000600001X0000A00003@<008`1000R000030000?oooolH000030000000000I0000
30000?ooo`0U0000300000@0000W0000600000T000000000oooo0000000U0000300000T0000V0000
700000P0000000000@000000003oool09@0000`000080000:`0001P0000E0@00204003d1000N0@00
9@0000`000040000:00000`0000900009@0000`000020000:00000`0000800008@0000P0000N0000
600001P100090@00>`4001h1000U0000300000D0000U0000300000<0000U0000300000D0000U0000
300000<0000U0000300000D0000D0000300000d0000B000030000040001D0000F00007`000070@00
R@0001H100010000000P@[</8d8H0@002`400080001<00000000000000000000oooooooooom@0000
HP1R00L0000700009@0000`000030000E0000600002:00003@4009P0000H0@000@00000084:c;2=2
9P40014100030000C00000000000000000000?ooooooooooE00007<0I@1a00001@0000D000050000
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A0000
3@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000
600000P000000000oooo0000000U0000300000P0000V0000700000T0000000000@000000003oool0
9@0000`000090000:`0001P0003300001P400>/0000L0@009@0000`000040000:00000`000080000
9@0000`000020000:00000`0000900008@0000P0000N000060000<H000070@00j@0001`1000U0000
300000D0000U0000300000<0000U0000300000D0000U0000300000<0000U0000300000D0000D0000
300000d0000B000030000040001D0000F00002X000050@00>@0001@100010000000P@[</8d;60000
2@400080001<00000000000000000000oooooooooom@0000C01>00L0000900009@0000`000030000
E00005P0000j00002`4004D0000F0@000@00000084:c;2=2eP0000l100020000C000000000000000
00000?ooooooooooD00005@0B00500001`000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P00009000000000?ooo`0000009@0000`000090000
9P0001`0000800000000004000000000oooo02D0000<0000200002/0000H0000a00006l0003/0000
Q@0002D0000<0000100002P0000<00002@0002D0000<00000P0002P0000<00002000024000080000
7P0001P000370000L0000>X0002500009@0000`0000500009@0000`0000300009@0000`000050000
9@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000E00005P0000[0000
J`0003X0001j00000@00000084:c;2=2a`00078000020000C00000000000000000000?oooooooooo
D00004`0CP0700002@0002D0000<00000`0005@0001H0000>`00074000150000O000004000000212
/b`S@]L0001h00000P0004`00000000000000000003ooooooooooe00001505@01P0000D0000R0000
30000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H00006P000140000=0`00
S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000100002H0000L0000
200000000001000000000000000U0000300000P0000U0000300000D0081G0000900005/0001d0000
L@0007@0000200003@5k0?L0N`0U0000300000P0080X0000300000P0000W0000600000P000000000
00000000000U0000300000P0001F0000:00005@0001_0000GP0007X000030000nP1f0?00O03j0840
9@0000`0000200009@0000`000040000:00000`0000800009`0001P00008000000000?ooo`000000
9@0000`0000800009P0001`0000900000000004000000000oooo02D0000<00002@0002/0000H0000
MP400<D0002B0@00f00002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<0000
2@000240000800007P0001P0001i0@00aP000901003H00009@0000`0000500009@0000`000030000
9@0000`0000500009@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000
E00005P0003M0000``000>h0003B00000@00000084:c;2=2N@400<P000020000C000000000000000
00000?ooooooooooD0000480@P0900002@0002D0000<00000`0005@0001D0000k`000<T0003c0000
dP00004000000212/b`S@X/1003>00000@0004`00000000000000000003ooooooooooe00000b0000
1@000280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000040000
9`0001P00009000000000?ooo`0000009@0000`0000900009P0001`0000800000000004000000000
oooo02D0000<0000200002/0000H0000N@4000P1002D0@006`4002D0000<0000100002P0000<0000
2@0002D0000<00000P0002P0000<000020000240000800007P0001P0001l0@002@400981000K0@00
9@0000`0000500009@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000
500000`0000=00004P0000`000010000E00005P0003P00001`400>d0000F0@000@00000084:c;2=2
O04000/100020000C00000000000000000000?ooooooooooD0000680HP0700001`0002D0000<0000
0`0005@0001D0000kP0000d1003b00005P40004000000212/b`S@XX1000A0@000@0004`000000000
00000000003ooooooooooe00000b00001@000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`0000009@0000`000080000
9P0001`0000900000000004000000000000002D0000<00002@0002/0000H0000e`0005T1003]0000
IP4002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<00002@00024000080000
7P0001P0003J0000FP400>/0001V0@00DP00070100090000mOooo`00000000000000090100000000
1`008440LP1Y0640K000000000000000000000000000000000000000000000000000000000000000
00000000000001<0Y4[;<=l>8@l8?Cd26`@006S>4`000000T1KdMmQCn@I>5_AgB0LE06XFm7O[3S0c
h5?i1^1Cn@H00000j=_i1P0000000000<P1R0740000400008000000000000000YAo4MjDO0@0001D0
[<dC0000002PcQ<01I3fM`004`000000T1KdMf0Y>`9>5_Agj0HE06XFm7LD8[l7J2Tk0VPY>`800000
00000000000000001000020000000000YAo4MjDOa7NU7`40000E0:c=4`2U7lAgYAo4MlC`oGl0h?eo
000000000000000000000<8ma7L20000I7H02000000U0000300000T0000U0000300000T0000D0000
300000d0000B000030000040001D0000F00003h0001H0@00B@0006<100010000000P@[</8d;J0000
FP400080001<00000000000000000000oooooooooom@0000<@0`00H0000600008P0000`0003ooooo
8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R0000
30000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000600000P000000000
oooo0000000U0000300000P0000V0000700000X0000000000@000000000000009@0000`0000:0000
:`0001P0001M0P00FP4006L2001V0@009@0000`000040000:00000`0000800009@0000`000020000
:00000`0000:00008@0000P0000N000060000602001K0@00I@8006H1000U0000300000T0000U0000
300000T0000U0000300000T0000D0000300000d0000B000030000040001D0000E0000<@1001I0@00
b04006<100010000000P@[</8d9P0P00F`400040001<00000000000000000000oooooooooom@0000
<@0000H0000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
6P000140000=0`00S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
100002L0000H00002P000000003oool0000002D0000<00002P0002H0000L00002000000000010000
00000000000U0000300000P0000[0000600002<2001J0@00;@8006H1000U0000300000@0000X0000
300000X0000U000030000080000X0000300000P0000Q0000200001h0000H00009P8005/1000[0P00
IP4002D0000<00002@0002D0000<00002@0002D0000<00002@0001@0000<00003@000180000<0000
0@0005@0001D0000RP4005T1002>0@00H`40004000000212/b`S@RH2001K0@000@0004`000000000
00000000003ooooooooooe00000b00001P000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`0000009@0000`000080000
9P0001`0000:00000000004000000000000002D0000<00002P0002/0000H0000jP4005X1003d0@00
IP4002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<00002P00024000080000
7P0001P0003]0@00F`400?81001V0@009@0000`0000900009@0000`0000900009@0000`000090000
500000`0000=00004P0000`000010000E00005@0001A0@00F@4005D1001S0@000@00000084:c;2=2
k@4005/100010000C00000000000000000000?ooooooooooD00003<0000600008P0000`0003ooooo
8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R0000
30000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000600000X000000000
oooo0000000U0000300000X0000V0000700000P0000000000@000000000000009@0000`000080000
:`0001P0001L0P00604006H2000T0@009@0000`000040000:00000`0000:00009@0000`000020000
:00000`0000800008@0000P0000N0000600005l2000I0@00I08002@1000U0000300000T0000U0000
300000T0000U0000300000T0000D0000300000d0000B000030000040001D0000E0000<<1000E0@00
a`40020100010000000P@[</8d9O0P006@400040001<00000000000000000000oooooooooom@0000
=00000H0000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
6P000140000=0`00S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
100002L0000H000020000000003oool0000002D0000<0000200002H0000L00002P00000000010000
00000000000U0000300000X0000[0000600005/2003B0000I@800=h0000U0000300000@0000X0000
300000P0000U000030000080000X0000300000X0000Q0000200001h0000H0000GP800=<0001S0P00
gP0002D0000<00002@0002D0000<00002@0002D0000<00002@0001@0000<00003@000180000<0000
0@0005@0001D0000`P400<h000360@00f000004000000212/b`S@Uh2003C00000@0004`000000000
00000000003ooooooooooe00000g00001P000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P0000:000000000?ooo`0000009@0000`0000:0000
9P0001`0000800000000004000000000000002D0000<0000200002/0000H0000T@400=40002N0@00
h00002D0000<0000100002P0000<00002P0002D0000<00000P0002P0000<00002000024000080000
7P0001P0002D0@00dP0009`1003P00009@0000`0000900009@0000`000090000500000`0000=0000
4P0000`000010000E00005@0003h0000c@000?d0003J00000@00000084:c;2=2U0400=8000010000
C00000000000000000000?ooooooooooD00003P0000600008P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R000030000?oooolH0000
30000000000I000030000?ooo`0U0000300000@0000W0000600000P000000000oooo0000000U0000
300000P0000V0000700000X0000000000@000000000000009@0000`0000:0000:`0001P0002C0@00
5`4009h1000T0@009@0000`000040000:00000`0000800009@0000`000020000:00000`0000:0000
8@0000P0000N0000600009H1000H0@00W04002@1000U0000300000T0000U0000300000T0000D0000
300000d0000B000030000040001D0000E0000?X0000D0@00o`00020100010000000P@[</8d:F0@00
60400040001<00000000000000000000oooooooooom@0000=@0000H0000R000030000?oooolQ0000
200001T0000<0000oooo01P0000<0000000001h0000H00006P000140000=0`00S0400280000<0000
oooooaP0000<0000000001T0000<0000oooo02D0000<0000100002L0000H00002P000000003oool0
000002D0000<00002P0002H0000L0000200000000001000000000000000U0000300000P0000[0000
600003h1003@0000B@400=l0000U0000300000@0000X0000300000X0000U000030000080000X0000
300000P0000Q0000200001h0000H0000@@400=4000170@00g`0002D0000<00002@0002D0000<0000
2@0001@0000<00003@000180000<00000@0005@0001D0000Y@000<`0002Z0000f@00004000000212
/b`S@T41003A00000@0004`00000000000000000003ooooooooooe00000i00001P000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009`0001P000080000
00000?ooo`0000009@0000`0000800009P0001`0000:00000000004000000000000002D0000<0000
2P0002/0000H0000?`4001@1001:0@00904002D0000<0000100002P0000<0000200002D0000<0000
0P0002P0000<00002P000240000800007P0001P000120@005@4004P1000T0@009@0000`000090000
9@0000`000090000500000`0000=00004P0000`000010000E00005@0002V00004@400:/0000N0@00
0@00000084:c;2=2@P4001D100010000C00000000000000000000?ooooooooooD00003H000060000
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A0000
3@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000
600000X000000000oooo0000000U0000300000X0000V0000700000P0000000000@00000000000000
9@0000`000080000:`0001P0000l0@00PP000581002?00009@0000`000040000:00000`0000:0000
9@0000`000020000:00000`0000800008@0000P0000N0000600003l100230000D04008l0000U0000
300000T0000U0000300000T0000D0000300000d0000B000030000040001D0000F0000:<0001l0000
[P0008P000010000000P@[</8d8o0@00P`000080001<00000000000000000000oooooooooom@0000
<@0b00H0000600008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001X0000A00003@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000
300000@0000W0000600000P000000000oooo0000000U0000300000P0000V0000700000X000000000
0@000000000000009@0000`0000:0000:`0001P0003Q0000P`000?H0002?00009@0000`000040000
:00000`0000800009@0000`000020000:00000`0000:00008@0000P0000N000060000>@000240000
m00008l0000U0000300000T0000U0000300000T0000D0000300000d0000B000030000040001D0000
F00004P0001m0000D`0008P000010000000P@[</8d;T0000Q0000080001<00000000000000000000
oooooooooom@0000<@0c00H0000600008P0000`0003ooooo8@0000P0000I000030000?ooo`0H0000
30000000000N0000600001X0000A00003@<008`1000R000030000?oooolH000030000000000I0000
30000?ooo`0U0000300000@0000W0000600000X000000000oooo0000000U0000300000X0000V0000
700000P0000000000@000000000000009@0000`000080000:`0001P0001@0P00O`0006H2002<0000
9@0000`000040000:00000`0000:00009@0000`000020000:00000`0000800008@0000P0000N0000
600005<200200000I08008`0000U0000300000T0000U0000300000T0000D0000300000d0000B0000
30000040001D0000F0000;L1001i0000`P4008D000010000000P@[</8d9C0P00P0000080001<0000
0000000000000000oooooooooom@0000<@0a00H0000600008P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R000030000?oooolH0000
30000000000I000030000?ooo`0U0000300000@0000V0000700000P0000000000@00000000000000
9@0000`0000800009@0000`000050020E`0002@0000C0000E0000=D1001E00000P000:l0G01a0U/0
9@0000`000020000:00000`0000800009@0000`0000400009P0001`0000800000000004000000000
000002D0000<0000200002D0000<00001@00P5L0000T0000M`4008l0001g0@00^@000080000C0[h0
4`:E02D0000<00002000P2P0000<0000200002L0000H00002000000000000000000002D0000<0000
200005H0000X0000LP4008P0001m0@00TP0000<0000I0YP050:>00h2V00U000030000080000U0000
300000@0000X0000300000P0000V0000700000P0000000000@000000000000009@0000`000080000
9@0000`000050020E`0002@0001e0@00hP0007D100010@000P0001421@4A0^L09@0000`000080020
:00000`0000800009`0001P00008000000000000000000009@0000`000080000EP0002P0001`0@00
f`0007/1003U00000`0001L2jP0B0^0030;Z02D0000<00000P0002D0000<0000100002P0000<0000
200002H0000L0000200000000001000000000000000U0000300000P0000U0000300000D0081G0000
900003l1000X0@00?`4004@100020000f`570M/1:`4U0000300000P0080X0000300000P0000W0000
600000P00000000000000000000U0000300000P0001F0000:00003X1000Q0@00A@4002/100030000
h@4^0M`1907F0Bh19@0000`0000200009@0000`000040000:00000`0000800009P0001`000080000
0000004000000000000002D0000<0000200002D0000<00001@00P5L0000T0000M04002P1001d0@00
A0400080000@0TL1408[0BD0000<00002000P2P0000<0000200002L0000H00002000000000000000
000002D0000<0000200005H0000X0000K`400241001j0@00:`4000<0000F0Rh1408T0@/2;P4U0000
30000080000U0000300000@0000X0000300000P0000V0000700000P0000000000@00000000000000
9@0000`0000800009@0000`000050020E`0002@0002]0@00:0400:d100140@000P0004T2A`590R/1
9@0000`000080020:00000`0000800009`0001P00008000000000000000000009@0000`000080000
EP0002P0002X0@008@400;<1000[0@000`0004l2;P5:0R@1A08^0BD0000<00000P0002D0000<0000
100002P0000<0000200002H0000L0000200000000001000000000000000U0000300000P0000W0000
600000X000000000oooo0000000U0000300000X0000[000060000:L0003S0@00S0800?`2000U0000
30000080000X0000300000P0000U0000300000@0000X0000300000X0000Q0000200001h0000H0000
Z`000>@100290P00o08002D0000<00001`0001@0000<00003@000180000<00000@0005@0001D0000
fP400502003V0@00I@80004000000212/b`S@WH2001=0P000@0004`00000000000000000003ooooo
oooooe00001@00003@0005@0001D0000f`4006P2003V0@00O@80004000000212/b`S@WL2001U0P00
0@0004`00000000000000000003ooooooooooe00001D0000300005@0001D0000fP400802003V0@00
U@80004000000212/b`S@WH2001m0P000@0004`00000000000000000003ooooooooooe00001C0000
3@000280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000040000
9`0001P0000:000000000?ooo`0000009@0000`0000:00009P0001`0000800000000004000000000
000002D0000<0000200002/0000H0000_P400=02001V0P00l@8002D0000<0000100002P0000<0000
2P0002D0000<00000P0002P0000<0000200002L0000H000020000000003oool0000002D0000<0000
200002H0000L00002P0000000001000000000000000U0000300000X0000[000060000<0000190P00
k0000?42000U0000300000@0000X0000300000P0000U000030000080000X0000300000X0000V0000
700000X0000000000@000000000000009@0000`0000:00009@0000`000050020E`0002@0001H0000
iP8001l1003V0P000P000;/1h@;d0>429@0000`000080020:00000`0000:00009`0001P0000:0000
00000000000000009@0000`0000:0000EP0002P0001@0000h@8005/0003]0P000`000?L0g0;/0>82
m`3W0RD0000<00000P0002D0000<0000100002P0000<00002P0002L0000H00002P000000003oool0
000002D0000<00002P0002H0000L0000200000000001000000000000000U0000300000P0000[0000
60000;d1002>0P00IP800:l2000U0000300000@0000X0000300000X0000U000030000080000X0000
300000P0000W0000600000P000000000oooo0000000U0000300000P0000V0000700000X000000000
0@000000000000009@0000`0000:0000:`0001P0002o0@00B08006D2001Y0P009@0000`000040000
:00000`0000800009@0000`000020000:00000`0000:00009P0001`0000:00000000004000000000
000002D0000<00002P0002D0000<00001@00P5L0000T0000F0400=D2001H0@00n0800080003d0M02
m07b0RD0000<00000P0002P0000<00002P0002D0000<0000100002H0000L00002P00000000010000
00000000000U0000300000X0000U0000300000D0081G000090000901003F0P00T0400?P200020000
;0;A0R`2lP8U000030000080000X0000300000X0000U0000300000@0000W0000600000X000000000
oooo0000000U0000300000X0000V0000700000P0000000000@000000000000009@0000`000080000
:`0001P0002m0@00mP4006H2000G0P009@0000`000040000:00000`0000:00009@0000`000020000
:00000`0000800009`0001P00008000000000?ooo`0000009@0000`0000800009P0001`0000:0000
0000004000000000oooo02D0000<00002P0002/0000H0000c`400=L2003Z0@00jP8002D0000<0000
100002P0000<0000200002D0000<00000P0002P0000<00002P000240000800007P0001P0003B0@00
f0800>P1003Z0P009@0000`0000500009@0000`0000300009@0000`0000500009@0000`000030000
9@0000`000050000500000`0000=00004P0000`000010000E00005P0000f0@00g`800441003^0P00
0@00000084:c;2=2dP400=X200020000C00000000000000000000?ooooooooooD0000440B@090000
0`0002D0000<00000`0005@0001D0000@P400>D200160@00k`80004000000212/b`S@]h1003P0P00
0@0004`00000000000000000003ooooooooooe00000c00001@000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P0000:000000000?ooo`000000
9@0000`0000:00009P0001`0000800000000004000000000oooo02D0000<0000200002/0000H0000
1@800=L2000O0P00jP8002D0000<0000100002P0000<00002P0002D0000<00000P0002P0000<0000
20000240000800007P0001P000080P00f08001d2003Z0P009@0000`0000500009@0000`000030000
9@0000`0000500009@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000
E00005P0001/0@00g`8007L1003^0P000@00000084:c;2=220800=X200020000C000000000000000
00000?ooooooooooD0000440B@0900000`0002D0000<00000`0005@0001D0000N0400>D2001l0@00
k`80004000000212/b`S@Q@2003P0P000@0004`00000000000000000003ooooooooooe00000b0000
1@000280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000040000
9`0001P00008000000000?ooo`0000009@0000`0000800009P0001`0000:00000000004000000000
oooo02D0000<00002P0002/0000H0000?@800=T2001E0P00k08002D0000<0000100002P0000<0000
200002D0000<00000P0002P0000<00002P000240000800007P0001P000100P00fP8005<2003/0P00
9@0000`0000500009@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000
500000`0000=00004P0000`000010000E00005P0002T0@00h@800:l1003`0P000@00000084:c;2=2
@0800=`200020000C00000000000000000000?ooooooooooD0000440B@0900000`0002D0000<0000
0`0005@0001D0000/0400>L2002d0@00l@80004000000212/b`S@T`2003R0P000@0004`000000000
00000000003ooooooooooe00000a00001@000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P0000:000000000?ooo`0000009@0000`0000:0000
9P0001`0000800000000004000000000oooo02D0000<0000200002/0000H00001P8009@2000Q0P00
Y`8002D0000<0000100002P0000<00002P0002D0000<00000P0002P0000<00002000024000080000
7P0001P000090P00U@8001l2002W0P009@0000`0000500009@0000`0000300009@0000`000050000
9@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000E00005P0001]0@00
V`8007X1002Z0P000@00000084:c;2=22@8009L200020000C00000000000000000000?oooooooooo
D0000680HP0700001`0002D0000<00000`0005@0001D0000N`400:42001o0@00ZP80004000000212
/b`S@QL2002M0P000@0004`00000000000000000003ooooooooooe00000a00001@000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009`0001P000080000
00000?ooo`0000009@0000`0000800009P0001`0000:00000000004000000000oooo02D0000<0000
2P0002/0000H00000`8004l2000O0P00HP8002D0000<0000100002P0000<0000200002D0000<0000
0P0002P0000<00002P000240000800007P0001P000060P00D08001d2001R0P009@0000`000050000
9@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000500000`0000=0000
4P0000`000010000E00005P0001Z0@00E@8007/1001T0P000@00000084:c;2=21P80058200020000
C00000000000000000000?ooooooooooD0000480@P0900002@0002D0000<00000`0005@0001D0000
O04005/200200@00I080004000000212/b`S@QP2001H0P000@0004`00000000000000000003ooooo
oooooe00000a00001@000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P0000:000000000?ooo`0000009@0000`0000:00009P0001`000080000
0000004000000000oooo02D0000<0000200002/0000H00001@800?X1000Q0P00408002D0000<0000
100002P0000<00002P0002D0000<00000P0002P0000<000020000240000800007P0001P000080P00
n`4001l2000@0P009@0000`0000500009@0000`0000300009@0000`0000500009@0000`000030000
9@0000`000050000500000`0000=00004P0000`000010000E00005P0001/0@00oP4007/1000=0P00
0@00000084:c;2=220800?d100020000C00000000000000000000?ooooooooooD00004D0E0090000
1`0002D0000<00000`0005@0001D0000O04000@200200@003`80004000000212/b`S@QP200030P00
0@0004`00000000000000000003ooooooooooe00000b00001@000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`000000
9@0000`0000800009P0001`0000:00000000004000000000000002D0000<00002P0002/0000H0000
L04004T2002M0@00JP8002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<0000
2P0002L0000H00002P000000003oool0000002D0000<00002P0002H0000L00002000000000010000
00000000000U0000300000P0000[000060000701002=0P00W@400:h2000U0000300000@0000X0000
300000X0000U000030000080000X0000300000P0000W0000600000P000000000oooo0000000U0000
300000P0000V0000700000X0000000000@000000000000009@0000`0000:0000:`0001P0000?0@00
B@8004T1001Z0P009@0000`000040000:00000`0000800009@0000`000020000:00000`0000:0000
9`0001P0000:000000000?ooo`0000009@0000`0000:00009P0001`0000800000000004000000000
000002D0000<0000200002/0000H00003`4008d200190@00[P8002D0000<0000100002P0000<0000
2P0002D0000<00000P0002P0000<0000200002H0000L0000200000000001000000000000000U0000
300000P0000U0000300000D0081G000090000>`0001^0P007P40090200020000R06<0[X1J`8U0000
300000P0080X0000300000P0000W0000600000P00000000000000000000U0000300000P0001F0000
:00001T1001[0P00904007H200030000^P5c0/01J0:e0FX29@0000`0000200009@0000`000040000
:00000`0000800009P0001`0000800000000004000000000000002D0000<0000200002D0000<0000
1@00P5L0000T0000j`0001/2000N0@00B@80008000270DL2^P4J0RD0000<00002000P2P0000<0000
200002L0000H00002000000000000000000002D0000<0000200005H0000X0000604001L2000T0@00
8`8000<0002l0B42`04F0[@16@8U000030000080000U0000300000@0000X0000300000P0000V0000
700000P0000000000@000000000000009@0000`0000800009@0000`000050020E`0002@0001J0000
GP800700001N0P000P0000`1F`;f05/29@0000`000080020:00000`0000800009`0001P000080000
00000000000000009@0000`000080000EP0002P0001B0000F@8005d0001T0P000`000?T0EP;^05`2
n@1Q0RD0000<00000P0002D0000<0000100002P0000<0000200002H0000L00002000000000010000
00000000000U0000300000P0000U0000300000D0081G0000900005T0002R0P00K`000:8200020000
2`6N0_D0WP8U0000300000P0080X0000300000P0000W0000600000P00000000000000000000U0000
300000P0001F0000:0000580002M0P00G0000:P200030000n02I0^h0WP;h0:@29@0000`000020000
9@0000`000040000:00000`0000800009`0001P00008000000000?ooo`0000009@0000`000080000
9P0001`0000:00000000004000000000000002D0000<00002P0002/0000H0000`@000?@1003^0000
5@8002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<00002P0002L0000H0000
2P000000003oool0000002D0000<00002P0002H0000L0000200000000001000000000000000U0000
300000P0000[0000600000l1003d0@00A`4001D2000U0000300000@0000X0000300000X0000U0000
30000080000X0000300000P0000W0000600000P000000000oooo0000000U0000300000P0000V0000
700000X0000000000@000000003oool09@0000`0000:0000:`0001P0000I0@00n0400441000>0P00
9@0000`000040000:00000`0000800009@0000`000020000:00000`0000:00008@0000P0000N0000
600001`1003i0@00?`4000h2000U0000300000D0000U0000300000<0000U0000300000D0000U0000
300000<0000U0000300000D0000D0000300000d0000B000030000040001D0000F0000800003l0@00
S`0000/200010000000P@[</8d8L0@00n`400080001<00000000000000000000oooooooooom@0000
A@1D00T0000700009@0000`000030000E0000600002@00000P8009h0000=0P000@00000084:c;2=2
;040004200030000C00000000000000000000?ooooooooooE00007<0I@1a00001@0000D000050000
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A0000
3@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000
600000X000000000oooo0000000U0000300000X0000V0000700000P0000000000@000000003oool0
9@0000`000080000:`0001P0000F0@00CP8003h1001T0P009@0000`000040000:00000`0000:0000
9@0000`000020000:00000`0000800008@0000P0000N0000600001T1001?0P00?04006@2000U0000
300000D0000U0000300000<0000U0000300000D0000U0000300000<0000U0000300000D0000D0000
300000d0000B000030000040001D0000F00007d0001D0P00SP0006<200010000000P@[</8d8I0@00
D@800080001<00000000000000000000oooooooooom@0000@P1200T0000900009@0000`000030000
E0000600002?0000FP8009d0001U0P000@00000084:c;2=2:`4005L200030000C000000000000000
00000?ooooooooooE00007<0I@1a00001@0000D0000500008P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R000030000?oooolH0000
30000000000I000030000?ooo`0U0000300000@0000W0000600000P000000000oooo0000000U0000
300000P0000V0000700000X0000000000@000000003oool09@0000`0000:0000:`0001P0000D0@00
TP8003`1002X0P009@0000`000040000:00000`0000800009@0000`000020000:00000`0000:0000
8@0000P0000N0000600001L1002C0P00>P400:P2000U0000300000D0000U0000300000<0000U0000
300000D0000U0000300000<0000U0000300000D0000D0000300000d0000B000030000040001D0000
F00007/0002I0P00R0000:P200010000000P@[</8d8G0@00U@800080001<00000000000000000000
oooooooooom@0000HP1R00L0000700009@0000`000030000E000060000290000W`8009L0002Z0P00
0@00000084:c;2=29@4009/200030000C00000000000000000000?ooooooooooE00007<0I@1a0000
1@0000D0000500008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001X0000A00003@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000
300000@0000W0000600000X000000000oooo0000000U0000300000X0000V0000700000P000000000
0@000000003oool09@0000`000080000:`0001P000320000T0800>X0002V0P009@0000`000040000
:00000`0000:00009@0000`000020000:00000`0000800008@0000P0000N000060000<D0002A0P00
j0000:H2000U0000300000D0000U0000300000<0000U0000300000D0000U0000300000<0000U0000
300000D0000D0000300000d0000B000030000040001D0000F00002T0002G0P00>0000:H200010000
000P@[</8d;50000T`800080001<00000000000000000000oooooooooom@0000C01>00L000090000
9@0000`000030000E00005P0000i0000W@8004@0002X0P000@00000084:c;2=2e@0009T200020000
C00000000000000000000?ooooooooooD00005@0B00500001`000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`000000
9@0000`0000800009P0001`0000:00000000004000000000oooo02D0000<00002P0002/0000H0000
``000?T1003[00003`8002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<0000
2P000240000800007P0001P000360000nP400>T0000?0P009@0000`0000500009@0000`000030000
9@0000`0000500009@0000`0000300009@0000`000050000500000`0000=00004P0000`000010000
E00005P0000Z0000o@4003T0000<0P000@00000084:c;2=2aP000?`100020000C000000000000000
00000?ooooooooooD00004`0CP0700002@0002D0000<00000`0005@0001H0000>P0000<200140000
3P80004000000212/b`S@]H000020P000P0004`00000000000000000003ooooooooooe00001505@0
1P0000D0000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
6P000140000=0`00S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
100002H0000L00002P0000000001000000000000000U0000300000X0000U0000300000D0081G0000
900005X000060P00L00000H20002000030450_H01@8U0000300000P0080X0000300000X0000W0000
600000X00000000000000000000U0000300000X0001F0000:000058000010P00G@0000`200030000
n@000^h01P;i00/29@0000`0000200009@0000`000040000:00000`0000:00009`0001P0000:0000
00000?ooo`0000009@0000`0000:00009P0001`0000800000000004000000000oooo02D0000<0000
200002/0000H0000M@400502002A0@00H`8002D0000<0000100002P0000<00002P0002D0000<0000
0P0002P0000<000020000240000800007P0001P0001h0@00D@8008l1001S0P009@0000`000050000
9@0000`0000300009@0000`0000500009@0000`0000300009@0000`000050000500000`0000=0000
4P0000`000010000E00005P0003L0000EP800>d0001U0P000@00000084:c;2=2N04005<200020000
C00000000000000000000?ooooooooooD0000480@P0900002@0002D0000<00000`0005@0001D0000
kP0005`2003b0000I@80004000000212/b`S@XX1001I0P000@0004`00000000000000000003ooooo
oooooe00000b00001@000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P00008000000000?ooo`0000009@0000`0000800009P0001`0000:0000
0000004000000000oooo02D0000<00002P0002/0000H0000N0400982002C0@00Y@8002D0000<0000
100002P0000<0000200002D0000<00000P0002P0000<00002P000240000800007P0001P0001k0@00
T`800941002U0P009@0000`0000500009@0000`0000300009@0000`0000500009@0000`000030000
9@0000`000050000500000`0000=00004P0000`000010000E00005P0003O0000V@800>`0002X0P00
0@00000084:c;2=2N`4009D200020000C00000000000000000000?ooooooooooD0000680HP070000
1`0002D0000<00000`0005@0001D0000k@0009l2003a0000Z080004000000212/b`S@XT1002K0P00
0@0004`00000000000000000003ooooooooooe00000b00001@000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P0000:000000000?ooo`000000
9@0000`0000:00009P0001`0000800000000004000000000000002D0000<0000200002/0000H0000
eP000><2003/0000l08002D0000<0000100002P0000<00002P0002D0000<00000P0002P0000<0000
20000240000800007P0001P0003I0000i0800>X0003`0P009@0000`0000900009@0000`000090000
500000`0000=00004P0000`000010000E00005P0000m0000jP8004P0003e0P000@00000084:c;2=2
f@000>@200020000C00000000000000000000?ooooooooooD0000340<00600001P000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009`0001P000080000
00000?ooo`0000009@0000`0000800009P0001`0000:00000000004000000000000002D0000<0000
2P0002/0000H0000G0800>@2001V0P00l08002D0000<0000100002P0000<0000200002D0000<0000
0P0002P0000<00002P000240000800007P0001P0001O0P00i@8006@2003`0P009@0000`000090000
9@0000`0000900009@0000`000090000500000`0000=00004P0000`000010000E00005@000330@00
j`800<L1003e0P000@00000084:c;2=2G`800>D200010000C00000000000000000000?oooooooooo
D0000340000600008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001X0000A00003@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000
300000@0000W0000600000X000000000oooo0000000U0000300000X0000V0000700000P000000000
0@000000000000009@0000`000080000:`0001P0000R0P00i08002`2003`0P009@0000`000040000
:00000`0000:00009@0000`000020000:00000`0000800008@0000P0000N0000600002D2003U0P00
:P800?02000U0000300000T0000U0000300000T0000U0000300000T0000D0000300000d0000B0000
30000040001D0000E00008T1003[0P00S@400?D200010000000P@[</8d8U0P00i@800040001<0000
0000000000000000oooooooooom@0000<P0000H0000R000030000?oooolQ0000200001T0000<0000
oooo01P0000<0000000001h0000H00006P000140000=0`00S0400280000<0000oooooaP0000<0000
000001T0000<0000oooo02D0000<0000100002L0000H000020000000003oool0000002D0000<0000
200002H0000L00002P0000000001000000000000000U0000300000X0000[000060000>T1003T0P00
l`400?02000U0000300000@0000X0000300000P0000U000030000080000X0000300000X0000Q0000
200001h0000H0000k0400>D2003a0@00l08002D0000<00002@0002D0000<00002@0002D0000<0000
2@0001@0000<00003@000180000<00000@0005@0001D0000D0400>/2001D0@00m@80004000000212
/b`S@^`1003U0P000@0004`00000000000000000003ooooooooooe00000c00001P000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000400009`0001P0000:0000
00000?ooo`0000009@0000`0000:00009P0001`0000800000000004000000000000002D0000<0000
200002/0000H0000F`800:82001U0P00[P8002D0000<0000100002P0000<00002P0002D0000<0000
0P0002P0000<000020000240000800007P0001P0001N0P00X`8006<2002^0P009@0000`000090000
9@0000`0000900009@0000`000090000500000`0000=00004P0000`000010000E00005@000320@00
Y`800<H1002a0P000@00000084:c;2=2GP800:<200010000C00000000000000000000?oooooooooo
D00003@0000600008P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001X0000A00003@<008`1000R000030000?oooolH000030000000000I000030000?ooo`0U0000
300000@0000W0000600000P000000000oooo0000000U0000300000P0000V0000700000X000000000
0@000000000000009@0000`0000:0000:`0001P0001K0P00G@8006D2001Y0P009@0000`000040000
:00000`0000800009@0000`000020000:00000`0000:00008@0000P0000N0000600005h2001N0P00
H`8006T2000U0000300000T0000U0000300000T0000U0000300000T0000D0000300000d0000B0000
30000040001D0000E0000<81001Q0P00aP4006/200010000000P@[</8d9N0P00GP800040001<0000
0000000000000000oooooooooom@0000=`0000H0000R000030000?oooolQ0000200001T0000<0000
oooo01P0000<0000000001h0000H00006P000140000=0`00S0400280000<0000oooooaP0000<0000
000001T0000<0000oooo02D0000<0000100002L0000H00002P000000003oool0000002D0000<0000
2P0002H0000L0000200000000001000000000000000U0000300000P0000[000060000981001L0P00
W@4006X2000U0000300000@0000X0000300000X0000U000030000080000X0000300000P0000Q0000
200001h0000H0000U@4005d2002K0@00JP8002D0000<00002@0002D0000<00002@0001@0000<0000
3@000180000<00000@0005@0001D0000n@000602003n0000K080004000000212/b`S@YD1001M0P00
0@0004`00000000000000000003ooooooooooe00000h00001P000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009`0001P00008000000000?ooo`000000
9@0000`0000800009P0001`0000:00000000004000000000000002D0000<00002P0002/0000H0000
T@400:02002M0@00[P8002D0000<0000100002P0000<0000200002D0000<00000P0002P0000<0000
2P000240000800007P0001P0002D0@00X@8009/1002^0P009@0000`0000900009@0000`000090000
500000`0000=00004P0000`000010000E00005@0003h0000Y@800?d0002a0P000@00000084:c;2=2
U0400:4200010000C00000000000000000000?ooooooooooD00003D0000600008P0000`0003ooooo
8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R0000
30000?oooolH000030000000000I000030000?ooo`0U0000300000@0000W0000600000X000000000
oooo0000000U0000300000X0000V0000700000P0000000000@000000000000009@0000`000080000
:`0001P0000l0@00G@8004P1001Z0P009@0000`000040000:00000`0000:00009@0000`000020000
:00000`0000800008@0000P0000N0000600003l1001N0P00AP4006X2000U0000300000T0000U0000
300000T0000D0000300000d0000B000030000040001D0000E0000:<0001Q0P00Z00006`200010000
000P@[</8d8o0@00GP800040001<00000000000000000000oooooooooom@0000>@0000H0000R0000
30000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H00006P000140000=0`00
S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000100002L0000H0000
20000000003oool0000002D0000<0000200002H0000L00002P0000000001000000000000000U0000
300000X0000[0000600003d1002P0P00B@400:h2000U0000300000@0000X0000300000P0000U0000
30000080000X0000300000X0000Q0000200001h0000H0000@0400:4200170@00[P8002D0000<0000
2@0002D0000<00002@0001@0000<00003@000180000<00000@0005@0001D0000Y0000:D2002Y0000
/@80004000000212/b`S@T01002Q0P000@0004`00000000000000000003ooooooooooe00000f0000
1P000280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000040000
9`0001P0000:000000000?ooo`0000009@0000`0000:00009P0001`0000800000000004000000000
000002D0000<0000200002/0000H0000>`4000`2001A0@006@8002D0000<0000100002P0000<0000
2P0002D0000<00000P0002P0000<000020000240000800007P0001P0000n0@003@8004l1000I0P00
9@0000`0000900009@0000`000090000500000`0000=00004P0000`000010000E00005P0002R0000
3P800:d0000I0P000@00000084:c;2=2?P4000d200020000C00000000000000000000?oooooooooo
D0000340<P0600001P000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P00008000000000?ooo`0000009@0000`0000800009P0001`0000:0000
0000004000000000000002D0000<00002P0002/0000H0000h00000d2003e00006@8002D0000<0000
100002P0000<0000200002D0000<00000P0002P0000<00002P000240000800007P0001P0003S0000
3P800?<0000I0P009@0000`0000900009@0000`000090000500000`0000=00004P0000`000010000
E00005P0001700003`800580000I0P000@00000084:c;2=2h`0000h200020000C000000000000000
00000?ooooooooooD0000340<`0600001P000280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000400009`0001P0000:000000000?ooo`0000009@0000`0000:0000
9P0001`0000800000000004000000000000002D0000<0000200002/0000H0000C`8000T2001U0P00
5P8002D0000<0000100002P0000<00002P0002D0000<00000P0002P0000<00002000024000080000
7P0001P0001B0P002P8006<2000F0P009@0000`0000900009@0000`000090000500000`0000=0000
4P0000`000010000E00005P0002f0@002`800<41000F0P000@00000084:c;2=2DP8000X200020000
C00000000000000000000?ooooooooooD0000340<@0600001P000280000<0000ooooob4000080000
6@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@008P0000`0003ooooo
600000`0000000006@0000`0003oool09@0000`0000400009P0001`0000800000000004000000000
000002D0000<0000200002D0000<00001@00P5L0000T00004P000>D1003D0@00iP400080002^0>H1
L0;U0BD0000<00000P0002P0000<0000200002D0000<0000100002H0000L00002000000000010000
00000000000U0000300000P0000U0000300000D0081G0000900007H1000Q0P00MP4004X200020000
4P980Q827`8U0000300000P0080X0000300000P0000W0000600000P00000000000000000000U0000
300000P0001F0000:0000741000I0P00O04002@200030000608R0Q82608=0R829@0000`000020000
9@0000`000040000:00000`0000800009P0001`0000800000000004000000000000002D0000<0000
200002D0000<00001@00P5L0000T0000M04007@2001d0@00T`800080000@0Xl2409a0RD0000<0000
2000P2P0000<0000200002L0000H00002000000000000000000002D0000<0000200005H0000X0000
K`4006d2001j0@00M`8000<0000F0W@2409Z0P/2M08U000030000080000U0000300000@0000X0000
300000P0000V0000700000P0000000000@000000000000009@0000`0000800009@0000`000050020
E`0002@0000n0@00^P8003h1003F0P000P000=X1d@;J0KD29@0000`000080020:00000`000080000
9`0001P00008000000000000000000009@0000`000080000EP0002P0000i0@00/P8004@1002m0P00
0`000>01^0;J0Jh2e@6h0RD0000<00000P0002D0000<0000100002P0000<0000200002H0000L0000
200000000001000000000000000U0000300000P0000U0000300000D0081G0000900007<1002j0P00
L`400=H2000200003`;A0Pl2]@8U0000300000P0080X0000300000P0000W0000600000P000000000
00000000000U0000300000P0001F0000:00006h1002b0P00N@400;d2000300005@:h0Q02[P8:0[P2
9@0000`0000200009@0000`000040000:00000`0000800009P0001`0000800000000004000000000
000002D0000<0000200002D0000<00001@00P5L0000T0000[0400;X2002/0@00eP80008000180]42
B0:e0RD0000<00002000P2P0000<0000200002L0000H00002000000000000000000002D0000<0000
200005H0000X0000Y`400;82002b0@00_@8000<0001>0[P2B0:^0T<2^08U000030000080000U0000
300000@0000X0000300000P0000W0000600000P000000000oooo0000000U0000300000P0000V0000
700000X0000000000@000000003oool09@0000`0000:0000:`0001P0000I0@00a04003X1003J0@00
9@0000`000040000:00000`0000800009@0000`000020000:00000`0000:00008@0000P0000N0000
600001`100350@00>0400=X1000U0000300000D0000U0000300000<0000U0000300000D0000U0000
300000<0000U0000300000D0000D0000300000d0000B000030000040001D0000E000080000370@00
QP000=H100010000000P@[</8d8L0@00a`400040001<00000000000000000000oooooooooom@0000
L`0000L0000U0000300000<0001D0000E00008H0003=0@00R@000=P100010000000P@[</8d8S0@00
c@400040001<00000000000000000000oooooooooom@0000M00000<0000R000030000?oooolQ0000
200001T0000<0000oooo01P0000<0000000001h0000H00006P000140000=0`00S0400280000<0000
oooooaP0000<0000000001T0000<0000oooo02D0000<0000100002H0000L00002P00000000010000
00000000000U0000300000X0000W0000600000P000000000oooo0000000U0000300000P0001F0000
>00006h0002k0@00N@000>@1000700002P750@d1a@4=0N@14P7T0A81a@4E0LD13`6k0BD0000<0000
0P0002P0000<00002P0002D0000<0000100002P0000<0000200002D0000<00002000P2L0000H0000
20000000003oool0000002D0000<0000200005H0000h0000004006l1000?0@00i@4000L0002L0LP1
X0780J01L@6W0G41Y`780J/1b06S0ND19@0000`0000200009@0000`000040000:00000`000080000
9@0000`0000800209`0001P00008000000000000000000009@0000`0000800004`0000`000020000
EP0004`000000@00b04000@1003<0@00300009`1b06L0LP1W0780I`1c06M0L`1W@7<0Id1b06L0LP1
W0790J01b@6P0LP1X0780EH0000d000010400<4100050@00a@4000H0002P0LD1X0750J41a@6Q0L41
X0710J01`@5F0000=00000@1002j0@001@400;h100060000X06n0J01_P6Q0Kh1X@6j0J01^P6P0KX1
EP0003@000040@00/P4000D1002g0@001P000:01]`6P0KL1X@6g0J41/`6P0K<1X06c0EH0000d0000
10400:/100050@00[`4000H0002P0K01X06`0J41/06Q0J`1X06/0J01[05F0000=00000@1002T0@00
1@400:P100060000X06Y0J01Z@6Q0JT1X@6U0J01Y@6P0JD1EP0003@000040@00W@4000D1002Q0@00
1P000:01XP6P0J81X@6R0J41WP6P0Ih1X06N0EH0000d0000104009H100050@00VP4000H0002P0I/1
X06K0J41V`6Q0IL1X06G0J01U`5F0000=00000@1002?0@001@4009<100060000X06D0J01U06Q0I@1
X@6@0J01T06P0I01EP0003@000040@00R04000D1002<0@001P000:01S@6P0Hd1X@6=0J41R@6P0HT1
X0690EH0000d00001040084100050@00Q@4000H0002P0HH1X0660J41QP6Q0H81X0620J01PP5F0000
=00000@1001i0@001@4007d100060000X05o0J01O`6Q0Gl1X@5k0J01N`6P0G/1EP0003@000040@00
LP4000D1001f0@001P000:01N06P0GP1X@5h0J41M06P0G@1X05d0EH0000d0000104006l100080@00
L04000H0002P0G41X05a0J01LP6T0G81Y05a0J@1L@5F0000=00000/1001_0@00304007<100060000
Z05a0JL1L@6W0G41Y`5e0JL1M@6X0GD1EP0003@0000;0@00M@4000`1001j0@001P000:P1N06W0GL1
Y`5h0JL1O06W0G`1Z05l0EH0000d00002`4007`1000<0@00PP4000H0002X0Gl1Y`5n0JL1O`6W0H<1
Y`630JP1P`5F0000=00000/100240@00304008T100060000Z0660JL1Q@6W0HH1Y`6:0JL1RP6X0HX1
EP0003@0000;0@00R`4000`1002@0@001P000:P1S@6W0H`1Y`6=0JL1T@6W0I41Z06A0EH0000d0000
2`400981000<0@00U`4000H0002X0I@1Y`6C0JL1U06W0IP1Y`6H0JP1V05F0000=00000/1002I0@00
304009h100060000Z06K0JL1VP6W0I/1Y`6O0JL1W`6X0Il1EP0003@0000;0@00X04000`1002U0@00
1P000:P1XP6W0J41Y`6R0JL1YP6W0JH1Z06V0EH0000d00002`400:L1000<0@00[04000H0002X0JT1
Y`6X0JL1Z@6W0Jd1Y`6]0JP1[@5F0000=00000/1002^0@0030400;<100060000Z06`0JL1[`6W0K01
Y`6d0JL1]06X0K@1EP0003@0000;0@00]P4000`1002k0@001P000:P1]`6W0KH1Y`6g0JL1^`6W0K/1
Z06k0EH0000d00002`400;d1000<0@00`P4000H0002X0Kh1Y`6m0JL1_P6W0L81Y`720JP1`P5F0000
B00000/100340@0030400<T1000;0000Z0750JL1a06W0LD1Y`780JL1b@6X0LT1Z0780JP1b06W0LP1
Y`780JP1b05F0000=00000d100380@0040400<`100060000[0780J/1b06[0LP1Z@7<0JX1c06Z0L`1
EP0003@0000<0@00cP4000h1003C0@001P000:X1c`6Y0Lh1Z@7?0JP1d`6X0M<1Z@7C0EH0000d0000
2P400=D1000<0@00fP4000H0002X0MD1Y`7E0JL1e@6V0MT1YP7J0JL1f@5F0000=00000P1003L0@00
2P400>4100060000YP7L0JD1g06U0M`1Y07P0J@1h@6U0N01EP00050000060@00hP4000P1003U0@00
3@000:@1h`6T0N81X`7S0J<1i@6S0ND1Y07U0J<1h`6S0N<1XP7S0J<1i@6S0ND1X`7U0J@1i@5F0000
=00000@1003L0@001P400>4100060000X@7P0J81h@6R0N01X@7L0J41g06P0M`1EP0003@000030@00
e@4000D1003J0@001P000:01f@6P0MX1X@7I0J01eP6O0MD1W`7F0EH0000d00000@400<h100030@00
d`4000H0002N0M<1W`7C0Il1d`6N0Ll1WP7>0Id1c`4C000030000040000U000030000080000U0000
300000@0000X0000300000P0000V0000700000P0000000000@000000000000009@0000`000080000
9@0000`000050020E`0002@0001P0@00;`0009h1000_00000P000?`1=`0j0SL09@0000`000080020
:00000`0000800009`0001P00008000000000000000000009@0000`000080000EP0002P0002L0@00
:P000:H1000e00000`0003P2?@120SP0>08b02D0000<00000P0002D0000<0000100002P0000<0000
200002H0000L0000200000000001000000000000000U0000300000P0000U0000300000D0081G0000
<0000:4100330@00hP4000P200050000IP870Wh21`9n0]P1?@;H0Cd2``4U0000300000P0080X0000
300000P0000W0000600000P00000000000000000000U0000300000P0001F0000:00009`1002l0@00
Y`400<H100030000@`;60Ch2_04h0/H19@0000`0000200009@0000`000040000:00000`000080000
9P0001`0000800000000004000000000000002D0000<0000200002L0000H00002P000000003oool0
000002D0000<00002P0005H0001000002P4001/0000Y0@00>00000T000350CP0^`4_0;/1=02`0C@0
/04S0:H18`2V0C`0^`4l0;/1@00U000030000080000X0000300000P0000U0000300000@0000X0000
300000X0000V0000700000X0000000000@000000000000009@0000`0000:00009`0001P000080000
00000?ooo`0000009@0000`000080000EP0003P0003i00006`000101001C00001`0009D1C02K0D`0
V`4S0:H18`2V0D`0[05<0:01FP0U000030000080000X0000300000X0000U0000300000@0000X0000
300000P0000V0000700000P0000000000@000000000000009@0000`0000800009@0000`000050020
E`0002`0003;0@00MP0000D2002Z0@00100006L2O@2Q0Wd0X@:[0Fh2Z`4U0000300000P0080X0000
300000P0000W0000600000P00000000000000000000U0000300000P0001F0000:0000<X1002U0@00
e@400;0100030000L@:V0FH2[05a0[419@0000`0000200009@0000`000040000:00000`000080000
9`0001P00008000000000<30`00000009@0000`0000800009P0001`0000:00000000004000000000
000002D0000<00002P0002/0000H0000i`0009/1000j0@00^`4002D0000<0000100002P0000<0000
200002D0000<00000P0002P0000<00002P000240000800007P0001P0003Z0000W04003P1002k0@00
9@0000`0000600009@0000`000060000500000`0000=00004P0000`000010000E00009@0001B0000
XP4009/0002a0@000@00000084:c;2=2kP000:<1000<0000C00000000000000000000?oooooooooo
I0000480K`1T07T0801V06`0M@1Y06@0L`0P00T000080000200000L000040000100000@000080000
100000P00006000010000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000400009`0001P0000:000000000?ooo`0000009@0000`0000:00009P0001`000080000
0000004000000000oooo02D0000<0000200002/0000H0000TP4000T0002k0@008P0002D0000<0000
100002P0000<00002P0002D0000<00000P0002P0000<000020000240000800007P0001P0002F0@00
2P000;P1000R0000DP00070100080000l?ooo`000000000000000;`2000000001`008440LP1Y0640
K00000000000000000000000000000000000000000000000000000000000000000000000000001<0
Y4[;<=l>8@l8?Cd26`@006S>4`000000T1KdMaS?>`9>5_AgB0LE06XFm7O/3S0Q8<lk0R3?>`9X:C/2
J2Tk0P0000000000@P1_06@0N@0P06H0K01e06T0I01c0200YAo4MjDO0@0001D0[<dC0:DOa7NU7lAg
a?3mO`004`000000T1KdMc2U?09>5_Agf0LE06XFm7MjJKl7>:Dl0SRU?081800000000000002h??X6
1000020000000000YAo4MjDOa7NU7`40000E0:c=4`2U7lAgYAo4MlC`oGl0h?eo0000000000000000
00000<8ma7L20000I7H02000000U0000300000P0001B0000L04000X0003`oooo0000000000000000
T04000000007000P@@1b06T0H@1/0000000000000000000000000000000000000000000000000000
000000000000000000000000a7NU7`40000E0:c=4`2U7lAgYAo4MlC`oGl001<00000090Fm7L`YC`2
CQKdMmP75@1Z5_AgNVVo1cRU?08hYC`20B00000000000000^3cj1P@0000P000000000:DOa7NU7lAg
YAl100005@2/cA<0YAo4MjDOa7O4l?eo003mO`0000000000000000000032?LAg0P0006Af00P00000
>:Dl0P4P0000000000000;PlnPH4000080000000002U7lAgYAo4MjDO0@0001D0[<dC0:DOa7NU7lAg
a?3mO`3PoGl000000000000000000000`Sg4M`80001TMP08000002D0000<00002P000580001`0@00
2`000?3oool0000000000000002@0@000@0000L002110780J@1Q06`0000000000000000000000000
0000000000000000000000000000000000000000000000000034MjDO0@0001D0[<dC0:DOa7NU7lAg
a?3mO`00oGl000000000000000000000`Sg4M`80001TMP08000003RU?081800000000000002h??X6
1000020000000000YAo4MjDOa7NU7`40000E0:c=4`2U7lAgYAo4MlC`oGl00?eo0000000000000000
00000<8ma7L20000I7H02000000hYC`20B00000000000000^3cj1P@0000P000000000:DOa7NU7lAg
YAl100005@2/cA<0YAo4MjDOa7O4l?eo0>3mO`0000000000000000000032?LAg0P0006Af00P00000
9@0000`0000;00009@0000`0000:00009@0000`0000800009@0000`0000:00009@0000`000080000
500000`0000=00004P0000`000010000E00005@0003j00000P0000<1000D00000@00000084:c;2=2
UP4000/000010000C00000000000000000000?ooooooooooD0000680000:00009@0000`0000:0000
E00005@000040@000P0000P1000C00000@00000084:c;2=2X04000/000010000C000000000000000
00000?ooooooooooD00002P0000500009@0000`0000;0000E00005@000090@000@0000`1000C0000
0@00000084:c;2=2Y@4000X000010000C00000000000000000000?ooooooooooD00007@000040000
9@0000`0000:0000E00005@0000@0@000P0001@1000C00000@00000084:c;2=2[04000/000010000
C00000000000000000000?ooooooooooD00002T0000500008P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R000030000?oooolH0000
30000000000I000030000?ooo`0U0000300000@0000H000030000000000I000030000?ooo`0U0000
300000@0000R000030000?oooolU0000300000L0080U000030000000080`0000300000l0080U0000
300000d0081;00004000000000050000:00000`000020000:00000`000050000:00000`000040000
:00000`000030000:00000`000060000:00000`000070000:00000`000090000:00000`000080000
:00000`0000:0000:00000`0000;00009@0000`0000000209@0000`0000700208P0000`0003ooooo
9@0000`0000=0020:00000`0000100008P0000`0003ooooo8P0000`0003oooooAP0003P0000/0000
ADe6:bI0000@000010000000000Q@0L0300000000004@0003000000000160000500000P00017A4U3
0`0001P0000<0000000001T0000<0000oooo02D0000<00000000P2D0000<00003@00P280000<0000
ooooodH0000d0000:00004E=AR/Z@000900001P00000080o0000P0000800080o0000P000080Q0000
20000680000<00000@0004`0001T00002`00000000090P000P<000/000000000o`4000<3000Y0:X0
000000000000080o000000000000080o0000000000000000000000000000000000000000000R0000
30000?oooom60000700001000015CDH[0T0000`0000000003P0001@000000000400001@0
\>"], "Text",
 ImageSize->{384.875, 581.188},
 ImageMargins->{{0, 0}, {0, 63}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
 StyleBox["Figure 1:",
  FontWeight->"Bold"],
 " Respiratory tract model (ICRP66). "
}], "Text"],

Cell[TextData[{
 "The retention in each compartment as function of time is obtained with \
functions ",
 StyleBox["RespiratoryTract",
  FontWeight->"Bold"],
 ". These functions compute the retention  in  Respiratory Tract \
compartments, Lungs and ST (Stomach)  an  B (transferred to blood directly \
from Respiratory Tract) after a single intake. ST and B are considered as \
trap compartments\n"
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Function for solving the ICRP 66 model ", "SubsubsectionIcon"],

Cell[TextData[{
 "Here are included the specific functions used for evaluated the respiratory \
tract contents ",
 StyleBox["for persons exposed to inhalation ",
  CharacterEncoding -> "WindowsANSI"],
 "of aerosols as function ",
 StyleBox["of the activity median aerodynamic diameter (AMAD).",
  CharacterEncoding -> "WindowsANSI"]
}], "Text"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{
   StyleBox["RespiratoryTract", "Input"], 
   StyleBox["[", "Input"], 
   StyleBox[
    RowBox[{
    "Intake", ",", " ", "IFD", " ", ",", " ", "FRA", ",", " ", "t", ",", " ", 
     "\[Lambda]", ",", " ", "options"}],
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"CompatibilityType"->0,
    "Masked"->False,
    "Outline"->False,
    "RotationAngle"->0,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Underline"->False}], 
   StyleBox["]", "Input"]}]]],
 " for one specific nuclide, gives the retention in compartments  of the \
respiratory tract (see fig.1) for  an intake",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", "I"}], TraditionalForm]]],
 " by inhalation. By default an acute intake is assumed. Other type of intake \
can be chosen with Options. For each type of intake mush be used a format for \
intake data input."
}], "DefinitionBox",
 CellTags->"Introduction"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{
   StyleBox["LungsRetention", "Input"], 
   StyleBox["[", "Input"], 
   StyleBox[
    RowBox[{
    "Intake", ",", " ", "IFD", " ", ",", " ", "FRA", ",", " ", "t", ",", " ", 
     "\[Lambda]", ",", " ", "options"}],
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"CompatibilityType"->0,
    "Masked"->False,
    "Outline"->False,
    "RotationAngle"->0,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Underline"->False}], 
   StyleBox["]", "Input"]}]]],
 " for one specific nuclide, gives the retention in Lungs for  an intake",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", "I"}], TraditionalForm]]],
 " by inhalation. By default an acute intake is assumed. Other type of intake \
can be chosen with Options. For each type of intake mush be used a format for \
intake data input."
}], "DefinitionBox",
 CellTags->"Introduction"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{
   StyleBox["qBfromRT", "Input"], 
   StyleBox["[", "Input"], 
   StyleBox[
    RowBox[{
     SubscriptBox["I", "0"], ",", " ", "IFD", " ", ",", " ", "FRA", ",", " ", 
     "t", ",", " ", "\[Lambda]", ",", " ", "options"}],
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"CompatibilityType"->0,
    "Masked"->False,
    "Outline"->False,
    "RotationAngle"->0,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Underline"->False}], 
   StyleBox["]", "Input"]}]]],
 " for one specific nuclide, gives the retention in compartments B (blood)   \
from the flow of the respiratory tract as function of time ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", "t"}], TraditionalForm]]],
 ", in days,  after an acute intake ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["I", "0"], " "}]]],
 "in ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 "=0, B -blood-  is assumed as the final -trap- compartments of the system, \
see fig.1)"
}], "DefinitionBox",
 CellTags->"Introduction"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{
   StyleBox["qSTfromRT", "Input"], 
   StyleBox["[", "Input"], 
   StyleBox[
    RowBox[{
     SubscriptBox["I", "0"], ",", " ", "IFD", " ", ",", " ", "FRA", ",", " ", 
     "t", ",", " ", "\[Lambda]", ",", " ", "options"}],
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"CompatibilityType"->0,
    "Masked"->False,
    "Outline"->False,
    "RotationAngle"->0,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Underline"->False}], 
   StyleBox["]", "Input"]}]]],
 "for one specific nuclide, gives the retention in compartments ST (stomach)  \
from the flow of the respiratory tract as function of time ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", "t"}], TraditionalForm]]],
 ", in days,  after an acute intake ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["I", "0"], " "}]]],
 "in ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 "=0,  ST-stomach- is assumed as the final -trap- compartments of the system, \
see fig.1)  "
}], "DefinitionBox",
 CellTags->"Introduction"],

Cell[TextData[{
 StyleBox["Intake",
  FontFamily->"Courier New",
  FontSlant->"Italic"],
 ": \n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "0"], TraditionalForm]]],
 " for an Acute input (Bq);",
 StyleBox[" ",
  FontSlant->"Italic"],
 "The intake type can be chosen with Options: ",
 StyleBox["IntakeType",
  FontFamily->"Courier New"],
 "\[Rule] \"Acute\", it is assumed by default. ",
 StyleBox["\n",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "d"], TraditionalForm]]],
 " for a Constant input (Bq/day); chosing",
 StyleBox[" ",
  FontSlant->"Italic"],
 StyleBox["IntakeType",
  FontFamily->"Courier New"],
 "\[Rule]\"Constant\" with options. \"Constant\" means a daily chronic intake \
",
 Cell[BoxData[
  SubscriptBox["I", "d"]]],
 " ;  ",
 StyleBox["\n",
  FontSlant->"Italic"],
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     RowBox[{"I", "(", "t", ")"}], ",", " ", "t"}], "}"}], TraditionalForm]]],
 " for a continuous input; chosing",
 StyleBox[" ",
  FontSlant->"Italic"],
 StyleBox["IntakeType ",
  FontFamily->"Courier New"],
 "\[Rule] \"Continuous\" with options. \"Continuous\" mean a daily continuous \
intake  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"I", "(", "t", ")"}], TraditionalForm]]],
 ";  \n",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     StyleBox["{",
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontTracking->"Plain",
      FontVariations->{"CompatibilityType"->0,
      "Masked"->False,
      "Outline"->False,
      "RotationAngle"->0,
      "Shadow"->False,
      "StrikeThrough"->False,
      "Underline"->False}], 
     RowBox[{
      StyleBox[
       SubscriptBox["I", "0"],
       FontWeight->"Plain",
       FontSlant->"Italic",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], ",", " ", "0"}], "}"}], ",", " ", 
    RowBox[{"{", 
     StyleBox[
      RowBox[{
       SubscriptBox["I", "1"], ",", 
       SubscriptBox["\[Tau]", "1"]}],
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontTracking->"Plain",
      FontVariations->{"CompatibilityType"->0,
      "Masked"->False,
      "Outline"->False,
      "RotationAngle"->0,
      "Shadow"->False,
      "StrikeThrough"->False,
      "Underline"->False}], 
     StyleBox["}",
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontTracking->"Plain",
      FontVariations->{"CompatibilityType"->0,
      "Masked"->False,
      "Outline"->False,
      "RotationAngle"->0,
      "Shadow"->False,
      "StrikeThrough"->False,
      "Underline"->False}]}], 
    StyleBox[",",
     FontWeight->"Plain",
     FontSlant->"Italic",
     FontTracking->"Plain",
     FontVariations->{"CompatibilityType"->0,
     "Masked"->False,
     "Outline"->False,
     "RotationAngle"->0,
     "Shadow"->False,
     "StrikeThrough"->False,
     "Underline"->False}], 
    StyleBox[" ",
     FontWeight->"Plain",
     FontSlant->"Italic",
     FontTracking->"Plain",
     FontVariations->{"CompatibilityType"->0,
     "Masked"->False,
     "Outline"->False,
     "RotationAngle"->0,
     "Shadow"->False,
     "StrikeThrough"->False,
     "Underline"->False}], 
    StyleBox["...",
     FontWeight->"Plain",
     FontSlant->"Italic",
     FontTracking->"Plain",
     FontVariations->{"CompatibilityType"->0,
     "Masked"->False,
     "Outline"->False,
     "RotationAngle"->0,
     "Shadow"->False,
     "StrikeThrough"->False,
     "Underline"->False}], 
    StyleBox[",",
     FontWeight->"Plain",
     FontSlant->"Italic",
     FontTracking->"Plain",
     FontVariations->{"CompatibilityType"->0,
     "Masked"->False,
     "Outline"->False,
     "RotationAngle"->0,
     "Shadow"->False,
     "StrikeThrough"->False,
     "Underline"->False}], 
    StyleBox[" ",
     FontWeight->"Plain",
     FontSlant->"Italic",
     FontTracking->"Plain",
     FontVariations->{"CompatibilityType"->0,
     "Masked"->False,
     "Outline"->False,
     "RotationAngle"->0,
     "Shadow"->False,
     "StrikeThrough"->False,
     "Underline"->False}], 
    RowBox[{
     StyleBox["{",
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontTracking->"Plain",
      FontVariations->{"CompatibilityType"->0,
      "Masked"->False,
      "Outline"->False,
      "RotationAngle"->0,
      "Shadow"->False,
      "StrikeThrough"->False,
      "Underline"->False}], 
     RowBox[{
      StyleBox[
       SubscriptBox["I", "n"],
       FontWeight->"Plain",
       FontSlant->"Italic",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}], ",", " ", 
      StyleBox[
       SubscriptBox["\[Tau]", "n"],
       FontWeight->"Plain",
       FontSlant->"Italic",
       FontTracking->"Plain",
       FontVariations->{"CompatibilityType"->0,
       "Masked"->False,
       "Outline"->False,
       "RotationAngle"->0,
       "Shadow"->False,
       "StrikeThrough"->False,
       "Underline"->False}]}], 
     StyleBox["}",
      FontWeight->"Plain",
      FontSlant->"Italic",
      FontTracking->"Plain",
      FontVariations->{"CompatibilityType"->0,
      "Masked"->False,
      "Outline"->False,
      "RotationAngle"->0,
      "Shadow"->False,
      "StrikeThrough"->False,
      "Underline"->False}]}]}], 
   StyleBox["}",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"CompatibilityType"->0,
    "Masked"->False,
    "Outline"->False,
    "RotationAngle"->0,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Underline"->False}]}]]],
 "for multi acute inputs (This option only works with LungsRetention chosing ",
 StyleBox["IntakeType",
  FontFamily->"Courier New"],
 "\[Rule]\"MultiInputs\") ; \"MultiInputs\" means multiple single intakes {",
 Cell[BoxData[
  SubscriptBox["I", "0"]]],
 ", ..., ",
 Cell[BoxData[
  SubscriptBox["I", "n"]]],
 "} at time 0<",
 Cell[BoxData[
  SubscriptBox["\[Tau]", "1"]]],
 "< ...<",
 Cell[BoxData[
  SubscriptBox["\[Tau]", "n"]]],
 ", in this case  the function give he retention in Lungs  after the last \
intake ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    StyleBox[
     SubscriptBox["I", "n"],
     FontWeight->"Plain",
     FontSlant->"Italic",
     FontTracking->"Plain",
     FontVariations->{"CompatibilityType"->0,
     "Masked"->False,
     "Outline"->False,
     "RotationAngle"->0,
     "Shadow"->False,
     "StrikeThrough"->False,
     "Underline"->False}], ",", " ", 
    StyleBox[
     SubscriptBox["\[Tau]", "n"],
     FontWeight->"Plain",
     FontSlant->"Italic",
     FontTracking->"Plain",
     FontVariations->{"CompatibilityType"->0,
     "Masked"->False,
     "Outline"->False,
     "RotationAngle"->0,
     "Shadow"->False,
     "StrikeThrough"->False,
     "Underline"->False}]}], 
   StyleBox["}",
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"CompatibilityType"->0,
    "Masked"->False,
    "Outline"->False,
    "RotationAngle"->0,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Underline"->False}]}]]],
 ". "
}], "Text",
 CellDingbat->None],

Cell[TextData[{
 StyleBox["IFD: Initial fractional  deposition values ",
  FontSlant->"Italic"],
 StyleBox["as function of AMAD",
  FontVariations->{"CompatibilityType"->0}],
 ". It can be directly written the values with this pattern ",
 Cell[BoxData[
  RowBox[{"{", "AI"}]]],
 ", ",
 Cell[BoxData[
  SubscriptBox["bb", 
   RowBox[{"fast", "+", "seq"}]]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["bb", "slow"], ","}]]],
 " ",
 Cell[BoxData[
  SubscriptBox["BB", 
   RowBox[{"fast", "+", "seq"}]]]],
 " ",
 Cell[BoxData[
  RowBox[{",", " ", 
   SubscriptBox["BB", "slow"], ",", " "}]]],
 " ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["ET", "2"], ",", " ", 
    SubscriptBox["ET", "1"]}], "}"}]]],
 " (i.e: {0.12, 0.011, 0.011, 0.0039, 0.004, 0.11, 0.089} or writing ",
 StyleBox["AMADAdultW[x]", "Input",
  FontWeight->"Bold"],
 " where X means AMAD size in \[Mu]m (i.e:  ",
 StyleBox["AMADAdultW[5])", "Input",
  FontWeight->"Bold"],
 " "
}], "Text",
 CellDingbat->None],

Cell[TextData[{
 StyleBox["IFD",
  FontSlant->"Italic"],
 " for normal adult (female and male), Child (10 y old) or Infant (1 y old) \
can be obtained applied  ",
 StyleBox["AMADAdultP[x], ", "Input",
  FontWeight->"Bold"],
 "  ",
 StyleBox["AMADyr10[x], AMADyr1[x].", "Input",
  FontWeight->"Bold"],
 "  "
}], "Commentary"],

Cell[TextData[{
 StyleBox["FRA: Fractional rate of absorption",
  FontSlant->"Italic"],
 " {",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    SubscriptBox["s", "p"], ",", 
    SubscriptBox["s", "pt"], ",", 
    SubscriptBox["s", "t"]}], "Input"]]],
 "} of material into the blood, they can be written directly (i.e.: {10, 90, \
0.005}) or writing ",
 StyleBox[" F ",
  FontWeight->"Bold"],
 StyleBox["or",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox[" M ",
  FontWeight->"Bold"],
 StyleBox["or",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox[" S, ",
  FontWeight->"Bold"],
 StyleBox["in these case are applied default values. ",
  FontVariations->{"CompatibilityType"->0}],
 "The default",
 Cell[BoxData[
  RowBox[{" ", 
   StyleBox[
    RowBox[{
     SubscriptBox["s", "p"], ",", 
     SubscriptBox["s", "pt"], ",", 
     SubscriptBox["s", "t"]}], "Input"]}]]],
 "  values  are (ICRP 66): type F:{100, 0, 0};  type M: {10, 90, 0.005};  \
type S: {0.1, 100, 0.0001}; "
}], "Text",
 CellDingbat->None],

Cell[TextData[{
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 " always in days. "
}], "Text",
 CellDingbat->None],

Cell[TextData[{
 "\[Lambda]: Radioactive Decay constant in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox[
    RowBox[{"day", " "}], 
    RowBox[{"-", "1"}]], TraditionalForm]]]
}], "Text",
 CellDingbat->None],

Cell[TextData[{
 "The function ",
 Cell[BoxData[
  RowBox[{
   StyleBox["qLungs", "Input"], 
   StyleBox["[", "Input"], 
   StyleBox[
    RowBox[{
     SubscriptBox["I", "0"], ",", " ", "IFD", " ", ",", " ", "FRA", ",", " ", 
     "t", ",", " ", "\[Lambda]", ",", " ", "options"}],
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"CompatibilityType"->0,
    "Masked"->False,
    "Outline"->False,
    "RotationAngle"->0,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Underline"->False}], 
   StyleBox["]", "Input"]}]]],
 " is equivalent to ",
 Cell[BoxData[
  RowBox[{
   StyleBox["LungsRetention", "Input"], 
   StyleBox["[", "Input"], 
   StyleBox[
    RowBox[{
     SubscriptBox["I", "0"], ",", " ", "IFD", " ", ",", " ", "FRA", ",", " ", 
     "t", ",", " ", "\[Lambda]", ",", " ", "options"}],
    FontWeight->"Plain",
    FontSlant->"Italic",
    FontTracking->"Plain",
    FontVariations->{"CompatibilityType"->0,
    "Masked"->False,
    "Outline"->False,
    "RotationAngle"->0,
    "Shadow"->False,
    "StrikeThrough"->False,
    "Underline"->False}], 
   StyleBox["]", "Input"]}]]],
 ". It will be an obsolete function in futures version of this package. "
}], "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "\"\<Biokmod`Resptract`*\>\""}]], "Input",
 CellTags->"Introduction",
 CellLabel->"In[3]:="],

Cell[BoxData[
 DynamicModuleBox[{Typeset`open$$ = True}, 
  PaneSelectorBox[{False->
   RowBox[{
    OpenerBox[Dynamic[Typeset`open$$],
     ImageSize->Small], 
    StyleBox["Biokmod`Resptract`", "InfoHeading"]}], True->GridBox[{
     {
      RowBox[{
       OpenerBox[Dynamic[Typeset`open$$],
        ImageSize->Small], 
       StyleBox["Biokmod`Resptract`", "InfoHeading"]}]},
     {GridBox[{
        {
         ButtonBox["AMADAdultP",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-0fa48f8d-9bd5-4ead-b7f6-edff3c5e4cf9", {
            "AMADAdultP", "Biokmod`Resptract`"}},
          ButtonNote->"Biokmod`Resptract`"], 
         ButtonBox["AMADfit",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-0fa48f8d-9bd5-4ead-b7f6-edff3c5e4cf9", {
            "AMADfit", "Biokmod`Resptract`"}},
          ButtonNote->"Biokmod`Resptract`"], 
         ButtonBox["AMADyr10",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-0fa48f8d-9bd5-4ead-b7f6-edff3c5e4cf9", {
            "AMADyr10", "Biokmod`Resptract`"}},
          ButtonNote->"Biokmod`Resptract`"], 
         ButtonBox["qLungs",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-0fa48f8d-9bd5-4ead-b7f6-edff3c5e4cf9", {
            "qLungs", "Biokmod`Resptract`"}},
          ButtonNote->"Biokmod`Resptract`"], 
         ButtonBox["qRT2",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-0fa48f8d-9bd5-4ead-b7f6-edff3c5e4cf9", {
            "qRT2", "Biokmod`Resptract`"}},
          ButtonNote->"Biokmod`Resptract`"]},
        {
         ButtonBox["AMADAdultW",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-0fa48f8d-9bd5-4ead-b7f6-edff3c5e4cf9", {
            "AMADAdultW", "Biokmod`Resptract`"}},
          ButtonNote->"Biokmod`Resptract`"], 
         ButtonBox["AMADyr1",
          BaseStyle->"InformationLink",
          ButtonData:>{
           "Info-0fa48f8d-9bd5-4ead-b7f6-edff3c5e4cf9", {
            "AMADyr1", "Biokmod`Resptract`"}},
          ButtonNote->"Biokmod`Resptract`"], 
         ButtonBox["LungsRetention",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-0fa48f8d-9bd5-4ead-b7f6-edff3c5e4cf9", {
            "LungsRetention", "Biokmod`Resptract`"}},
          ButtonNote->"Biokmod`Resptract`"], 
         ButtonBox["qRespTract",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-0fa48f8d-9bd5-4ead-b7f6-edff3c5e4cf9", {
            "qRespTract", "Biokmod`Resptract`"}},
          ButtonNote->"Biokmod`Resptract`"], 
         ButtonBox["RespiratoryTract",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info-0fa48f8d-9bd5-4ead-b7f6-edff3c5e4cf9", {
            "RespiratoryTract", "Biokmod`Resptract`"}},
          ButtonNote->"Biokmod`Resptract`"]}
       },
       DefaultBaseStyle->"InfoGrid",
       GridBoxItemSize->{"Columns" -> {{
            Scaled[0.19]}}}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}]}, 
   Dynamic[Typeset`open$$],
   ImageSize->Automatic]]], "Print", "InfoCell",
 CellChangeTimes->{3.6506055152628975`*^9},
 CellTags->"Introduction"]
}, Open  ]],

Cell["For fitting purposed sometime is useful applied AMADfit[x]", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "AMADfit"}]], "Input",
 CellLabel->"In[4]:="],

Cell[BoxData[
 StyleBox["\<\"AMADfit[x] gives an ajusted function of the fractional \
\\ndeposition values for AMAD x , where x can be a parameter. This function \
\\nis applicable when 0.5<=x<=20. It has been obtained fitting the values \
given \\nin  Annex F -workers- of ICRP 66.\"\>", "MSG"]], "Print", \
"PrintUsage",
 CellChangeTimes->{3.6506055154816036`*^9},
 CellTags->"Info-85e9d0ec-8b79-4122-80a0-1978472d8035"]
}, Open  ]],

Cell["\<\
To check what are the fractional deposition values for AMAD 0.5 write  \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AMADAdultW", "[", "0.5", "]"}]], "Input",
 CellLabel->"In[5]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "0.12`", ",", "0.011`", ",", "0.011`", ",", "0.004`", ",", "0.0039`", ",", 
    "0.11`", ",", "0.089`"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.399281687119726*^9, 3.442220234881233*^9, 
  3.442220347237732*^9, 3.442220703671385*^9, 3.476682534644663*^9, 
  3.477901736482994*^9, 3.518532748720748*^9, 3.5874741519662733`*^9, 
  3.5874756283125935`*^9, 3.587475967470188*^9, 3.643609073085354*^9, 
  3.6506055155128546`*^9},
 CellLabel->"Out[5]="]
}, Open  ]],

Cell["To check what are the FRA applied write S, M or F", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData["S"], "Input",
 CellLabel->"In[6]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0.1`", ",", "100", ",", "0.0001`"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.3992816871510057`*^9, 3.4422202349124823`*^9, 
  3.442220347268981*^9, 3.44222070371826*^9, 3.476682534691537*^9, 
  3.4779017365298786`*^9, 3.518532748751999*^9, 3.587474152169079*^9, 
  3.5874756283325944`*^9, 3.587475967500189*^9, 3.6436090731166043`*^9, 
  3.6506055155284915`*^9},
 CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[{
 "Partition of deposit in each region between compartments and rate transfers \
(in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["days", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 ") applied by default are obtained from Table 29 ICRP 66. It can changes \
with Options. "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", 
  StyleBox["LungsRetention", "Input"], "]"}]], "Input",
 CellLabel->"In[7]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"IntakeType", "\[Rule]", "\<\"Acute\"\>"}], ",", 
    RowBox[{"fAI1", "\[Rule]", "0.3`"}], ",", 
    RowBox[{"fAI2", "\[Rule]", "0.6`"}], ",", 
    RowBox[{"fAI3", "\[Rule]", "0.1`"}], ",", 
    RowBox[{"fbs", "\[Rule]", "0.007`"}], ",", 
    RowBox[{"fBs", "\[Rule]", "0.007`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"AI1,bb1\"\>"], "\[Rule]", "0.02`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"AI2,bb1\"\>"], "\[Rule]", "0.001`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"AI3,bb1\"\>"], "\[Rule]", "0.0001`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"AI3,TH\"\>"], "\[Rule]", "0.00002`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"bb1,BB1\"\>"], "\[Rule]", "2"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"bb2,BB1\"\>"], "\[Rule]", "0.03`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"bbseq,TH\"\>"], "\[Rule]", "0.01`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"BB1,ET2\"\>"], "\[Rule]", "10"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"BB2,ET2\"\>"], "\[Rule]", "0.03`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"BBseq,TH\"\>"], "\[Rule]", "0.01`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"ETseq,ET\"\>"], "\[Rule]", "0.001`"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.3992816871666455`*^9, 3.4422202349593563`*^9, 
  3.44222034730023*^9, 3.44222070374951*^9, 3.476682534738411*^9, 
  3.477901736561135*^9, 3.518532748783249*^9, 3.5874741523874846`*^9, 
  3.5874756283525953`*^9, 3.5874759675301895`*^9, 3.6436090731322284`*^9, 
  3.6506055155597315`*^9},
 CellLabel->"Out[7]="]
}, Open  ]],

Cell["\<\
To obtain information about options white the name of the option\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", " ", "fAI1"}]], "Input",
 CellLabel->"In[8]:="],

Cell[BoxData[
 StyleBox["\<\"Fraction of deposition factor fAI1 = AI1/AI\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellChangeTimes->{3.650605515622233*^9},
 CellTags->"Info-fb3ef736-86ba-4079-af16-62bcc5aa9156"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "k"}]], "Input",
 CellLabel->"In[9]:="],

Cell[BoxData[
 StyleBox["\<\"Represent the rate transfer coefficient\"\>", "MSG"]], "Print",\
 "PrintUsage",
 CellChangeTimes->{3.6506055156847353`*^9},
 CellTags->"Info-e45e6c48-50a4-42f3-8075-3c404883ef97"]
}, Open  ]],

Cell[TextData[{
 "Transfer coefficients can be modifies with options (note: ",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    SubscriptBox["k", "\"\<A,B\>\""], "Input"], " "}]]],
 "must be write using \")"
}], "Text"],

Cell[TextData[{
 "Recommended fractional  deposition values (",
 Cell[BoxData[
  FormBox["F", TraditionalForm]]],
 ") for other reference subjects and AMADs can be obtained from Annex F of \
ICRP 66.   Annex F gives ",
 Cell[BoxData[
  FormBox["F", TraditionalForm]]],
 " for AI",
 Cell[BoxData[
  FormBox[
   RowBox[{",", " ", 
    SubscriptBox["bb", 
     RowBox[{"(", 
      RowBox[{"fast", "+", "seq"}], ")"}]], ",", " ", "bb", ",", " ", 
    SubscriptBox["BB", 
     RowBox[{"(", 
      RowBox[{"fast", "+", "seq"}], ")"}]], ",", "  ", "BB"}], 
   TraditionalForm]]],
 " and we need ",
 Cell[BoxData[
  RowBox[{"{", "AI"}]]],
 ", ",
 Cell[BoxData[
  SubscriptBox["bb", 
   RowBox[{"fast", "+", "seq"}]]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["bb", "slow"], ","}]]],
 " ",
 Cell[BoxData[
  SubscriptBox["BB", 
   RowBox[{"fast", "+", "seq"}]]]],
 " ",
 Cell[BoxData[
  RowBox[{",", " ", 
   SubscriptBox["BB", "slow"], ",", " "}]]],
 " ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["ET", "2"], ",", " ", 
    SubscriptBox["ET", "1"]}], "}"}]]],
 "\nIt can be done using these relationship:"
}], "Text"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "bb1"], TraditionalForm]]],
 " = (1-",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "bs"], TraditionalForm]]],
 ")*",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", 
    RowBox[{
     RowBox[{"bb1", "(", "fast", ")"}], "+", "bbseq"}]], TraditionalForm]]],
 " - ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "bs"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", 
    RowBox[{"bb2", "(", "slow", ")"}]], TraditionalForm]]],
 "; ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "bb2"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", 
    RowBox[{"bb2", "(", "slow", ")"}]], TraditionalForm]]],
 "; ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "bbseq"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "bs"], TraditionalForm]]],
 " (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", 
    RowBox[{
     RowBox[{"bb1", "(", "fast", ")"}], "+", "bbseq"}]], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", 
    RowBox[{"bb2", "(", "slow", ")"}]], TraditionalForm]]],
 ")\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "BB1"], TraditionalForm]]],
 " = (1-",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "Bs"], TraditionalForm]]],
 ")*",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", 
    RowBox[{
     RowBox[{"BB1", "(", "fast", ")"}], "+", "BBseq"}]], TraditionalForm]]],
 " - ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "Bs"], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", 
    RowBox[{"BB2", "(", "slow", ")"}]], TraditionalForm]]],
 "; ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "BB2"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", 
    RowBox[{"BB2", "(", "slow", ")"}]], TraditionalForm]]],
 "; ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", "BBseq"], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "Bs"], TraditionalForm]]],
 " (",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", 
    RowBox[{
     RowBox[{"BB1", "(", "fast", ")"}], "+", "bbseq"}]], TraditionalForm]]],
 "+",
 Cell[BoxData[
  FormBox[
   SubscriptBox["F", 
    RowBox[{"BB2", "(", "slow", ")"}]], TraditionalForm]]],
 ")"
}], "Commentary"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "bs"], TraditionalForm]]],
 "bs and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "Bs"], TraditionalForm]]],
 " default values can be modified with options  "
}], "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Demostration", "SubsectionIcon",
 CellChangeTimes->{{3.3985837956481028`*^9, 3.3985838073484955`*^9}, {
  3.542174541343413*^9, 3.542174552528632*^9}, {3.5421769623110657`*^9, 
  3.5421769627010665`*^9}, {3.5874748046789093`*^9, 3.5874748095150332`*^9}}],

Cell[TextData[{
 " (Note: Disintegration constant in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["days", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 " by default = 0, but  it can be modified by user). It can by obtained using \
(here it is supposed that U235 is isotope measured) : "
}], "Text",
 CellChangeTimes->{{3.592201075170151*^9, 3.5922010946590996`*^9}, 
   3.6506065353018904`*^9, {3.6506066563332095`*^9, 3.650606717473871*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"UnitConvert", "[", 
  RowBox[{
   RowBox[{"IsotopeData", "[", 
    RowBox[{"\"\<U235\>\"", ",", "\"\<Lifetime\>\""}], "]"}], ",", " ", 
   "\"\<Days\>\""}], "]"}]], "Input",
 CellChangeTimes->{{3.59167135068777*^9, 3.5916713598816895`*^9}, {
  3.650606489379985*^9, 3.650606507473745*^9}},
 CellLabel->"In[61]:="],

Cell[BoxData[
 FormBox[
  TemplateBox[{
   "3.715277777777777777777777777778`3.*^11","\"days\"","days","\"Days\""},
   "QuantityTF"], TraditionalForm]], "Output",
 CellChangeTimes->{3.591671537846484*^9, 3.6436090759134827`*^9, 
  3.6506055184504633`*^9, 3.650606508333063*^9, 3.6506066305050106`*^9},
 CellLabel->"Out[61]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Log", "[", "2", "]"}], "/", 
  RowBox[{"QuantityMagnitude", "[", "%", "]"}]}]], "Input",
 CellChangeTimes->{{3.6506065606299987`*^9, 3.6506065759424877`*^9}, {
  3.6506066078956795`*^9, 3.6506066182706313`*^9}},
 CellLabel->"In[62]:="],

Cell[BoxData[
 FormBox["1.86566717758190887020712945`3.*^-12", TraditionalForm]], "Output",
 CellChangeTimes->{3.650606630708136*^9},
 CellLabel->"Out[62]="]
}, Open  ]],

Cell["In these cases can used as disintegration constant 0.", "Text",
 CellChangeTimes->{{3.6506067221301003`*^9, 3.6506067787551603`*^9}}],

Cell["\<\
Here it is plotted the lung retention a time t (in days) after an acute \
intake as funtion of intake, AMAD and type of metabolization.\
\>", "MathCaption",
 CellChangeTimes->{{3.5421788628286047`*^9, 3.5421789301739225`*^9}, {
  3.5421789668495874`*^9, 3.5421790580015473`*^9}, {3.542179319012606*^9, 
  3.542179333380232*^9}, {3.591603306602672*^9, 3.5916033250830417`*^9}, {
  3.5916708459014683`*^9, 3.5916709345893364`*^9}, {3.591670973711248*^9, 
  3.591670992450122*^9}, {3.591671065210166*^9, 3.591671080306735*^9}, {
  3.5916711199777017`*^9, 3.591671135720276*^9}, {3.5922010000426393`*^9, 
  3.5922010635119853`*^9}, {3.656752012233192*^9, 3.656752012795697*^9}},
 CellID->100072831],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Manipulate", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"met", "=", " ", 
     RowBox[{"ToExpression", "[", "metabolization", "]"}]}], ";", 
    RowBox[{"LogPlot", "[", 
     RowBox[{
      RowBox[{"LungsRetention", "[", 
       RowBox[{"int", ",", 
        StyleBox[
         RowBox[{"AMADfit", "[", "amad", "]"}], "Input"], " ", ",", " ", 
        "met", ",", " ", "t", ",", " ", "lambda"}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{"t", ",", "0", ",", "tmax"}], "}"}], ",", " ", 
      RowBox[{"AxesLabel", "\[Rule]", 
       RowBox[{"{", 
        RowBox[{"\"\<days\>\"", ",", " ", "\"\<kBq\>\""}], "}"}]}], ",", " ", 
      RowBox[{"PlotRange", "->", "All"}]}], "]"}]}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"tmax", ",", "10", ",", "\"\<days\>\""}], "}"}], ",", " ", "1", 
     ",", " ", "100", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"int", ",", "10", ",", "\"\<kBq\>\""}], "}"}], ",", " ", "1", 
     ",", " ", "100", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"amad", ",", "5", ",", "\"\<AMAD(\[Mu]m)\>\""}], "}"}], ",", 
     " ", "1", ",", " ", "10", ",", 
     RowBox[{"Appearance", "\[Rule]", "\"\<Open\>\""}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"metabolization", ",", 
     RowBox[{"{", 
      RowBox[{"\"\<S\>\"", ",", "\"\<M\>\"", ",", "\"\<F\>\""}], "}"}], ",", 
     RowBox[{"ControlType", "\[Rule]", "PopupMenu"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"lambda", ",", "0", ",", 
     RowBox[{"ControlType", "\[Rule]", "InputField"}]}], "}"}], ",", " ", 
   RowBox[{"Initialization", ":>", 
    RowBox[{"Get", "[", "\"\<Biokmod`Resptract`\>\"", "]"}]}], ",", "  ", 
   RowBox[{"SynchronousUpdating", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.476689910237214*^9, 3.476689929408966*^9}, {
   3.476689960877392*^9, 3.4766899912361836`*^9}, {3.4766900452663965`*^9, 
   3.47669004793822*^9}, {3.4766901470144424`*^9, 3.4766901482644186`*^9}, {
   3.4766901877949095`*^9, 3.476690231153452*^9}, {3.4766903286052012`*^9, 
   3.4766904100572834`*^9}, {3.476690459259779*^9, 3.476690480087637*^9}, {
   3.4779019126909485`*^9, 3.4779019260530596`*^9}, {3.4779019891381435`*^9, 
   3.4779020313763027`*^9}, {3.4779020666294613`*^9, 
   3.4779020902878304`*^9}, {3.477902224487354*^9, 3.477902255473697*^9}, 
   3.5421749562301416`*^9, {3.5421754075409346`*^9, 3.542175434825382*^9}, {
   3.5421754649958353`*^9, 3.542175473981451*^9}, 3.5421755526367893`*^9, {
   3.5421756372201376`*^9, 3.542175690884232*^9}, {3.542175798324621*^9, 
   3.5421758248602676`*^9}, {3.542175891209184*^9, 3.542175900522401*^9}, {
   3.54217596278211*^9, 3.542175991782561*^9}, {3.54217602532262*^9, 
   3.5421761147419767`*^9}, {3.542176483824025*^9, 3.5421764858988285`*^9}, {
   3.542176565037768*^9, 3.5421766427591047`*^9}, {3.5421766899491873`*^9, 
   3.5421766912751894`*^9}, {3.542176730041258*^9, 3.5421768476966643`*^9}, {
   3.542176929161008*^9, 3.5421769333886147`*^9}, {3.54217714694139*^9, 
   3.5421771521205993`*^9}, {3.5421775220958495`*^9, 
   3.5421775272594585`*^9}, {3.5421775654171257`*^9, 
   3.5421775704559345`*^9}, {3.5421779309141674`*^9, 
   3.5421779758110466`*^9}, {3.542178033983549*^9, 3.54217806905241*^9}, {
   3.5421781004708652`*^9, 3.542178144743743*^9}, {3.5421781868170176`*^9, 
   3.54217824542632*^9}, {3.5421785711236925`*^9, 3.542178622026582*^9}, {
   3.542178807932108*^9, 3.542178810864913*^9}, {3.542179113085244*^9, 
   3.542179124410864*^9}, 3.5421792553332944`*^9, {3.5916032219709797`*^9, 
   3.5916032684219084`*^9}, {3.5916035253596907`*^9, 
   3.5916035802821827`*^9}, {3.591603704048558*^9, 3.591603714451598*^9}, {
   3.591603794627615*^9, 3.591603819638116*^9}, {3.5916040978929386`*^9, 
   3.591604110890238*^9}, {3.59160414521467*^9, 3.5916041515173006`*^9}, {
   3.5916041857737255`*^9, 3.5916042183819857`*^9}, {3.59160428002815*^9, 
   3.5916042875629034`*^9}, {3.591671244343137*^9, 3.591671293649067*^9}, 
   3.591671514450145*^9, {3.6436094096796703`*^9, 3.6436094232265644`*^9}, 
   3.6436095085391655`*^9, {3.6567523838416705`*^9, 3.656752399654318*^9}},
 CellLabel->"In[1]:=",
 CellID->32272491],

Cell[BoxData[
 TagBox[
  StyleBox[
   DynamicModuleBox[{$CellContext`amad$$ = 5, $CellContext`int$$ = 
    10, $CellContext`lambda$$ = 0, $CellContext`metabolization$$ = 
    "S", $CellContext`tmax$$ = 10, Typeset`show$$ = True, 
    Typeset`bookmarkList$$ = {}, Typeset`bookmarkMode$$ = "Menu", 
    Typeset`animator$$, Typeset`animvar$$ = 1, Typeset`name$$ = 
    "\"untitled\"", Typeset`specs$$ = {{{
       Hold[$CellContext`tmax$$], 10, "days"}, 1, 100}, {{
       Hold[$CellContext`int$$], 10, "kBq"}, 1, 100}, {{
       Hold[$CellContext`amad$$], 5, "AMAD(\[Mu]m)"}, 1, 10}, {
      Hold[$CellContext`metabolization$$], {"S", "M", "F"}}, {
      Hold[$CellContext`lambda$$], 0}}, Typeset`size$$ = {540., {160., 170.}},
     Typeset`update$$ = 0, Typeset`initDone$$, Typeset`skipInitDone$$ = 
    False, $CellContext`tmax$451$$ = 0, $CellContext`int$456$$ = 
    0, $CellContext`amad$457$$ = 0, $CellContext`metabolization$458$$ = 0}, 
    DynamicBox[Manipulate`ManipulateBoxes[
     1, StandardForm, 
      "Variables" :> {$CellContext`amad$$ = 5, $CellContext`int$$ = 
        10, $CellContext`lambda$$ = 0, $CellContext`metabolization$$ = 
        "S", $CellContext`tmax$$ = 10}, "ControllerVariables" :> {
        Hold[$CellContext`tmax$$, $CellContext`tmax$451$$, 0], 
        Hold[$CellContext`int$$, $CellContext`int$456$$, 0], 
        Hold[$CellContext`amad$$, $CellContext`amad$457$$, 0], 
        Hold[$CellContext`metabolization$$, $CellContext`metabolization$458$$,
          0]}, "OtherVariables" :> {
       Typeset`show$$, Typeset`bookmarkList$$, Typeset`bookmarkMode$$, 
        Typeset`animator$$, Typeset`animvar$$, Typeset`name$$, 
        Typeset`specs$$, Typeset`size$$, Typeset`update$$, Typeset`initDone$$,
         Typeset`skipInitDone$$}, 
      "Body" :> ($CellContext`met = 
        ToExpression[$CellContext`metabolization$$]; LogPlot[
         Biokmod`Resptract`LungsRetention[$CellContext`int$$, 
          
          Biokmod`Resptract`AMADfit[$CellContext`amad$$], $CellContext`met, \
$CellContext`t, $CellContext`lambda$$], {$CellContext`t, 
          0, $CellContext`tmax$$}, AxesLabel -> {"days", "kBq"}, PlotRange -> 
         All]), "Specifications" :> {{{$CellContext`tmax$$, 10, "days"}, 1, 
         100, Appearance -> "Open"}, {{$CellContext`int$$, 10, "kBq"}, 1, 100,
          Appearance -> "Open"}, {{$CellContext`amad$$, 5, "AMAD(\[Mu]m)"}, 1,
          10, Appearance -> "Open"}, {$CellContext`metabolization$$, {
         "S", "M", "F"}, ControlType -> PopupMenu}, {$CellContext`lambda$$, 0,
          ControlType -> InputField}}, 
      "Options" :> {SynchronousUpdating -> False}, "DefaultOptions" :> {}],
     ImageSizeCache->{610., {351., 360.}},
     SingleEvaluation->True],
    Deinitialization:>None,
    DynamicModuleValues:>{},
    Initialization:>(Get["Biokmod`Resptract`"]; Typeset`initDone$$ = True),
    SynchronousInitialization->True,
    UndoTrackedVariables:>{Typeset`show$$, Typeset`bookmarkMode$$},
    UnsavedVariables:>{Typeset`initDone$$},
    UntrackedVariables:>{Typeset`size$$}], "Manipulate",
   Deployed->True,
   StripOnInput->False],
  Manipulate`InterpretManipulate[1]]], "Output",
 CellChangeTimes->{
  3.5916713878044815`*^9, {3.5916715180715065`*^9, 3.5916715379874983`*^9}, 
   3.643609076147871*^9, 3.643609489273485*^9, 3.6436095911642623`*^9, 
   3.6506055189817195`*^9, {3.656752394669901*^9, 3.6567524045137367`*^9}, 
   3.65675244538912*^9},
 CellLabel->"Out[1]="],

Cell[BoxData["\<\"Resptract 1.2  2005-05-16\"\>"], "Print",
 CellChangeTimes->{3.656752445748501*^9},
 CellLabel->""]
}, {2}]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples ", "SubsectionIcon",
 CellTags->"Examples"],

Cell[CellGroupData[{

Cell["Example 1", "SubsubsectionIcon",
 CellTags->"Examples"],

Cell["\<\
Here is evaluated the retention in the Respiratory tract compartments \
supposing  a single intake 1 Bq   of aerosols type S and AMAD = 5 \[Mu]m  in \
t = 0 with lambda \[Rule] 0 \
\>", "MathCaption",
 CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RTAMAD5S", "[", "t_", "]"}], "=", 
  RowBox[{
   StyleBox["RespiratoryTract", "Input"], "[", 
   RowBox[{"1", ",", 
    RowBox[{"AMADAdultW", "[", "5", "]"}], ",", "S", ",", " ", "t", ",", 
    "0"}], "]"}]}]], "Input",
 CellLabel->"In[12]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["q", "ET1"], "(", "t", ")"}], "\[Rule]", 
     RowBox[{"0.3386996`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "t"}]]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "AI"], "(", "t", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"0.00001592483439044265`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.11999999999999`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.0000318496687808853`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.101`"}], " ", "t"}]]}], "+", 
      RowBox[{"5.308278130147261`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.10012`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.015940775165609558`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0201`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.031881550331219116`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.005313591721869853`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00022`"}], " ", "t"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "bb1"], "(", "t", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"6.378825063484139`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "102.1`"}], " ", "t"}]]}], "+", 
      RowBox[{"1.608569130347507`*^-7", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.11999999999999`"}], " ", "t"}]]}], "+", 
      RowBox[{"1.5932800790838773`*^-8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.101`"}], " ", "t"}]]}], "+", 
      RowBox[{"2.654298322973571`*^-10", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.10012`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.006385210273758899`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2.0001`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.00016101793096575314`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0201`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.00001594874954037975`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t"}]]}], "+", 
      RowBox[{"2.6569552782516216`*^-7", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00022`"}], " ", "t"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "bb2"], "(", "t", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"4.375245130114162`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.13`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.004379624754869886`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0301`"}], " ", "t"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "bbseq"], "(", "t", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"7.70572783089738`*^-8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.11`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.00007713441272169102`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0101`"}], " ", "t"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "BB1"], "(", "t", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"0.000010043280629059431`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "110.1`"}], " ", "t"}]]}], "+", 
      RowBox[{"1.5947062658710348`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "102.1`"}], " ", "t"}]]}], "+", 
      RowBox[{"1.316523108359444`*^-8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.13`"}], " ", "t"}]]}], "+", 
      RowBox[{"3.223585431558597`*^-8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.11999999999999`"}], " ", "t"}]]}], "+", 
      RowBox[{"3.186878846053216`*^-9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.101`"}], " ", "t"}]]}], "+", 
      RowBox[{"5.308660349870766`*^-11", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.10012`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.010053333963025171`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.0015963025684397247`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2.0001`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.000013178409493088923`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0301`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.000032268122438026674`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0201`"}], " ", "t"}]]}], "+", 
      RowBox[{"3.1900689149674457`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t"}]]}], "+", 
      RowBox[{"5.313974324195134`*^-8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00022`"}], " ", "t"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "BB2"], "(", "t", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"5.90917573344181`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.13`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.005915090824266558`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0301`"}], " ", "t"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "BBseq"], "(", "t", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"1.240388980408222`*^-7", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.11`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.00012416306110195918`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0101`"}], " ", "t"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "LNth"], "(", "t", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"2.0109617634980954`*^-7", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "100.11`"}], " ", "t"}]]}]}], "-", 
      RowBox[{"8.847130216914269`*^-7", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.10012`"}], " ", "t"}]]}], "+", 
      RowBox[{"1.085809198041101`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.1`"}], " ", "t"}]]}], "-", 
      RowBox[{"0.0002012974738236502`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0101`"}], " ", "t"}]]}], "-", 
      RowBox[{"0.0008855986203116422`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00022`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.0010868960941352924`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0001`"}], " ", "t"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "ET2"], "(", "t", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"0.0003966190593791552`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "200.1`"}], " ", "t"}]]}], "+", 
      RowBox[{"1.115920069896456`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "110.1`"}], " ", "t"}]]}], "+", 
      RowBox[{"1.6272512916998272`*^-7", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "102.1`"}], " ", "t"}]]}], "+", 
      RowBox[{"3.090202889584337`*^-9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.13`"}], " ", "t"}]]}], "+", 
      RowBox[{"3.2242302777305`*^-9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.11999999999999`"}], " ", "t"}]]}], "+", 
      RowBox[{"3.1869107152511164`*^-10", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.101`"}], " ", "t"}]]}], "+", 
      RowBox[{"5.308666721005103`*^-12", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.10012`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.39701607545481515`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.0001`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.0011170371070027968`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.00016288801718772697`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2.0001`"}], " ", "t"}]]}], "+", 
      RowBox[{"3.093296185444493`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0301`"}], " ", "t"}]]}], "+", 
      RowBox[{"3.227457735349738`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0201`"}], " ", "t"}]]}], "+", 
      RowBox[{"3.190100815975606`*^-7", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t"}]]}], "+", 
      RowBox[{"5.3139807009719745`*^-9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00022`"}], " ", "t"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "ETseq"], "(", "t", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"1.9905169735425876`*^-7", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.101`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.00019925094830262376`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "LNet"], "(", "t", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"1.9905169735431297`*^-7", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "100.101`"}], " ", "t"}]]}]}], "+", 
      RowBox[{"1.9905169735425876`*^-7", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.1`"}], " ", "t"}]]}], "-", 
      RowBox[{"0.00019925094830262376`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t"}]]}], "+", 
      RowBox[{"0.0001992509483026237`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0001`"}], " ", "t"}]]}]}]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.399281687948641*^9, 3.442220235662463*^9, 
  3.442220347972088*^9, 3.4422207043588805`*^9, 3.476682535722767*^9, 
  3.477901737514455*^9, 3.518532749283259*^9, 3.5874741536823177`*^9, 
  3.5874756315426908`*^9, 3.5874757928183036`*^9, 3.5874759708102884`*^9, 
  3.6436090778978605`*^9, 3.643609632273697*^9, 3.6436097047581825`*^9, 
  3.6506055191849017`*^9},
 CellLabel->"Out[12]="]
}, Open  ]],

Cell["\<\
The default initial deposition values (IFD) applied for AMAD = 5 \[Mu]m and \
the FRA (fractional rate absorption) for S can be obtained as follow\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"AMADAdultW", "[", "5", "]"}]], "Input",
 CellLabel->"In[13]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "0.053189`", ",", "0.00664621`", ",", "0.004384`", ",", "0.0118343`", ",", 
    "0.005921`", ",", "0.3989`", ",", "0.3386996`"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.3992816879799204`*^9, 3.442220255583828*^9, 
  3.442220348018962*^9, 3.44222070439013*^9, 3.476682535785266*^9, 
  3.4779017375769677`*^9, 3.5185327493145094`*^9, 3.587474153713518*^9, 
  3.587475631582692*^9, 3.5874757928883057`*^9, 3.5874759708502893`*^9, 
  3.6436090779134855`*^9, 3.6436096323205857`*^9, 3.643609704789432*^9, 
  3.6506055192161007`*^9},
 CellLabel->"Out[13]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData["S"], "Input",
 CellLabel->"In[14]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{"0.1`", ",", "100", ",", "0.0001`"}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.3992816879955606`*^9, 3.442220255630702*^9, 
  3.442220348050211*^9, 3.44222070442138*^9, 3.476682535879014*^9, 
  3.4779017376238527`*^9, 3.518532749377011*^9, 3.587474153729119*^9, 
  3.587475631622693*^9, 3.587475792908306*^9, 3.5874759708802905`*^9, 
  3.643609077929144*^9, 3.6436096323362074`*^9, 3.643609704789432*^9, 
  3.6506055192317257`*^9},
 CellLabel->"Out[14]="]
}, Open  ]],

Cell["\<\
Now it is evaluated the retention in AI,  bb, and BB showing the solution for \
different days\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qAI", "[", "t_", "]"}], ",", 
     RowBox[{"qbb", "[", "t_", "]"}], ",", " ", 
     RowBox[{"qBB", "[", "t_", "]"}]}], "}"}], "=", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{
       SubscriptBox["q", "AI"], "[", "t", "]"}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["q", "bb1"], "[", "t", "]"}], "+", " ", 
       RowBox[{
        SubscriptBox["q", "bb2"], "[", "t", "]"}], "+", 
       RowBox[{
        SubscriptBox["q", "bbseq"], "[", "t", "]"}]}], ",", 
      RowBox[{
       RowBox[{
        SubscriptBox["q", "BB1"], "[", "t", "]"}], "+", 
       RowBox[{
        SubscriptBox["q", "BB2"], "[", "t", "]"}], "+", 
       RowBox[{
        SubscriptBox["q", "BBseq"], "[", "t", "]"}]}]}], "}"}], "/.", 
    RowBox[{"RTAMAD5S", "[", "t", "]"}]}]}], ";"}]], "Input",
 CellLabel->"In[15]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"t", ",", " ", 
       RowBox[{"qAI", "[", "t", "]"}], ",", " ", 
       RowBox[{"qbb", "[", "t", "]"}], ",", " ", 
       RowBox[{"qBB", "[", "t", "]"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"t", ",", "0", ",", "100", ",", "10"}], "}"}]}], "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<Days after\\nintake\>\"", ",", "\"\<AI\>\"", ",", "\"\<bb\>\"", 
        ",", "\"\<BB\>\""}], "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[16]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"Days after\\nintake\"\>",
        HoldForm], 
       TagBox["\<\"AI\"\>",
        HoldForm], 
       TagBox["\<\"bb\"\>",
        HoldForm], 
       TagBox["\<\"BB\"\>",
        HoldForm]},
      {"0", "0.05318900000000001`", "0.011030209999999999`", 
       "0.017755299999999998`"},
      {"10", "0.04987284790449266`", "0.0034587252445762566`", 
       "0.004529216078344519`"},
      {"20", "0.047142150225485985`", "0.0025853969235850208`", 
       "0.0033732159540632097`"},
      {"30", "0.04484754355666152`", "0.0019360588747911567`", 
       "0.0025155365802198276`"},
      {"40", "0.04291027162394983`", "0.0014529368168218523`", 
       "0.0018788756867220233`"},
      {"50", "0.041265911615949925`", "0.0010932012774089346`", 
       "0.0014059948763755104`"},
      {"60", "0.03986176431588312`", "0.0008250953374473403`", 
       "0.0010545084005333777`"},
      {"70", "0.03865471945722764`", "0.0006250667247958805`", 
       "0.0007930258885427081`"},
      {"80", "0.03760950977071896`", "0.0004756435778731962`", 
       "0.000598297195199564`"},
      {"90", "0.036697282946859075`", "0.0003638608964494478`", 
       "0.00045309896777544277`"},
      {"100", "0.035894433625481975`", "0.0002800948010769304`", 
       "0.0003446702051134617`"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {None, {"Days after\nintake", "AI", "bb", "BB"}}]]], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.39928168802684*^9, 3.4422202556775756`*^9, 
  3.442220348128334*^9, 3.442220704468255*^9, 3.476682536082135*^9, 
  3.4779017377957625`*^9, 3.5185327494238863`*^9, 3.58747415379152*^9, 
  3.5874756316726947`*^9, 3.5874757929483075`*^9, 3.587475970930292*^9, 
  3.6436090782259865`*^9, 3.6436096323518243`*^9, 3.6436097048050566`*^9, 
  3.6506055192786026`*^9},
 CellLabel->"Out[16]//TableForm="]
}, Open  ]],

Cell["\<\
In this example is evaluated the Lung retention where some by default \
parameters are modified (Some parameters instead of values are applied). \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", 
  StyleBox["LungsRetention", "Input"], 
  StyleBox["]", "Input"]}]], "Input",
 CellLabel->"In[17]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"IntakeType", "\[Rule]", "\<\"Acute\"\>"}], ",", 
    RowBox[{"fAI1", "\[Rule]", "0.3`"}], ",", 
    RowBox[{"fAI2", "\[Rule]", "0.6`"}], ",", 
    RowBox[{"fAI3", "\[Rule]", "0.1`"}], ",", 
    RowBox[{"fbs", "\[Rule]", "0.007`"}], ",", 
    RowBox[{"fBs", "\[Rule]", "0.007`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"AI1,bb1\"\>"], "\[Rule]", "0.02`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"AI2,bb1\"\>"], "\[Rule]", "0.001`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"AI3,bb1\"\>"], "\[Rule]", "0.0001`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"AI3,TH\"\>"], "\[Rule]", "0.00002`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"bb1,BB1\"\>"], "\[Rule]", "2"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"bb2,BB1\"\>"], "\[Rule]", "0.03`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"bbseq,TH\"\>"], "\[Rule]", "0.01`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"BB1,ET2\"\>"], "\[Rule]", "10"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"BB2,ET2\"\>"], "\[Rule]", "0.03`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"BBseq,TH\"\>"], "\[Rule]", "0.01`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"ETseq,ET\"\>"], "\[Rule]", "0.001`"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.39928168805812*^9, 3.442220255708825*^9, 
  3.442220348159583*^9, 3.442220704499505*^9, 3.4766825361290092`*^9, 
  3.4779017378426476`*^9, 3.5185327494707623`*^9, 3.5874741538227215`*^9, 
  3.5874756317226963`*^9, 3.587475792968308*^9, 3.587475970970293*^9, 
  3.6436090782416115`*^9, 3.6436096323518243`*^9, 3.6436097048050566`*^9, 
  3.650605519294247*^9},
 CellLabel->"Out[17]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"qLungsExample", "[", "t_", "]"}], "=", 
   RowBox[{
    RowBox[{
     StyleBox["LungsRetention", "Input"], 
     StyleBox["[", "Input"], 
     RowBox[{"A", ",", 
      RowBox[{"{", 
       RowBox[{
       "AI", ",", "0.006", ",", "0.004", ",", "0.01", ",", "0.005", ",", 
        "0.3", ",", " ", "0.5"}], "}"}], ",", "S", ",", " ", "t", ",", 
      RowBox[{
       RowBox[{"Log", "[", "2", "]"}], "/", "7.3"}], ",", " ", 
      RowBox[{"fAI1", "\[Rule]", "0.15"}], ",", " ", 
      RowBox[{"fAI2", "\[Rule]", "0.7"}], ",", 
      RowBox[{"fAI3", "\[Rule]", "0.15"}], " ", ",", " ", 
      RowBox[{
       SubscriptBox["k", "\"\<bb2,BB1\>\""], "\[Rule]", "0.05"}]}], "]"}], "//",
     "Expand"}]}]}]], "Input",
 CellLabel->"In[18]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"9.284127978248958`*^-8", " ", "A", " ", "AI", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "110.19495166856986`"}], " ", "t"}]]}], "-", 
   RowBox[{"2.3363587596855057`*^-6", " ", "A", " ", "AI", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "102.19495166856986`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.0001515156062136258`", " ", "A", " ", "AI", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.21495166856985`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.00069902147443901`", " ", "A", " ", "AI", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.19595166856986`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.00012475935695985263`", " ", "A", " ", "AI", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.19507166856987`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.0000249500748751956`", " ", "A", " ", "AI", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.19495166856986`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.00009293421399649143`", " ", "A", " ", "AI", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "10.095051668569855`"}], " ", "t"}]]}], "-", 
   RowBox[{"0.002338697457143175`", " ", "A", " ", "AI", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "2.0950516685698557`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.15166727348712458`", " ", "A", " ", "AI", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.11505166856985552`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.6997211956348156`", " ", "A", " ", "AI", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.09605166856985552`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.12488424120107385`", " ", "A", " ", "AI", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.09517166856985551`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.024975049925124802`", " ", "A", " ", "AI", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.09505166856985552`"}], " ", "t"}]]}], "+", 
   RowBox[{"8.375639833795023`*^-6", " ", "A", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "110.19495166856986`"}], " ", "t"}]]}], "+", 
   RowBox[{"7.3976972004945185`*^-6", " ", "A", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "102.19495166856986`"}], " ", "t"}]]}], "+", 
   RowBox[{"4.012072341740523`*^-6", " ", "A", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.24495166856985`"}], " ", "t"}]]}], "+", 
   RowBox[{"4.990014975039293`*^-6", " ", "A", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.22495166856986`"}], " ", "t"}]]}], "-", 
   RowBox[{"5.421010862427522`*^-20", " ", "A", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.20495166856986`"}], " ", "t"}]]}], "+", 
   RowBox[{"1.7465052412637635`*^-7", " ", "A", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.19495166856986`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.008384023857653642`", " ", "A", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "10.095051668569855`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.0074051023027995036`", " ", "A", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "2.0950516685698557`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.004016088430170823`", " ", "A", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.14505166856985552`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.004995009985024961`", " ", "A", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.1250516685698555`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.00017482534947587362`", " ", "A", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.09505166856985552`"}], " ", "t"}]]}], "+", "0.`"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.3992816884491177`*^9, 3.4422202560056925`*^9, 
  3.442220348472075*^9, 3.442220704796378*^9, 3.476682536457128*^9, 
  3.4779017381552114`*^9, 3.518532749767643*^9, 3.5874741541191287`*^9, 
  3.587475632052706*^9, 3.587475793268317*^9, 3.587475971280302*^9, 
  3.6436090785228615`*^9, 3.6436096324455843`*^9, 3.6436097048988066`*^9, 
  3.650605519419232*^9},
 CellLabel->"Out[18]="]
}, Open  ]],

Cell[TextData[{
 "You realize that the default parameters  given by ",
 StyleBox["Options[",
  FontWeight->"Bold"],
 "LungsRetention",
 StyleBox["]",
  FontWeight->"Bold"],
 " can be changed. The double subscript (e.i.:\"bb2, BB1\") of transfer \
coeffs. should be written with quotation marks. "
}], "MathCaption",
 CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Table", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"t", ",", " ", 
      RowBox[{"qLungsExample", "[", "t", "]"}]}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"t", ",", " ", "0", ",", " ", "100", ",", "10"}], "}"}]}], "]"}],
   "//", "TableForm"}]], "Input",
 CellLabel->"In[19]:="],

Cell[BoxData[
 FormBox[
  TagBox[GridBox[{
     {"0", 
      RowBox[{
       RowBox[{"1.`", " ", "A", " ", "AI"}], "+", 
       RowBox[{"0.025`", " ", "A"}], "+", "0.`"}]},
     {"10", 
      RowBox[{
       RowBox[{"0.3736474082679879`", " ", "A", " ", "AI"}], "+", 
       RowBox[{"0.0024395007008250844`", " ", "A"}], "+", "0.`"}]},
     {"20", 
      RowBox[{
       RowBox[{"0.14001469430763053`", " ", "A", " ", "AI"}], "+", 
       RowBox[{"0.0006564631704440644`", " ", "A"}], "+", "0.`"}]},
     {"30", 
      RowBox[{
       RowBox[{"0.05265432681781928`", " ", "A", " ", "AI"}], "+", 
       RowBox[{"0.00017914103550955372`", " ", "A"}], "+", "0.`"}]},
     {"40", 
      RowBox[{
       RowBox[{"0.019862060844575733`", " ", "A", " ", "AI"}], "+", 
       RowBox[{"0.00004962335336912687`", " ", "A"}], "+", "0.`"}]},
     {"50", 
      RowBox[{
       RowBox[{"0.0075118941571334485`", " ", "A", " ", "AI"}], "+", 
       RowBox[{"0.000013971156324003039`", " ", "A"}], "+", "0.`"}]},
     {"60", 
      RowBox[{
       RowBox[{"0.00284733312546126`", " ", "A", " ", "AI"}], "+", 
       RowBox[{"4.004212103700719`*^-6", " ", "A"}], "+", "0.`"}]},
     {"70", 
      RowBox[{
       RowBox[{"0.001081289248437165`", " ", "A", " ", "AI"}], "+", 
       RowBox[{"1.170435870582635`*^-6", " ", "A"}], "+", "0.`"}]},
     {"80", 
      RowBox[{
       RowBox[{"0.00041127466513392715`", " ", "A", " ", "AI"}], "+", 
       RowBox[{"3.496283434757837`*^-7", " ", "A"}], "+", "0.`"}]},
     {"90", 
      RowBox[{
       RowBox[{"0.00015663857359856943`", " ", "A", " ", "AI"}], "+", 
       RowBox[{"1.0694466121828233`*^-7", " ", "A"}], "+", "0.`"}]},
     {"100", 
      RowBox[{
       RowBox[{"0.00005972399100667384`", " ", "A", " ", "AI"}], "+", 
       RowBox[{"3.355236303917017`*^-8", " ", "A"}], "+", "0.`"}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   Function[BoxForm`e$, 
    TableForm[BoxForm`e$]]], TraditionalForm]], "Output",
 CellChangeTimes->{3.399281688511677*^9, 3.4422202560369415`*^9, 
  3.4422203485189486`*^9, 3.442220704843252*^9, 3.4766825365196266`*^9, 
  3.4779017382802367`*^9, 3.518532749814519*^9, 3.5874741541815305`*^9, 
  3.587475632102708*^9, 3.587475793298318*^9, 3.587475971320304*^9, 
  3.6436090788353662`*^9, 3.6436096324455843`*^9, 3.6436097048988066`*^9, 
  3.650605519466109*^9},
 CellLabel->"Out[19]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "RTAMAD5S", ",", "qLungsExample", ",", "qAI", ",", "qbb", ",", "qBB"}], 
  "]"}]], "Input",
 CellLabel->"In[20]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 2", "SubsubsectionIcon",
 CellTags->"Examples"],

Cell["\<\
Here is shown the thoracic lung retention fraction  for a single intake 1 Bq  \
of aerosols class F, M and S and AMAD = 5 \[Mu]m  in t = 0. (The radioactive \
decay constant is taken \"0\") \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"qLungs5F", "[", "t1_", "]"}], ",", " ", 
    RowBox[{"qLungs5M", "[", "t1_", "]"}], ",", " ", 
    RowBox[{"qLungs5S", "[", "t1_", "]"}]}], "}"}], "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{
      StyleBox["LungsRetention", "Input"], "[", 
      RowBox[{"1", ",", 
       RowBox[{"AMADAdultW", "[", "5", "]"}], ",", "#", ",", " ", "t1", ",", 
       "0"}], "]"}], "&"}], ",", 
    RowBox[{"{", 
     RowBox[{"F", ",", " ", "M", ",", " ", "S"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[21]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"0.`", "\[VeryThinSpace]", "+", 
     RowBox[{"0.01006337724365423`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00798948637352798`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "102"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.010318191574724172`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.03`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.01615017914617113`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.02`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.03193255793813499`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.001`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00443273582045417`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.00012000000001`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.0010879819033333335`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100"}], " ", "t1"}]]}]}], ",", 
    RowBox[{
     RowBox[{"0.001005884849745729`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.0007985890924887447`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "102"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.0010313548156344627`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.03`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.001614291120215815`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.02`"}], " ", "t1"}]]}], "-", 
     RowBox[{"8.131516293641283`*^-20", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.01`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.003191818756854436`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.001`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00044307409895934236`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.00012000000001`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00010874922869960179`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.009057492393908503`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "10.005`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.0071908972810392335`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.005`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00928683675908971`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.034999999999999996`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.014535888025955316`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.025`"}], " ", "t1"}]]}], "+", 
     RowBox[{"2.710505431213761`*^-20", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.015`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.02874073918128055`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.006`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.003989661721494828`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.00512`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.0009792326746337317`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.005`"}], " ", "t1"}]]}]}], ",", 
    RowBox[{"0.`", "\[VeryThinSpace]", "+", 
     RowBox[{"0.000010043280629059431`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110.1`"}], " ", "t1"}]]}], "+", 
     RowBox[{"7.97353132935344`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "102.1`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.000010297586094639224`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.13`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.000016117927157791034`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.11999999999999`"}], " ", "t1"}]]}], "-", 
     RowBox[{"5.421010862427522`*^-20", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.11`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.000031868788460523434`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.101`"}], " ", "t1"}]]}], "+", 
     RowBox[{"4.423883624891933`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.10012`"}], " ", "t1"}]]}], "+", 
     RowBox[{"1.085809198041101`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.1`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.010053333963025171`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "10.0001`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.007981512842198623`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.0001`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.010307893988629533`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0301`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.016134061219013337`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0201`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.03190068914967446`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0011`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.004428311936829278`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.00022`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.0010868960941352924`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0001`"}], " ", "t1"}]]}]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.399281688871395*^9, 3.442220256380683*^9, 
  3.4422203488783145`*^9, 3.4422207051870003`*^9, 3.47668253689462*^9, 
  3.477901738670942*^9, 3.5185327501426506`*^9, 3.5874741546963434`*^9, 
  3.587475632552721*^9, 3.5874757936483283`*^9, 3.587475971720316*^9, 
  3.6436090791791286`*^9, 3.643609632554949*^9, 3.6436097050081835`*^9, 
  3.650605519731743*^9},
 CellLabel->"Out[21]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{
   RowBox[{"TableForm", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"#1", ",", 
          RowBox[{"qLungs5F", "[", "#1", "]"}], ",", " ", 
          RowBox[{"qLungs5M", "[", "#1", "]"}], "  ", ",", 
          RowBox[{"qLungs5S", "[", "#1", "]"}]}], "}"}], "&"}], ")"}], "/@", 
      RowBox[{"Join", "[", 
       RowBox[{
        RowBox[{"Range", "[", 
         RowBox[{"0.25", ",", " ", "0.75", ",", " ", "0.25"}], "]"}], ",", 
        RowBox[{"Range", "[", "10", "]"}], ",", 
        RowBox[{"Range", "[", 
         RowBox[{"20", ",", "100", ",", "10"}], "]"}], ",", " ", 
        RowBox[{"Range", "[", 
         RowBox[{"200", ",", "1000", ",", "100"}], "]"}], ",", "  ", 
        RowBox[{"Range", "[", 
         RowBox[{"2000", ",", "10000", ",", "1000"}], "]"}]}], "]"}]}], ",", 
     RowBox[{"TableHeadings", "\[Rule]", 
      RowBox[{"{", 
       RowBox[{"None", ",", 
        RowBox[{"{", 
         RowBox[{
         "\"\<Days after\\nintake\>\"", ",", "\"\<Class F\>\"", ",", 
          "\"\<Class M\>\"", ",", "\"\<Class S\>\""}], "}"}]}], "}"}]}]}], 
    "]"}], ",", " ", 
   SuperscriptBox["10", 
    RowBox[{"-", "45"}]]}], "]"}]], "Input",
 CellLabel->"In[22]:="],

Cell[BoxData[
 FormBox[
  TagBox[
   TagBox[GridBox[{
      {
       TagBox["\<\"Days after\\nintake\"\>",
        HoldForm], 
       TagBox["\<\"Class F\"\>",
        HoldForm], 
       TagBox["\<\"Class M\"\>",
        HoldForm], 
       TagBox["\<\"Class S\"\>",
        HoldForm]},
      {"0.25`", "9.642094681294492`*^-13", "0.062410088142724994`", 
       "0.06935678259355905`"},
      {"0.5`", "1.2845103203910413`*^-23", "0.05979160089348118`", 
       "0.0665282860182201`"},
      {"0.75`", "1.7468879998135926`*^-34", "0.058477234336997655`", 
       "0.06514558502332594`"},
      {"1", "2.393726432015305`*^-45", "0.05762559969442553`", 
       "0.06427552500237536`"},
      {"2", "0", "0.05593276558815258`", "0.06269378801433073`"},
      {"3", "0", "0.05498583800741929`", "0.06193513789049532`"},
      {"4", "0", "0.05415636789713769`", "0.06130047409779483`"},
      {"5", "0", "0.053359294815146105`", "0.060694931817597914`"},
      {"6", "0", "0.05258269101268844`", "0.060105359291272434`"},
      {"7", "0", "0.05182449123151804`", "0.05952967062958558`"},
      {"8", "0", "0.05108397226897482`", "0.058967285487397984`"},
      {"9", "0", "0.050360605175065756`", "0.058417835123414426`"},
      {"10", "0", "0.049653900264422415`", "0.057880987087771014`"},
      {"20", "0", "0.04340630532925459`", "0.05313929788613847`"},
      {"30", "0", "0.038386792466525516`", "0.04935432825601153`"},
      {"40", "0", "0.034298371519371526`", "0.04631240670334732`"},
      {"50", "0", "0.03092126690692689`", "0.0438491883809243`"},
      {"60", "0", "0.028092204712756585`", "0.041837963228833416`"},
      {"70", "0", "0.025689367601014104`", "0.04018079749916242`"},
      {"80", "0", "0.02362144232042384`", "0.03880180963056222`"},
      {"90", "0", "0.021819627998477756`", "0.037642056328222546`"},
      {"100", "0", "0.020231790716410868`", "0.036655635365972564`"},
      {"200", "0", "0.010556103115000716`", "0.0312186664649487`"},
      {"300", "0", "0.005836340033898102`", "0.028174460369493545`"},
      {"400", "0", "0.0032551303788948944`", "0.0256500197832833`"},
      {"500", "0", "0.001819771626553487`", "0.023406716857724684`"},
      {"600", "0", "0.0010188962233987154`", "0.02139231874660401`"},
      {"700", "0", "0.0005713252284099428`", "0.019580131605462667`"},
      {"800", "0", "0.0003208486912963452`", "0.0179488559839372`"},
      {"900", "0", "0.0001804720465158918`", "0.01647975458899397`"},
      {"1000", "0", "0.00010168149765891541`", "0.01515608482609662`"},
      {"2000", "0", "3.6352848855164195`*^-7", "0.007276566540623153`"},
      {"3000", "0", "1.5887472477352625`*^-9", "0.004270569822741313`"},
      {"4000", "0", "8.191795546467708`*^-12", "0.002957011962681757`"},
      {"5000", "0", "4.669764224003561`*^-14", "0.002263663623664677`"},
      {"6000", "0", "2.800222529014985`*^-16", "0.0018228563480254336`"},
      {"7000", "0", "1.7199222254277957`*^-18", "0.0015035285167753596`"},
      {"8000", "0", "1.0690929143315241`*^-20", "0.0012550507091918428`"},
      {"9000", "0", "6.691568944533769`*^-23", "0.0010549132337941709`"},
      {"10000", "0", "4.208918921515847`*^-25", "0.0008910504723014032`"}
     },
     GridBoxAlignment->{
      "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
       "RowsIndexed" -> {}},
     GridBoxDividers->{
      "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
       "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
     GridBoxSpacings->{"Columns" -> {
         Offset[0.27999999999999997`], {
          Offset[2.0999999999999996`]}, 
         Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
         Offset[0.2], {
          Offset[0.4]}, 
         Offset[0.2]}, "RowsIndexed" -> {}}],
    {None, OutputFormsDump`HeadedColumns}],
   Function[BoxForm`e$, 
    TableForm[
    BoxForm`e$, 
     TableHeadings -> {
      None, {"Days after\nintake", "Class F", "Class M", "Class S"}}]]], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.3992816889339542`*^9, 3.4422202564588056`*^9, 
  3.442220348987687*^9, 3.4422207052963743`*^9, 3.476682537019617*^9, 
  3.477901738764711*^9, 3.5185327502207766`*^9, 3.587474154867948*^9, 
  3.5874756326327233`*^9, 3.58747579370833*^9, 3.5874759717903175`*^9, 
  3.6436090813197403`*^9, 3.6436096325705748`*^9, 3.6436097050238085`*^9, 
  3.6506055197786193`*^9},
 CellLabel->"Out[22]//TableForm="]
}, Open  ]],

Cell["\<\
This solution is the same that the obtained by Potter (in Table A1, Health \
Phys 83 (5):594-789; 2002)\
\>", "Text"],

Cell["\<\
Here is evaluated the lung retention for AMAD 1, 3, 5, and 10 \[Mu]m (Type S) \
for an acute input = \"1\"\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qLungs1S", "[", "t1_", "]"}], ",", 
     RowBox[{"qLungs3S", "[", "t1_", "]"}], ",", 
     RowBox[{"qLungs5S", "[", "t1_", "]"}], ",", 
     RowBox[{"qLungs10S", "[", "t1_", "]"}]}], "}"}], "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{
       StyleBox["LungsRetention", "Input"], "[", 
       RowBox[{"1", ",", 
        RowBox[{"AMADAdultW", "[", "#", "]"}], ",", "S", ",", "t1", ",", 
        "0"}], "]"}], "&"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", " ", "3", ",", " ", "5", ",", " ", "10"}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellLabel->"In[23]:="],

Cell["\<\
 We can eliminate the negligible terms for Lungs (AMAD 5, and S)\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"qLungs5SShort", "[", "t_", "]"}], "=", 
  RowBox[{"Drop", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"qLungs5S", "[", "t", "]"}], "//", "Chop"}], ",", " ", "7"}], 
   "]"}]}]], "Input",
 CellLabel->"In[24]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"0.010053333963025171`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.007981512842198623`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "2.0001`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.010307893988629533`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0301`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.016134061219013337`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0201`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.03190068914967446`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0011`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.004428311936829278`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.00022`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.0010868960941352924`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0001`"}], " ", "t"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.3992816895126305`*^9, 3.4422202695834694`*^9, 
  3.4422203499876614`*^9, 3.442220705858871*^9, 3.476682537613356*^9, 
  3.4779017394210954`*^9, 3.518532750970791*^9, 3.587474155772771*^9, 
  3.5874756332727423`*^9, 3.587475794298348*^9, 3.5874759724003363`*^9, 
  3.6436090819603786`*^9, 3.643609632742449*^9, 3.6436097051956835`*^9, 
  3.6506055199817505`*^9},
 CellLabel->"Out[24]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"PlotLegends", "\[Rule]", 
   RowBox[{"LineLegend", "[", 
    RowBox[{"\"\<Expressions\>\"", ",", 
     RowBox[{"LegendLabel", "\[Rule]", "\"\<label\>\""}], ",", 
     RowBox[{"LegendFunction", "\[Rule]", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"Framed", "[", 
         RowBox[{"#", ",", 
          RowBox[{"RoundingRadius", "\[Rule]", "5"}]}], "]"}], "&"}], ")"}]}],
      ",", 
     RowBox[{"LegendMargins", "\[Rule]", "5"}]}], "]"}]}], "]"}]], "Input"],

Cell["\<\
Here is shown the thoracic lung retention fraction  for AMAD 5,  Class F, M \
and S\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qLungs1S", "[", "t", "]"}], ",", 
     RowBox[{"qLungs3S", "[", "t", "]"}], ",", 
     RowBox[{"qLungs5S", "[", "t", "]"}], ",", 
     RowBox[{"qLungs10S", "[", "t", "]"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", "0", ",", " ", "1000"}], "}"}], ",", " ", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<days\>\"", ",", " ", "\"\<r\>\""}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"Style", "[", 
     RowBox[{
      RowBox[{
      "Framed", "[", 
       "\"\<Acute intake lung retention fraction,\\n class S, for different \
AMADs\>\"", "]"}], ",", "11", ",", 
      RowBox[{"Background", "\[Rule]", "LightBlue"}]}], "]"}]}], ",", " ", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"LineLegend", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<1\>\"", ",", "\"\<3\>\"", ",", " ", "\"\<5\>\"", ",", " ", 
        "\"\<10\>\""}], "}"}], ",", 
      RowBox[{"LegendLabel", "\[Rule]", "\"\<AMAD\>\""}], ",", 
      RowBox[{"LegendFunction", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Framed", "[", 
          RowBox[{"#", ",", 
           RowBox[{"RoundingRadius", "\[Rule]", "5"}]}], "]"}], "&"}], 
        ")"}]}], ",", 
      RowBox[{"LegendMargins", "\[Rule]", "5"}]}], "]"}]}]}], " ", 
  "]"}]], "Input",
 CellChangeTimes->{{3.44222006056019*^9, 3.44222006313815*^9}, {
   3.4422201091664543`*^9, 3.4422201309932675`*^9}, 3.442220294910946*^9, {
   3.4422203614561176`*^9, 3.442220377783825*^9}, {3.5874744446427865`*^9, 
   3.58747445697602*^9}, {3.587474507649087*^9, 3.587474541118433*^9}, 
   3.587475847729951*^9, {3.6506056825327525`*^9, 3.65060570843929*^9}, {
   3.6506057931435375`*^9, 3.650605834456645*^9}, 3.650606220317322*^9},
 CellLabel->"In[57]:="],

Cell[BoxData[
 FormBox[
  TemplateBox[{GraphicsBox[{{{}, {}, {
        Directive[
         Opacity[1.], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJwVk/c/FQofgGWFWxwNGbdSGkJEpczvl4yMRKWQ7CPKSEYUQlbKOUe4cukc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         "]]}, {
        Directive[
         Opacity[1.], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJwVlvk/FAgfgF0rqyIlDVsJLdZZwqYX3y8NSpNciUIo17oaIQkNucsMyUjk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         "]]}, {
        Directive[
         Opacity[1.], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJwVk2k41Qkbh0UhSVTWRLIkicpShOc5helQtmIczClCDELWSsa+NfwdHLJ2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         "]]}, {
        Directive[
         Opacity[1.], 
         RGBColor[0.922526, 0.385626, 0.209179], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJwVk2k4FQgbhoWkQlREzZAlI3u20uB9CUX2fUvWyu4gyTnJvuYsjn2XwviE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         "]]}}}, {
     DisplayFunction -> Identity, AspectRatio -> 
      NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
      AxesLabel -> {
        FormBox["\"days\"", TraditionalForm], 
        FormBox["\"r\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
      DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
      FrameLabel -> {{None, None}, {None, None}}, 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, None}, GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], 
      Method -> {
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None}, PlotLabel -> 
      FormBox[
        StyleBox[
         FrameBox[
         "\"Acute intake lung retention fraction,\\n class S, for different \
AMADs\"", StripOnInput -> False], 11, Background -> RGBColor[0.87, 0.94, 1], 
         StripOnInput -> False], TraditionalForm], 
      PlotRange -> {{0, 1000}, {0., 0.09817803017271953}}, PlotRangeClipping -> 
      True, PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
     FormBox[
      TemplateBox[{"\"1\"", "\"3\"", "\"5\"", "\"10\""}, "LineLegend", 
       DisplayFunction -> (FormBox[
         FrameBox[
          StyleBox[
           StyleBox[
            PaneBox[
             TagBox[
              GridBox[{{
                 StyleBox[
                 "\"AMAD\"", {FontFamily -> "Arial"}, Background -> Automatic,
                   StripOnInput -> False]}, {
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"]}}, GridBoxAlignment -> {"Columns" -> {{Center}}}, 
               AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
              "Grid"], Alignment -> Left, AppearanceElements -> None, 
             ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
             "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
           FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
           False], RoundingRadius -> 5, StripOnInput -> False], 
         TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                  "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendFunction", "\[Rule]", 
              RowBox[{"(", 
                RowBox[{
                  FrameBox["#1", RoundingRadius -> 5, StripOnInput -> False], 
                  "&"}], ")"}]}], ",", 
            RowBox[{"LegendLabel", "\[Rule]", "\"AMAD\""}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
            RowBox[{"LegendMargins", "\[Rule]", "5"}]}], "]"}]& ), Editable -> 
       True], TraditionalForm], TraditionalForm]},
   "Legended",
   DisplayFunction->(FormBox[
     GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}], TraditionalForm]& ),
   Editable->True,
   InterpretationFunction->(FormBox[
     RowBox[{"Legended", "(", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], ")"}], TraditionalForm]& )], 
  TraditionalForm]], "Output",
 CellChangeTimes->{
  3.5874744615924816`*^9, {3.5874745336876903`*^9, 3.5874745419935207`*^9}, 
   3.5874756342527723`*^9, 3.5874757951983747`*^9, 3.587475972830349*^9, 
   3.643609083038493*^9, 3.643609632898711*^9, 3.6436097052894344`*^9, 
   3.6506055202786474`*^9, 3.65060571648627*^9, {3.650605803190559*^9, 
   3.6506058355347257`*^9}, 3.650606227692268*^9},
 CellLabel->"Out[57]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 3", "SubsubsectionIcon",
 CellTags->"Examples"],

Cell[TextData[{
 "Not only single intakes  can be calculated. For instance, if we to estimate \
the retention of the lungs   for an daily constant intake (AMAD 5 \[Mu]m and \
S, and \[Lambda]=0) with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "c"], TraditionalForm]]],
 "= 0.3 Bq/day, the first step is to evaluate the retention for an acute unit \
intake  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "0"], TraditionalForm]]],
 "= 1 in ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 "=0. Now it can be calculated for a constant intake  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "c"], TraditionalForm]]],
 "= 0.3 Bq/day."
}], "MathCaption",
 CellTags->"Examples"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"inputconst", "[", "t_", "]"}], "=", 
  RowBox[{"LungsRetention", "[", 
   RowBox[{"0.3", ",", 
    RowBox[{"AMADAdultW", "[", "5", "]"}], ",", "S", ",", "t", ",", " ", "0", 
    ",", 
    RowBox[{"IntakeType", "\[Rule]", "\"\<Constant\>\""}]}], "]"}]}]], "Input",
 CellLabel->"In[26]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"18.344525793741152`", "\[VeryThinSpace]", "-", 
   RowBox[{"2.73658872726415`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "110.1`"}], " ", "t"}]]}], "-", 
   RowBox[{"2.3428593524055162`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "102.1`"}], " ", "t"}]]}], "-", 
   RowBox[{"3.085264983912681`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.13`"}], " ", "t"}]]}], "-", 
   RowBox[{"4.8295826481595195`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.11999999999999`"}], " ", "t"}]]}], "-", 
   RowBox[{"9.550990038218429`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.101`"}], " ", "t"}]]}], "-", 
   RowBox[{"1.3258376588035858`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.10012`"}], " ", "t"}]]}], "-", 
   RowBox[{"3.2541734207026003`*^-9", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.1`"}], " ", "t"}]]}], "-", 
   RowBox[{"0.0003015970029207259`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "-", 
   RowBox[{"0.0011971670679763945`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "2.0001`"}], " ", "t"}]]}], "-", 
   RowBox[{"0.10273648493650696`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0301`"}], " ", "t"}]]}], "-", 
   RowBox[{"0.2408068838658707`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0201`"}], " ", "t"}]]}], "-", 
   RowBox[{"8.700187949911216`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0011`"}], " ", "t"}]]}], "-", 
   RowBox[{"6.038607186585378`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.00022`"}], " ", "t"}]]}], "-", 
   RowBox[{"3.260688282405877`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0001`"}], " ", "t"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.399281690826382*^9, 3.442220706999489*^9, 
  3.4766825398164387`*^9, 3.477901740796377*^9, 3.5185327525333214`*^9, 
  3.587474158346837*^9, 3.5874756345627813`*^9, 3.5874757954483824`*^9, 
  3.587475973070356*^9, 3.6436090854603715`*^9, 3.6436096329611998`*^9, 
  3.643609705351948*^9, 3.650605520372403*^9},
 CellLabel->"Out[26]="]
}, Open  ]],

Cell[TextData[{
 "We can supposed other kinds of intakes: continuous ",
 Cell[BoxData[
  FormBox[
   RowBox[{"I", "(", "t", ")"}], TraditionalForm]]],
 " or multiple single intakes "
}], "Text"],

Cell[TextData[{
 " Here it assumed a periodic (",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"I", "(", "t", ")"}], "  ", "=", " ", 
    RowBox[{"0.3", "+", 
     RowBox[{"0.3", " ", 
      RowBox[{"Cos", "[", "t", "]"}]}]}]}], TraditionalForm]]],
 ") intake. "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"inputcos", "[", "t_", "]"}], "=", 
  RowBox[{"LungsRetention", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"0.3", "+", 
       RowBox[{"0.3", " ", 
        RowBox[{"Cos", "[", "t", "]"}]}]}], ",", "t"}], "}"}], ",", 
    RowBox[{"AMADAdultW", "[", "5", "]"}], ",", "S", ",", "t", ",", " ", "0", 
    ",", 
    RowBox[{"IntakeType", "\[Rule]", "\"\<Continuous\>\""}]}], 
   "]"}]}]], "Input",
 CellLabel->"In[27]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"5.4729517194404586`*^-8", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "110.1`"}], " ", "t"}]]}]}], "-", 
   RowBox[{"4.685493978939108`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "102.1`"}], " ", "t"}]]}], "-", 
   RowBox[{"6.170222272624019`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.13`"}], " ", "t"}]]}], "-", 
   RowBox[{"9.658683543130919`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.11999999999999`"}], " ", "t"}]]}], "-", 
   RowBox[{"1.9101026998929587`*^-7", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.101`"}], " ", "t"}]]}], "-", 
   RowBox[{"2.651543012132943`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.10012`"}], " ", "t"}]]}], "-", 
   RowBox[{"6.50802210633152`*^-9", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.1`"}], " ", "t"}]]}], "-", 
   RowBox[{"0.0006002079560316375`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "-", 
   RowBox[{"0.0021549198759771367`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "2.0001`"}], " ", "t"}]]}], "-", 
   RowBox[{"0.10282948096389351`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0301`"}], " ", "t"}]]}], "-", 
   RowBox[{"0.24090413296541266`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0201`"}], " ", "t"}]]}], "-", 
   RowBox[{"8.700198477125898`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0011`"}], " ", "t"}]]}], "-", 
   RowBox[{"6.038607478853952`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.00022`"}], " ", "t"}]]}], "-", 
   RowBox[{"3.2606883150127595`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0001`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.019661305794627944`", " ", 
    RowBox[{"sin", "(", "t", ")"}]}], "+", 
   RowBox[{"0.0014577029200076462`", " ", 
    RowBox[{"cos", "(", "t", ")"}]}], "+", "18.344525793741152`"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.3992816979581766`*^9, 3.442220716843176*^9, 
  3.476682550222489*^9, 3.4779017523925014`*^9, 3.518532758158429*^9, 
  3.5874741790329676`*^9, 3.587475653554889*^9, 3.587475815968998*^9, 
  3.587475993240961*^9, 3.6436091076791573`*^9, 3.6436096347268267`*^9, 
  3.64360970711756*^9, 3.650605522278701*^9},
 CellLabel->"Out[27]="]
}, Open  ]],

Cell["Here are compared both kind of intakes", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"inputconst", "[", "t", "]"}], ",", 
     RowBox[{"inputcos", "[", "t", "]"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0.1", ",", "100"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{3.5874758783608694`*^9},
 CellTags->"Examples",
 CellLabel->"In[28]:="],

Cell[BoxData[
 FormBox[
  GraphicsBox[{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVj3s0lAkYxj/aoVOIFutSsY6OOhYV0zqaet/UYpD75ct1Nl3cdsyQRGOa
tlJzimorW9tU01JZXahoM0qjjRI5FskldpDRRIxpvontYr/94z3PH8/5nd/z
frslI2ybPkEQm+j7P/v+Xdhae7YGCIUdm2GYBJ0pXQ499+RA2L/oMzuaDF5R
JQmdpY+BEHXfXj/zExi6re16Jmih+6WnXgXthBDevaFYyy4gKqu8M64LgTLV
JTsODwEh/XLh8nYx+A6aXz/MngIi+WI5e3cx8Nilz2UCAglJd/H9+lKYTDfX
83poioSn5bnWvCq4nX2is7PCCombc9PT/nwAIaOrvf1Y9ihipO/8EvgXCAJy
na2zHVEkW3I0zvApTCzYvLJp2zIk2hO3mcW1gIVRod94+XcoslRZafa0wXJy
WrmAuwLl7k2LpVXtkNo7/f3ZLauQ8EhauryuEwp2l5jF7fNAeTa0bX/bBQ2N
klwTwWok7jVWk6puMFHdsGpK90Ri5Oq+hq5ecHdKwQeHvFCumipyVL6CPIss
nVTIQsLYLXB+8wBI7JyYdRfXITF1t6s4WQEjwtwX/FhE+XGeLjBpEIwbC6I/
RaxHuR//pYH/EDjYqs6XJHkjEdq41Wj9MLCfZl7z5mxAHMuLuev4GuL3h+Z/
4W9E6UlWH8dqBHYtu59aJ/wBOaYtl298pYRLS4PsduX6oDT/jd6FASXUrGCe
8Rf7onzvgLX/01EYPrmh2/KQH0rbHA1spG9g4WC/++heNhImP9cU8lXgynoe
3lnoj3LXNKe9YW8hbnLYq0YcgPZ7jn0d6zAGOZXBStlvgSjipc8R6I3DmVjf
G/Irm1A0tHIss3ccniVsX1MnDUKCIXvJKHkHqozewu6KYBT9mNB4NW8CCsdl
4dlRIcjJEVmB9yQsKw7iitpDUHqMOeimr4aaRqMx682hyMs/7VaRqobwkoSA
iq5QPM4scs5oVsNrgz7jjoQwtJdvtT3sPgX5lmN3NP1hqGjtZRqcmgJr2/od
p2LCEeNzj3ycmoLrV+rzHw+Go71jKtcjWgO+A5E56sQIFE34EEbVGuiRmHeU
v4lAxW0bE3Ob98ANOcsa5UYiVt9xuSh4D0aVt8R245HIWedl/vnle5AWaz2V
WVEoH2hi7vbSwtrlzc1lmihsi5GkKE5rob9yR/o7bjQqFE48YlILWQ9dM+RU
NK4Y5mucgylYmCeOPJZFotyF8wu3jIJKOzOr+mwS1ZucFn36g4LghjO9mhwS
237XOy++RsFR07LEKAGJilva/aU3KWBcbUxZfJBE4hml7KmiYLpjjvBaMYmc
NVz9DfUU9LsIrzypITEkUfirSS8Fgg5Gykwtzc+ZZpzro8Amt9DZuY7E45fK
05z6KYh6LKksekTzvIeLUEFBW0ytLLKZ3jf2xIKvpODRoenW4VckmpqQW//W
UMBxEZ2w+If2i8d94rUUzLYbRvgO0vyBFnsVRQFryTc95SMkSk9nyYgZCqqr
mMP8CbpnCw+6zVIQEfPgcomaRJwscqgldKCZ3Zj8QkP7vLV3ffR14BoQ8c7z
A733QH1DPEMHLeq+itQZ2n/fGVUGOkgrTsqUfKT9qyZv7Zyrg3msMY/Wz/S/
84xtiXk6KBvM/DA7S/uTC/Ycma+D/wBub1Gw
      "]]}, 
    {RGBColor[0.880722, 0.611041, 0.142051], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwUl3c81X0Uxy8pSkalkj0iykzZnJ9ZJKtSGZkpspKEJCtUCA0hO00roRJZ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      "]]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{0, 0},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   Method->{
    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
     AbsolutePointSize[6], "ScalingFunctions" -> None},
   PlotRange->{{0.1, 100}, {0., 1.377818567771591}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}], TraditionalForm]], "Output",
 CellChangeTimes->{3.3992816988027315`*^9, 3.44222071771817*^9, 
  3.4766825510662227`*^9, 3.477901753298937*^9, 3.5185327588459425`*^9, 
  3.5874741800781946`*^9, 3.587475654522114*^9, 3.5874758169990287`*^9, 
  3.587475993970983*^9, 3.643609108304159*^9, 3.6436096349924517`*^9, 
  3.6436097072581863`*^9, 3.6506055226224613`*^9},
 CellTags->"Examples",
 CellLabel->"Out[28]="]
}, Open  ]],

Cell["\<\
 Here are assumed multiples intake: 3 Bq the at the beginning, that is \[Tau] \
= 0, follow 5 Bq the third day {\[Tau] = 3}, 6  Bq at \[Tau] =5. Then the \
lung retention starting when ceased the intake will be:\
\>", "MathCaption",
 CellChangeTimes->{3.4766825937372785`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"inputmultiple", "[", "t1_", "]"}], "=", 
  RowBox[{"LungsRetention", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"3", ",", " ", "0"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"5", ",", " ", "3"}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"6", ",", " ", "5"}], "}"}]}], "}"}], ",", 
    RowBox[{"AMADAdultW", "[", "5", "]"}], ",", "S", ",", " ", "t1", ",", " ",
     "0", ",", " ", 
    RowBox[{"IntakeType", "\[Rule]", "\"\<MultiInputs\>\""}]}], 
   "]"}]}]], "Input",
 CellLabel->"In[29]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"0.`", "\[VeryThinSpace]", "+", 
   RowBox[{"0.00006025968377435659`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "110.1`"}], " ", "t1"}]]}], "+", 
   RowBox[{"0.000047841187976120636`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "102.1`"}], " ", "t1"}]]}], "+", 
   RowBox[{"0.00006178551656783535`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.13`"}], " ", "t1"}]]}], "+", 
   RowBox[{"0.0000967075629467462`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.11999999999999`"}], " ", "t1"}]]}], "-", 
   RowBox[{"3.2526065174565133`*^-19", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.11`"}], " ", "t1"}]]}], "+", 
   RowBox[{"0.0001912127307631406`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.101`"}], " ", "t1"}]]}], "+", 
   RowBox[{"0.0000265433017493516`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.10012`"}], " ", "t1"}]]}], "+", 
   RowBox[{"6.514855188246606`*^-6", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.1`"}], " ", "t1"}]]}], "+", 
   RowBox[{"0.06032000388173764`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "10.0001`"}], " ", "t1"}]]}], "+", 
   RowBox[{"0.048620949953282915`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "2.0001`"}], " ", "t1"}]]}], "+", 
   RowBox[{"0.13697865709077264`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0301`"}], " ", "t1"}]]}], "+", 
   RowBox[{"0.2180702598855114`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0201`"}], " ", "t1"}]]}], "+", 
   RowBox[{"0.44573420970293176`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0011`"}], " ", "t1"}]]}], "+", 
   RowBox[{"0.061972021577385926`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.00022`"}], " ", "t1"}]]}], "+", 
   RowBox[{"0.015213828593859231`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0001`"}], " ", "t1"}]]}]}], TraditionalForm]], "Output",
 CellChangeTimes->{3.3992816990686097`*^9, 3.4422207179837933`*^9, 
  3.476682551316218*^9, 3.477901753564616*^9, 3.5185327590803223`*^9, 
  3.5874741805618067`*^9, 3.5874756547561197`*^9, 3.5874758172890377`*^9, 
  3.5874759942009897`*^9, 3.6436091097572837`*^9, 3.6436096350549517`*^9, 
  3.6436097073206863`*^9, 3.650605522763104*^9},
 CellLabel->"Out[29]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"inputmultiple", "[", "t", "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0.1", ",", " ", "100"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[30]:="],

Cell[BoxData[
 FormBox[
  GraphicsBox[{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVznk8lQkXwHFLSr2I7BWiJqRpZCmvpXNG1hZkfSxhqETlkokUItmSZCai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      "]]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{0, 0.5},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   Method->{
    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
     AbsolutePointSize[6], "ScalingFunctions" -> None},
   PlotRange->{{0.1, 100}, {0.5109607493523883, 0.9390655896034839}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->{Automatic, Automatic}], TraditionalForm]], "Output",
 CellChangeTimes->{3.399281699162449*^9, 3.442220718077543*^9, 
  3.4766825514255905`*^9, 3.477901753674014*^9, 3.5185327591740737`*^9, 
  3.587474180842614*^9, 3.5874756549277244`*^9, 3.587475817389041*^9, 
  3.5874759942709923`*^9, 3.6436091104916596`*^9, 3.643609635086214*^9, 
  3.643609707351939*^9, 3.650605522809967*^9},
 CellLabel->"Out[30]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"inputcos", ",", "inputconst", ",", "inputmultiple"}], 
  "]"}]], "Input",
 CellLabel->"In[31]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 4", "SubsubsectionIcon",
 CellTags->"Examples"],

Cell["\<\
Here is shown the retention  in each compartment of RT assuming a constant \
intake a (Bq/day) by inhalation (S, AMAD 5).\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"qRTConstant", "[", 
   RowBox[{"int_", ",", " ", "t1_"}], "]"}], "=", 
  RowBox[{"RespiratoryTract", "[", 
   RowBox[{"int", ",", 
    RowBox[{"AMADAdultW", "[", "5", "]"}], ",", "S", ",", " ", "t1", ",", "0",
     ",", 
    RowBox[{"IntakeType", "\[Rule]", "\"\<Constant\>\""}]}], "]"}]}]], "Input",
 CellLabel->"In[32]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["q", "ET1"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"0.3386996`", " ", "int"}], "-", 
      RowBox[{"0.3386996`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{"-", "t1"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "AI"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"1.590574749345051`*^-7", " ", "int", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "100.11999999999999`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"3.181753307248209`*^-7", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.101`"}], " ", "t1"}]]}], "-", 
      RowBox[{"5.302968797786916`*^-8", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.10012`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.7930733913238587`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0201`"}], " ", "t1"}]]}], "-", 
      RowBox[{"28.983227573835556`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t1"}]]}], "-", 
      RowBox[{"24.152689644862967`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00022`"}], " ", "t1"}]]}], "+", 
      RowBox[{"53.92899114028488`", " ", "int"}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "bb1"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"6.247624939749402`*^-8", " ", "int", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "102.1`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"1.6066411609543618`*^-9", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.11999999999999`"}], " ", "t1"}]]}], "-", 
      RowBox[{"1.5916724898691094`*^-10", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.101`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.003192445514603719`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2.0001`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.008010842336604634`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0201`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.014498863218527043`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.0012077069446598278`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00022`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.026909922259104675`", " ", "int"}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "bb2"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"4.3695646960093505`*^-8", " ", "int", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "100.13`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"0.14550248355049453`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0301`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.1455025272461415`", " ", "int"}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "bbseq"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"7.697260843969014`*^-10", " ", "int", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "100.11`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"0.007637070566504062`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0101`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.007637071336230146`", " ", "int"}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "BB1"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"9.121962424213835`*^-8", " ", "int", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "110.1`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"1.5619062349373505`*^-8", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "102.1`"}], " ", "t1"}]]}], "-", 
      RowBox[{"1.3148138503539838`*^-10", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.13`"}], " ", "t1"}]]}], "-", 
      RowBox[{"3.2197217654400695`*^-10", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.11999999999999`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.0010053233430690864`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "10.0001`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.0007981113786509297`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2.0001`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.00043782091339165854`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0301`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.0016053792257724713`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0201`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.002900062649970405`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.00024154428746341516`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00022`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.006988349122294753`", " ", "int"}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "BB2"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"5.901503778529722`*^-8", " ", "int", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "100.13`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"0.19651464532447036`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0301`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.19651470433950813`", " ", "int"}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "BBseq"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"1.2390260517512954`*^-9", " ", "int", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "100.11`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"0.012293372386332593`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0101`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.012293373625358645`", " ", "int"}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "LNth"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"2.008752136148332`*^-9", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.11`"}], " ", "t1"}]]}], "+", 
      RowBox[{"8.838281329647026`*^-9", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.10012`"}], " ", "t1"}]]}], "-", 
      RowBox[{"1.0847244735675335`*^-8", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.1`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.019930442952836653`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0101`"}], " ", "t1"}]]}], "+", 
      RowBox[{"4.025448274143828`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00022`"}], " ", "t1"}]]}], "-", 
      RowBox[{"10.868960941352924`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0001`"}], " ", "t1"}]]}], "+", 
      RowBox[{"6.82358222425647`", " ", "int"}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "ET2"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"1.9821042447733896`*^-6", " ", "int", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "200.1`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"1.0135513804690792`*^-8", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "110.1`"}], " ", "t1"}]]}], "-", 
      RowBox[{"1.5937818723798504`*^-9", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "102.1`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.003970156784391367`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.0001`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.00011170259367434294`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "10.0001`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.00008143993659703362`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2.0001`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.00010276731513104627`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0301`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.0001605700365845641`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0201`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.0002900091650886914`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.00002415445773169079`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00022`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.004742794188988448`", " ", "int"}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "ETseq"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"1.988508579876912`*^-9", " ", "int", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "100.101`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"0.18113722572965793`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.1811372277181665`", " ", "int"}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "LNet"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"1.9885085798774533`*^-9", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.101`"}], " ", "t1"}]]}], "-", 
      RowBox[{"1.9885284450974902`*^-9", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.1`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.18113722572965793`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t1"}]]}], "-", 
      RowBox[{"1.992509483026237`", " ", "int", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0001`"}], " ", "t1"}]]}], "+", 
      RowBox[{"1.8113722572965991`", " ", "int"}]}]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.399281699616006*^9, 3.4422207185306644`*^9, 
  3.4766825518630824`*^9, 3.4779017541584883`*^9, 3.5185327596115823`*^9, 
  3.5874741815134315`*^9, 3.5874756553645353`*^9, 3.5874758178190536`*^9, 
  3.587475994751006*^9, 3.643609112194787*^9, 3.643609635226827*^9, 
  3.6436097074925737`*^9, 3.6506055230287633`*^9},
 CellLabel->"Out[32]="]
}, Open  ]],

Cell["\<\
The same function can be applied for computing the total disintegration Us \
for each retention compartments for different times. Ex.. 50 years\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"qRTConstant", "[", 
  RowBox[{
   RowBox[{"3600", "*", "24"}], ",", "  ", 
   RowBox[{"365.24", "*", "50"}]}], "]"}]], "Input",
 CellLabel->"In[33]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["q", "ET1"], "(", "18262.`", ")"}], "\[Rule]", 
     "29263.64544`"}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "AI"], "(", "18262.`", ")"}], "\[Rule]", 
     "4.6219121995522855`*^6"}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "bb1"], "(", "18262.`", ")"}], "\[Rule]", 
     "2323.13953664583`"}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "bb2"], "(", "18262.`", ")"}], "\[Rule]", 
     "12571.418354066625`"}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "bbseq"], "(", "18262.`", ")"}], "\[Rule]", 
     "659.8429634502846`"}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "BB1"], "(", "18262.`", ")"}], "\[Rule]", 
     "603.4178103514165`"}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "BB2"], "(", "18262.`", ")"}], "\[Rule]", 
     "16978.8704549335`"}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "BBseq"], "(", "18262.`", ")"}], "\[Rule]", 
     "1062.1474812309868`"}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "LNth"], "(", "18262.`", ")"}], "\[Rule]", 
     "444601.8629545773`"}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "ET2"], "(", "18262.`", ")"}], "\[Rule]", 
     "409.73986250204996`"}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "ETseq"], "(", "18262.`", ")"}], "\[Rule]", 
     "15650.25644531526`"}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "LNet"], "(", "18262.`", ")"}], "\[Rule]", 
     "128781.77600813471`"}]}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.3992816996472855`*^9, 3.4422207185619144`*^9, 
  3.476682551925581*^9, 3.477901754205373*^9, 3.5185327596584578`*^9, 
  3.587474181731837*^9, 3.5874756553957367`*^9, 3.587475817869055*^9, 
  3.587475994801008*^9, 3.643609112272913*^9, 3.643609635242452*^9, 
  3.6436097074925737`*^9, 3.650605523059976*^9},
 CellLabel->"Out[33]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", "qRTConstant", "]"}]], "Input",
 CellLabel->"In[34]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 5", "SubsubsectionIcon",
 CellTags->"Examples"],

Cell["\<\
The thoracic lung retention for a  daily constant intake \"1\" for different \
AMADs can be evaluated as follow\
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qLungs1SChronic", "[", "t1_", "]"}], ",", 
     RowBox[{"qLungs3SChronic", "[", "t1_", "]"}], ",", 
     RowBox[{"qLungs5SChronic", "[", "t1_", "]"}], ",", 
     RowBox[{"qLungs10SChronic", "[", "t1_", "]"}]}], "}"}], "=", " ", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"LungsRetention", "[", 
       RowBox[{"1", ",", 
        RowBox[{"AMADAdultW", "[", "#", "]"}], ",", "S", ",", "t1", ",", "0", 
        ",", " ", 
        RowBox[{"IntakeType", "\[Rule]", "\"\<Constant\>\""}]}], "]"}], "&"}],
      ",", " ", 
     RowBox[{"{", 
      RowBox[{"1", ",", " ", "3", ",", " ", "5", ",", " ", "10"}], "}"}]}], 
    "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.6506063668174095`*^9, 3.6506063744892344`*^9}},
 CellLabel->"In[58]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"qLungs1SChronic", "[", "t", "]"}], ",", 
     RowBox[{"qLungs3SChronic", "[", "t", "]"}], ",", 
     RowBox[{"qLungs5SChronic", "[", "t", "]"}], ",", 
     RowBox[{"qLungs10SChronic", "[", "t", "]"}]}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", "0", ",", " ", "10000"}], "}"}], ",", " ", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"\"\<days\>\"", ",", " ", "\"\<r\>\""}], "}"}]}], ",", 
   "\[IndentingNewLine]", 
   RowBox[{"PlotLabel", "\[Rule]", 
    RowBox[{"Style", "[", 
     RowBox[{
      RowBox[{
      "Framed", "[", 
       "\"\<Chronic intake lung retention fraction,\\n class S, for different \
AMADs\>\"", "]"}], ",", "11", ",", 
      RowBox[{"Background", "\[Rule]", "LightBlue"}]}], "]"}]}], ",", "  ", 
   RowBox[{"PlotLegends", "\[Rule]", 
    RowBox[{"LineLegend", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
       "\"\<1\>\"", ",", "\"\<3\>\"", ",", " ", "\"\<5\>\"", ",", " ", 
        "\"\<10\>\""}], "}"}], ",", 
      RowBox[{"LegendLabel", "\[Rule]", "\"\<AMAD\>\""}], ",", 
      RowBox[{"LegendFunction", "\[Rule]", 
       RowBox[{"(", 
        RowBox[{
         RowBox[{"Framed", "[", 
          RowBox[{"#", ",", 
           RowBox[{"RoundingRadius", "\[Rule]", "5"}]}], "]"}], "&"}], 
        ")"}]}], ",", 
      RowBox[{"LegendMargins", "\[Rule]", "5"}]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.442220562172291*^9, 3.4422205762503257`*^9}, {
   3.5874746727325935`*^9, 3.5874747014242516`*^9}, 3.587475896181404*^9, {
   3.650606074239107*^9, 3.650606079817237*^9}, {3.6506061482704034`*^9, 
   3.6506061885985413`*^9}, {3.65060635141115*^9, 3.6506063618017807`*^9}},
 CellLabel->"In[59]:="],

Cell[BoxData[
 FormBox[
  TemplateBox[{GraphicsBox[{{{}, {}, {
        Directive[
         Opacity[1.], 
         RGBColor[0.368417, 0.506779, 0.709798], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJwVzHs8lIkCxvEpWy6FZESGYdxvIbesEc9OyaVIgzEz76GSJi1R2WNF5R4j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         "]]}, {
        Directive[
         Opacity[1.], 
         RGBColor[0.880722, 0.611041, 0.142051], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJwVz3k81AkfB3DR5mh5COWeRe4zjWURn+Qm5pCcocNjsY6dUqIwSDN5anK0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         "]]}, {
        Directive[
         Opacity[1.], 
         RGBColor[0.560181, 0.691569, 0.194885], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJwVz3k81AkfB/BJh2Mfypkr49gkNFmNowbzcc/Mr3KsM+SoUIQldt3LSGbS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         "]]}, {
        Directive[
         Opacity[1.], 
         RGBColor[0.922526, 0.385626, 0.209179], 
         AbsoluteThickness[1.6]], 
        LineBox[CompressedData["
1:eJwVz3k41IkDx/FhKscaRhRyaylGFMN8HZlPtvmRcuwklAhFkqOyKeQalLHa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         "]]}}}, {
     DisplayFunction -> Identity, AspectRatio -> 
      NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
      AxesLabel -> {
        FormBox["\"days\"", TraditionalForm], 
        FormBox["\"r\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
      DisplayFunction :> Identity, Frame -> {{False, False}, {False, False}}, 
      FrameLabel -> {{None, None}, {None, None}}, 
      FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
      GridLines -> {None, None}, GridLinesStyle -> Directive[
        GrayLevel[0.5, 0.4]], 
      Method -> {
       "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
        AbsolutePointSize[6], "ScalingFunctions" -> None}, PlotLabel -> 
      FormBox[
        StyleBox[
         FrameBox[
         "\"Chronic intake lung retention fraction,\\n class S, for different \
AMADs\"", StripOnInput -> False], 11, Background -> RGBColor[0.87, 0.94, 1], 
         StripOnInput -> False], TraditionalForm], 
      PlotRange -> {{0, 10000}, {0., 108.5692469707318}}, PlotRangeClipping -> 
      True, PlotRangePadding -> {{
         Scaled[0.02], 
         Scaled[0.02]}, {
         Scaled[0.05], 
         Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
     FormBox[
      TemplateBox[{"\"1\"", "\"3\"", "\"5\"", "\"10\""}, "LineLegend", 
       DisplayFunction -> (FormBox[
         FrameBox[
          StyleBox[
           StyleBox[
            PaneBox[
             TagBox[
              GridBox[{{
                 StyleBox[
                 "\"AMAD\"", {FontFamily -> "Arial"}, Background -> Automatic,
                   StripOnInput -> False]}, {
                 TagBox[
                  GridBox[{{
                    TagBox[
                    GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {
                    LineBox[{{0, 10}, {20, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    AbsoluteThickness[1.6]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {20, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #4}}, 
                    GridBoxAlignment -> {
                    "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                    AutoDelete -> False, 
                    GridBoxDividers -> {
                    "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                    GridBoxItemSize -> {
                    "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                    GridBoxSpacings -> {
                    "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
                   GridBoxAlignment -> {
                    "Columns" -> {{Left}}, "Rows" -> {{Top}}}, AutoDelete -> 
                   False, GridBoxItemSize -> {
                    "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                   GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
                  "Grid"]}}, GridBoxAlignment -> {"Columns" -> {{Center}}}, 
               AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
              "Grid"], Alignment -> Left, AppearanceElements -> None, 
             ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
             "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
           FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
           False], RoundingRadius -> 5, StripOnInput -> False], 
         TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.368417, 0.506779, 0.709798], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.24561133333333335`, 0.3378526666666667, 
                    0.4731986666666667], FrameTicks -> None, PlotRangePadding -> 
                    None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.368417, 0.506779, 0.709798]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.368417, 0.506779, 0.709798]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.368417, 0.506779, 0.709798], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.880722, 0.611041, 0.142051], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.587148, 0.40736066666666665`, 0.09470066666666668], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.880722, 0.611041, 0.142051]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.880722, 0.611041, 0.142051]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.880722, 0.611041, 0.142051], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.922526, 0.385626, 0.209179], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.6150173333333333, 0.25708400000000003`, 
                    0.13945266666666667`], FrameTicks -> None, 
                    PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "RGBColor[0.922526, 0.385626, 0.209179]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.922526, 0.385626, 0.209179]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.922526, 0.385626, 0.209179], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}]}], 
                  "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3, ",", #4}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendFunction", "\[Rule]", 
              RowBox[{"(", 
                RowBox[{
                  FrameBox["#1", RoundingRadius -> 5, StripOnInput -> False], 
                  "&"}], ")"}]}], ",", 
            RowBox[{"LegendLabel", "\[Rule]", "\"AMAD\""}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}], ",", 
            RowBox[{"LegendMargins", "\[Rule]", "5"}]}], "]"}]& ), Editable -> 
       True], TraditionalForm], TraditionalForm]},
   "Legended",
   DisplayFunction->(FormBox[
     GridBox[{{
        TagBox[
         ItemBox[
          PaneBox[
           TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
           BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
         "SkipImageSizeLevel"], 
        ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
      GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
      AutoDelete -> False, GridBoxItemSize -> Automatic, 
      BaselinePosition -> {1, 1}], TraditionalForm]& ),
   Editable->True,
   InterpretationFunction->(FormBox[
     RowBox[{"Legended", "(", 
       RowBox[{#, ",", 
         RowBox[{"Placed", "[", 
           RowBox[{#2, ",", "After"}], "]"}]}], ")"}], TraditionalForm]& )], 
  TraditionalForm]], "Output",
 CellChangeTimes->{{3.6506061730516233`*^9, 3.6506061898953705`*^9}, 
   3.650606381301736*^9},
 CellLabel->"Out[59]="]
}, Open  ]],

Cell["\<\
Input more complicated  can be evaluated. Here is supposed  a continuous \
input: 1+0.3 Cos[t] Bq/day \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RespiratoryTract", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "+", 
      RowBox[{"0.3", " ", 
       RowBox[{"Cos", "[", "t", "]"}]}]}], ",", " ", "t"}], "}"}], ",", 
   RowBox[{"AMADAdultW", "[", "5", "]"}], ",", "S", ",", " ", "t1", ",", "0", 
   ",", 
   RowBox[{"IntakeType", "\[Rule]", "\"\<Continuous\>\""}]}], "]"}]], "Input",
 CellLabel->"In[37]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["q", "ET1"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"0.38950454`", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{"-", "t1"}]]}]}], "+", 
      RowBox[{"0.05080494`", " ", 
       RowBox[{"sin", "(", "t1", ")"}]}], "+", 
      RowBox[{"0.05080494`", " ", 
       RowBox[{"cos", "(", "t1", ")"}]}], "+", "0.3386996`"}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "AI"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"2.0676995759700737`*^-7", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "100.11999999999999`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"4.13618404885183`*^-7", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.101`"}], " ", "t1"}]]}], "-", 
      RowBox[{"6.893700681984995`*^-8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.10012`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.7931694753791881`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0201`"}], " ", "t1"}]]}], "-", 
      RowBox[{"28.983238094734435`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t1"}]]}], "-", 
      RowBox[{"24.152689995560003`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00022`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.015938833814890103`", " ", 
       RowBox[{"sin", "(", "t1", ")"}]}], "+", 
      RowBox[{"0.00010711471412078116`", " ", 
       RowBox[{"cos", "(", "t1", ")"}]}], "+", "53.92899114028488`"}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "bb1"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"8.121732640976684`*^-8", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "102.1`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"2.088585430272496`*^-9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.11999999999999`"}], " ", "t1"}]]}], "-", 
      RowBox[{"2.069126587719866`*^-10", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.101`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.0039586477610043126`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2.0001`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.008011812882618062`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0201`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.014498868481608022`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.0012077069621957317`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00022`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.0004362323569906431`", " ", 
       RowBox[{"sin", "(", "t1", ")"}]}], "+", 
      RowBox[{"0.0007671973437975978`", " ", 
       RowBox[{"cos", "(", "t1", ")"}]}], "+", "0.026909922259104675`"}]}], 
    ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "bb2"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"5.68030337107331`*^-8", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "100.13`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"0.14554199576357083`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0301`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.0013126982397510616`", " ", 
       RowBox[{"sin", "(", "t1", ")"}]}], "+", 
      RowBox[{"0.00003952532046305643`", " ", 
       RowBox[{"cos", "(", "t1", ")"}]}], "+", "0.1455025272461415`"}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "bbseq"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"1.0006208709504774`*^-9", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "100.11`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"0.007637304259935541`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0101`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.000023137965819260175`", " ", 
       RowBox[{"sin", "(", "t1", ")"}]}], "+", 
      RowBox[{"2.3392432626633213`*^-7", " ", 
       RowBox[{"cos", "(", "t1", ")"}]}], "+", "0.007637071336230146`"}]}], 
    ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "BB1"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"1.1858325416390144`*^-7", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "110.1`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"2.030433160244171`*^-8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "102.1`"}], " ", "t1"}]]}], "-", 
      RowBox[{"1.7092186673241171`*^-10", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.13`"}], " ", "t1"}]]}], "-", 
      RowBox[{"4.1855419444344666`*^-10", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.11999999999999`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.001303934296179998`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "10.0001`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.0009896619402510781`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2.0001`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.000437939806710845`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0301`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.0016055737239715551`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0201`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.002900063702691873`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.00024154429097063805`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00022`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.00014023101777122188`", " ", 
       RowBox[{"sin", "(", "t1", ")"}]}], "+", 
      RowBox[{"0.0004905081569297328`", " ", 
       RowBox[{"cos", "(", "t1", ")"}]}], "+", "0.006988349122294753`"}]}], 
    ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "BB2"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"7.671778344007501`*^-8", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "100.13`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"0.19656801024546142`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0301`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.0017729211399557564`", " ", 
       RowBox[{"sin", "(", "t1", ")"}]}], "+", 
      RowBox[{"0.00005338262373671468`", " ", 
       RowBox[{"cos", "(", "t1", ")"}]}], "+", "0.19651470433950813`"}]}], 
    ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "BBseq"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"1.6106967818365173`*^-9", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "100.11`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"0.012293748562034048`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0101`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.00003724512266862647`", " ", 
       RowBox[{"sin", "(", "t1", ")"}]}], "+", 
      RowBox[{"3.7654737218571607`*^-7", " ", 
       RowBox[{"cos", "(", "t1", ")"}]}], "+", "0.012293373625358645`"}]}], 
    ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "LNth"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"2.6113176527871707`*^-9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.11`"}], " ", "t1"}]]}], "+", 
      RowBox[{"1.1489501136644475`*^-8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.10012`"}], " ", "t1"}]]}], "-", 
      RowBox[{"1.4101093421304255`*^-8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.1`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.019931052821969587`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0101`"}], " ", "t1"}]]}], "+", 
      RowBox[{"4.025448332593334`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00022`"}], " ", "t1"}]]}], "-", 
      RowBox[{"10.868960973959807`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0001`"}], " ", "t1"}]]}], "+", 
      RowBox[{"6.169277711896761`*^-9", " ", 
       RowBox[{"sin", "(", "t1", ")"}]}], "-", 
      RowBox[{"6.357116931870392`*^-7", " ", 
       RowBox[{"cos", "(", "t1", ")"}]}], "+", "6.82358222425647`"}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "ET2"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"2.5767206676491033`*^-6", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "200.1`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"1.317591712933376`*^-8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "110.1`"}], " ", "t1"}]]}], "-", 
      RowBox[{"2.071870571670964`*^-9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "102.1`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.005161084727152686`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.0001`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.00014488158846444424`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "10.0001`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.00010098591227051816`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2.0001`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.00010279522231141635`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0301`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.0001605894902952146`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0201`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.00029000927036189095`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.0000241544580824135`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00022`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.000026994929366548606`", " ", 
       RowBox[{"sin", "(", "t1", ")"}]}], "+", 
      RowBox[{"0.0012442985335725306`", " ", 
       RowBox[{"cos", "(", "t1", ")"}]}], "+", "0.004742794188988449`"}]}], 
    ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "ETseq"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"2.5850016248447843`*^-9", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "100.101`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"0.1811372914823913`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.00005977521812169235`", " ", 
       RowBox[{"sin", "(", "t1", ")"}]}], "+", 
      RowBox[{"6.634922642402631`*^-8", " ", 
       RowBox[{"cos", "(", "t1", ")"}]}], "+", "0.1811372277181665`"}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "LNet"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"2.5850016248454882`*^-9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.101`"}], " ", "t1"}]]}], "-", 
      RowBox[{"2.5850274478475513`*^-9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.1`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.1811372914823913`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t1"}]]}], "-", 
      RowBox[{"1.9925094890037656`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0001`"}], " ", "t1"}]]}], "-", 
      RowBox[{"5.977519903197298`*^-8", " ", 
       RowBox[{"cos", "(", "t1", ")"}]}], "+", "1.8113722572965991`"}]}]}], 
   "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.3992817175236917`*^9, 3.4422207401399016`*^9, 
  3.4766825750345125`*^9, 3.477901781101505*^9, 3.518532776330653*^9, 
  3.5874742411849613`*^9, 3.587475714348939*^9, 3.5874758800909214`*^9, 
  3.5874760555028286`*^9, 3.6436096415549617`*^9, 3.6436097153988233`*^9, 
  3.6506055301539564`*^9},
 CellLabel->"Out[37]="]
}, Open  ]],

Cell[TextData[{
 "Here is supposed a constant intake during  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"0", "<", "t", "<", "T"}], TraditionalForm]]],
 ", in ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"t", "=", "T"}]}], TraditionalForm]]],
 " it is cutted the intake. We want to know the retention in lungs (AMAD 5, \
and S) as function of ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 ". At the en of ",
 Cell[BoxData[
  FormBox["T", TraditionalForm]]],
 " the retention in lungs is qLungs5SCronic[T] that it must be multiplied by \
1/ qLungs5S[0] because  of the total intake only the fraction qLungs5S[0] is \
retained in Lungs."
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"qLungscutting", "[", 
    RowBox[{"t1_", ",", "T_"}], "]"}], ":=", 
   RowBox[{"If", "[", 
    RowBox[{
     RowBox[{"t1", "<", "T"}], ",", 
     RowBox[{"qLungs5SCronic", "[", "t1", "]"}], ",", 
     RowBox[{
      FractionBox[
       RowBox[{"1", " "}], 
       RowBox[{"qLungs5S", "[", "0", "]"}]], 
      RowBox[{"qLungs5SCronic", "[", "T", "]"}], 
      RowBox[{"qLungs5S", "[", 
       RowBox[{"t1", " ", "-", "T"}], " ", "]"}]}]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[38]:="],

Cell[TextData[{
 "Now we plot in log-scale the retention in Lungs assuming a constant intake \
during  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"T", " ", "="}], TraditionalForm]]],
 "200 days"
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"LogPlot", "[", 
  RowBox[{
   RowBox[{"qLungscutting", "[", 
    RowBox[{"t", ",", "200"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", "1000"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[39]:="],

Cell[BoxData[
 FormBox[
  GraphicsBox[{{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
     1.], LineBox[CompressedData["
1:eJwVU3k4FIoXHVTWRCERJRGiZCsV9xKJLBEVksJkRsNY40kSZanMZOsR2Soq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      "]]}},
   AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
   Axes->{True, True},
   AxesLabel->{None, None},
   AxesOrigin->{0, -0.389172274297685},
   CoordinatesToolOptions:>{"DisplayFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& ), "CopiedValueFunction" -> ({
       Part[#, 1], 
       Exp[
        Part[#, 2]]}& )},
   DisplayFunction->Identity,
   Frame->{{False, False}, {False, False}},
   FrameLabel->{{None, None}, {None, None}},
   FrameTicks->{{
      Charting`ScaledTicks[{Log, Exp}], 
      Charting`ScaledFrameTicks[{Log, Exp}]}, {Automatic, Automatic}},
   GridLines->{None, None},
   GridLinesStyle->Directive[
     GrayLevel[0.5, 0.4]],
   Method->{
    "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
     AbsolutePointSize[6], "ScalingFunctions" -> None},
   PlotRange->{{0, 1000}, {-0.389172274297685, 2.195230265385453}},
   PlotRangeClipping->True,
   PlotRangePadding->{{
      Scaled[0.02], 
      Scaled[0.02]}, {
      Scaled[0.05], 
      Scaled[0.05]}},
   Ticks->FrontEndValueCache[{Automatic, 
      Charting`ScaledTicks[{Log, Exp}]}, {Automatic, {{0., 
        FormBox["1", TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {0.6931471805599453, 
        FormBox["2", TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {1.6094379124341003`, 
        FormBox["5", TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {2.302585092994046, 
        FormBox["10", TraditionalForm], {0.01, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.6931471805599453, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.5108256237659907, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.35667494393873245`, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.2231435513142097, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {-0.10536051565782628`, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {0.4054651081081644, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.0986122886681098`, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.3862943611198906`, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.791759469228055, 
        FormBox[
         InterpretationBox[
          StyleBox[
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {1.9459101490553132`, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.0794415416798357`, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.1972245773362196`, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.70805020110221, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {2.995732273553991, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.4011973816621555`, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.6888794541139363`, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}, {3.912023005428146, 
        FormBox[
         InterpretationBox[
          StyleBox[
           
           GraphicsBox[{}, ImageSize -> {0., 0.}, BaselinePosition -> 
            Baseline], "CacheGraphics" -> False], 
          Spacer[{0., 0.}]], TraditionalForm], {0.005, 0.}, {
         AbsoluteThickness[0.1]}}}}]], TraditionalForm]], "Output",
 CellChangeTimes->{3.39928171778957*^9, 3.4422207405461493`*^9, 
  3.4766825770188494`*^9, 3.4779017825549273`*^9, 3.518532776596283*^9, 
  3.587474241481369*^9, 3.587475714638948*^9, 3.5874758803909307`*^9, 
  3.5874760557928376`*^9, 3.643609641648712*^9, 3.64360971547696*^9, 
  3.650605530247712*^9},
 CellLabel->"Out[39]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "qLungs1SChronic", ",", "qLungs3SChronic", ",", "qLungs5SChronic", ",", 
   "qLungs10SChronic", ",", " ", "qLungscutting"}], "]"}]], "Input",
 CellChangeTimes->{{3.650606406504933*^9, 3.650606412286187*^9}},
 CellLabel->"In[40]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 6", "SubsubsectionIcon",
 CellTags->"Examples"],

Cell[TextData[{
 "Here is evaluated the retention in RT for a child 10 y old (breathing rate \
1.12 m3/h) of a intake \"int\"  of U-238 (\[Lambda] = 0)  of aerosols type S  \
and AMAD = 1 \[Mu]m  in t = 0. Also, are changed same clearance rates. {",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["k", "\<\"ET2,ST\"\>"], "\[Rule]", "50"}]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["k", "\<\"AI3,bb1\"\>"], "\[Rule]", "0.003"}]]],
 "}"
}], "MathCaption",
 CellTags->"Examples"],

Cell[TextData[{
 "The fractional deposition ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"AI", ",", 
    SubscriptBox["bb", 
     RowBox[{"fast", "+", "seq"}]], ",", 
    SubscriptBox["bb", "slow"], ",", " ", 
    SubscriptBox["BB", 
     RowBox[{"fast", "+", "seq"}]], " ", ",", " ", 
    SubscriptBox["BB", "slow"], ",", "  ", 
    SubscriptBox["ET", "2"], ",", " ", 
    SubscriptBox["ET", "1"]}], "}"}]]],
 " are taken from ICRP 66, Table F5 "
}], "SmallText"],

Cell["By default RespiratoryTract has the following options", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "RespiratoryTract", "]"}]], "Input",
 CellLabel->"In[41]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"IntakeType", "\[Rule]", "\<\"Acute\"\>"}], ",", 
    RowBox[{"fAI1", "\[Rule]", "0.3`"}], ",", 
    RowBox[{"fAI2", "\[Rule]", "0.6`"}], ",", 
    RowBox[{"fAI3", "\[Rule]", "0.1`"}], ",", 
    RowBox[{"fbs", "\[Rule]", "0.007`"}], ",", 
    RowBox[{"fBs", "\[Rule]", "0.007`"}], ",", 
    RowBox[{"fet2", "\[Rule]", "0.9995`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"AI1,bb1\"\>"], "\[Rule]", "0.02`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"AI2,bb1\"\>"], "\[Rule]", "0.001`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"AI3,bb1\"\>"], "\[Rule]", "0.0001`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"AI3,TH\"\>"], "\[Rule]", "0.00002`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"bb1,BB1\"\>"], "\[Rule]", "2"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"bb2,BB1\"\>"], "\[Rule]", "0.03`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"bbseq,TH\"\>"], "\[Rule]", "0.01`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"BB1,ET2\"\>"], "\[Rule]", "10"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"BB2,ET2\"\>"], "\[Rule]", "0.03`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"BBseq,TH\"\>"], "\[Rule]", "0.01`"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"ET2,ST\"\>"], "\[Rule]", "100"}], ",", 
    RowBox[{
     SubscriptBox["k", "\<\"ETseq,ET\"\>"], "\[Rule]", "0.001`"}], ",", 
    RowBox[{
     SubscriptBox["k", "Env"], "\[Rule]", "1"}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.3992817178208494`*^9, 3.4422207405617743`*^9, 
  3.476682577706336*^9, 3.477901783476991*^9, 3.518532776643159*^9, 
  3.58747424152817*^9, 3.5874757146589484`*^9, 3.587475880410931*^9, 
  3.5874760558128386`*^9, 3.643609641664336*^9, 3.6436097154925737`*^9, 
  3.650605530278961*^9},
 CellLabel->"Out[41]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"RespiratoryTract", "[", 
  RowBox[{"int", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"8.0", " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "2"}]}]}], ",", " ", 
     RowBox[{"6.4", " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "3"}]}]}], ",", " ", 
     RowBox[{"6.3", " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "3"}]}]}], " ", ",", " ", 
     RowBox[{"6.8", " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "3"}]}]}], ",", 
     RowBox[{"6.2", " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "3"}]}]}], ",", 
     RowBox[{"2.7", " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "1"}]}]}], ",", 
     RowBox[{"2.1", " ", 
      RowBox[{"10", "^", 
       RowBox[{"-", "1"}]}]}]}], " ", "}"}], ",", "S", ",", " ", "t1", ",", 
   "0", ",", " ", 
   RowBox[{
    SubscriptBox["k", "\"\<ET2,ST\>\""], "\[Rule]", "50"}], ",", 
   RowBox[{
    SubscriptBox["k", "\"\<AI3,bb1\>\""], "\[Rule]", "0.003"}]}], 
  "]"}]], "Input",
 CellLabel->"In[42]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     RowBox[{
      SubscriptBox["q", "ET1"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{"0.21000000000000002`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{"-", "t1"}]]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "AI"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"0.000023952071880189996`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.11999999999999`"}], " ", "t1"}]]}], "+", 
      RowBox[{"7.984023960062175`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.10302`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.00004790414376037999`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.101`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.02397604792811981`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0201`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.007992015976039938`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00312`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.04795209585623962`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t1"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "bb1"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"6.020598380781367`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "102.1`"}], " ", "t1"}]]}], "+", 
      RowBox[{"2.4194012000189314`*^-7", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.11999999999999`"}], " ", "t1"}]]}], "+", 
      RowBox[{"1.1994147102219194`*^-8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.10302`"}], " ", "t1"}]]}], "+", 
      RowBox[{"2.3964053907148618`*^-8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.101`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.006026625005789396`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2.0001`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.00024218230230424055`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0201`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.000012006153255475676`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00312`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.000023988041949094356`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t1"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "bb2"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"6.2874188685490065`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.13`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.006293712581131451`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0301`"}], " ", "t1"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "bbseq"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"8.8722466256189`*^-8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.11`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.0000888112775337438`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0101`"}], " ", "t1"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "BB1"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"5.115855646484202`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "110.1`"}], " ", "t1"}]]}], "+", 
      RowBox[{"1.5051495951959922`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "102.1`"}], " ", "t1"}]]}], "+", 
      RowBox[{"1.8919013646584486`*^-8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.13`"}], " ", "t1"}]]}], "+", 
      RowBox[{"4.8484993988360105`*^-8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.11999999999999`"}], " ", "t1"}]]}], "+", 
      RowBox[{"2.3995540857778008`*^-9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.10302`"}], " ", "t1"}]]}], "+", 
      RowBox[{"4.793290110439916`*^-9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.101`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.005120976623104616`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "10.0001`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.001506656251447349`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2.0001`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.000018937951598188918`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0301`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.000048533527515879866`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0201`"}], " ", "t1"}]]}], "+", 
      RowBox[{"2.4019560418197646`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00312`"}], " ", "t1"}]]}], "+", 
      RowBox[{"4.7980881986387344`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t1"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "BB2"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"6.187618569047926`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.13`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.006193812381430953`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0301`"}], " ", "t1"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "BBseq"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"9.081827254573088`*^-8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.11`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.00009090918172745429`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0101`"}], " ", "t1"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "LNth"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"1.7954073880193343`*^-7", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "100.11`"}], " ", "t1"}]]}]}], "-", 
      RowBox[{"5.287433086133828`*^-8", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.10302`"}], " ", "t1"}]]}], "+", 
      RowBox[{"2.3241506966325816`*^-7", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.1`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.0001797204592611981`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0101`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.000052927258119469785`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00312`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.00023264771738066786`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0001`"}], " ", "t1"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "ET2"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"0.0002677149011332536`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "150.1`"}], " ", "t1"}]]}], "+", 
      RowBox[{"1.2789639116199663`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "110.1`"}], " ", "t1"}]]}], "+", 
      RowBox[{"3.135728323325616`*^-7", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "102.1`"}], " ", "t1"}]]}], "+", 
      RowBox[{"7.500874395383044`*^-9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.13`"}], " ", "t1"}]]}], "+", 
      RowBox[{"9.700879149334026`*^-9", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.11999999999999`"}], " ", "t1"}]]}], "+", 
      RowBox[{"4.79939805519762`*^-10", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.10302`"}], " ", "t1"}]]}], "+", 
      RowBox[{"9.586771956319952`*^-10", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.101`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.26798288401734915`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "50.0001`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.0012802441557761542`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "10.0001`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.00031388671905153103`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "2.0001`"}], " ", "t1"}]]}], "+", 
      RowBox[{"7.508382778163253`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0301`"}], " ", "t1"}]]}], "+", 
      RowBox[{"9.710589739071601`*^-6", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0201`"}], " ", "t1"}]]}], "+", 
      RowBox[{"4.80420225745588`*^-7", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.00312`"}], " ", "t1"}]]}], "+", 
      RowBox[{"9.59636832464396`*^-7", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t1"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "ETseq"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"1.3473040432604704`*^-7", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.101`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.0001348652695956591`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t1"}]]}]}]}], ",", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "LNet"], "(", "t1", ")"}], "\[Rule]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"1.3473040432607415`*^-7", " ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "100.101`"}], " ", "t1"}]]}]}], "+", 
      RowBox[{"1.3473040432604704`*^-7", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "100.1`"}], " ", "t1"}]]}], "-", 
      RowBox[{"0.0001348652695956591`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0011`"}], " ", "t1"}]]}], "+", 
      RowBox[{"0.00013486526959565907`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "0.0001`"}], " ", "t1"}]]}]}]}]}], "}"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.3992817181492877`*^9, 3.4422207409055214`*^9, 
  3.4766825780500793`*^9, 3.4779017838989525`*^9, 3.518532776955665*^9, 
  3.587474241886979*^9, 3.587475715008959*^9, 3.5874758807809424`*^9, 
  3.5874760561528482`*^9, 3.643609641773713*^9, 3.6436097156488237`*^9, 
  3.6506055304508543`*^9},
 CellLabel->"Out[42]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 7", "SubsubsectionIcon",
 CellTags->"Examples"],

Cell[TextData[{
 "Here is shown how can be a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " function to evaluate the lung retention for an acute intake type S as \
function of  initial deposition values: ",
 Cell[BoxData[
  RowBox[{"{", "AI"}]]],
 ", ",
 Cell[BoxData[
  SubscriptBox["bb", 
   RowBox[{"fast", "+", "seq"}]]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["bb", "slow"], ","}]]],
 " ",
 Cell[BoxData[
  SubscriptBox["BB", 
   RowBox[{"fast", "+", "seq"}]]]],
 " ",
 Cell[BoxData[
  RowBox[{",", " ", 
   SubscriptBox["BB", "slow"], ",", " "}]]],
 " ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["ET", "2"], ",", " ", 
    SubscriptBox["ET", "1"]}], "}"}]]]
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"lung", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
     "ai_", ",", "bbf_", ",", " ", "bbs_", ",", " ", "BBf_", ",", " ", "BBs_",
       ",", " ", "et2_", ",", " ", "et1_"}], "}"}], ",", " ", "t_"}], " ", 
   "]"}], "=", 
  RowBox[{"LungsRetention", "[", 
   RowBox[{"1", ",", 
    RowBox[{"{", 
     RowBox[{
     "ai", ",", "bbf", ",", " ", "bbs", ",", " ", "BBf", ",", " ", "BBs", ",",
       " ", "et2", ",", " ", "et1"}], "}"}], " ", ",", "S", ",", " ", "t", 
    ",", "0"}], "]"}]}]], "Input",
 CellLabel->"In[43]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"1.6522149597360367`*^-7", " ", "ai", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "110.1`"}], " ", "t"}]]}], "-", 
   RowBox[{"4.160990610320783`*^-6", " ", "ai", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "102.1`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.0003030312124272516`", " ", "ai", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.11999999999999`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.0005991612638047705`", " ", "ai", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.101`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.00008317290463989713`", " ", "ai", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.10012`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.000016633383250131556`", " ", "ai", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.1`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.0001653868828564822`", " ", "ai", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "-", 
   RowBox[{"0.004165155766087867`", " ", "ai", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "2.0001`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.30333454697424916`", " ", "ai", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0201`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.599761024829842`", " ", "ai", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0011`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.08325616080071588`", " ", "ai", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.00022`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.016650033283416535`", " ", "ai", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0001`"}], " ", "t"}]]}], "-", 
   RowBox[{"0.0002477542435107005`", " ", "bbf", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "110.1`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.0012387712175536691`", " ", "bbf", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "102.1`"}], " ", "t"}]]}], "-", 
   RowBox[{"2.6020852139652106`*^-18", " ", "bbf", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.11`"}], " ", "t"}]]}], "+", 
   RowBox[{"6.986020965054837`*^-6", " ", "bbf", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.1`"}], " ", "t"}]]}], "-", 
   RowBox[{"0.24800224575648927`", " ", "bbf", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "+", 
   RowBox[{"1.2400112287824465`", " ", "bbf", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "2.0001`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.0069930139790349444`", " ", "bbf", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0001`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.000991016974042802`", " ", "BBf", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "110.1`"}], " ", "t"}]]}], "-", 
   RowBox[{"2.6020852139652106`*^-18", " ", "BBf", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.11`"}], " ", "t"}]]}], "+", 
   RowBox[{"6.986020965054837`*^-6", " ", "BBf", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.1`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.9920089830259572`", " ", "BBf", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.0069930139790349444`", " ", "BBf", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0001`"}], " ", "t"}]]}], "-", 
   RowBox[{"1.2565127978773384`*^-6", " ", "bbs", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "110.1`"}], " ", "t"}]]}], "-", 
   RowBox[{"8.732526206318113`*^-6", " ", "bbs", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "102.1`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.001001006013046979`", " ", "bbs", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.13`"}], " ", "t"}]]}], "-", 
   RowBox[{"2.6020852139652106`*^-18", " ", "bbs", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.11`"}], " ", "t"}]]}], "+", 
   RowBox[{"6.986020965054837`*^-6", " ", "bbs", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.1`"}], " ", "t"}]]}], "-", 
   RowBox[{"0.0012577705684458532`", " ", "bbs", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "-", 
   RowBox[{"0.008741267473793682`", " ", "bbs", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "2.0001`"}], " ", "t"}]]}], "+", 
   RowBox[{"1.0020080210681968`", " ", "bbs", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0301`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.0069930139790349444`", " ", "bbs", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0001`"}], " ", "t"}]]}], "-", 
   RowBox[{"6.98602096505397`*^-6", " ", "BBs", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "110.1`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.0009980029950078517`", " ", "BBs", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.13`"}], " ", "t"}]]}], "-", 
   RowBox[{"2.6020852139652106`*^-18", " ", "BBs", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.11`"}], " ", "t"}]]}], "+", 
   RowBox[{"6.986020965054837`*^-6", " ", "BBs", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "100.1`"}], " ", "t"}]]}], "-", 
   RowBox[{"0.006993013979034946`", " ", "BBs", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.9990019970049921`", " ", "BBs", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0301`"}], " ", "t"}]]}], "+", 
   RowBox[{"0.0069930139790349444`", " ", "BBs", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", "0.0001`"}], " ", "t"}]]}], "+", "0.`"}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.3992817183369665`*^9, 3.4422207410930204`*^9, 
  3.4766825794875517`*^9, 3.477901784367799*^9, 3.5185327771275434`*^9, 
  3.5874742420897846`*^9, 3.587475715198965*^9, 3.587475880970948*^9, 
  3.587476056342854*^9, 3.643609641851836*^9, 3.643609715726963*^9, 
  3.6506055305758457`*^9},
 CellLabel->"Out[43]="]
}, Open  ]],

Cell["\<\
It can be used to compute very fast the lung retention for different AMADs \
(p)  and intakes (inp). For instance, it assumed an intake and AMAD {{3, \
5.7},{7, 7.2},{8, 4.4}} for three workers, it is computed the lung retention \
20 days after the intakes. \
\>", "MathCaption"],

Cell["\<\
modelAMAD[inp_, p_, t1_]:= inp Map[lung[AMADAdultW[#] ,t1]&, p]  \
\>", "Input",
 CellLabel->"In[44]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"modelAMAD", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", " ", "7", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.7", ",", " ", "7.2", ",", " ", "4.4"}], "}"}], ",", " ", 
   "20"}], "]"}]], "Input",
 CellLabel->"In[45]:="],

Cell[BoxData[
 FormBox[
  RowBox[{"{", 
   RowBox[{
   "0.14126705985563506`", ",", "0.25946316584343754`", ",", 
    "0.4728268253789156`"}], "}"}], TraditionalForm]], "Output",
 CellChangeTimes->{3.3992817183838863`*^9, 3.4422207412805195`*^9, 
  3.4766825813781404`*^9, 3.4779017851804647`*^9, 3.518532777158794*^9, 
  3.5874742421365857`*^9, 3.587475715248966*^9, 3.5874758810209494`*^9, 
  3.5874760563828554`*^9, 3.6436096418830867`*^9, 3.6436097157425737`*^9, 
  3.6506055306070976`*^9},
 CellLabel->"Out[45]="]
}, Open  ]],

Cell["\<\
Here it is represented the lung retention as function of t and AMAD \
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot3D", "[", 
  RowBox[{
   RowBox[{"lung", "[", 
    RowBox[{
     RowBox[{"AMADAdultW", "[", "p", "]"}], ",", "t"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"p", ",", " ", "2", ",", " ", "10"}], "}"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", "0", ",", " ", "1000"}], "}"}], ",", 
   RowBox[{"ViewPoint", "->", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "1.7"}], ",", " ", 
      RowBox[{"-", "0.5"}], ",", " ", "1"}], "}"}]}], ",", 
   RowBox[{"Mesh", "\[Rule]", "False"}], ",", 
   RowBox[{"FaceGrids", "\[Rule]", "All"}], ",", 
   RowBox[{"AxesLabel", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
     "\"\<AMAD\>\"", ",", "\"\<time, in days \>\"", ",", "\"\<IRF\>\""}], 
     "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[46]:="],

Cell[BoxData[
 FormBox[
  Graphics3DBox[GraphicsComplex3DBox[CompressedData["
1:eJyF2Hk01fkfx3FCu7K1UL8WS9ukkKSyfGWJkBnSplRIjeyaSGTfuVzrdWXX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    "], {{
      {RGBColor[0.880722, 0.611041, 0.142051], EdgeForm[None], Specularity[
        GrayLevel[1], 3], 
       StyleBox[GraphicsGroup3DBox[{Polygon3DBox[CompressedData["
1:eJxNmGm0llMUx8/LJ2QoFaUoXFIiRUippEHpajbF5UYyXZWxiIwNKg1EKpUx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           "]], 
          Polygon3DBox[{{278, 20, 19, 279}, {282, 18, 17, 283}, {272, 23, 22, 
           273}, {276, 21, 20, 277}, {269, 9, 24, 270}, {280, 19, 18, 281}, {
           287, 32, 31, 259}, {270, 24, 23, 271}, {274, 22, 21, 275}, {285, 
           17, 32, 287}}]}],
        Lighting->{{"Ambient", 
           RGBColor[0.30100577, 0.22414668499999998`, 0.090484535]}, {
          "Directional", 
           RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
           ImageScaled[{0, 2, 2}]}, {"Directional", 
           RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
           ImageScaled[{2, 2, 2}]}, {"Directional", 
           RGBColor[0.2642166, 0.18331229999999998`, 0.04261530000000001], 
           ImageScaled[{2, 0, 2}]}}]}, {}, 
      {GrayLevel[1], EdgeForm[None], 
       StyleBox[
        GraphicsGroup3DBox[{
          Polygon3DBox[{{257, 8, 267}, {238, 234, 226}, {242, 238, 227}, {227,
            226, 16}, {246, 238, 1}, {253, 4, 263}, {227, 238, 226}, {238, 
           246, 234}, {250, 2, 261}, {238, 242, 1}, {252, 3, 262}, {268, 16, 
           251}, {226, 234, 2}, {267, 8, 258}, {286, 16, 268}, {254, 5, 
           264}, {256, 7, 266}, {255, 6, 265}}], 
          Polygon3DBox[{{251, 16, 226, 260}, {263, 4, 5, 254}, {265, 6, 7, 
           256}, {266, 7, 8, 257}, {261, 2, 3, 252}, {264, 5, 6, 255}, {262, 
           3, 4, 253}, {260, 226, 2, 250}}]}],
        Lighting->{{"Ambient", 
           GrayLevel[0.8]}}]}, {}, {}}, 
     {GrayLevel[0], 
      Line3DBox[{246, 1, 242, 227, 16, 286, 268, 251, 260, 250, 261, 252, 262,
        253, 263, 254, 264, 255, 265, 256, 266, 257, 267, 258, 8, 7, 6, 5, 4, 
       3, 2, 234, 246}], Line3DBox[CompressedData["
1:eJwt0LtNQgEABdBHrAB5iAqCCMYBdAKcABITS+jstJBWJ4AJcAKZACfQCVRU
fn4KYwxaiVE7zkssTm5yi1vcrYPm/nEsCII9EsRJKULSLJFhmRVWyZJjjTwF
1imyQYlNFqK0t8MuNRoccUqbM7pccMUbv9ww44Nb+txxzwMDhowYM+GRJ555
548Xvvnkmkt6nNOhxQmH1KlSYZsyr/yQ5ospYfQRiyT/f5sD6SEnaA==
       "]]}},
    VertexNormals->CompressedData["
1:eJzdmGc8lu3fwG3ZDSUjKhpCKbLi+JWRUGZF9t7rsrklO5KtJYlyJ4qWyKZB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     "]],
   Axes->True,
   AxesLabel->{
     FormBox["\"AMAD\"", TraditionalForm], 
     FormBox["\"time, in days \"", TraditionalForm], 
     FormBox["\"IRF\"", TraditionalForm]},
   BoxRatios->{1, 1, 0.4},
   DisplayFunction->Identity,
   FaceGrids->All,
   FaceGridsStyle->Automatic,
   Method->{"DefaultBoundaryStyle" -> Directive[
       GrayLevel[0.3]], "RotationControl" -> "Globe"},
   PlotRange->{{2, 10}, {0, 1000}, {0.006786717762242472, 
     0.06588804922877572}},
   PlotRangePadding->{
     Scaled[0.02], 
     Scaled[0.02], 
     Scaled[0.02]},
   Ticks->{Automatic, Automatic, Automatic},
   ViewPoint->{-1.7, -0.5, 1}], TraditionalForm]], "Output",
 CellChangeTimes->{3.39928172085499*^9, 3.4422207438898773`*^9, 
  3.476682584956197*^9, 3.477901787665349*^9, 3.5185327786900735`*^9, 
  3.587474244024234*^9, 3.5874757171290226`*^9, 3.5874758827110004`*^9, 
  3.5874760582429113`*^9, 3.643609642398713*^9, 3.643609716430087*^9, 
  3.6506055311383643`*^9},
 CellLabel->"Out[46]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{"lung", ",", " ", "modelAMAD"}], "]"}]], "Input",
 CellLabel->"In[47]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Example 8", "SubsubsectionIcon",
 CellTags->"Examples"],

Cell[TextData[{
 "Here is used the function ",
 StyleBox["AMADfit[x]", "Input"],
 " to get a fitted intake retention function as funtion of AMAD and ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 "."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LungsRet", "[", 
   RowBox[{"x_", " ", ",", " ", "t_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"LungsRetention", "[", 
    RowBox[{"1", ",", 
     RowBox[{"AMADfit", "[", "x", "]"}], " ", ",", "S", ",", " ", "t", ",", 
     "0"}], "]"}], "//", "Chop"}]}]], "Input",
 CellChangeTimes->{{3.477901847208791*^9, 3.477901895828121*^9}},
 CellLabel->"In[48]:="],

Cell[BoxData[
 FormBox[
  RowBox[{
   RowBox[{"-", 
    RowBox[{"2.6744111608650476`*^-8", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", 
        RowBox[{"110.1`", " ", "t"}]}], "-", 
       RowBox[{"4.353270952537328`", " ", "x"}]}]]}]}], "-", 
   RowBox[{"1.8586651555154462`*^-7", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"102.1`", " ", "t"}]}], "-", 
      RowBox[{"4.353270952537328`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.00002130580490632139`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"100.13`", " ", "t"}]}], "-", 
      RowBox[{"4.353270952537328`", " ", "x"}]}]]}], "+", 
   RowBox[{"1.4869321244122486`*^-7", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"100.1`", " ", "t"}]}], "-", 
      RowBox[{"4.353270952537328`", " ", "x"}]}]]}], "-", 
   RowBox[{"0.00002677088249115705`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"10.0001`", " ", "t"}]}], "-", 
      RowBox[{"4.353270952537328`", " ", "x"}]}]]}], "-", 
   RowBox[{"0.00018605256811968248`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"2.0001`", " ", "t"}]}], "-", 
      RowBox[{"4.353270952537328`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.021327132038364522`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"0.0301`", " ", "t"}]}], "-", 
      RowBox[{"4.353270952537328`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.000148842054495746`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"0.0001`", " ", "t"}]}], "-", 
      RowBox[{"4.353270952537328`", " ", "x"}]}]]}], "+", 
   RowBox[{"7.743249257250958`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"110.1`", " ", "t"}]}], "-", 
      RowBox[{"1.1114709327884795`", " ", "x"}]}]]}], "-", 
   RowBox[{"0.000011061784653215376`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"100.13`", " ", "t"}]}], "-", 
      RowBox[{"1.1114709327884795`", " ", "x"}]}]]}], "-", 
   RowBox[{"7.743249257250958`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"100.1`", " ", "t"}]}], "-", 
      RowBox[{"1.1114709327884795`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.00007751000257509473`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"10.0001`", " ", "t"}]}], "-", 
      RowBox[{"1.1114709327884795`", " ", "x"}]}]]}], "-", 
   RowBox[{"0.011072857510727818`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"0.0301`", " ", "t"}]}], "-", 
      RowBox[{"1.1114709327884795`", " ", "x"}]}]]}], "-", 
   RowBox[{"0.00007751000257509471`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"0.0001`", " ", "t"}]}], "-", 
      RowBox[{"1.1114709327884795`", " ", "x"}]}]]}], "-", 
   RowBox[{"0.000017019528996169847`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"110.1`", " ", "t"}]}], "-", 
      RowBox[{"0.5667829354923091`", " ", "x"}]}]]}], "-", 
   RowBox[{"1.1997653874440298`*^-7", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"100.1`", " ", "t"}]}], "-", 
      RowBox[{"0.5667829354923091`", " ", "x"}]}]]}], "-", 
   RowBox[{"0.017036565561733847`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"10.0001`", " ", "t"}]}], "-", 
      RowBox[{"0.5667829354923091`", " ", "x"}]}]]}], "-", 
   RowBox[{"0.00012009663537979549`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"0.0001`", " ", "t"}]}], "-", 
      RowBox[{"0.5667829354923091`", " ", "x"}]}]]}], "+", 
   RowBox[{"2.1179221904039762`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"110.1`", " ", "t"}]}], "-", 
      RowBox[{"0.17011061305604133`", " ", "x"}]}]]}], "-", 
   RowBox[{"5.333842485646511`*^-7", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"102.1`", " ", "t"}]}], "-", 
      RowBox[{"0.17011061305604133`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.00003884461434045666`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"100.11999999999999`", " ", "t"}]}], "-", 
      RowBox[{"0.17011061305604133`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.00007680459063545697`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"100.101`", " ", "t"}]}], "-", 
      RowBox[{"0.17011061305604133`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.000010661672038446077`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"100.10012`", " ", "t"}]}], "-", 
      RowBox[{"0.17011061305604133`", " ", "x"}]}]]}], "+", 
   RowBox[{"2.1321808811470416`*^-6", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"100.1`", " ", "t"}]}], "-", 
      RowBox[{"0.17011061305604133`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.000021200422326368132`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"10.0001`", " ", "t"}]}], "-", 
      RowBox[{"0.17011061305604133`", " ", "x"}]}]]}], "-", 
   RowBox[{"0.000533918166731499`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"2.0001`", " ", "t"}]}], "-", 
      RowBox[{"0.17011061305604133`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.03888349783829052`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"0.0201`", " ", "t"}]}], "-", 
      RowBox[{"0.17011061305604133`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.07688147210756655`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"0.0011`", " ", "t"}]}], "-", 
      RowBox[{"0.17011061305604133`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.010672344382830311`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"0.00022`", " ", "t"}]}], "-", 
      RowBox[{"0.17011061305604133`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.0021343151963437667`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"0.0001`", " ", "t"}]}], "-", 
      RowBox[{"0.17011061305604133`", " ", "x"}]}]]}], "-", 
   RowBox[{"1.1572369185725587`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"110.1`", " ", "t"}]}], "-", 
      RowBox[{"0.14724386061421538`", " ", "x"}]}]]}], "-", 
   RowBox[{"8.042577628677191`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"102.1`", " ", "t"}]}], "-", 
      RowBox[{"0.14724386061421538`", " ", "x"}]}]]}], "+", 
   RowBox[{"9.219174814358716`*^-6", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"100.13`", " ", "t"}]}], "-", 
      RowBox[{"0.14724386061421538`", " ", "x"}]}]]}], "+", 
   RowBox[{"6.434062102942024`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"100.1`", " ", "t"}]}], "-", 
      RowBox[{"0.14724386061421538`", " ", "x"}]}]]}], "-", 
   RowBox[{"0.000011583953138867041`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"10.0001`", " ", "t"}]}], "-", 
      RowBox[{"0.14724386061421538`", " ", "x"}]}]]}], "-", 
   RowBox[{"0.0000805062825693618`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"2.0001`", " ", "t"}]}], "-", 
      RowBox[{"0.14724386061421538`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.009228403217579801`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"0.0301`", " ", "t"}]}], "-", 
      RowBox[{"0.14724386061421538`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.00006440502605548944`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"0.0001`", " ", "t"}]}], "-", 
      RowBox[{"0.14724386061421538`", " ", "x"}]}]]}], "-", 
   RowBox[{"7.743249257250958`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"110.1`", " ", "t"}]}], "-", 
      RowBox[{"0.1235776148578769`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.000011061784653215376`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"100.13`", " ", "t"}]}], "-", 
      RowBox[{"0.1235776148578769`", " ", "x"}]}]]}], "+", 
   RowBox[{"7.743249257250958`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"100.1`", " ", "t"}]}], "-", 
      RowBox[{"0.1235776148578769`", " ", "x"}]}]]}], "-", 
   RowBox[{"0.00007751000257509473`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"10.0001`", " ", "t"}]}], "-", 
      RowBox[{"0.1235776148578769`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.011072857510727818`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"0.0301`", " ", "t"}]}], "-", 
      RowBox[{"0.1235776148578769`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.00007751000257509471`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"0.0001`", " ", "t"}]}], "-", 
      RowBox[{"0.1235776148578769`", " ", "x"}]}]]}], "-", 
   RowBox[{"2.495804722963974`*^-6", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"110.1`", " ", "t"}]}], "-", 
      RowBox[{"0.08789446045802779`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.000012479023614819437`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"102.1`", " ", "t"}]}], "-", 
      RowBox[{"0.08789446045802779`", " ", "x"}]}]]}], "+", 
   RowBox[{"7.037515835146455`*^-8", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"100.1`", " ", "t"}]}], "-", 
      RowBox[{"0.08789446045802779`", " ", "x"}]}]]}], "-", 
   RowBox[{"0.002498303025990488`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"10.0001`", " ", "t"}]}], "-", 
      RowBox[{"0.08789446045802779`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.01249151512995244`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"2.0001`", " ", "t"}]}], "-", 
      RowBox[{"0.08789446045802779`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.0000704456039554216`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"0.0001`", " ", "t"}]}], "-", 
      RowBox[{"0.08789446045802779`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.000017019528996169847`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"110.1`", " ", "t"}]}], "-", 
      RowBox[{"0.05778349162703789`", " ", "x"}]}]]}], "+", 
   RowBox[{"1.1997653874440298`*^-7", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"100.1`", " ", "t"}]}], "-", 
      RowBox[{"0.05778349162703789`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.017036565561733847`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"10.0001`", " ", "t"}]}], "-", 
      RowBox[{"0.05778349162703789`", " ", "x"}]}]]}], "+", 
   RowBox[{"0.00012009663537979549`", " ", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{"-", 
       RowBox[{"0.0001`", " ", "t"}]}], "-", 
      RowBox[{"0.05778349162703789`", " ", "x"}]}]]}]}], 
  TraditionalForm]], "Output",
 CellChangeTimes->{3.399281721355467*^9, 3.4422207442336254`*^9, 
  3.476682585378064*^9, 3.4766900265948796`*^9, 3.4779017891343994`*^9, 
  3.477901900579094*^9, 3.4798157291780624`*^9, 3.5185327790182047`*^9, 
  3.5874742447106514`*^9, 3.5874757175290346`*^9, 3.587475883101012*^9, 
  3.587476058632923*^9, 3.643609642508088*^9, 3.6436097166175756`*^9, 
  3.6506055313571215`*^9},
 CellLabel->"Out[48]="]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Brackets",
WindowToolbars->"EditBar",
WindowSize->{1664, 912},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
   Cell[
    TextData[
     StyleBox[
      CounterBox["Page"], "PageNumber"]], "Header", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, 
   Cell[
    TextData[
     StyleBox[
      RowBox[{"Printed", " ", "from", " ", "the", " ", 
        StyleBox["Mathematica", FontSlant -> "Italic"], " ", "Help", " ", 
        "Browser"}], "PageHeader"]], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}, {None, 
   Cell[
    TextData["Biokmod"], "Header"], 
   Cell[
    TextData[
     StyleBox[
      CounterBox["Page"], "PageNumber"]], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}},
PageFooters->{{None, 
   Cell[
    TextData[
     StyleBox[
      RowBox[{
       "\[Copyright]2013", " ", "Guillermo", " ", "Sanchez", " ", "&", " ", 
        "ENUSA", ".", " ", "All", " ", "rights", " ", "reserved", "."}], 
      "PageFooter"]], "Footer"], None}, {None, 
   Cell[
    TextData[{
     "http", ":", "//", "diarium", ".", "usal", ".", "es", "/", "guillermo"}],
     "Footer"], None}},
PageHeaderLines->{True, True},
PageFooterLines->{True, True},
PrintingOptions->{"FacingPages"->True,
"FirstPageFace"->Right,
"FirstPageFooter"->True,
"FirstPageHeader"->True},
ShowSelection->True,
Magnification->1.5,
FrontEndVersion->"10.2 for Microsoft Windows (64-bit) (July 29, 2015)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Introduction"->{
  Cell[2405, 69, 133, 3, 37, "Input",
   CellTags->"Introduction"],
  Cell[2541, 74, 200, 4, 29, "Print",
   CellTags->"Introduction"],
  Cell[115828, 1634, 973, 29, 80, "DefinitionBox",
   CellTags->"Introduction"],
  Cell[116804, 1665, 924, 28, 80, "DefinitionBox",
   CellTags->"Introduction"],
  Cell[117731, 1695, 1068, 35, 81, "DefinitionBox",
   CellTags->"Introduction"],
  Cell[118802, 1732, 1074, 35, 81, "DefinitionBox",
   CellTags->"Introduction"],
  Cell[131181, 2197, 120, 3, 37, "Input",
   CellTags->"Introduction"],
  Cell[131304, 2202, 3353, 93, 109, "Print",
   CellTags->"Introduction"]},
 "Info-85e9d0ec-8b79-4122-80a0-1978472d8035"->{
  Cell[134847, 2306, 422, 7, 148, "Print",
   CellTags->"Info-85e9d0ec-8b79-4122-80a0-1978472d8035"]},
 "Info-fb3ef736-86ba-4079-af16-62bcc5aa9156"->{
  Cell[138965, 2429, 211, 4, 60, "Print",
   CellTags->"Info-fb3ef736-86ba-4079-af16-62bcc5aa9156"]},
 "Info-e45e6c48-50a4-42f3-8075-3c404883ef97"->{
  Cell[139283, 2442, 208, 4, 60, "Print",
   CellTags->"Info-e45e6c48-50a4-42f3-8075-3c404883ef97"]},
 "Examples"->{
  Cell[154150, 2852, 58, 1, 37, "SubsectionIcon",
   CellTags->"Examples"],
  Cell[154233, 2857, 61, 1, 33, "SubsubsectionIcon",
   CellTags->"Examples"],
  Cell[154297, 2860, 233, 5, 126, "MathCaption",
   CellTags->"Examples"],
  Cell[179811, 3538, 338, 10, 126, "MathCaption",
   CellTags->"Examples"],
  Cell[183473, 3643, 61, 1, 25, "SubsubsectionIcon",
   CellTags->"Examples"],
  Cell[234717, 4752, 61, 1, 25, "SubsubsectionIcon",
   CellTags->"Examples"],
  Cell[234781, 4755, 690, 21, 175, "MathCaption",
   CellTags->"Examples"],
  Cell[242190, 4972, 366, 11, 82, "Input",
   CellTags->"Examples"],
  Cell[242559, 4985, 41474, 694, 780, "Output",
   CellTags->"Examples"],
  Cell[291908, 5877, 61, 1, 25, "SubsubsectionIcon",
   CellTags->"Examples"],
  Cell[307073, 6276, 61, 1, 25, "SubsubsectionIcon",
   CellTags->"Examples"],
  Cell[366598, 7613, 61, 1, 25, "SubsubsectionIcon",
   CellTags->"Examples"],
  Cell[366662, 7616, 481, 13, 177, "MathCaption",
   CellTags->"Examples"],
  Cell[382418, 8045, 61, 1, 25, "SubsubsectionIcon",
   CellTags->"Examples"],
  Cell[410368, 8653, 61, 1, 25, "SubsubsectionIcon",
   CellTags->"Examples"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Introduction", 425535, 9079},
 {"Info-85e9d0ec-8b79-4122-80a0-1978472d8035", 426193, 9096},
 {"Info-fb3ef736-86ba-4079-af16-62bcc5aa9156", 426344, 9099},
 {"Info-e45e6c48-50a4-42f3-8075-3c404883ef97", 426494, 9102},
 {"Examples", 426611, 9105}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 60, 0, 128, "Chapter"],
Cell[630, 24, 388, 10, 32, "Text"],
Cell[1021, 36, 723, 9, 41, "Commentary"],
Cell[CellGroupData[{
Cell[1769, 49, 57, 1, 37, "Input"],
Cell[1829, 52, 471, 8, 35, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2337, 65, 43, 0, 33, "SubsubsectionIcon"],
Cell[CellGroupData[{
Cell[2405, 69, 133, 3, 37, "Input",
 CellTags->"Introduction"],
Cell[2541, 74, 200, 4, 29, "Print",
 CellTags->"Introduction"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[2790, 84, 63, 0, 56, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[2878, 88, 49, 0, 33, "SubsubsectionIcon"],
Cell[2930, 90, 879, 23, 75, "Text"],
Cell[3812, 115, 2037, 53, 156, "Text"],
Cell[5852, 170, 583, 18, 58, "Text"],
Cell[6438, 190, 142, 4, 32, "Text"],
Cell[6583, 196, 1673, 59, 131, "Commentary"],
Cell[8259, 257, 176, 5, 32, "Text"],
Cell[8438, 264, 382, 7, 115, "Commentary"],
Cell[8823, 273, 1878, 37, 353, "Output"],
Cell[10704, 312, 104142, 1288, 979, "Text"],
Cell[114849, 1602, 112, 4, 32, "Text"],
Cell[114964, 1608, 409, 9, 83, "Text"]
}, Open  ]],
Cell[CellGroupData[{
Cell[115410, 1622, 68, 0, 33, "SubsubsectionIcon"],
Cell[115481, 1624, 344, 8, 32, "Text"],
Cell[115828, 1634, 973, 29, 80, "DefinitionBox",
 CellTags->"Introduction"],
Cell[116804, 1665, 924, 28, 80, "DefinitionBox",
 CellTags->"Introduction"],
Cell[117731, 1695, 1068, 35, 81, "DefinitionBox",
 CellTags->"Introduction"],
Cell[118802, 1732, 1074, 35, 81, "DefinitionBox",
 CellTags->"Introduction"],
Cell[119879, 1769, 7353, 273, 177, "Text"],
Cell[127235, 2044, 995, 38, 62, "Text"],
Cell[128233, 2084, 324, 11, 42, "Commentary"],
Cell[128560, 2097, 1016, 35, 60, "Text"],
Cell[129579, 2134, 118, 5, 32, "Text"],
Cell[129700, 2141, 209, 8, 34, "Text"],
Cell[129912, 2151, 1244, 42, 67, "Commentary"],
Cell[CellGroupData[{
Cell[131181, 2197, 120, 3, 37, "Input",
 CellTags->"Introduction"],
Cell[131304, 2202, 3353, 93, 109, "Print",
 CellTags->"Introduction"]
}, Open  ]],
Cell[134672, 2298, 74, 0, 32, "Text"],
Cell[CellGroupData[{
Cell[134771, 2302, 73, 2, 37, "Input"],
Cell[134847, 2306, 422, 7, 148, "Print",
 CellTags->"Info-85e9d0ec-8b79-4122-80a0-1978472d8035"]
}, Open  ]],
Cell[135284, 2316, 102, 2, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[135411, 2322, 88, 2, 37, "Input"],
Cell[135502, 2326, 521, 11, 35, "Output"]
}, Open  ]],
Cell[136038, 2340, 72, 0, 56, "MathCaption"],
Cell[CellGroupData[{
Cell[136135, 2344, 50, 1, 37, "Input"],
Cell[136188, 2347, 457, 10, 35, "Output"]
}, Open  ]],
Cell[136660, 2360, 311, 9, 58, "MathCaption"],
Cell[CellGroupData[{
Cell[136996, 2373, 118, 3, 37, "Input"],
Cell[137117, 2378, 1642, 38, 68, "Output"]
}, Open  ]],
Cell[138774, 2419, 88, 2, 32, "Text"],
Cell[CellGroupData[{
Cell[138887, 2425, 75, 2, 37, "Input"],
Cell[138965, 2429, 211, 4, 60, "Print",
 CellTags->"Info-fb3ef736-86ba-4079-af16-62bcc5aa9156"]
}, Open  ]],
Cell[CellGroupData[{
Cell[139213, 2438, 67, 2, 37, "Input"],
Cell[139283, 2442, 208, 4, 60, "Print",
 CellTags->"Info-e45e6c48-50a4-42f3-8075-3c404883ef97"]
}, Open  ]],
Cell[139506, 2449, 213, 7, 33, "Text"],
Cell[139722, 2458, 1131, 45, 90, "Text"],
Cell[140856, 2505, 2282, 101, 74, "Commentary"],
Cell[143141, 2608, 237, 9, 32, "Text"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[143427, 2623, 260, 3, 37, "SubsectionIcon"],
Cell[143690, 2628, 445, 10, 34, "Text"],
Cell[CellGroupData[{
Cell[144160, 2642, 337, 8, 37, "Input"],
Cell[144500, 2652, 325, 7, 38, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[144862, 2664, 270, 6, 37, "Input"],
Cell[145135, 2672, 157, 3, 38, "Output"]
}, Open  ]],
Cell[145307, 2678, 139, 1, 32, "Text"],
Cell[145449, 2681, 704, 11, 56, "MathCaption",
 CellID->100072831],
Cell[CellGroupData[{
Cell[146178, 2696, 4345, 82, 146, "Input",
 CellID->32272491],
Cell[150526, 2780, 3458, 62, 728, "Output"],
Cell[153987, 2844, 117, 2, 29, "Print"]
}, {2}]]
}, Closed]],
Cell[CellGroupData[{
Cell[154150, 2852, 58, 1, 37, "SubsectionIcon",
 CellTags->"Examples"],
Cell[CellGroupData[{
Cell[154233, 2857, 61, 1, 33, "SubsubsectionIcon",
 CellTags->"Examples"],
Cell[154297, 2860, 233, 5, 126, "MathCaption",
 CellTags->"Examples"],
Cell[CellGroupData[{
Cell[154555, 2869, 278, 8, 82, "Input"],
Cell[154836, 2879, 11662, 303, 681, "Output"]
}, Open  ]],
Cell[166513, 3185, 177, 3, 126, "MathCaption"],
Cell[CellGroupData[{
Cell[166715, 3192, 87, 2, 82, "Input"],
Cell[166805, 3196, 627, 13, 78, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[167469, 3214, 51, 1, 82, "Input"],
Cell[167523, 3217, 525, 11, 78, "Output"]
}, Open  ]],
Cell[168063, 3231, 125, 3, 126, "MathCaption"],
Cell[168191, 3236, 901, 28, 87, "Input"],
Cell[CellGroupData[{
Cell[169117, 3268, 682, 19, 82, "Input"],
Cell[169802, 3289, 2552, 61, 780, "Output"]
}, Open  ]],
Cell[172369, 3353, 176, 3, 126, "MathCaption"],
Cell[CellGroupData[{
Cell[172570, 3360, 141, 4, 82, "Input"],
Cell[172714, 3366, 1715, 39, 153, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[174466, 3410, 786, 21, 145, "Input"],
Cell[175255, 3433, 4541, 102, 276, "Output"]
}, Open  ]],
Cell[179811, 3538, 338, 10, 126, "MathCaption",
 CellTags->"Examples"],
Cell[CellGroupData[{
Cell[180174, 3552, 330, 10, 82, "Input"],
Cell[180507, 3564, 2748, 66, 703, "Output"]
}, Open  ]],
Cell[183270, 3633, 166, 5, 82, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[183473, 3643, 61, 1, 25, "SubsubsectionIcon",
 CellTags->"Examples"],
Cell[183537, 3646, 221, 4, 126, "MathCaption"],
Cell[CellGroupData[{
Cell[183783, 3654, 585, 17, 82, "Input"],
Cell[184371, 3673, 6612, 166, 352, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[191020, 3844, 1288, 34, 208, "Input"],
Cell[192311, 3880, 4420, 84, 2463, "Output"]
}, Open  ]],
Cell[196746, 3967, 127, 3, 72, "Text"],
Cell[196876, 3972, 137, 3, 126, "MathCaption"],
Cell[197016, 3977, 685, 20, 82, "Input"],
Cell[197704, 3999, 95, 2, 126, "MathCaption"],
Cell[CellGroupData[{
Cell[197824, 4005, 245, 8, 82, "Input"],
Cell[198072, 4015, 1504, 37, 85, "Output"]
}, Open  ]],
Cell[199591, 4055, 502, 13, 82, "Input"],
Cell[200096, 4070, 107, 3, 72, "Text"],
Cell[CellGroupData[{
Cell[200228, 4077, 1904, 46, 267, "Input"],
Cell[202135, 4125, 32533, 621, 918, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[234717, 4752, 61, 1, 25, "SubsubsectionIcon",
 CellTags->"Examples"],
Cell[234781, 4755, 690, 21, 175, "MathCaption",
 CellTags->"Examples"],
Cell[CellGroupData[{
Cell[235496, 4780, 322, 8, 82, "Input"],
Cell[235821, 4790, 2548, 64, 150, "Output"]
}, Open  ]],
Cell[238384, 4857, 194, 6, 72, "Text"],
Cell[238581, 4865, 286, 10, 126, "MathCaption"],
Cell[CellGroupData[{
Cell[238892, 4879, 470, 14, 82, "Input"],
Cell[239365, 4895, 2724, 70, 150, "Output"]
}, Open  ]],
Cell[242104, 4968, 61, 0, 126, "MathCaption"],
Cell[CellGroupData[{
Cell[242190, 4972, 366, 11, 82, "Input",
 CellTags->"Examples"],
Cell[242559, 4985, 41474, 694, 780, "Output",
 CellTags->"Examples"]
}, Open  ]],
Cell[284048, 5682, 286, 5, 126, "MathCaption"],
Cell[CellGroupData[{
Cell[284359, 5691, 593, 17, 82, "Input"],
Cell[284955, 5710, 2712, 68, 150, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[287704, 5783, 218, 6, 82, "Input"],
Cell[287925, 5791, 3785, 74, 796, "Output"]
}, Open  ]],
Cell[291725, 5868, 146, 4, 82, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[291908, 5877, 61, 1, 25, "SubsubsectionIcon",
 CellTags->"Examples"],
Cell[291972, 5880, 152, 3, 126, "MathCaption"],
Cell[CellGroupData[{
Cell[292149, 5887, 359, 9, 82, "Input"],
Cell[292511, 5898, 12036, 294, 879, "Output"]
}, Open  ]],
Cell[304562, 6195, 174, 3, 126, "MathCaption"],
Cell[CellGroupData[{
Cell[304761, 6202, 175, 5, 82, "Input"],
Cell[304939, 6209, 1990, 57, 159, "Output"]
}, Open  ]],
Cell[306944, 6269, 92, 2, 82, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[307073, 6276, 61, 1, 25, "SubsubsectionIcon",
 CellTags->"Examples"],
Cell[307137, 6279, 142, 3, 126, "MathCaption"],
Cell[307282, 6284, 836, 22, 145, "Input"],
Cell[CellGroupData[{
Cell[308143, 6310, 1787, 43, 267, "Input"],
Cell[309933, 6355, 28256, 553, 924, "Output"]
}, Open  ]],
Cell[338204, 6911, 133, 3, 126, "MathCaption"],
Cell[CellGroupData[{
Cell[338362, 6918, 404, 11, 82, "Input"],
Cell[338769, 6931, 13220, 335, 1068, "Output"]
}, Open  ]],
Cell[352004, 7269, 671, 20, 175, "MathCaption"],
Cell[352678, 7291, 535, 16, 150, "Input"],
Cell[353216, 7309, 210, 7, 126, "MathCaption"],
Cell[CellGroupData[{
Cell[353451, 7320, 242, 7, 82, "Input"],
Cell[353696, 7329, 12568, 270, 792, "Output"]
}, Open  ]],
Cell[366279, 7602, 282, 6, 82, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[366598, 7613, 61, 1, 25, "SubsubsectionIcon",
 CellTags->"Examples"],
Cell[366662, 7616, 481, 13, 177, "MathCaption",
 CellTags->"Examples"],
Cell[367146, 7631, 464, 14, 76, "SmallText"],
Cell[367613, 7647, 69, 0, 72, "Text"],
Cell[CellGroupData[{
Cell[367707, 7651, 99, 2, 82, "Input"],
Cell[367809, 7655, 1839, 43, 153, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[369685, 7703, 1003, 32, 145, "Input"],
Cell[370691, 7737, 11678, 302, 681, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[382418, 8045, 61, 1, 25, "SubsubsectionIcon",
 CellTags->"Examples"],
Cell[382482, 8048, 715, 30, 177, "MathCaption"],
Cell[CellGroupData[{
Cell[383222, 8082, 564, 16, 82, "Input"],
Cell[383789, 8100, 6827, 169, 465, "Output"]
}, Open  ]],
Cell[390631, 8272, 289, 5, 175, "MathCaption"],
Cell[390923, 8279, 114, 3, 82, "Input"],
Cell[CellGroupData[{
Cell[391062, 8286, 268, 8, 82, "Input"],
Cell[391333, 8296, 518, 11, 78, "Output"]
}, Open  ]],
Cell[391866, 8310, 99, 2, 126, "MathCaption"],
Cell[CellGroupData[{
Cell[391990, 8316, 787, 22, 145, "Input"],
Cell[392780, 8340, 17415, 302, 994, "Output"]
}, Open  ]],
Cell[410210, 8645, 121, 3, 82, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[410368, 8653, 61, 1, 25, "SubsubsectionIcon",
 CellTags->"Examples"],
Cell[410432, 8656, 225, 7, 127, "MathCaption"],
Cell[CellGroupData[{
Cell[410682, 8667, 387, 10, 82, "Input"],
Cell[411072, 8679, 12529, 335, 717, "Output"]
}, Open  ]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
