(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[   5733417,      92819]
NotebookOptionsPosition[   5686600,      91381]
NotebookOutlinePosition[   5689292,      91467]
CellTagsIndexPosition[   5689173,      91461]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["Biokinetic model for ICRP Isotopes ", "Chapter",
 CellChangeTimes->{{3.6434438017887955`*^9, 3.643443803054432*^9}, {
  3.6434438355547132`*^9, 3.643443855523704*^9}}],

Cell[TextData[{
 StyleBox["Author",
  FontWeight->"Bold"],
 ": Guillermo Sanchez:  ",
 StyleBox["guillermo@usal.es, ",
  FontColor->RGBColor[0, 0, 1]],
 " ",
 ButtonBox["http://diarium.usal.es/guillermo",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["http://diarium.usal.es/guillermo"], None},
  ButtonNote->"http://diarium.usal.es/guillermo"]
}], "Text",
 CellChangeTimes->{{3.3992809464453416`*^9, 3.3992809874687996`*^9}, {
  3.591672762932617*^9, 3.59167279274479*^9}}],

Cell["Last update of this help:  \t  2015-06-16 ", "Commentary",
 CellChangeTimes->{{3.39928025384801*^9, 3.399280259603493*^9}, {
   3.4228525171714554`*^9, 3.4228525382666454`*^9}, {3.422936332120079*^9, 
   3.422936340401223*^9}, {3.442218589593443*^9, 3.4422185944372244`*^9}, {
   3.479816247027495*^9, 3.4798162579804096`*^9}, {3.513395822423673*^9, 
   3.513395880159526*^9}, 3.5185325242008123`*^9, {3.518532954709078*^9, 
   3.518532984615902*^9}, {3.591673321795082*^9, 3.5916733359601545`*^9}, {
   3.643443707553585*^9, 3.6434437173193264`*^9}}],

Cell[CellGroupData[{

Cell[BoxData["$Version"], "Input",
 CellLabel->"In[1]:="],

Cell[BoxData["\<\"10.0 for Microsoft Windows (64-bit) (December 4, \
2014)\"\>"], "Output",
 CellChangeTimes->{3.3992752647824697`*^9, 3.422852547121887*^9, 
  3.4422186266093054`*^9, 3.4798162427619514`*^9, 3.479963027849038*^9, 
  3.479963528528038*^9, 3.479963679586038*^9, 3.479965799445038*^9, 
  3.518533213370294*^9, 3.5185349763728933`*^9, 3.5916734128479395`*^9, 
  3.591674620662286*^9, 3.6434437311006436`*^9},
 CellLabel->"Out[1]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["Biokdata functions", "SubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Biokmod`Biokdata`\>\"", "]"}]], "Input",
 CellLabel->"In[2]:="],

Cell[BoxData["\<\"Resptract 1.2  2005-05-16\"\>"], "Print",
 CellChangeTimes->{3.6434437312256556`*^9},
 CellLabel->"During evaluation of In[2]:="],

Cell[BoxData["\<\"SysModel, version 1.5.1   2013-11-12\"\>"], "Print",
 CellChangeTimes->{3.6434437312256556`*^9},
 CellLabel->"During evaluation of In[2]:="],

Cell[BoxData["\<\"Humorap 3.7b1 2015-06-15\"\>"], "Print",
 CellChangeTimes->{3.6434437312569065`*^9},
 CellLabel->"During evaluation of In[2]:="],

Cell[BoxData["\<\"Biokdata 1.2.2 2004-09-3\"\>"], "Print",
 CellChangeTimes->{3.6434437313037825`*^9},
 CellLabel->"During evaluation of In[2]:="]
}, Open  ]],

Cell[TextData[{
 "In this notebook are shown and solved different biokinetic models of \
ICRP78. We will need the  ",
 StyleBox["Biokdata", "Input"],
 " package (it has been downloaded in the section Initialization). "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"?", "\"\<Biokmod`Biokdata`*\>\""}]], "Input",
 CellLabel->"In[3]:="],

Cell[BoxData[
 DynamicModuleBox[{Typeset`open$$ = True}, 
  PaneSelectorBox[{False->
   RowBox[{
    OpenerBox[Dynamic[Typeset`open$$],
     ImageSize->Small], 
    StyleBox["Biokmod`Biokdata`", "InfoHeading"]}], True->GridBox[{
     {
      RowBox[{
       OpenerBox[Dynamic[Typeset`open$$],
        ImageSize->Small], 
       StyleBox["Biokmod`Biokdata`", "InfoHeading"]}]},
     {GridBox[{
        {
         ButtonBox["actinium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"actinium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["bromine",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"bromine", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["CompartNumbers",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"CompartNumbers", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["germanium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"germanium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["magnesium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"magnesium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["palladium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"palladium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["rhodium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"rhodium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["tantalum",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"tantalum", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["tungsten",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"tungsten", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"]},
        {
         ButtonBox["aluminium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"aluminium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["cadmium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"cadmium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["copper",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"copper", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["gold",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"gold", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["manganese",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"manganese", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["phosphorus",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"phosphorus", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["rubidium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"rubidium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["technetium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"technetium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["Unknown",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"Unknown", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"]},
        {
         ButtonBox["americium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"americium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["caesium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"caesium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["curium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"curium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["hafnium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"hafnium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["mendelevium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"mendelevium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["platinum",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"platinum", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["ruthenium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"ruthenium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["tellurium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"tellurium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["uranium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"uranium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"]},
        {
         ButtonBox["antimony",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"antimony", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["calcium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"calcium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["dysprosium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"dysprosium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["holmium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"holmium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["mercuryinorg",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"mercuryinorg", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["plutonium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"plutonium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["samarium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"samarium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["terbium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"terbium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["vanadium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"vanadium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"]},
        {
         ButtonBox["arsenic",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"arsenic", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["californium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"californium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["einsteinium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"einsteinium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["indium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"indium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["mercuryorg",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"mercuryorg", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["polonium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"polonium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["scandium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"scandium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["thallium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"thallium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["ytterbium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"ytterbium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"]},
        {
         ButtonBox["astatine",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"astatine", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["cerium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"cerium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["ElementICRP",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"ElementICRP", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["iodine",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"iodine", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["molybdenum",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"molybdenum", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["potassium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"potassium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["selenium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"selenium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["thorium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"thorium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["yttrium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"yttrium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"]},
        {
         ButtonBox["barium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"barium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["chlorine",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"chlorine", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["erbium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"erbium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["iridium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"iridium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["neodymium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"neodymium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["praseodymium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"praseodymium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["silicon",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"silicon", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["thulium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"thulium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["zinc",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"zinc", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"]},
        {
         ButtonBox["berkelium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"berkelium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["chromium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"chromium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["europium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"europium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["iron",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"iron", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["neptunium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"neptunium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["promethium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"promethium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["silver",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"silver", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["tin",
          BaseStyle->"InformationLink",
          ButtonData:>{"Info3643450931-4967554", {"tin", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["zirconium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"zirconium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"]},
        {
         ButtonBox["beryllium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"beryllium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["cobalt",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"cobalt", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["fermium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"fermium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["lanthanum",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"lanthanum", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["nickel",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"nickel", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["protactinium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"protactinium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["sodium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"sodium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["titanium",
          BaseStyle->"InformationLink",
          ButtonData:>{
           "Info3643450931-4967554", {"titanium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], ""},
        {
         ButtonBox["BiokdataReport",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"BiokdataReport", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["compartMatrix",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"compartMatrix", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["gadolinium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"gadolinium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["lead",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"lead", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["niobium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"niobium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["radium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"radium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["strontium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"strontium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["TransferRates",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"TransferRates", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], ""},
        {
         ButtonBox["bismuth",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"bismuth", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["compartMatrixE",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"compartMatrixE", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["gallium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"gallium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["lutetium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"lutetium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["osmium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"osmium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["rhenium",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"rhenium", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["sulfur",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"sulfur", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], 
         ButtonBox["TransferRatesE",
          BaseStyle->"InformationLink",
          
          ButtonData:>{
           "Info3643450931-4967554", {"TransferRatesE", "Biokmod`Biokdata`"}},
          ButtonNote->"Biokmod`Biokdata`"], ""}
       },
       DefaultBaseStyle->"InfoGrid",
       GridBoxItemSize->{"Columns" -> {{
            Scaled[0.10555555555555554`]}}}]}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}}]}, 
   Dynamic[Typeset`open$$],
   ImageSize->Automatic]]], "Print", "InfoCell",
 CellChangeTimes->{3.6434437314444056`*^9}]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"BioakdataReport", "[", 
   StyleBox[
    RowBox[{"element", 
     StyleBox[",", "Text"], 
     StyleBox[" ", "Text"], 
     StyleBox["\"\<IntakeWay\>\"", "Text"], ",", " ", 
     StyleBox["\"\<IntakeType\>\"", "Text"], 
     StyleBox[",", "Text"], 
     StyleBox[" ", "Text"], 
     StyleBox["\"\<Report\>\"", "Text"], 
     StyleBox[",", "Text"], 
     StyleBox[" ", "Text"], 
     StyleBox["Intake", "Text"], 
     StyleBox[",", "Text"], 
     StyleBox[" ", "Text"], "IFD", " ", ",", " ", "FRA", ",", " ", "f1", ",", 
     " ", "t", ",", " ", "\[Lambda]", ",", " ", "options"}],
    FontWeight->"Plain",
    FontSlant->"Italic"], 
   StyleBox["]", "Text"]}]], "Input"],
 " \ngives for element the Bioassayreport  defined with   \"IntakeWay\", \
\"IntakeType\", \"Report\". \n\nIf \"IntakeWay\" is \"Injection\" or \
\"Ingestion\"  IFD and FRA are unnecessary, then BioakdataReport can be also \
written: \n\n",
 Cell[BoxData[
  RowBox[{"BiokdataReport", "[", 
   StyleBox[
    RowBox[{"element", 
     StyleBox[",", "Text"], 
     StyleBox[" ", "Text"], 
     StyleBox["\"\<IntakeWay\>\"", "Text"], ",", " ", 
     StyleBox["\"\<IntakeType\>\"", "Text"], 
     StyleBox[",", "Text"], 
     StyleBox[" ", "Text"], 
     StyleBox["\"\<Report\>\"", "Text"], 
     StyleBox[",", "Text"], 
     StyleBox[" ", "Text"], 
     StyleBox["Intake", "Text"], 
     StyleBox[",", "Text"], 
     StyleBox[" ", "Text"], "f1", ",", " ", "t", ",", " ", "\[Lambda]", ",", 
     " ", "options"}],
    FontWeight->"Plain",
    FontSlant->"Italic"], 
   StyleBox["]", "Text"]}]], "Input"],
 " \ngives for element the Bioassayreport  defined with   \"IntakeWay\", \
\"IntakeType\", \"Report\". "
}], "DefinitionBox"],

Cell[TextData[{
 StyleBox["\nelement",
  FontWeight->"Bold"],
 " write the name of the element as appeared in  ",
 StyleBox["?\"Biokmod`Biokdata`*\"",
  FontWeight->"Bold"],
 "\n\n",
 StyleBox["IntakeWay ",
  FontWeight->"Bold"],
 "write \"Injection\" or \"Ingestion\" or \"Inhalation\"; \n\n",
 StyleBox["IntakeType",
  FontWeight->"Bold"],
 " write \"Acute\" or \"Constant\", \"Continuous\" or \"MultiInputs\"; \n",
 StyleBox["\[CenterDot]\t",
  FontFamily->"Symbol"],
 "\"Acute\" is a single intake at t = 0, \n",
 StyleBox["\[CenterDot]\t",
  FontFamily->"Symbol"],
 "\"Constant\" (or Chronic) means a constant daily intake (all days the \
same). \n",
 StyleBox["\[CenterDot]\t",
  FontFamily->"Symbol"],
 "\"Continuous\" is an intake variable in the time, ej: 0.1 Exp[- 0.02 t] \
(not available for inhalation).\n",
 StyleBox["\[CenterDot]\t",
  FontFamily->"Symbol"],
 "\"MultiInputs\" are multi single (or acute) inputs.\n\n",
 StyleBox["Report",
  FontWeight->"Bold"],
 " write:  \"Automatic\" or \"BioassayTable\" or \"GraphicsReport\" , or \
\"CompartmentContent\" or \"Disintegrations\". \n",
 StyleBox["\[CenterDot]\t",
  FontFamily->"Symbol"],
 "\"Automatic\" gives the Lungs (only by inhation) and whole body retention , \
daily urine and faecal excretion as function of t\n",
 StyleBox["\[CenterDot]\t",
  FontFamily->"Symbol"],
 "\"BioassayTable\" gives the Lungs (only by inhalation) and whole body \
retention , daily urine and faecal excretion for different days.\n",
 StyleBox["\[CenterDot]\t",
  FontFamily->"Symbol"],
 "\"GraphicsReport\" gives the graphics representation as function of time of \
 the Lungs  retention (only by inhalation), the daily urine and faecal \
excretion, from 0 to t (chosen with\"Time\").\n",
 StyleBox["\[CenterDot]\t",
  FontFamily->"Symbol"],
 "\"CompartmentContent\" gives the retention in each compartment of the model \
as function of t.\n",
 StyleBox["\[CenterDot]\t",
  FontFamily->"Symbol"],
 "\"Disintegrations\" gives the total disintegration accumulated at time t \
(that is: Us or SA values.)\n\n",
 StyleBox["Intake",
  FontWeight->"Bold"],
 ".- The input format depends on the \"Intake type\" chosen. \n",
 StyleBox["\[CenterDot]\t",
  FontFamily->"Symbol"],
 "For \"Acute\" write the number of Bq in t = 0\n",
 StyleBox["\[CenterDot]\t",
  FontFamily->"Symbol"],
 "For \"Constant\" write the number of Bq/day.\n",
 StyleBox["\[CenterDot]\t",
  FontFamily->"Symbol"],
 "For \"Continuous\" write {",
 StyleBox["f",
  FontSlant->"Italic"],
 "(",
 StyleBox["t)",
  FontSlant->"Italic"],
 " , ",
 StyleBox["t",
  FontSlant->"Italic"],
 "} where f(t) is the input functions. Ej.: {0.1 Exp[- 0.02 t], t} \n",
 StyleBox["\[CenterDot]\t",
  FontFamily->"Symbol"],
 "For \"MultiInputs\" write {{I",
 StyleBox["0",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 ", t",
 StyleBox["0",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "}, {I",
 StyleBox["1",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 ", t",
 StyleBox["1",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "}, .... {I",
 StyleBox["j",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 ", t",
 StyleBox["j",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "},\[Ellipsis],{I",
 StyleBox["n",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 ", t",
 StyleBox["n",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "}} (where I",
 StyleBox["j",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 ", represents the intake the day t",
 StyleBox["j",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 ", and t",
 StyleBox["1",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "<t",
 StyleBox["2",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "<..<t",
 StyleBox["n",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 " ). Ej.:  {{3, 0},{7, 3}}. The retention is given as function of t after \
the last intake (t",
 StyleBox["n",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "=0); Note: The length of the list {{I",
 StyleBox["0",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 ", t",
 StyleBox["0",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "},....., {I",
 StyleBox["n",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 ", t",
 StyleBox["n",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "}} can be hundred of elements, it will be computed in a few seconds. It can \
be copied from a ASCII standard program (ej: Notebook)\n\n",
 StyleBox["IFD",
  FontWeight->"Bold"],
 ": (only by Inhalation) write AMADxx, being xx the AMAD value which you wish \
(chose one of the included  in  ",
 StyleBox["?\"Biokmod`Biokdata`*\")",
  FontWeight->"Bold"],
 ". Then the program will select the appropriated Initial fractional \
Deposition (IFD) values. If you wish, you  can be directly written the IFD \
values with this pattern ",
 Cell[BoxData[
  RowBox[{"{", "AI"}]]],
 ", ",
 Cell[BoxData[
  SubscriptBox["bb", 
   RowBox[{"fast", "+", "seq"}]]]],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["bb", "slow"], ","}]]],
 " ",
 Cell[BoxData[
  SubscriptBox["BB", 
   RowBox[{"fast", "+", "seq"}]]]],
 " ",
 Cell[BoxData[
  RowBox[{",", " ", 
   SubscriptBox["BB", "slow"], ",", " "}]]],
 " ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["ET", "2"], ",", " ", 
    SubscriptBox["ET", "1"]}], "}"}]]],
 " (i.e: {0.12, 0.011, 0.011, 0.0039, 0.004, 0.11, 0.089}) \n\n",
 StyleBox["FRA",
  FontWeight->"Bold"],
 " (only by Inhalation) .",
 StyleBox["FRA: Fractional rate of absorption",
  FontSlant->"Italic"],
 "  of material into the blood. Write: F or M or S, then the program will \
select the appropriate fractional rate of absorption: type F:{100, 0, 0};  \
type M: {10, 90, 0.005};  type S: {0.1, 100, 0.0001}. If you wish, you  can \
be directly written the FRA values with this pattern {",
 Cell[BoxData[
  StyleBox[
   RowBox[{
    SubscriptBox["s", "p"], ",", 
    SubscriptBox["s", "pt"], ",", 
    SubscriptBox["s", "t"]}], "Input"]]],
 "} (i.e.: {10, 90, 0.005}) \n\n",
 StyleBox["f1",
  FontWeight->"Bold"],
 ": fraction from GI (SI) to Blood. By default are given the included in \
ICRPs, but you can change this value.\n",
 StyleBox["t",
  FontWeight->"Bold",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontSlant->"Italic"],
 " always in days. The meaning depends on the \"Intake type\" chosen.\n",
 StyleBox["\[CenterDot]\t",
  FontFamily->"Symbol"],
 "For \"Acute\" means time after the intake. Write ",
 StyleBox["t",
  FontSlant->"Italic"],
 " (symbolic solution) or the numeric number of days (ej: 2 ).\n",
 StyleBox["\[CenterDot]\t",
  FontFamily->"Symbol"],
 "For \"Constant\" means time after starting the intake. Write ",
 StyleBox["t",
  FontSlant->"Italic"],
 " (symbolic solution) or the numeric number of days (ej: 2 )\n",
 StyleBox["\[CenterDot]\t",
  FontFamily->"Symbol"],
 "For \"Continuous\" means time after starting the intake. Write ",
 StyleBox["t",
  FontSlant->"Italic"],
 " (symbolic solution) or the numeric number of days (ej: 2 )   \n",
 StyleBox["\[CenterDot]\t",
  FontFamily->"Symbol"],
 "For \"MultiInputs\" means the time after last intake. Write ",
 StyleBox["t",
  FontSlant->"Italic"],
 " (symbolic solution) or the numeric number of days (ej: 2 ).\n\tNote: If in \
",
 StyleBox["Output Report",
  FontWeight->"Bold"],
 " you has chosen \"GraphicsReport\" or \"Retention Functions\" must be \
chosen a numeric value for Time\n\n",
 StyleBox["\[Lambda]",
  FontFamily->"Times New Roman Greek",
  FontWeight->"Bold"],
 " is the radioactive decay constant, in day",
 StyleBox["-1",
  FontVariations->{"CompatibilityType"->"Superscript"}],
 ". If you know the half-life T, as ",
 StyleBox["\[Lambda]",
  FontFamily->"Times New Roman Greek",
  FontWeight->"Bold"],
 " = Log[t]/T you can write: Log[2]/T, ej.: For T = 8.2 year, then write: \
Log[2]/(365.24*8.2) .\n\nCompartNumbers and  TransferRates options: ",
 StyleBox["(",
  FontSlant->"Italic"],
 "By default: CompartNumbers \[Rule] \"False\", TransferRates\[Rule] \
\"False\" ) : If CompartNumbers \[Rule] \"True\", TransferRates\[Rule] \"True\
\" gives a report where is indicated the relation between the number and the  \
name of compartments, and also the Tranfer Rates. It a good idea to choose \
this option if  in REPORT has been chosen  \"CompartmentContent\" or \
\"Desintegration\"\n"
}], "Text"],

Cell[TextData[{
 "Other funtions (push on the blue names) ",
 Cell[BoxData[
  ButtonBox[
   StyleBox["CompartNumbers",
    FontVariations->{"Underline"->True},
    FontColor->RGBColor[0, 0, 1]],
   Appearance->{Automatic, None},
   ButtonData:>{"Info3263734794-7542638", "Biokmod`Biokdata`CompartNumbers"},
   ButtonFunction:>(Internal`PutInformation[#, LongForm -> False]& ),
   ButtonNote->"Biokmod`Biokdata`",
   Evaluator->Automatic]],
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->GrayLevel[0.930022],
  ButtonBoxOptions->{Active->True}],
 ", ",
 Cell[BoxData[
  ButtonBox[
   StyleBox["TransferRates",
    FontVariations->{"Underline"->True},
    FontColor->RGBColor[0, 0, 1]],
   Appearance->{Automatic, None},
   ButtonData:>{"Info3263734794-7542638", "Biokmod`Biokdata`TransferRates"},
   ButtonFunction:>(Internal`PutInformation[#, LongForm -> False]& ),
   ButtonNote->"Biokmod`Biokdata`",
   Evaluator->Automatic]],
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->GrayLevel[0.930022],
  ButtonBoxOptions->{Active->True}],
 ", ",
 Cell[BoxData[
  ButtonBox[
   StyleBox["TransferRatesE",
    FontVariations->{"Underline"->True},
    FontColor->RGBColor[0, 0, 1]],
   Appearance->{Automatic, None},
   ButtonData:>{"Info3263734794-7542638", "Biokmod`Biokdata`TransferRatesE"},
   ButtonFunction:>(Internal`PutInformation[#, LongForm -> False]& ),
   ButtonNote->"Biokmod`Biokdata`",
   Evaluator->Automatic]],
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->GrayLevel[0.930022],
  ButtonBoxOptions->{Active->True}],
 ", ",
 Cell[BoxData[
  ButtonBox[
   StyleBox["compartMatrix",
    FontVariations->{"Underline"->True},
    FontColor->RGBColor[0, 0, 1]],
   Appearance->{Automatic, None},
   ButtonData:>{"Info3263734794-7542638", "Biokmod`Biokdata`compartMatrix"},
   ButtonFunction:>(Internal`PutInformation[#, LongForm -> False]& ),
   ButtonNote->"Biokmod`Biokdata`",
   Evaluator->Automatic]],
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->GrayLevel[0.930022],
  ButtonBoxOptions->{Active->True}],
 " and ",
 Cell[BoxData[
  ButtonBox[
   StyleBox["compartMatrixE",
    FontVariations->{"Underline"->True},
    FontColor->RGBColor[0, 0, 1]],
   Appearance->{Automatic, None},
   ButtonData:>{"Info3263734794-7542638", "Biokmod`Biokdata`compartMatrixE"},
   ButtonFunction:>(Internal`PutInformation[#, LongForm -> False]& ),
   ButtonNote->"Biokmod`Biokdata`",
   Evaluator->Automatic]],
  CellMargins->{{20, Inherited}, {Inherited, Inherited}},
  ShowCellLabel->False,
  CellFrameMargins->{{Inherited, Inherited}, {14, 14}},
  Background->GrayLevel[0.930022],
  ButtonBoxOptions->{Active->True}],
 ". "
}], "DefinitionBox"],

Cell[BoxData[
 StyleBox["\<\"compartMatrixE[element] gives for element the \\ncompartmental \
matrix using the applicable ICRP model adding the GI Tract\"\>", 
  "MSG"]], "Print", "PrintUsage",
 CellTags->"Info3263734794-7542638"]
}, Closed]],

Cell[CellGroupData[{

Cell["A general example : Iodine", "Section"],

Cell[TextData[{
 "Here are shown how work",
 StyleBox[" IntakeType", "Input"],
 ", ",
 StyleBox["IntakeWay", "Input"],
 " and ",
 StyleBox["ShowReport", "Input"],
 ". All examples of this section are made using the iodine model."
}], "Text"],

Cell[CellGroupData[{

Cell["The model", "SubsectionIcon"],

Cell[TextData[{
 "Also, we will need the following information: We suppose the nuclide iodine \
131 (half-life = 8.0 days),  taken  f1 = 1 (f1 is called fn1) , and (by \
inhalation) AMAD = 5 \[Mu]m and class F. The examples included for kind of \
intake: a) Acute input: 1 Bq in t=0, b) Constant intake =1 Bq/day all days), \
c)  A continuous intake 1.2 Exp[-0.3 t] and b) Multiple single intakes  \
{{1,0}, {3,4}, {7, 6}} [remember: {",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       FormBox[
        SubscriptBox["I", "1"],
        TraditionalForm], ",", " ", 
       SubscriptBox["t", "1"]}], "}"}], ",", 
     RowBox[{"...", "."}], ","}]}], TraditionalForm]]],
 " ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      SubscriptBox["I", "j"], ",", "  ", 
      SubscriptBox["t", "j"]}], "}"}], ",", " "}], TraditionalForm]]],
 "..., ",
 Cell[BoxData[
  FormBox[
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["I", "n"], ",", "  ", 
     SubscriptBox["t", "n"]}], "}"}], TraditionalForm]]],
 "}  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "j"], TraditionalForm]]],
 " = intake de day ",
 Cell[BoxData[
  FormBox["j", TraditionalForm]]],
 "]. "
}], "Text"],

Cell["We define the values to be used in the esamples", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"element", "=", " ", "iodine"}], ";"}]], "Input",
 CellLabel->"In[4]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"lambda", " ", "=", " ", 
   RowBox[{
    RowBox[{"Log", "[", "2", "]"}], "/", "8.0"}]}], ";", " ", 
  RowBox[{"fn1", " ", "=", " ", "1"}], ";", " ", 
  RowBox[{"amad", "=", " ", 
   RowBox[{"AMADAdultW", "[", "5", "]"}]}], ";", 
  RowBox[{"class", " ", "=", " ", "F"}], ";", " ", 
  RowBox[{"inputs1", " ", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1.2", " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "0.3"}], " ", "t"}], "]"}]}], ",", "t"}], "}"}]}], ";", 
  RowBox[{"inputs2", " ", "=", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "0"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"3", ",", "4"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"7", ",", "6"}], "}"}]}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[5]:="],

Cell[TextData[{
 "This figure represent the model of Iodine ICRP 78, compartment 1 represents \
the blood, compartment 2 the thyroid, 3 rest of body, and 4 the bladder, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "40"], TraditionalForm]]],
 " means the rate transfer out of system  to urine) and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "30"], TraditionalForm]]],
 "means the rate transfer out of system  to ULI in GI system (see fig 6.). "
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .90909 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 0.17316 0.627706 0.17316 [
[ 0 0 0 0 ]
[ 1 .90909 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .90909 L
0 .90909 L
closepath
clip
newpath
% Start of user PostScript
/mathtops {
gsave
MBeginOrig
moveto
MEndOrig
currentpoint
grestore
} bind def
/MAtocoords {
mathtops 4 2 roll mathtops
4 copy pop pop
3 -1 roll sub
/arry exch def
exch sub
/arrx exch def
arrx dup mul
arry dup mul
add sqrt
/arrl exch def
translate
} bind def
/MAarrowhead1 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125  moveto 0 0 lineto 
-0.05 -0.0125  lineto stroke
} ifelse
grestore
} def
/MAarrowhead2 {
gsave
MAtocoords
arrl 0. eq
{ 0 0 Mdot }
{
[ arrx arrl div
arry arrl div
-1 arry mul arrl div
arrx arrl div
0 0 ]
concat
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto fill
-0.05 0.0125 moveto 0 0 lineto
-0.05 -0.0125 lineto
-0.05 0.0125 lineto stroke
} ifelse
grestore
} def
% End of user PostScript
0 g
.5 Mabswid
[ ] 0 setdash
.11039 .88745 m
.11039 .71429 L
s
% Start of user PostScript
0 1.5 0 0.5 MAarrowhead1
% End of user PostScript
gsave
.04113 .80087 -80.3438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(b) show
75.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
79.688 12.813 moveto
(H) show
85.688 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
91.688 12.813 moveto
(L) show
97.688 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.11039 .62771 .08658 0 365.73 arc
s
gsave
.11039 .62771 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.19697 .62771 m
.62987 .62771 L
s
% Start of user PostScript
0.5 0 3. 0 MAarrowhead2
% End of user PostScript
newpath
.11039 .28139 .08658 0 365.73 arc
s
gsave
.11039 .28139 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .19481 m
.11039 .02165 L
s
% Start of user PostScript
0 -2.5 0 -3.5 MAarrowhead2
% End of user PostScript
gsave
.16234 .14286 -70.4375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(40) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.41342 .69697 -70.4375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .54113 m
.11039 .36797 L
s
% Start of user PostScript
0 -0.5 0 -1.5 MAarrowhead2
% End of user PostScript
gsave
.16234 .48918 -70.4375 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.71645 .62771 .08658 0 365.73 arc
s
gsave
.71645 .62771 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.71645 .54113 m
.71645 .36797 L
s
% Start of user PostScript
3.5 -0.5 3.5 -1.5 MAarrowhead2
% End of user PostScript
gsave
.6645 .45455 -70.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
newpath
.71645 .28139 .08658 0 365.73 arc
s
gsave
.71645 .28139 -66 -10.2813 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
69.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.62987 .31602 m
.17965 .57576 L
s
% Start of user PostScript
3. -1.8 0.4 -0.3 MAarrowhead2
% End of user PostScript
gsave
.45671 .45455 -70.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(31) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.80303 .28139 m
.97619 .28139 L
s
% Start of user PostScript
4. -2. 5. -2. MAarrowhead2
% End of user PostScript
gsave
.85498 .28139 -70.4375 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.5625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding WindowsANSIEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.813 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
69.000 14.313 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
77.875 12.813 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
 ImageSize->{288, 261.813},
 ImageMargins->{{1, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellLabel->"From In[15]:=",ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{94, 381}, {334.813, 74}} -> {-2.53078, -2.13544, \
0.0201296, 0.0201296}}],

Cell["Biokinetic data for iodine (taken from Publication 78/56): ", "Text"],

Cell["\<\
The compartments has been numbered as follow (Compartments 5-8 are not \
represented in the above figure) \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompartNumbers", "[", "iodine", "]"}]], "Input",
 CellLabel->"In[6]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "\<\"Blood\"\>"},
    {"2", "\<\"Thyroid\"\>"},
    {"3", "\<\"Rest\"\>"},
    {"4", "\<\"Bladder\"\>"},
    {"5", "\<\"Urine\"\>"},
    {"6", "\<\"ULI\"\>"},
    {"7", "\<\"LLI\"\>"},
    {"8", "\<\"FEC\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.399282193101771*^9, 3.417835648750705*^9, 
  3.479827555734285*^9, 3.4798282281735945`*^9, 3.479829194779241*^9, 
  3.4798294238998423`*^9, 3.5185349783260555`*^9, 3.5916734696986237`*^9, 
  3.6434437314912796`*^9},
 CellLabel->"Out[6]//TableForm="]
}, Open  ]],

Cell[TextData[{
 "The halt-life of  the blood is 0.25 days, the uptake to thyroid is 30% and \
to the bladder is  70%,  the halt-life of Thyroid is 80 days, and the \
halt-life of \"Rest of Body\" is 12 days to 20 % faecal excretion and 80% to \
blood, therefore the rate transfer are, in ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["d", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 ": Blood (Log[2]/0.25), Thyroid (Log[2]/80),  and Rest of body (Log[2]/12. \
As usual, the rate transfers from bladder is 12 ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["d", 
    RowBox[{"-", "1"}]], TraditionalForm]]],
 ", so the transfer rate are"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"TransferRates", "[", "iodine", "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<From\>\"", ",", " ", "\"\<to\>\"", ",", 
        "\"\<Tranfer Rates(\!\(\*SuperscriptBox[\(days\), \(-1\)]\))\>\""}], 
       "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[7]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"From\"\>",
       HoldForm], 
      TagBox["\<\"to\"\>",
       HoldForm], 
      TagBox["\<\"Tranfer Rates(\\!\\(\\*SuperscriptBox[\\(days\\), \\(-1\\)]\
\\))\"\>",
       HoldForm]},
     {"1", "2", "0.8317766166719344`"},
     {"1", "4", "1.9408121055678467`"},
     {"2", "3", 
      FractionBox[
       RowBox[{"Log", "[", "2", "]"}], "80"]},
     {"3", "6", "0.011552453009332421`"},
     {"3", "1", "0.046209812037329684`"},
     {"4", "5", "12"},
     {"6", "7", 
      SubscriptBox["k", "ULI"]},
     {"7", "8", 
      SubscriptBox["k", "LLI"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"From", "to", 
       "Tranfer Rates(\!\(\*SuperscriptBox[\(days\), \(-1\)]\))"}}]]]], \
"Output",
 CellChangeTimes->{3.3992821931330504`*^9, 3.41783564879758*^9, 
  3.4798275558436656`*^9, 3.4798282282048426`*^9, 3.4798291948417397`*^9, 
  3.479829423962341*^9, 3.5185349783729315`*^9, 3.5916734699506493`*^9, 
  3.6434437315381536`*^9},
 CellLabel->"Out[7]//TableForm="]
}, Open  ]],

Cell["Here is the coefficients matrix of iodine", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"compartMatrix", "[", "iodine", "]"}], " ", "//", 
  "MatrixForm"}]], "Input",
 CellLabel->"In[8]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      RowBox[{"-", "2.772588722239781`"}], "0.`", "0.046209812037329684`", 
      "0.`", "0.`", "0.`", "0.`", "0.`"},
     {"0.8317766166719344`", 
      RowBox[{"-", 
       FractionBox[
        RowBox[{"Log", "[", "2", "]"}], "80"]}], "0.`", "0.`", "0.`", "0.`", 
      "0.`", "0.`"},
     {"0.`", "0.008664339756999316`", 
      RowBox[{"-", "0.057762265046662105`"}], "0.`", "0.`", "0.`", "0.`", 
      "0.`"},
     {"1.9408121055678467`", "0.`", "0.`", 
      RowBox[{"-", "12"}], "0.`", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "12.`", "0", "0.`", "0.`", "0.`"},
     {"0.`", "0.`", "0.011552453009332421`", "0.`", "0.`", 
      RowBox[{"-", 
       SubscriptBox["k", "ULI"]}], "0.`", "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.`", 
      RowBox[{"0.`", "\[VeryThinSpace]", "+", 
       SubscriptBox["k", "ULI"]}], 
      RowBox[{"-", 
       SubscriptBox["k", "LLI"]}], "0.`"},
     {"0.`", "0.`", "0.`", "0.`", "0.`", "0.`", 
      RowBox[{"0.`", "\[VeryThinSpace]", "+", 
       SubscriptBox["k", "LLI"]}], "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.39928219314869*^9, 3.41783564882883*^9, 
  3.479827555906169*^9, 3.4798282282360907`*^9, 3.4798291948886137`*^9, 
  3.479829424009215*^9, 3.5185349784041824`*^9, 3.591673470205675*^9, 
  3.6434437315538054`*^9},
 CellLabel->"Out[8]//MatrixForm="]
}, Open  ]],

Cell["\<\
By default are applied the following values for GI tract rate transfer\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Options", "[", "qGI", "]"}]], "Input",
 CellLabel->"In[9]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["k", "ST"], "\[Rule]", "24"}], ",", 
   RowBox[{
    SubscriptBox["f", "B"], "\[Rule]", 
    FractionBox["f1", 
     RowBox[{"1", "-", "f1"}]]}], ",", 
   RowBox[{
    SubscriptBox["k", "SI"], "\[Rule]", "6"}], ",", 
   RowBox[{
    SubscriptBox["k", "ULI"], "\[Rule]", "1.8`"}], ",", 
   RowBox[{
    SubscriptBox["k", "LLI"], "\[Rule]", "1"}]}], "}"}]], "Output",
 CellChangeTimes->{3.3992821931799703`*^9, 3.41783564886008*^9, 
  3.479827555953046*^9, 3.479828228282963*^9, 3.479829194935488*^9, 
  3.479829424056089*^9, 3.518534978435433*^9, 3.5916734703896933`*^9, 
  3.643443731569397*^9},
 CellLabel->"Out[9]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["IntakeWay\[Rule] \"Injection\",ShowReport\[Rule] \"Automatic\"", \
"SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<Automatic\>\"", ",", "1", ",", "fn1", ",", "t1", ",", "lambda"}], 
   "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[10]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qDailyUrine", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "34232.18489959335`"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t1"}]]}], "+", 
     RowBox[{"13.654916357254283`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240243`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.0016907734626698222`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567382672`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.001575117502530976`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0929673078393539`"}], " ", "t1"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qDailyFaecal", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"0.00006268079502636275`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240243`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.00017314960229548363`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699932`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.0001944426198662067`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.00064702363604883`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567382672`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.0005665235164631771`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0929673078393539`"}], " ", "t1"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qWholebody", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.21033110566047455`"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.9103750343200605`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240243`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.000034289443672205606`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699932`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00011316107558477926`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.03771082614686523`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567382672`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.33758802585536707`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0929673078393539`"}], " ", "t1"}]]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.3992821933363695`*^9, 3.417835649344455*^9, 
  3.479827556796839*^9, 3.4798282285798206`*^9, 3.4798291952323575`*^9, 
  3.47982942425921*^9, 3.5185349785291843`*^9, 3.5916734707607303`*^9, 
  3.643443731647523*^9},
 CellLabel->"Out[10]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<Automatic\>\"", ",", "1", ",", "fn1", ",", "t1", ",", "lambda"}], 
  "]"}]], "Input",
 CellLabel->"In[11]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qDailyUrine", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{"0.6510615822290919`", "\[VeryThinSpace]", "+", 
     RowBox[{"2832.2325540336287`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t1"}]]}], "-", 
     RowBox[{"4.775802646387303`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240243`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.011518277700978186`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567382672`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.016942703183926877`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0929673078393539`"}], " ", "t1"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qDailyFaecal", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{"0.0017945794413077101`", "\[VeryThinSpace]", "-", 
     RowBox[{"0.00002192258809447271`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240243`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00009177653949787291`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699932`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.0001789387579228192`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.004407803933318785`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567382672`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.00609379285718481`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0929673078393539`"}], " ", "t1"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qWholebody", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{"3.6754402547765204`", "\[VeryThinSpace]", "+", 
     RowBox[{"0.017401945167238194`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.31840337826755644`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240243`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.000018174840945761448`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699932`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.00010413818906720988`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.25690240442206846`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567382672`"}], " ", "t1"}]]}], "-", 
     RowBox[{"3.631255262750149`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0929673078393539`"}], " ", "t1"}]]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.3992821935709677`*^9, 3.417835649625705*^9, 
  3.479827557140607*^9, 3.4798282288923025`*^9, 3.4798291954823527`*^9, 
  3.479829424509205*^9, 3.518534978701063*^9, 3.5916734711087646`*^9, 
  3.6434437317256484`*^9},
 CellLabel->"Out[11]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Continuous\>\"", ",", 
    "\"\<Automatic\>\"", ",", "inputs1", ",", "fn1", ",", "t", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[12]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qDailyUrine", "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"3485.1840760687687`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t"}]]}], "-", 
     RowBox[{"6.402773581893607`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240243`"}], " ", "t"}]]}], "+", 
     RowBox[{"1.0369968346810996`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.3`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.013242833068813187`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567382672`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.009129674078577121`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935392`"}], " ", "t"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qDailyFaecal", "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.000029390948138153437`"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240243`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.00013095540124063345`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699932`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.00029661615995281643`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0019785147327130905`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.3`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.005067755197814119`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567382672`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0032836756971130754`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935392`"}], " ", "t"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qWholebody", "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"0.021413842625000873`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.4268737403333348`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240243`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.000025933573019410337`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699932`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.0001726236959735655`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t"}]]}], "-", 
     RowBox[{"1.2557497162165498`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.3`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.29536669848212277`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567382672`"}], " ", "t"}]]}], "+", 
     RowBox[{"1.956723002529961`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935392`"}], " ", "t"}]]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399282193961965*^9, 3.417835649969455*^9, 
  3.479827557562504*^9, 3.479828229236033*^9, 3.4798291958417206`*^9, 
  3.479829424868573*^9, 3.518534978966693*^9, 3.591673471565811*^9, 
  3.643443731803774*^9},
 CellLabel->"Out[12]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<MultiInputs\>\"", ",", 
    "\"\<Automatic\>\"", ",", "inputs2", ",", "fn1", ",", "t", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[13]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qDailyUrine", "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "239625.29430041357`"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t"}]]}], "+", 
     RowBox[{"95.71898595576624`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240243`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.016318063001443422`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567382672`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.015851113955948154`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0929673078393539`"}], " ", "t"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qDailyFaecal", "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"0.0004393832947674753`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240243`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.001223984390395981`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699932`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0014277693570356245`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.006244581364434172`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567382672`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0057011802635376085`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0929673078393539`"}], " ", "t"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qWholebody", "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1.4723177396433527`"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t"}]]}], "+", 
     RowBox[{"6.381597136497157`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240243`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.00024239006762787486`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699932`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0008309285085765282`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.3639562901166723`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567382672`"}], " ", "t"}]]}], "+", 
     RowBox[{"3.39729973122551`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0929673078393539`"}], " ", "t"}]]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.3992821942904034`*^9, 3.41783565026633*^9, 
  3.479827557890645*^9, 3.479828229532891*^9, 3.47982919616984*^9, 
  3.4798294251654425`*^9, 3.518534979185447*^9, 3.5916734720028543`*^9, 
  3.6434437318819*^9},
 CellLabel->"Out[13]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IntakeWay\[Rule] \"Injection\",ShowReport\[Rule] \"BioassayTable\"", \
"SubsubsectionIcon"],

Cell[TextData[StyleBox["Appart the defauld days included in the \
BioassayTable, we chose the day 180 ", "Theorem"]], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[14]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.5897376338194578`", "4.819844605016913`*^-7", 
      "0.3272659274007525`"},
     {"2", "0.04490314572121769`", "6.34235038949857`*^-6", 
      "0.25519469055800914`"},
     {"3", "0.0026742325030671556`", "0.00001896126922590423`", 
      "0.23132136927376637`"},
     {"4", "0.00029340745961023814`", "0.000033331757658318554`", 
      "0.211795891686416`"},
     {"5", "0.00018640926219397`", "0.0000461706259307838`", 
      "0.19398510912245734`"},
     {"6", "0.00020140039897009778`", "0.000056424258262084394`", 
      "0.17762730472956048`"},
     {"7", "0.00021656866243096345`", "0.00006405716118298112`", 
      "0.16260433079694128`"},
     {"8", "0.00022621169513181716`", "0.0000693718756653583`", 
      "0.14881324521258785`"},
     {"9", "0.00023107636747749188`", "0.00007274180457057936`", 
      "0.13615852937030315`"},
     {"10", "0.0002321043723207475`", "0.0000745214989202843`", 
      "0.12455129607812895`"},
     {"20", "0.00015560374183476837`", "0.0000539008748308555`", 
      "0.050585606733999464`"},
     {"30", "0.00007615931837327062`", "0.000026916427401407222`", 
      "0.020294140395147587`"},
     {"40", "0.000033456177495148204`", "0.000011923566736009306`", 
      "0.00808552199682052`"},
     {"50", "0.000013987364818688866`", "5.005582989301436`*^-6", 
      "0.003208675066712108`"},
     {"60", "5.700931991757624`*^-6", "2.044637414665793`*^-6", 
      "0.0012704313492615995`"},
     {"70", "2.2916158682326628`*^-6", "8.228858684231714`*^-7", 
      "0.0005023441721747016`"},
     {"80", "9.14036128262381`*^-7", "3.2844296367201667`*^-7", 
      "0.0001984801225722965`"},
     {"90", "3.629604063757363`*^-7", "1.304750063239341`*^-7", 
      "0.00007838588009934403`"},
     {"100", "1.4376251236231487`*^-7", "5.16907507307754`*^-8", 
      "0.000030948889671903025`"},
     {"180", "8.506483511137133`*^-11", "3.0595193191000915`*^-11", 
      "1.8232660399238113`*^-8"},
     {"200", "1.3251509327179179`*^-11", "4.766171892206745`*^-12", 
      "2.840195599746938`*^-9"},
     {"300", "1.2155036700073193`*^-15", "4.3718097710543535`*^-16", 
      "2.605135947376218`*^-13"},
     {"400", "1.1149039146088426`*^-19", "4.009982018411115`*^-20", 
      "2.3895246615450384`*^-17"},
     {"500", "1.022630075941027`*^-23", "3.678100114639899`*^-24", 
      "2.191758189234873`*^-21"},
     {"600", "9.379931831069685`*^-28", "3.3736860625216536`*^-28", 
      "2.0103596489916677`*^-25"},
     {"700", "8.603611728743136`*^-32", "3.094466516319835`*^-32", 
      "1.843974366398448`*^-29"},
     {"800", "7.891542935716292`*^-36", "2.8383562795019112`*^-36", 
      "1.6913597851210375`*^-33"},
     {"900", "7.23840776056679`*^-40", "2.6034427346032785`*^-40", 
      "1.5513761876809966`*^-37"},
     {"1000", "6.639328624965079`*^-44", "2.3879715599158994`*^-44", 
      "1.4229781841072844`*^-41"},
     {"2000", "0", "0", "0"},
     {"3000", "0", "0", "0"},
     {"4000", "0", "0", "0"},
     {"5000", "0", "0", "0"},
     {"6000", "0", "0", "0"},
     {"7000", "0", "0", "0"},
     {"8000", "0", "0", "0"},
     {"9000", "0", "0", "0"},
     {"10000", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992821944155226`*^9, 3.41783565048508*^9, 
  3.479827558140658*^9, 3.4798282296735077`*^9, 3.479829196326086*^9, 
  3.4798294253373146`*^9, 3.5185349793729506`*^9, 3.591673472318886*^9, 
  3.643443731913166*^9},
 CellLabel->"Out[14]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[15]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.3877997512457769`", "9.195224249733402`*^-8", 
      "0.5701029990616222`"},
     {"2", "0.629892854776509`", "2.8157626364155863`*^-6", 
      "0.850793926903116`"},
     {"3", "0.64475872602815`", "0.000015107728924820124`", 
      "1.0933104794067026`"},
     {"4", "0.6457320346738609`", "0.000041289219549447975`", 
      "1.3146996484602176`"},
     {"5", "0.645943448080291`", "0.00008123545949395572`", 
      "1.5174630519576389`"},
     {"6", "0.6461363469904633`", "0.00013275837977467717`", 
      "1.7031534909482593`"},
     {"7", "0.6463457850552858`", "0.00019320716676251432`", 
      "1.8731624874352992`"},
     {"8", "0.6465676148816524`", "0.00026009939189819767`", 
      "2.0287727025435824`"},
     {"9", "0.6467966160082401`", "0.0003313029388376833`", 
      "2.1711676942882985`"},
     {"10", "0.6470284903918078`", "0.00040505343163509816`", 
      "2.301438852573935`"},
     {"20", "0.6490338211519848`", "0.0010793225061751545`", 
      "3.1234218311492`"},
     {"30", "0.6501608092429825`", "0.0014738394960422604`", 
      "3.455327680004557`"},
     {"40", "0.6506829180716256`", "0.0016591319633678034`", 
      "3.5880494099551568`"},
     {"50", "0.6509067973287381`", "0.0017390799492795692`", 
      "3.6408296584987863`"},
     {"60", "0.6509992626081118`", "0.0017722045547708537`", 
      "3.661752645819817`"},
     {"70", "0.6510367026506332`", "0.0017856401234209486`", 
      "3.6700316777958366`"},
     {"80", "0.6510516974607494`", "0.0017910262853715088`", 
      "3.673304128051913`"},
     {"90", "0.6510576658526519`", "0.001793171320704303`", 
      "3.674596827262126`"},
     {"100", "0.6510600330401468`", "0.0017940223552816471`", 
      "3.675107291276536`"},
     {"180", "0.6510615813140719`", "0.0017945791122029042`", 
      "3.675440058656969`"},
     {"200", "0.65106158208655`", "0.0017945793900400742`", 
      "3.675440224226017`"},
     {"300", "0.6510615822290795`", "0.001794579441303009`", 
      "3.675440254773718`"},
     {"400", "0.6510615822290919`", "0.0017945794413077101`", 
      "3.67544025477652`"},
     {"500", "0.6510615822290919`", "0.0017945794413077101`", 
      "3.6754402547765204`"},
     {"600", "0.6510615822290919`", "0.0017945794413077101`", 
      "3.6754402547765204`"},
     {"700", "0.6510615822290919`", "0.0017945794413077101`", 
      "3.6754402547765204`"},
     {"800", "0.6510615822290919`", "0.0017945794413077101`", 
      "3.6754402547765204`"},
     {"900", "0.6510615822290919`", "0.0017945794413077101`", 
      "3.6754402547765204`"},
     {"1000", "0.6510615822290919`", "0.0017945794413077101`", 
      "3.6754402547765204`"},
     {"2000", "0.6510615822290919`", "0.0017945794413077101`", 
      "3.6754402547765204`"},
     {"3000", "0.6510615822290919`", "0.0017945794413077101`", 
      "3.6754402547765204`"},
     {"4000", "0.6510615822290919`", "0.0017945794413077101`", 
      "3.6754402547765204`"},
     {"5000", "0.6510615822290919`", "0.0017945794413077101`", 
      "3.6754402547765204`"},
     {"6000", "0.6510615822290919`", "0.0017945794413077101`", 
      "3.6754402547765204`"},
     {"7000", "0.6510615822290919`", "0.0017945794413077101`", 
      "3.6754402547765204`"},
     {"8000", "0.6510615822290919`", "0.0017945794413077101`", 
      "3.6754402547765204`"},
     {"9000", "0.6510615822290919`", "0.0017945794413077101`", 
      "3.6754402547765204`"},
     {"10000", "0.6510615822290919`", "0.0017945794413077101`", 
      "3.6754402547765204`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992821946344805`*^9, 3.41783565079758*^9, 
  3.4798275584844255`*^9, 3.4798282299859896`*^9, 3.479829196560457*^9, 
  3.47982942558731*^9, 3.518534979529204*^9, 3.5916734726309175`*^9, 
  3.643443731975651*^9},
 CellLabel->"Out[15]//TableForm="]
}, Open  ]],

Cell["Nota: Incluir Chop para esta opcion en Humorap", "Commentary"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Continuous\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "inputs1", ",", "fn1", ",", "180", ",", 
   "lambda"}], "]"}]], "Input",
 CellLabel->"In[16]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.41777006124674587`", "1.0531989574815576`*^-7", 
      "0.5731669997528437`"},
     {"2", "0.5457895662949865`", "3.0540990928820677`*^-6", 
      "0.7139081441709528`"},
     {"3", "0.4187878560014302`", "0.000015335675623811672`", 
      "0.7796913105186274`"},
     {"4", "0.31120102402938454`", "0.000038877223233425764`", 
      "0.8066251694793386`"},
     {"5", "0.23076024917633842`", "0.00007054665508917247`", 
      "0.8073122847958882`"},
     {"6", "0.17115179293184857`", "0.00010594244967422422`", 
      "0.7901588625230053`"},
     {"7", "0.12700988941927133`", "0.00014135006441656707`", 
      "0.7612284441139721`"},
     {"8", "0.0943214657402755`", "0.00017420078830072483`", 
      "0.7249005205369526`"},
     {"9", "0.07011259703014686`", "0.00020295659632972585`", 
      "0.6843169461939932`"},
     {"10", "0.05218110565808842`", "0.0002268588193136449`", 
      "0.6417098823713397`"},
     {"20", "0.003289596209229558`", "0.0002473814176697503`", 
      "0.2860144089453728`"},
     {"30", "0.0005272974881576514`", "0.0001401415351864329`", 
      "0.11653438742738881`"},
     {"40", "0.0001905869039038672`", "0.00006541028829268793`", 
      "0.04664106273801712`"},
     {"50", "0.00007915497581494844`", "0.00002815837329204943`", 
      "0.018547830630989894`"},
     {"60", "0.00003254435341312544`", "0.000011654010038772064`", 
      "0.007352148536927963`"},
     {"70", "0.000013164734620870105`", "4.724183355036678`*^-6", 
      "0.0029090322197267305`"},
     {"80", "5.270616976095702`*^-6", "1.8932519994545136`*^-6", 
      "0.0011498177544741822`"},
     {"90", "2.0974873472942285`*^-6", "7.5384628994616`*^-7", 
      "0.00045419861272685054`"},
     {"100", "8.318226474831785`*^-7", "2.9905366632394074`*^-7", 
      "0.0001793531432033243`"},
     {"180", "4.930400789439111`*^-10", "1.7733101906106544`*^-10", 
      "1.0567963448602606`*^-7"},
     {"200", "7.680760122061837`*^-11", "2.7625384728837223`*^-11", 
      "1.646228843124699`*^-8"},
     {"300", "7.045285144801631`*^-15", "2.5339821774091305`*^-15", 
      "1.5099852551338322`*^-12"},
     {"400", "6.462190504011672`*^-19", "2.3242601789160726`*^-19", 
      "1.3850129483795798`*^-16"},
     {"500", "5.927354169617567`*^-23", "2.1318952535931517`*^-23", 
      "1.2703838218172738`*^-20"},
     {"600", "5.436782992961399`*^-27", "1.955451205688478`*^-27", 
      "1.1652418531649443`*^-24"},
     {"700", "4.986813418979722`*^-31", "1.793610362117596`*^-31", 
      "1.0688018479521735`*^-28"},
     {"800", "4.574085096275552`*^-35", "1.645164103948698`*^-35", 
      "9.80343597411348`*^-33"},
     {"900", "4.195515795708063`*^-39", "1.5090038428273262`*^-39", 
      "8.992065000887007`*^-37"},
     {"1000", "3.8482783972786104`*^-43", "1.384112742536455`*^-43", 
      "8.247846285086804`*^-41"},
     {"2000", "1.6221021810060705`*^-83", "5.834219942011122`*^-84", 
      "3.476576309189609`*^-81"},
     {"3000", "6.861141823109303`*^-124", "2.4612393775740434`*^-124", 
      "1.4654229014272983`*^-121"},
     {"4000", "8.465585081046682`*^-164", "1.5152023984022726`*^-164", 
      "6.176951371242119`*^-162"},
     {"5000", "1.3204539871214057`*^-201", "1.1332610963054764`*^-202", 
      "2.603666709830167`*^-202"},
     {"6000", 
      RowBox[{"-", "1.889617985508495`*^-239"}], 
      RowBox[{"-", "1.6150772141658212`*^-240"}], "1.0974799587121016`*^-242"},
     {"7000", 
      RowBox[{"-", "4.407212831701244`*^-277"}], 
      RowBox[{"-", "3.7902152723789345`*^-278"}], "4.626023197313723`*^-283"},
     {"8000", 
      "4.4512177333919970047453603491466529014919660296599276`15.\
954589770190935*^-314", 
      "3.823322489305690104128945536168679978665838338765456`15.\
954589769019135*^-315", 
      "1.9499299693087596642644011803097692953152085`15.954589770191005*^-\
323"},
     {"9000", 
      RowBox[{
      "-", "2.447297928409437544608486872690122`1.98663213217413*^-352"}], 
      RowBox[{
      "-", "2.09768393863655760313494505032241`1.9866321321740614*^-353"}], 
      "8.2192127514975916916237710077131572589434`15.954589770191005*^-364"},
     {"10000", 
      "3.97231014052991871607080061880182981`2.8257378965451516*^-389", 
      "3.4048372633113620450172730301097164`2.8257378965451516*^-390", 
      "3.464506896026049645982545399288546720344`15.954589770191005*^-404"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282194994199*^9, 3.41783565120383*^9, 
  3.4798275588594446`*^9, 3.47982823032972*^9, 3.4798291969198256`*^9, 
  3.479829425931053*^9, 3.518534979794834*^9, 3.5916734731289673`*^9, 
  3.6434437320694017`*^9},
 CellLabel->"Out[16]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<MultiInputs\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "inputs2", ",", "fn1", ",", "180", ",", 
   "lambda"}], "]"}]], "Input",
 CellLabel->"In[17]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nlast intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "4.136402702907835`", "0.00012431486008420147`", 
      "3.147429930423508`"},
     {"2", "0.31542845412248627`", "0.00021376360136689162`", 
      "2.5705637541779`"},
     {"3", "0.019509931675528853`", "0.00034398256694422827`", 
      "2.3373634416540394`"},
     {"4", "0.0028901577865026546`", "0.00047711657731486245`", 
      "2.1400044520717225`"},
     {"5", "0.0021846709475471507`", "0.0005903877589741198`", 
      "1.9596176763192448`"},
     {"6", "0.002314172156562789`", "0.000677592884577944`", 
      "1.7939855672789495`"},
     {"7", "0.002428772933406656`", "0.00073982554654211`", 
      "1.6419234201656736`"},
     {"8", "0.0024918414928943736`", "0.0007804518340772944`", 
      "1.5023781215973933`"},
     {"9", "0.002511397134687993`", "0.0008031711976157766`", 
      "1.374372243594745`"},
     {"10", "0.002496352783073741`", "0.0008113846974069533`", 
      "1.2569971667641755`"},
     {"20", "0.0016029096762866294`", "0.0005565875868556505`", 
      "0.5098908821566921`"},
     {"30", "0.0007749503364447614`", "0.0002741344040094395`", 
      "0.204419177488731`"},
     {"40", "0.00033864873646880227`", "0.00012074386458461098`", 
      "0.08141204430583154`"},
     {"50", "0.00014121369670862954`", "0.000050546616139117015`", 
      "0.03230043054711516`"},
     {"60", "0.000057475311547724455`", "0.000020616007577811785`", 
      "0.012787246281318295`"},
     {"70", "0.00002308558433450412`", "8.290263826875989`*^-6", 
      "0.005055850605774492`"},
     {"80", "9.20389131624366`*^-6", "3.3073872884929053`*^-6", 
      "0.0019975179718570235`"},
     {"90", "3.653908859601767`*^-6", "1.3135166143343956`*^-6", 
      "0.0007888607200922092`"},
     {"100", "1.4470405283884844`*^-6", "5.202996728928205`*^-7", 
      "0.0003114591137594946`"},
     {"180", "8.560479262981729`*^-10", "3.078940460001823`*^-10", 
      "1.834834920247381`*^-7"},
     {"200", "1.3335600632002088`*^-10", "4.796417306665577`*^-11", 
      "2.8582165070163276`*^-8"},
     {"300", "1.2232158704669135`*^-14", "4.3995482926402604`*^-15", 
      "2.6216651598754736`*^-12"},
     {"400", "1.121977818946322`*^-18", "4.035424775252529`*^-19", 
      "2.404685850415291`*^-16"},
     {"500", "1.0291185160767641`*^-22", "3.701437128650752`*^-23", 
      "2.2056645783962446`*^-20"},
     {"600", "9.439446143809463`*^-27", "3.395091613337536`*^-27", 
      "2.023115090614056`*^-24"},
     {"700", "8.658200402547269`*^-31", "3.114100459443013`*^-31", 
      "1.8556741174333394`*^-28"},
     {"800", "7.941613635855017`*^-35", "2.8563652401627873`*^-35", 
      "1.7020912186794174`*^-32"},
     {"900", "7.284334412325139`*^-39", "2.6199612027523553`*^-39", 
      "1.56121944553102`*^-36"},
     {"1000", "6.6814542060871856`*^-43", "2.4031228945856413`*^-43", 
      "1.4320067751687853`*^-40"},
     {"2000", "0", "0", "0"},
     {"3000", "0", "0", "0"},
     {"4000", "0", "0", "0"},
     {"5000", "0", "0", "0"},
     {"6000", "0", "0", "0"},
     {"7000", "0", "0", "0"},
     {"8000", "0", "0", "0"},
     {"9000", "0", "0", "0"},
     {"10000", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nlast intake", "Urine\n24 hours", "Faecal\n24 hours", 
       "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282195353916*^9, 3.417835651500705*^9, 
  3.479827559187587*^9, 3.4798282306265783`*^9, 3.479829197247944*^9, 
  3.479829426243547*^9, 3.518534980044839*^9, 3.591673473539008*^9, 
  3.6434437321475277`*^9},
 CellLabel->"Out[17]//TableForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IntakeWay\[Rule] \"Injection\",ShowReport\[Rule] \"GraphicReport\"", \
"SubsubsectionIcon"],

Cell[TextData[StyleBox["We chose the day 180 as the upper limit to be \
represented ", "Theorem"]], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[18]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwd13k8VF8bAPCZO7ZsWSbJeockS5ZoSHJOSFpJogilkhQttFBZUtmyRCpE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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV13k4VdsbB/Bz9j6OIYSO27ll3uY5MiTarzI1SUhdY8YrFRKXVIYmylCh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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -26.578420936596494`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-26.578420936596494`, 1.8405131283573786`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Acute intake in t = 0\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282198528816*^9, 3.41783565539133*^9, 
  3.4798275606876636`*^9, 3.479828231720265*^9, 3.479829198169801*^9, 
  3.4798294271029053`*^9, 3.5185349813886147`*^9, 3.591673475676222*^9, 
  3.6434437323975296`*^9},
 CellLabel->"Out[18]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[19]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwd13c81d8fB3CbzDtUlIyikBWFMs4hIxmhoiQtfZWRvoqMEiWSURqKQkq2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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwd1nk4Fu0XB3BLIevzzDxkLCUhW1mzheckW4qiohSVRLIlr1KWkK0ispUI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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -17.779280434187843`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-17.779280434187843`, 1.14813344351355}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282201187599*^9, 3.417835657813205*^9, 
  3.4798275616877146`*^9, 3.479828232813952*^9, 3.4798291991854067`*^9, 
  3.479829428024763*^9, 3.5185349827323904`*^9, 3.591673478519506*^9, 
  3.643443732678782*^9},
 CellLabel->"Out[19]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Continuous\>\"", ",", 
    "\"\<GraphicReport\>\"", ",", "inputs1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[20]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV1nk0Ff8bB3DZKluWSzchkcpSiCtFPWNrkaVUtrRJ5assUSpZS4voG22k
IipKoVTI0me+liL7vl7uzF3QTci+xG9+f8yZ8zrPOXM+8/m853lmtbuvw0lB
AQGBPur6/719Q6BhjX/w9qXSukE6v/koxP1o/z26K1x68/DqfBcfxU2XCbrS
vUDQ+H55cyUfrSyfvLuNHgS3PTun777iI5ZWnKMu/TZcM9L5x+4wH5UwmVvW
0xPBJso61Kb2JzLYHPl2DT0DLlpoD9TnD6D8aO9P3P4M+Gd2yfff6QNoO8ux
OO3LW9hxXmhkZfwA2hWlWbf+UCbUiSktvLwwgLK8T19WsH8POyKvR1w0GECl
SOKZ4r2P0OcgIm2V049+nXDiqNELQJKmXxlQ3IeCjV7PW0cVQFvl+YKYzD4k
sXSaHjBTADyZiitFz/qQTlaibWl3IUyvNSk4FtqHvKeYuSdSisFM9thMMdaH
Lu7IsXR4iINgjE1HayUPTXUaL7+vUgZtq+KuZg9yEWZ5fM06pzJo+Kvi/5nF
Rbcyo/QL75bBY7twTmMTF9HDO/ewBcrhHWeP6YECLjLWCA43YJfD77G6JX63
uOiyLxpoSv8Ow4dVdohoctGM0I4imn4VnBZ22XLkCgct6hAb6z9ZBVUhU8zB
cxy0JKtOuzixCvR9XnfFenLQcmeXJyeFq2G8pCpH2pGDDN+dDcptq4as+vGQ
CX0O8j5w39g5tBYk0gNf2Q+y0XlNZz+dj7WwsGnv8mVcNgqeV3ot0F8Lh7bE
rSC62ej267Tlb/bVwROHm4lF1Wy0f95tNli2Hjpt5BX3ZrKRn4NfZw23Hpps
udbMc2w0VuQwsVmgAY5+/RmMvNjo4jqGbKpiAzxd8ej0xxNsFDo3vTvQnqqH
zejWH2SjmLRrX1S+NMDMLRmJ7q1s9GbmUYJvTCO4tK7k6i1hI52Tlz91pDWC
xofyjesF2eh93aF6i/8aYdWxXwf05kiU/1J1CX2iEdQNvi34D5Pom13GRfxo
E7xjCu/FO0hEphY7yhg0w+m5Rr5PNoneGe6rmbBphtJV/nE3MkgU+I1j0X2q
GaQVpxIzX5Fo6U9x/fTEZrCz25yu+ZREevqu4tsEW6B1Y5BlexSJQtEE8mxo
gTFj0QxhTxLt2nfbyI7fAjqFQx8kPEgky1bONBBpBRVhJSf1YyR6JWqVOG/c
CoXlObuCnUlUbXv//IPnrVDusvRi124SKXbrauK+bRDrvSvWUpdEHO/S5FdR
bVCqsqVOT4dEWQuOCtEv2kC2+MqgliaJzNRDhRzb2uBzZ83jXeok8vSqZvK3
t8MhWpHfejqJNs0dPdDg3A7HRyT+uSpPork7oz9y/dvB+NhJ7oAsie5+UMyP
SGsHCwPrbYQkiXKnPO8tl+qA+Fdj+n7CJAq/Pbfk77oO2DVvLcsQJJG1UmwY
adYBKy+NKC8WIBET8s5mXuiAKv/H0Y2zBBK+KbLTgtkBuUIxcSJjBKqlPy5e
P9kB47F7n236Q6CEDB1DKZlO0C3bE3p2mEDatftXd1h2QphjykPRQQI5yKfO
+rzrhDpfxlgjj0C6H9453ajohJR9bOWdXAJJ2OZ9fMbphAdRS+Yr2QT6Fll9
plqpCw5dD8qcZRHohWrbd7ZxFwgfrHbP6CVQeBGhPnugC3yjkhNP9xDIZGyi
S/NOFxT6BhyR7CYQPXaRsdmbLrjH/FU/3kmgCW2JB87lXfB+Zce9Xx0Eavqu
MOxLdAE/LCF+pJ1A70+strn5twvk8x43ClO+s6D9OmlFN9QWu2xe20YgrydG
wrmMbohrP/HlYCuB1jTtKeJ4d4PIwx/snmYCLfJ1pM9FdYNyb2SAMeUesePn
5dK6QT7Ecii5iUCFaWfqtUq6QSW5y1qecoJ5oI55TzfkR2kFJTQS6EJP+C2X
mW7QjFl1TpOyQ1A0x0+BCeqTueoVDQTSU3iE3drEhNWys9fPU5bMef402Y4J
n2WEYzZS/mn7dirXiwlWklOaE/UEqhj4fKD2BhPoY2IHqii/uo6/56YyYcO1
0PlMyldXV0n8/cqE+S2pykmUjxa3eNK6mCBl3/TqCWVTF1aZ9iQTRNKCo9Mo
rxj/qWoh1wOjJQqlXylPxI4Hu+r2wGW0zoxDuUlHoOPcnh7wAosZBWo97yvE
GFGne+C4hxjbkfIdD/m459d6QKBUe/gFZS8B1cG85B5oOnhCYZ7yzqdau+sK
e6DjXJD1Ser91xgzXvHaeiCyYGdEB2XBZlg0P9oDvvLZ2a7U/vX6Wh+Wl+6F
Z89SfvRTLhI/+EVHpxcm4pW/X6P2PzH9qLzlrl6QOrUxUbuFQBctvM4d8uiF
kcu/jFmUD/Ser/EP74Xa3SEJKdR56l8J07z9tBcULOSyfKnzllp++3pKPlUv
HvSxpvJQYZe8rX6YqhOZ3zWoPDmMN1cHiLJg6WEH67VdBDKz6AwKo7HgWF++
rQGVP5VeTusjPRaUhbW886fyKbHhZ2TqdhYcz88efUnldzZoaFOWDQtWmTyI
Y1P5bleY+bfckwVPRmzfXP9//j0WTBsCWdAv8VZqgEOgzznC/O5IFvy7Ti3V
mfp+7tkt2zn2nAU3/Me13AYIZHtjzYJaBwvUXGbfjg4RSGeoPm87jwW/1TBu
wgiBxJxD/FxHWXDG+MGFXaPU8zVbiThJAl6WlF/5NkEgrOZmmYA5AU06pebb
5qn1GxmGKNkTIMrNczak+sFcEoth7EZAwibXm//vF1/8tqT7BhKwMKss7ShK
9SMaP6ong4Axr7JZqWUkkg6JN5/JI8DssZiQowyJhrgWs/LlBGy9UMVLk6P6
c97Ts7a9BMT/slp7iupnGofs7IvkSJDR+pDvokYieuoHWmIwCWbbDNlSxiSa
EDtS8zmKhG8VHvbDW0nUEiB2o+ERCcyFPxpd20h0z+rE5JIPJJgsK56otiCR
+ACt8yKXBLvMRk/VvSSa172UfNCODfzsv7nhXiRiF2/XklHlgMoL4+ppah5U
v01rsdrIgWbBs3QHal58eiwVEWTKAae/p69+yiJR5IWeNrYzB/YfTY6LzyPR
mg2h13PjOGCieKG6pZJEHk+LWYeEuBBY89ZOh5pPnCDT+DQeF94c49tIW7JR
tedL864xLsS9KDyXtJuNPjlK/F4mxAOl29EtDHs2itzUbXl5FQ8++udi4a5s
tObnlT97nHlgmTw3dpWatyddCm1HKnnwtVLDb2sKG/E2bxU2zeyD8MXWNrsW
c9C5LzNuGwv74KOiim+TJAfNbS38rFrZB7cC5L+fonGQ7HbT0yLcPvBxOSKY
tpqDwHL7j1qlflC2eLjyhikHJew1jz0e0w+jEdiTigAOsv7HWunmmQFg/xd4
1qifg7ISXQ0bNfkwq/xM+0cfF2luLolvNuJDT5v7VOYQF71s0pxtteADLJcW
TpjkokSJ6f+6DvNhhc27mtDFPHQ9NN6eG8eHawqdxKN1POTm3uw1Nc2HtO8O
Pb89eUhMyy5F5ccvcDqGPm0Y5qHTX8ykznj9hn0K7UkB0v1op+T1Pc+nhiF7
hVWrYP1P1PSk2kMi6Q+MWwt/0kKD6L+ktZobTcbA5uqV4+eChxHPfMTSZ3ac
+l/dvHTE7w8Sskr+nP1sEpqK13ykXx5DTv3FIctOTIPD+Ui/sF8TSFJgaHiN
6ix0PSVeX3syjYouCH0xQXNgvNmw7Kb7HEqJudXuFzEP4QHm0+kFCwgPv5TW
JCuAHdpf4zOQsAivEj8pETohgJFTxk3JWUL44obOnUKti7CV2nNGX8dFcLAq
2RCVJogFrH9rdt9+CS4n5g5Jt4QwRsnWvFhVcZwdEjD78ZAwppJ9LT5MVArn
aEvdeaklgoWNFg2lxErj4VrHrdeIi2J9Ig281JOy+Ip2jZyX3aKYDs/9RoQp
DbdtTbX6hBZjn5wnNU47KeA5Um+ykpKWYOV3qj30Auk4bUK1JMpnKdaWZ9W5
zlMRl9m4b5HwXjGMv1zKUs1dCReTH/0ZqiaO3Zbh6DlIqOAMI5WM5mFxTGVP
gXjljVX4bPqih1/qJTB/VdEfiddV8eIKR63kFEksKmHokdq21bjiVg++XKQU
5outs+yWVcPPu7Ido5yWYesVFnnZDKvhYZ3jVWflpLGsn3cUF7PVcVk9x6vd
16SxsQO5MdvFNXD1w0N3qn9JY+1uomvFzdfiETkeupFHZLBW2bp7tKJ1+NTL
JBPNWhnsr2gUQ+6wJj7oI/PMzkgW6ww9G01fpo3rHT/2wCRdFvs3x+hMy8oN
+IhWP+u1tBz2K0uOW7ZNF6+KM0wQuiSHHTE3aQv9rof/UT3M1eiXw0IG3Z23
bdiEx9/8erNiLw2Tfr233uu5AX7JzRc9caBhC1J8YdN0A9xVX3XS5wANkyqK
dJLOMsBVuiJOyTvTMFVZN7eSQgP85UYrK/ejNOx5/R4JmzYDPKelSnDOm4Y9
vTxiOSlliFerd4ToRtMwztn9JnnhhnjWVNRnwTs0zEDScPr3TUP8bs3WwZZ/
aVjqzvtCWncNcYeLT92C79GwSclqoYxnhnjHj6MmlY8pL7XsbigwxHnneFPu
r2mYt/IdrGTcEK/YEa9nlEHDmDtfXNH9a4hnrNzlufQdDav5HLnyuTAD9y5/
05adTcN+v265Gy3HwMfo3rlzuTRsLFcqMFqfgbcOKv+uy6dhh/PbBWlbGHhe
Sa3GiwIaJhTRIfAcY+BBZ/Ue7v5KwyylSx1L7Bm4mxlRrYTTsONhdR+cnRj4
doV7wsP/0TAQcY38c4SBq/LNTUtLaRjbfqLu7ikGvggfDXhUTsPcvhk/0vNh
4P8DdamTIA==
        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV1nlcTF8bAPBpZu5Mu5bBoLjTQiptKkTmiYpWKS1aSSqp0CJCC2lfREki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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -24.642629827261345`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-24.642629827261345`, 1.6329137912418188`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Continuous intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282204471978*^9, 3.41783566098508*^9, 
  3.4798275630002823`*^9, 3.479828233938887*^9, 3.4798292002010117`*^9, 
  3.479829429274739*^9, 3.518534984232419*^9, 3.591673481026757*^9, 
  3.6434437328194084`*^9},
 CellLabel->"Out[20]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<MultiInputs\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "inputs2", ",", "fn1", ",", "180", ",", 
   "lambda"}], "]"}]], "Input",
 CellLabel->"In[21]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV13k81M8bAPA9HOUox7IftxyVm2xCx0ySlDO5flTKlRQpd0lEkasilbNE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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV13k8VO0XAPCZO2MJWadI92Ls+xJDqdxTSd7skoqi7IQk3iQJKVmLXmkR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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -24.233404667022114`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-24.233404667022114`, 3.7522878343446235`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Multi Inputs\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992822077876368`*^9, 3.41783566423508*^9, 
  3.479827564344101*^9, 3.479828235141943*^9, 3.479829201247867*^9, 
  3.479829430305969*^9, 3.518534985748073*^9, 3.5916734839340477`*^9, 
  3.6434437329444094`*^9},
 CellLabel->"Out[21]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IntakeWay\[Rule] \"Injection\",ShowReport\[Rule] \
\"CompartmentContent\"", "SubsubsectionIcon"],

Cell[TextData[StyleBox["It computed the retention the day 180 (also can be \
used \"t\" in place of a numeric number)", "Theorem"]], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<CompartmentContent\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
   "lambda"}], "]"}]], "Input",
 CellLabel->"In[22]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qB", "[", "180", "]"}], "\[Rule]", "4.366813021347347`*^-11"}], 
   ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "2"], "[", "180", "]"}], "\[Rule]", 
    "1.5520475694779644`*^-8"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "3"], "[", "180", "]"}], "\[Rule]", 
    "2.6141150178278785`*^-9"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "4"], "[", "180", "]"}], "\[Rule]", 
    "7.066358176484791`*^-12"}], ",", 
   RowBox[{
    RowBox[{"qURI", "[", "180", "]"}], "\[Rule]", "1.418682459316836`*^-7"}], 
   ",", 
   RowBox[{
    RowBox[{"qULI", "[", "180", "]"}], "\[Rule]", 
    "1.6836586042241565`*^-11"}], ",", 
   RowBox[{
    RowBox[{"qLLI", "[", "180", "]"}], "\[Rule]", "3.049861219838786`*^-11"}],
    ",", 
   RowBox[{
    RowBox[{"qFEC", "[", "180", "]"}], "\[Rule]", 
    "8.486487712654458`*^-9"}]}], "}"}]], "Output",
 CellChangeTimes->{3.3992822079909554`*^9, 3.417835664406955*^9, 
  3.479827564750372*^9, 3.479828235438801*^9, 3.479829201497862*^9, 
  3.4798294304309664`*^9, 3.5185349857949495`*^9, 3.5916734842940836`*^9, 
  3.64344373297566*^9},
 CellLabel->"Out[22]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<CompartmentContent\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
   "lambda"}], "]"}]], "Input",
 CellLabel->"In[23]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qB", "[", "180", "]"}], "\[Rule]", "0.35272933316985944`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "2"], "[", "180", "]"}], "\[Rule]", 
    "3.0783649266364965`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "3"], "[", "180", "]"}], "\[Rule]", 
    "0.18470187749561007`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "4"], "[", "180", "]"}], "\[Rule]", 
    "0.05663949347057804`"}], ",", 
   RowBox[{
    RowBox[{"qURI", "[", "180", "]"}], "\[Rule]", "7.844495932071795`"}], ",", 
   RowBox[{
    RowBox[{"qULI", "[", "180", "]"}], "\[Rule]", "0.0011309820109169635`"}], 
   ",", 
   RowBox[{
    RowBox[{"qLLI", "[", "180", "]"}], "\[Rule]", "0.0018734458735077282`"}], 
   ",", 
   RowBox[{
    RowBox[{"qFEC", "[", "180", "]"}], "\[Rule]", "0.02162239062135812`"}], 
   ",", 
   RowBox[{
    RowBox[{"qWB", "[", "180", "]"}], "\[Rule]", "3.675440058656969`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399282208194274*^9, 3.41783566461008*^9, 
  3.4798275649847584`*^9, 3.4798282357669067`*^9, 3.479829201700983*^9, 
  3.4798294306497126`*^9, 3.518534985951202*^9, 3.5916734845521092`*^9, 
  3.6434437330225353`*^9},
 CellLabel->"Out[23]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Continuous\>\"", ",", 
    "\"\<CompartmentContent\>\"", ",", "inputs1", ",", "fn1", ",", "180", ",",
     "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[24]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qB", "[", "180", "]"}], "\[Rule]", "2.531028712744696`*^-10"}], 
   ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "2"], "[", "180", "]"}], "\[Rule]", 
    "8.995965721094697`*^-8"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "3"], "[", "180", "]"}], "\[Rule]", 
    "1.5151560310876442`*^-8"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "4"], "[", "180", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"qURI", "[", "180", "]"}], "\[Rule]", "7.95618271254772`*^-7"}], 
   ",", 
   RowBox[{
    RowBox[{"qULI", "[", "180", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"qLLI", "[", "180", "]"}], "\[Rule]", 
    "1.7677134903184493`*^-10"}], ",", 
   RowBox[{
    RowBox[{"qFEC", "[", "180", "]"}], "\[Rule]", "4.690276181838029`*^-8"}], 
   ",", 
   RowBox[{
    RowBox[{"qWB", "[", "180", "]"}], "\[Rule]", 
    "1.0567963448602606`*^-7"}]}], "}"}]], "Output",
 CellChangeTimes->{3.3992822085227118`*^9, 3.417835665000705*^9, 
  3.4798275653129005`*^9, 3.4798282360793886`*^9, 3.4798292020134773`*^9, 
  3.479829430977831*^9, 3.5185349861855817`*^9, 3.591673484989153*^9, 
  3.6434437331006637`*^9},
 CellLabel->"Out[24]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<MultiInputs\>\"", ",", 
   "\"\<CompartmentContent\>\"", ",", "inputs2", ",", "fn1", ",", "180", ",", 
   "lambda"}], "]"}]], "Input",
 CellLabel->"In[25]:="],

Cell[BoxData["\<\"Option not available for MultiInputs intake\"\>"], "Output",
 CellChangeTimes->{3.3992822085539923`*^9, 3.417835665031955*^9, 
  3.4798275653597775`*^9, 3.479828236126261*^9, 3.4798292020603514`*^9, 
  3.479829432009061*^9, 3.5185349862324576`*^9, 3.5916734852501793`*^9, 
  3.643443733116289*^9},
 CellLabel->"Out[25]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IntakeWay\[Rule] \"Injection\",ShowReport\[Rule] \"Disintegrations\"", \
"SubsubsectionIcon"],

Cell[TextData[StyleBox["It computed the accumulted disintegration over 180 \
days  (also can be used \"t\" in place of a numeric number)", "Theorem"]], \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<Disintegrations\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
   "lambda"}], "]"}]], "Input",
 CellLabel->"In[26]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qB", "[", "180", "]"}], "\[Rule]", "30475.814385875856`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "2"], "[", "180", "]"}], "\[Rule]", 
    "265970.7296613933`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "3"], "[", "180", "]"}], "\[Rule]", 
    "15958.242215620712`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "4"], "[", "180", "]"}], "\[Rule]", 
    "4893.652235857944`"}], ",", 
   RowBox[{
    RowBox[{"qURI", "[", "180", "]"}], "\[Rule]", "677764.4485310033`"}], ",", 
   RowBox[{
    RowBox[{"qULI", "[", "180", "]"}], "\[Rule]", "97.7168457432256`"}], ",", 
   RowBox[{
    RowBox[{"qLLI", "[", "180", "]"}], "\[Rule]", "161.86572347106778`"}], 
   ",", 
   RowBox[{
    RowBox[{"qFEC", "[", "180", "]"}], "\[Rule]", "1868.1745496853348`"}], 
   ",", 
   RowBox[{
    RowBox[{"qWB", "[", "180", "]"}], "\[Rule]", "317558.0210679621`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.3992822088042307`*^9, 3.417835665250705*^9, 
  3.4798275657973003`*^9, 3.4798282363762465`*^9, 3.479829202294722*^9, 
  3.4798294338371515`*^9, 3.5185349863887105`*^9, 3.591673485650219*^9, 
  3.6434437331787963`*^9},
 CellLabel->"Out[26]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<Disintegrations\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
   "lambda"}], "]"}]], "Input",
 CellLabel->"In[27]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qB", "[", "180", "]"}], "\[Rule]", "5.470366438849678`*^6"}], 
   ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "2"], "[", "180", "]"}], "\[Rule]", 
    "4.495072781029458`*^7"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "3"], "[", "180", "]"}], "\[Rule]", 
    "2.586533859469927`*^6"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "4"], "[", "180", "]"}], "\[Rule]", 
    "877998.9121139464`"}], ",", 
   RowBox[{
    RowBox[{"qURI", "[", "180", "]"}], "\[Rule]", "1.137792696653266`*^8"}], 
   ",", 
   RowBox[{
    RowBox[{"qULI", "[", "180", "]"}], "\[Rule]", "15786.28693752678`"}], ",", 
   RowBox[{
    RowBox[{"qLLI", "[", "180", "]"}], "\[Rule]", "26000.66482459558`"}], ",", 
   RowBox[{
    RowBox[{"qFEC", "[", "180", "]"}], "\[Rule]", "278526.59235131316`"}], 
   ",", 
   RowBox[{
    RowBox[{"qWB", "[", "180", "]"}], "\[Rule]", "5.3927413972490266`*^7"}]}],
   "}"}]], "Output",
 CellChangeTimes->{3.3992822090857487`*^9, 3.417835665531955*^9, 
  3.4798275660941906`*^9, 3.479828236735601*^9, 3.479829202638465*^9, 
  3.479829434196519*^9, 3.5185349865918393`*^9, 3.5916734859782515`*^9, 
  3.643443733256913*^9},
 CellLabel->"Out[27]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Continuous\>\"", ",", 
    "\"\<Disintegrations\>\"", ",", "inputs1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[28]:="],

Cell[BoxData["\<\"Option not available for continuous intake\"\>"], "Output",
 CellChangeTimes->{3.3992822091795883`*^9, 3.417835665563205*^9, 
  3.4798275661410675`*^9, 3.479828236782473*^9, 3.479829202700964*^9, 
  3.4798294342433934`*^9, 3.5185349866387153`*^9, 3.5916734861692705`*^9, 
  3.643443733272538*^9},
 CellLabel->"Out[28]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<MultiInputs\>\"", ",", 
   "\"\<Disintegrations\>\"", ",", "inputs2", ",", "fn1", ",", "180", ",", 
   "lambda"}], "]"}]], "Input",
 CellLabel->"In[29]:="],

Cell[BoxData["\<\"Option not available for MultiInputs intake\"\>"], "Output",
 CellChangeTimes->{3.3992822092265077`*^9, 3.417835665594455*^9, 
  3.4798275661723194`*^9, 3.4798282368293457`*^9, 3.479829202763463*^9, 
  3.479829434290268*^9, 3.518534986685591*^9, 3.591673486289283*^9, 
  3.643443733272538*^9},
 CellLabel->"Out[29]="]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["IntakeWay\[Rule] \"Ingestion\",ShowReport\[Rule] \"Automatic\"", \
"SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<Automatic\>\"", ",", "1", ",", "fn1", ",", "t1", ",", "lambda"}], 
  "]"}]], "Input",
 CellLabel->"In[30]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qDailyUrine", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"2.421887757139943`*^9", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "24.086643397569993`"}], " ", "t1"}]]}], "-", 
     RowBox[{"68464.3697991867`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t1"}]]}], "+", 
     RowBox[{"15.43840193580571`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240244`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.0016950214037013689`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.1467904756738283`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.001575532649493866`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935535`"}], " ", "t1"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qDailyFaecal", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.6376162230444735`"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "24.086643397569993`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00007086761148549592`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240244`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.00018718875923836085`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699939`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00020289664681691136`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.0006486492342218757`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.1467904756738283`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.0005666728326360337`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935535`"}], " ", "t1"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qWholebody", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"0.09142952132283698`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "24.086643397569993`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.4206622113209491`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t1"}]]}], "+", 
     RowBox[{"1.0292802478199954`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240244`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.00003706966883481688`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699939`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00011808112234933487`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.03780557175841999`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.1467904756738283`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.33767700248302257`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935535`"}], " ", "t1"}]]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399282209554946*^9, 3.41783566604758*^9, 
  3.4798275666098413`*^9, 3.4798282371574516`*^9, 3.4798292031228313`*^9, 
  3.4798294346496353`*^9, 3.518534986935596*^9, 3.5916734867153254`*^9, 
  3.6434437333662977`*^9},
 CellLabel->"Out[30]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<Automatic\>\"", ",", "1", ",", "fn1", ",", "t1", ",", "lambda"}], 
  "]"}]], "Input",
 CellLabel->"In[31]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qDailyUrine", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{"0.6487196125913783`", "\[VeryThinSpace]", "-", 
     RowBox[{"1.0054899377902853`*^8", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "24.086643397569993`"}], " ", "t1"}]]}], "+", 
     RowBox[{"5664.4651080672575`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t1"}]]}], "-", 
     RowBox[{"5.399576159383922`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240244`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.011547216506524183`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.1467904756738283`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.016947168699521065`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935535`"}], " ", "t1"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qDailyFaecal", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{"0.001788124060231669`", "\[VeryThinSpace]", "-", 
     RowBox[{"0.00002478592454327079`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240244`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00009921788053824104`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699939`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.00018671870391946346`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00441887820885048`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.1467904756738283`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.006095398972025823`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935535`"}], " ", "t1"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qWholebody", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{"3.7037359104853658`", "\[VeryThinSpace]", "-", 
     RowBox[{"0.0037958597972211`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "24.086643397569993`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.03480389033447639`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.35999043881374215`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240244`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.000019648476698120484`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699939`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.00010866593641795813`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.25754785237173566`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.1467904756738283`"}], " ", "t1"}]]}], "-", 
     RowBox[{"3.6322123371208948`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935535`"}], " ", "t1"}]]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399282209961583*^9, 3.41783566645383*^9, 
  3.479827567141119*^9, 3.4798282375636787`*^9, 3.4798292035759473`*^9, 
  3.4798294350715027`*^9, 3.518534987263727*^9, 3.59167348725838*^9, 
  3.643443733475665*^9},
 CellLabel->"Out[31]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Continuous\>\"", ",", 
   "\"\<Automatic\>\"", ",", "inputs1", ",", "fn1", ",", "t", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[32]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qDailyUrine", "[", "t", "]"}], "\[Rule]", 
    RowBox[{"0.`", "\[VeryThinSpace]", "-", 
     RowBox[{"1.2218055570063461`*^8", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "24.086643397569993`"}], " ", "t"}]]}], "+", 
     RowBox[{"6970.368152137537`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t"}]]}], "-", 
     RowBox[{"7.239047788726864`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240244`"}], " ", "t"}]]}], "+", 
     RowBox[{"1.0462982782551347`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.3`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.013276104689884383`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.1467904756738283`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.009132080347608262`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935536`"}], " ", "t"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qDailyFaecal", "[", "t", "]"}], "\[Rule]", 
    RowBox[{"0.`", "\[VeryThinSpace]", "-", 
     RowBox[{"0.00003322973636452743`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240244`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.00014157340674663085`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699939`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.0003095125147333736`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.001996261212576903`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.3`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.005080487551212154`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.1467904756738283`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0032845411614296216`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935536`"}], " ", "t"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qWholebody", "[", "t", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.004612480363606609`"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "24.086643397569993`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.042827685250001746`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.48262824953926936`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240244`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.000028036295156119283`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699939`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.00018012907405937268`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t"}]]}], "-", 
     RowBox[{"1.2165648051104903`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.3`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.2961087850747561`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.1467904756738283`"}], " ", "t"}]]}], "+", 
     RowBox[{"1.9572387276170238`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935536`"}], " ", "t"}]]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.3992822105402594`*^9, 3.417835667000705*^9, 
  3.479827567781777*^9, 3.4798282381886425`*^9, 3.4798292041540613`*^9, 
  3.4798294356496162`*^9, 3.518534987701236*^9, 3.591673487927447*^9, 
  3.643443733631969*^9},
 CellLabel->"Out[32]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<MultiInputs\>\"", ",", 
   "\"\<Automatic\>\"", ",", "inputs2", ",", "fn1", ",", "t", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[33]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qDailyUrine", "[", "t", "]"}], "\[Rule]", 
    RowBox[{"0.`", "\[VeryThinSpace]", "+", 
     RowBox[{"1.6953214299979605`*^10", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "24.086643397569993`"}], " ", "t"}]]}], "-", 
     RowBox[{"479250.58860082715`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t"}]]}], "+", 
     RowBox[{"108.2209615504379`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240244`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.016359060906195128`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.1467904756738283`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.015855291766052576`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935535`"}], " ", "t"}]]}], "-", 
     RowBox[{"4.440892098500626`*^-16", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.08664339756999316`"}], " ", "t"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qDailyFaecal", "[", "t", "]"}], "\[Rule]", 
    RowBox[{"0.`", "\[VeryThinSpace]", "-", 
     RowBox[{"4.463313561311316`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "24.086643397569993`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.000496771692409171`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240244`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.0013232263679956568`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699939`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0014898462856023904`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.006260270404975959`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.1467904756738283`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.005702682899161794`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935535`"}], " ", "t"}]]}], "+", 
     RowBox[{"4.163336342344337`*^-17", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.08664339756999316`"}], " ", "t"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qWholebody", "[", "t", "]"}], "\[Rule]", 
    RowBox[{"0.`", "\[VeryThinSpace]", "+", 
     RowBox[{"0.6400066492598588`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "24.086643397569993`"}], " ", "t"}]]}], "-", 
     RowBox[{"2.9446354792867053`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t"}]]}], "+", 
     RowBox[{"7.215105461505765`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240244`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.0002620433163544594`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699939`"}], " ", "t"}]]}], "+", 
     RowBox[{"0.0008670558350363772`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t"}]]}], "-", 
     RowBox[{"0.36487070289437157`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.1467904756738283`"}], " ", "t"}]]}], "+", 
     RowBox[{"3.3981951429405797`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935535`"}], " ", "t"}]]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399282211072016*^9, 3.417835667500705*^9, 
  3.479827568359931*^9, 3.479828238657365*^9, 3.479829204654052*^9, 
  3.4798294361183577`*^9, 3.5185349880449924`*^9, 3.591673488439498*^9, 
  3.643443733756917*^9},
 CellLabel->"Out[33]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IntakeWay\[Rule] \"Ingestion\",ShowReport\[Rule] \"BioassayTable\"", \
"SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[34]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.5829233003607028`", "4.074775878120601`*^-7", 
      "0.33408033536638027`"},
     {"2", "0.05075806371033046`", "5.9207215967035345`*^-6", 
      "0.2555890338542159`"},
     {"3", "0.003007612208077261`", "0.00001830489394327031`", 
      "0.2313502603410711`"},
     {"4", "0.0003105787387522951`", "0.00003263319426309914`", 
      "0.2118059121962001`"},
     {"5", "0.00018573414614355454`", "0.000045519949191670896`", 
      "0.19399562376323384`"},
     {"6", "0.0001999406166759005`", "0.00005584825706421515`", 
      "0.1776389824811575`"},
     {"7", "0.0002152685549291185`", "0.00006355744541750786`", 
      "0.1626168391656386`"},
     {"8", "0.00022509650394224312`", "0.00006894190960445717`", 
      "0.14882626059450757`"},
     {"9", "0.0002301226828146073`", "0.00007237318535444615`", 
      "0.13617178683202644`"},
     {"10", "0.00023128946584243546`", "0.00007420604231544845`", 
      "0.12456458358721498`"},
     {"20", "0.00015544289759181082`", "0.00005383783516701451`", 
      "0.05059443719002945`"},
     {"30", "0.00007613288216095423`", "0.000026905723551854097`", 
      "0.02029845189862514`"},
     {"40", "0.00003345427931731714`", "0.000011922608560068805`", 
      "0.008087414052911699`"},
     {"50", "0.000013988582340882188`", "5.005957428834905`*^-6", 
      "0.003209465693621216`"},
     {"60", "5.701865669672103`*^-6", "2.044958607804842`*^-6", 
      "0.0012707535028908521`"},
     {"70", "2.292088782412886`*^-6", "8.23052592425232`*^-7", 
      "0.0005024736493418201`"},
     {"80", "9.142468356458883`*^-7", "3.2851797260838214`*^-7", 
      "0.00019853176152245921`"},
     {"90", "3.630491117032536`*^-7", "1.3050673215490112`*^-7", 
      "0.00007840638472583891`"},
     {"100", "1.4379879991802904`*^-7", "5.170376108587288`*^-8", 
      "0.00003095701097785678`"},
     {"180", "0", "0", "1.823746561927576`*^-8"},
     {"200", "0", "0", "2.840944162836449`*^-9"},
     {"300", "0", "0", "0"},
     {"400", "0", "0", "0"},
     {"500", "0", "0", "0"},
     {"600", "0", "0", "0"},
     {"700", "0", "0", "0"},
     {"800", "0", "0", "0"},
     {"900", "0", "0", "0"},
     {"1000", "0", "0", "0"},
     {"2000", "0", "0", "0"},
     {"3000", "0", "0", "0"},
     {"4000", "0", "0", "0"},
     {"5000", "0", "0", "0"},
     {"6000", "0", "0", "0"},
     {"7000", "0", "0", "0"},
     {"8000", "0", "0", "0"},
     {"9000", "0", "0", "0"},
     {"10000", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282211384814*^9, 3.417835667781955*^9, 
  3.479827568688073*^9, 3.479828239032344*^9, 3.479829204950921*^9, 
  3.479829436415227*^9, 3.5185349881856203`*^9, 3.5916734889115453`*^9, 
  3.6434437338350544`*^9},
 CellLabel->"Out[34]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[35]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\n start intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.36220367385927066`", "7.470331711556533`*^-8", 
      "0.5956990936960569`"},
     {"2", "0.6255197207115168`", "2.559824491380619`*^-6", 
      "0.8786390391761953`"},
     {"3", "0.6423145623531923`", "0.000014293423644791414`", 
      "1.1212895379247612`"},
     {"4", "0.6433963420157331`", "0.00003978587041440079`", 
      "1.342693754253518`"},
     {"5", "0.6436121780814368`", "0.00007905340089311291`", 
      "1.5454672122133668`"},
     {"6", "0.6438037932972813`", "0.00012996218708724236`", 
      "1.7311687690151`"},
     {"7", "0.6440118416141329`", "0.000189873469682314`", 
      "1.9011898878322455`"},
     {"8", "0.6442324654593108`", "0.0002563015274511596`", 
      "2.0568128893148034`"},
     {"9", "0.6444604341624878`", "0.00032710648863437664`", 
      "2.1992210372255947`"},
     {"10", "0.6446914260168022`", "0.00040051559512515114`", 
      "2.329505483684275`"},
     {"20", "0.6466926921964395`", "0.0010732048415542511`", 
      "3.1516026644895034`"},
     {"30", "0.6478189190330967`", "0.001467420827223169`", 
      "3.4835723883666954`"},
     {"40", "0.648340921633574`", "0.00165266881952977`", 
      "3.616323660674838`"},
     {"50", "0.6485648037153844`", "0.001732616377237567`", 
      "3.6691165672005606`"},
     {"60", "0.6486572804206219`", "0.0017657447595298206`", 
      "3.6900447803839005`"},
     {"70", "0.6486947273484702`", "0.001779182727962167`", 
      "3.698325927905606`"},
     {"80", "0.648709725423493`", "0.001784570046539164`", 
      "3.7015992253398844`"},
     {"90", "0.6487156952301225`", "0.0017867155866368202`", 
      "3.702892261729714`"},
     {"100", "0.6487180630050418`", "0.0017875668315566334`", 
      "3.7034028594712334`"},
     {"180", "0.6487196116761167`", "0.0017881237310401546`", 
      "3.703735714314126`"},
     {"200", "0.6487196124487999`", "0.0017881240089505264`", 
      "3.7037358799268105`"},
     {"300", "0.648719612591365`", "0.0017881240602269644`", 
      "3.7037359104825627`"},
     {"400", "0.6487196125913774`", "0.0017881240602316724`", 
      "3.7037359104853653`"},
     {"500", "0.6487196125913783`", "0.001788124060231669`", 
      "3.7037359104853658`"},
     {"600", "0.6487196125913783`", "0.001788124060231669`", 
      "3.7037359104853658`"},
     {"700", "0.6487196125913783`", "0.001788124060231669`", 
      "3.7037359104853658`"},
     {"800", "0.6487196125913783`", "0.001788124060231669`", 
      "3.7037359104853658`"},
     {"900", "0.6487196125913783`", "0.001788124060231669`", 
      "3.7037359104853658`"},
     {"1000", "0.6487196125913783`", "0.001788124060231669`", 
      "3.7037359104853658`"},
     {"2000", "0.6487196125913783`", "0.001788124060231669`", 
      "3.7037359104853658`"},
     {"3000", "0.6487196125913783`", "0.001788124060231669`", 
      "3.7037359104853658`"},
     {"4000", "0.6487196125913783`", "0.001788124060231669`", 
      "3.7037359104853658`"},
     {"5000", "0.6487196125913783`", "0.001788124060231669`", 
      "3.7037359104853658`"},
     {"6000", "0.6487196125913783`", "0.001788124060231669`", 
      "3.7037359104853658`"},
     {"7000", "0.6487196125913783`", "0.001788124060231669`", 
      "3.7037359104853658`"},
     {"8000", "0.6487196125913783`", "0.001788124060231669`", 
      "3.7037359104853658`"},
     {"9000", "0.6487196125913783`", "0.001788124060231669`", 
      "3.7037359104853658`"},
     {"10000", "0.6487196125913783`", "0.001788124060231669`", 
      "3.7037359104853658`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\n start intake", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282211807091*^9, 3.41783566817258*^9, 
  3.479827569141221*^9, 3.479828239454194*^9, 3.4798292053727875`*^9, 
  3.4798294368058443`*^9, 3.518534988513751*^9, 3.5916734898146353`*^9, 
  3.6434437339444184`*^9},
 CellLabel->"Out[35]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Continuous\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "inputs1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[36]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\n start intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.392109695916234`", "8.570704829700959`*^-8", 
      "0.5988273846953035`"},
     {"2", "0.5481244115325348`", "2.782801885093701`*^-6", 
      "0.7351042469731954`"},
     {"3", "0.42239248478459324`", "0.000014549776496439615`", 
      "0.7955243796045471`"},
     {"4", "0.3139767035386638`", "0.000037579641297863595`", 
      "0.8183697759202095`"},
     {"5", "0.23282070558229773`", "0.00006888301797214422`", 
      "0.8160233436192356`"},
     {"6", "0.1726768688197503`", "0.00010407525111758671`", 
      "0.7966237299953114`"},
     {"7", "0.12813825695591807`", "0.00013941154104499102`", 
      "0.7660303247116194`"},
     {"8", "0.09515613548875596`", "0.000172285284637517`", 
      "0.72847111021519`"},
     {"9", "0.07072986942226761`", "0.0002011259180202098`", 
      "0.6869757496517702`"},
     {"10", "0.052637480938694914`", "0.00022515006945639726`", 
      "0.6436933493614728`"},
     {"20", "0.0033112607032419923`", "0.000246884292320682`", 
      "0.28615247973020486`"},
     {"30", "0.000528186345891752`", "0.00014004119541110078`", 
      "0.11656185370093164`"},
     {"40", "0.000190608674066905`", "0.00006539551473293457`", 
      "0.046651726490213756`"},
     {"50", "0.00007915926132487758`", "0.000028158399606862303`", 
      "0.01855229996171926`"},
     {"60", "0.00003254861268868826`", "0.000011655376757760994`", 
      "0.007353987531365358`"},
     {"70", "0.000013167184588725962`", "4.725035623204237`*^-6", 
      "0.002909776072533331`"},
     {"80", "5.271769922624502`*^-6", "1.8936604743647522`*^-6", 
      "0.0011501155325533167`"},
     {"90", "2.097985687469108`*^-6", "7.540241210307266`*^-7", 
      "0.00045431710836222906`"},
     {"100", "8.320293304483835`*^-7", "2.991276810077103`*^-7", 
      "0.00017940013445755842`"},
     {"180", "4.931699276573997`*^-10", "1.7737771926667276`*^-10", 
      "1.0570748578917719`*^-7"},
     {"200", "0", "0", "1.646662720787355`*^-8"},
     {"300", "0", "0", "0"},
     {"400", "0", "0", "0"},
     {"500", "0", "0", "0"},
     {"600", "0", "0", "0"},
     {"700", "0", "0", "0"},
     {"800", "0", "0", "0"},
     {"900", "0", "0", "0"},
     {"1000", "0", "0", "0"},
     {"2000", "0", "0", "0"},
     {"3000", "0", "0", "0"},
     {"4000", "0", "0", "0"},
     {"5000", "0", "0", "0"},
     {"6000", "0", "0", "0"},
     {"7000", "0", "0", "0"},
     {"8000", "0", "0", "0"},
     {"9000", "0", "0", "0"},
     {"10000", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\n start intake", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992822124170475`*^9, 3.417835668719455*^9, 
  3.4798275697506275`*^9, 3.4798282399854136`*^9, 3.4798292059665265`*^9, 
  3.479829437337084*^9, 3.5185349889356346`*^9, 3.5916734904546995`*^9, 
  3.643443734085045*^9},
 CellLabel->"Out[36]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<MultiInputs\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "inputs2", ",", "fn1", ",", "180", ",", 
   "lambda"}], "]"}]], "Input",
 CellLabel->"In[37]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nlast intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "4.0897012077040795`", "0.0001213244703621092`", 
      "3.195229967753514`"},
     {"2", "0.35646327869251243`", "0.00020828654357061866`", 
      "2.5733672341626197`"},
     {"3", "0.02184061057778577`", "0.00033706729053254553`", 
      "2.3376104805092255`"},
     {"4", "0.003005162487135964`", "0.00047018317334977664`", 
      "2.140122916404088`"},
     {"5", "0.0021753489845081305`", "0.000584064214745683`", 
      "1.9597419540982675`"},
     {"6", "0.0023000144058338977`", "0.0006720406690736209`", 
      "1.7941192404710269`"},
     {"7", "0.002416304977105299`", "0.0007350251393816803`", 
      "1.6420632673867381`"},
     {"8", "0.002481159306973162`", "0.0007763281210175849`", 
      "1.5025211679635213`"},
     {"9", "0.0025022669831369464`", "0.0007996391209526472`", 
      "1.3745160799190639`"},
     {"10", "0.002488555462729671`", "0.0008083640696555508`", 
      "1.257139883203231`"},
     {"20", "0.0016013839867924412`", "0.0005559887636187686`", 
      "0.5099818203277501`"},
     {"30", "0.000774705715287053`", "0.00027403488270739946`", 
      "0.204463043793704`"},
     {"40", "0.0003386345691971046`", "0.00012073611052987588`", 
      "0.08143119498340336`"},
     {"50", "0.00014122708622970592`", "0.000050550819417011324`", 
      "0.03230841234096076`"},
     {"60", "0.00005748496955230251`", "0.00002061934014459127`", 
      "0.012790494101076237`"},
     {"70", "0.00002309040384538043`", "8.29196474508639`*^-6", 
      "0.005057154938922542`"},
     {"80", "9.206025667341704`*^-6", "3.3081474594361475`*^-6", 
      "0.001998037947982063`"},
     {"90", "3.6548047456549003`*^-6", "1.3138371119176531`*^-6", 
      "0.0007890671388200973`"},
     {"100", "1.4474064446923967`*^-6", "5.204308844845922`*^-7", 
      "0.00031154085857232843`"},
     {"180", "8.562734282700699`*^-10", "3.079751492788652`*^-10", 
      "1.8353184924018997`*^-7"},
     {"200", "1.3339114786559952`*^-10", "4.7976812281039544`*^-11", 
      "2.8589698203249264`*^-8"},
     {"300", "1.2235382679506585`*^-14", "4.40070786165505`*^-15", 
      "2.622356140851696`*^-12"},
     {"400", "1.1222735338249865`*^-18", "4.036488374841912`*^-19", 
      "2.4053196431466454`*^-16"},
     {"500", "1.0293897564284062`*^-22", "3.7024127005530317`*^-23", 
      "2.2062459159448496`*^-20"},
     {"600", "9.441934058126379`*^-27", "3.395986443066288`*^-27", 
      "2.0236483143771702`*^-24"},
     {"700", "8.660482407275136`*^-31", "3.1149212295385774`*^-31", 
      "1.8561632094973884`*^-28"},
     {"800", "7.943706772882415`*^-35", "2.857118080092094`*^-35", 
      "1.7025398315576317`*^-32"},
     {"900", "7.286254313087146`*^-39", "2.6206517346836274`*^-39", 
      "1.561630929440318`*^-36"},
     {"1000", "6.68321520829942`*^-43", "2.4037562753741964`*^-43", 
      "1.4323842030488675`*^-40"},
     {"2000", "0", "0", "0"},
     {"3000", "0", "0", "0"},
     {"4000", "0", "0", "0"},
     {"5000", "0", "0", "0"},
     {"6000", "0", "0", "0"},
     {"7000", "0", "0", "0"},
     {"8000", "0", "0", "0"},
     {"9000", "0", "0", "0"},
     {"10000", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nlast intake", "Urine\n24 hours", "Faecal\n24 hours", 
       "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282213245962*^9, 3.417835669250705*^9, 
  3.4798275702662787`*^9, 3.4798282405791297`*^9, 3.4798292064821415`*^9, 
  3.479829438837055*^9, 3.518534989326267*^9, 3.591673490969751*^9, 
  3.643443734194433*^9},
 CellLabel->"Out[37]//TableForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IntakeWay\[Rule] \"Ingestion\",ShowReport\[Rule] \"GraphicReport\"", \
"SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[38]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV13c41V8YAPA7rKzCJSHda2XLukZyTpI0RBJFpSRJacgK2WVLSkWSWSiU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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV13k4Fe0bB/BzZo5jl+WICsmg7FuWUHMnJGRLFKGQUFSWeKtXlopsRatI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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -26.57721553363505}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-26.57721553363505, 1.830414156645809}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Acute intake in t = 0\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282217953572*^9, 3.417835672375705*^9, 
  3.4798275714069624`*^9, 3.479828241625944*^9, 3.479829207653994*^9, 
  3.47982943988391*^9, 3.518534990701293*^9, 3.591673493185972*^9, 
  3.6434437343350472`*^9},
 CellLabel->"Out[38]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[39]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwd13c0198fB3AjI/MzKJUKqZBNlHBvskdJomQ0KBGKKJIoGSVSGSn5kmQ0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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwd1nk0Vl0XAHBTkuHxPPfeyjVnKESEkOLZvEKUoqKUoZCSoYhKCMkUotGU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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -18.0074393684101}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-18.0074393684101, 1.1649439204596566`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992822206749144`*^9, 3.41783568192258*^9, 
  3.479827572735155*^9, 3.479828242844624*^9, 3.4798292088727207`*^9, 
  3.4798294409932637`*^9, 3.5185349920606947`*^9, 3.5916734970373573`*^9, 
  3.6434437345069237`*^9},
 CellLabel->"Out[39]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Continuous\>\"", ",", 
    "\"\<GraphicReport\>\"", ",", "inputs1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[40]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVlXk8lN37x20pa8XQWJoUyhpikO26iRRZkuzyVJSvKCUpD0IklUQrWSJp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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV1ndcze0bB/DTOed7TlvjICTf09DS0Dj1UJ0rkmiqnJKWpCWhSZGG0Y6U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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -24.641899270955676`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-24.641899270955676`, 1.6280374613602548`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Continuous intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992822240374928`*^9, 3.41783570901633*^9, 
  3.4798275741883545`*^9, 3.479828244157048*^9, 3.479829210169571*^9, 
  3.4798294422119904`*^9, 3.5185349936701*^9, 3.5916734995546093`*^9, 
  3.6434437347256756`*^9},
 CellLabel->"Out[40]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<MultiInputs\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "inputs2", ",", "fn1", ",", "180", ",", 
   "lambda"}], "]"}]], "Input",
 CellLabel->"In[41]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV13c81V0YAPB7r5mVcbk/JZvsvZrnVGjKqAiJhKSsFCnJyk5CZZctWVGK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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV13k4VN8bAPCZO2PIvkyo7rUvRVlikOS+SishSYUoJBGpKClrigilJIUs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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -24.23221477491804}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-24.23221477491804, 3.7423595603425754`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"MultiInputs\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992822273687916`*^9, 3.417835719563205*^9, 
  3.479827575719683*^9, 3.479828245469473*^9, 3.4798292115132947`*^9, 
  3.479829443430717*^9, 3.5185349952326307`*^9, 3.591673502121866*^9, 
  3.643443734913187*^9},
 CellLabel->"Out[41]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IntakeWay\[Rule] \"Ingestion\",ShowReport\[Rule] \
\"CompartmentContent\"", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<CompartmentContent\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
   "lambda"}], "]"}]], "Input",
 CellLabel->"In[42]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qST", "[", "180", "]"}], "\[Rule]", 
    "1.1875810950807211535187737301814128164831454`15.954589770191005*^-1883"}\
], ",", 
   RowBox[{
    RowBox[{"qSI", "[", "180", "]"}], "\[Rule]", "0.`"}], ",", 
   RowBox[{
    RowBox[{"qB", "[", "180", "]"}], "\[Rule]", "4.3679633300836606`*^-11"}], 
   ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "2"], "[", "180", "]"}], "\[Rule]", 
    "1.5524566462309165`*^-8"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "3"], "[", "180", "]"}], "\[Rule]", 
    "2.6148036370905764`*^-9"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "4"], "[", "180", "]"}], "\[Rule]", 
    "7.0682195965469104`*^-12"}], ",", 
   RowBox[{
    RowBox[{"qURI", "[", "180", "]"}], "\[Rule]", "1.4186471182188882`*^-7"}],
    ",", 
   RowBox[{
    RowBox[{"qULI", "[", "180", "]"}], "\[Rule]", 
    "1.6841021120160917`*^-11"}], ",", 
   RowBox[{
    RowBox[{"qLLI", "[", "180", "]"}], "\[Rule]", 
    "3.0506645858470834`*^-11"}], ",", 
   RowBox[{
    RowBox[{"qFEC", "[", "180", "]"}], "\[Rule]", 
    "8.485216602411606`*^-9"}]}], "}"}]], "Output",
 CellChangeTimes->{3.399282227744149*^9, 3.417835719969455*^9, 
  3.4798275760790763`*^9, 3.479828245844451*^9, 3.4798292118414135`*^9, 
  3.479829443743211*^9, 3.518534995388883*^9, 3.591673502680922*^9, 
  3.643443734975678*^9},
 CellLabel->"Out[42]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<CompartmentContent\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
   "lambda"}], "]"}]], "Input",
 CellLabel->"In[43]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qST", "[", "180", "]"}], "\[Rule]", "0.04151678519477255`"}], 
   ",", 
   RowBox[{
    RowBox[{"qSI", "[", "180", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"qB", "[", "180", "]"}], "\[Rule]", "0.3514605109687884`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "2"], "[", "180", "]"}], "\[Rule]", 
    "3.0672915692023626`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "3"], "[", "180", "]"}], "\[Rule]", 
    "0.1840374760447918`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "4"], "[", "180", "]"}], "\[Rule]", 
    "0.05643575241471559`"}], ",", 
   RowBox[{
    RowBox[{"qURI", "[", "180", "]"}], "\[Rule]", "7.816278055864478`"}], ",", 
   RowBox[{
    RowBox[{"qULI", "[", "180", "]"}], "\[Rule]", "0.0011269136922541826`"}], 
   ",", 
   RowBox[{
    RowBox[{"qLLI", "[", "180", "]"}], "\[Rule]", "0.0018667067964402962`"}], 
   ",", 
   RowBox[{
    RowBox[{"qFEC", "[", "180", "]"}], "\[Rule]", "0.02154461117052108`"}], 
   ",", 
   RowBox[{
    RowBox[{"qWB", "[", "180", "]"}], "\[Rule]", "3.703735714314126`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.3992822281038666`*^9, 3.41783572036008*^9, 
  3.479827576469722*^9, 3.4798282462194295`*^9, 3.479829212232031*^9, 
  3.479829444102579*^9, 3.5185349956857643`*^9, 3.5916735031989737`*^9, 
  3.6434437350694284`*^9},
 CellLabel->"Out[43]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Continuous\>\"", ",", 
    "\"\<CompartmentContent\>\"", ",", "inputs1", ",", "fn1", ",", "180", ",",
     "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[44]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qST", "[", "180", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"qSI", "[", "180", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"qB", "[", "180", "]"}], "\[Rule]", "2.5316953089900604`*^-10"}], 
   ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "2"], "[", "180", "]"}], "\[Rule]", 
    "8.998336829340418`*^-8"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "3"], "[", "180", "]"}], "\[Rule]", 
    "1.5155550830398463`*^-8"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "4"], "[", "180", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"qURI", "[", "180", "]"}], "\[Rule]", "7.955977873642331`*^-7"}], 
   ",", 
   RowBox[{
    RowBox[{"qULI", "[", "180", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"qLLI", "[", "180", "]"}], "\[Rule]", 
    "1.7681790286403803`*^-10"}], ",", 
   RowBox[{
    RowBox[{"qFEC", "[", "180", "]"}], "\[Rule]", "4.689539440576801`*^-8"}], 
   ",", 
   RowBox[{
    RowBox[{"qWB", "[", "180", "]"}], "\[Rule]", 
    "1.0570748578917719`*^-7"}]}], "}"}]], "Output",
 CellChangeTimes->{3.3992822286199837`*^9, 3.41783572089133*^9, 
  3.4798275770009985`*^9, 3.479828246719401*^9, 3.479829212763271*^9, 
  3.4798294446025696`*^9, 3.518534996092022*^9, 3.591673503804034*^9, 
  3.6434437352100587`*^9},
 CellLabel->"Out[44]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<MultiInputs\>\"", ",", 
   "\"\<CompartmentContent\>\"", ",", "inputs2", ",", "fn1", ",", "180", ",", 
   "lambda"}], "]"}]], "Input",
 CellLabel->"In[45]:="],

Cell[BoxData["\<\"Option not available for MultiInputs intake\"\>"], "Output",
 CellChangeTimes->{3.3992822286669035`*^9, 3.417835720969455*^9, 
  3.479827577110379*^9, 3.4798282468287697`*^9, 3.4798294446650686`*^9, 
  3.518534996138898*^9, 3.591673503942048*^9, 3.6434437352256804`*^9},
 CellLabel->"Out[45]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IntakeWay\[Rule] \"Ingestion\",ShowReport\[Rule] \"Disintegrations\"", \
"SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<Disintegrations\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
   "lambda"}], "]"}]], "Input",
 CellLabel->"In[46]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qST", "[", "180", "]"}], "\[Rule]", "3587.0502408283487`"}], ",", 
   RowBox[{
    RowBox[{"qSI", "[", "180", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"qB", "[", "180", "]"}], "\[Rule]", "30366.188147703317`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "2"], "[", "180", "]"}], "\[Rule]", 
    "265013.9915790841`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "3"], "[", "180", "]"}], "\[Rule]", 
    "15900.837930270014`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "4"], "[", "180", "]"}], "\[Rule]", 
    "4876.049008631426`"}], ",", 
   RowBox[{
    RowBox[{"qURI", "[", "180", "]"}], "\[Rule]", "675326.4240266909`"}], ",", 
   RowBox[{
    RowBox[{"qULI", "[", "180", "]"}], "\[Rule]", "97.36534301076135`"}], ",", 
   RowBox[{
    RowBox[{"qLLI", "[", "180", "]"}], "\[Rule]", "161.28346721244165`"}], 
   ",", 
   RowBox[{
    RowBox[{"qFEC", "[", "180", "]"}], "\[Rule]", "1861.4544052193849`"}], 
   ",", 
   RowBox[{
    RowBox[{"qWB", "[", "180", "]"}], "\[Rule]", "320002.7657167404`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399282229042261*^9, 3.41783572261008*^9, 
  3.479827577532276*^9, 3.479828247219372*^9, 3.479829445055686*^9, 
  3.5185349964357786`*^9, 3.5916735043720913`*^9, 3.6434437353194437`*^9},
 CellLabel->"Out[46]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<Disintegrations\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
   "lambda"}], "]"}]], "Input",
 CellLabel->"In[47]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qST", "[", "180", "]"}], "\[Rule]", "645520.1205547714`"}], ",", 
   RowBox[{
    RowBox[{"qSI", "[", "180", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"qB", "[", "180", "]"}], "\[Rule]", "5.449427974571444`*^6"}], 
   ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "2"], "[", "180", "]"}], "\[Rule]", 
    "4.477803053140587`*^7"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "3"], "[", "180", "]"}], "\[Rule]", 
    "2.576569543750029`*^6"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "4"], "[", "180", "]"}], "\[Rule]", 
    "874638.1757721974`"}], ",", 
   RowBox[{
    RowBox[{"qURI", "[", "180", "]"}], "\[Rule]", "1.13341950577441`*^8"}], 
   ",", 
   RowBox[{
    RowBox[{"qULI", "[", "180", "]"}], "\[Rule]", "15725.45891536868`"}], ",", 
   RowBox[{
    RowBox[{"qLLI", "[", "180", "]"}], "\[Rule]", "25900.440423591976`"}], 
   ",", 
   RowBox[{
    RowBox[{"qFEC", "[", "180", "]"}], "\[Rule]", "277447.4073338589`"}], ",", 
   RowBox[{
    RowBox[{"qWB", "[", "180", "]"}], "\[Rule]", "5.436581224539328`*^7"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399282229495818*^9, 3.417835724031955*^9, 
  3.4798275842201185`*^9, 3.479828247672471*^9, 3.479829445508802*^9, 
  3.5185349968107853`*^9, 3.591673504894143*^9, 3.643443735491308*^9},
 CellLabel->"Out[47]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Continuous\>\"", ",", 
    "\"\<Disintegrations\>\"", ",", "inputs1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[48]:="],

Cell[BoxData["\<\"Option not available for continuous intake\"\>"], "Output",
 CellChangeTimes->{3.3992822295270977`*^9, 3.41783572420383*^9, 
  3.479827584376376*^9, 3.479828247719343*^9, 3.4798294455556765`*^9, 
  3.5185349968576612`*^9, 3.5916735050181556`*^9, 3.6434437355225587`*^9},
 CellLabel->"Out[48]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<MultiInputs\>\"", ",", 
   "\"\<Disintegrations\>\"", ",", "inputs2", ",", "fn1", ",", "180", ",", 
   "lambda"}], "]"}]], "Input",
 CellLabel->"In[49]:="],

Cell[BoxData["\<\"Option not available for MultiInputs intake\"\>"], "Output",
 CellChangeTimes->{3.3992822295583773`*^9, 3.41783572423508*^9, 
  3.4798275844232535`*^9, 3.4798282477662153`*^9, 3.4798294456025505`*^9, 
  3.518534996904537*^9, 3.5916735051481686`*^9, 3.643443735538184*^9},
 CellLabel->"Out[49]="]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["IntakeWay\[Rule] \"Inhalation\",ShowReport\[Rule] \"Automatic\"", \
"SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<Automatic\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", " ", 
   "fn1", ",", "t1", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[50]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qLungs", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"0.01006337724365423`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110.08664339756999`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00798948637352798`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "102.08664339756999`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.010318191574724172`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.11664339756999`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.01615017914617113`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.10664339756998`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.03193255793813499`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08764339756999`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00443273582045417`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08676339757`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.0010879819033333335`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08664339756999`"}], " ", "t1"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qDailyUrine", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"7.788945328648337`*^82", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "200.08664339757`"}], " ", "t1"}]]}], "+", 
     RowBox[{"1.2967081356793035`*^43", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110.08664339756999`"}], " ", "t1"}]]}], "+", 
     RowBox[{"4.114712500478884`*^39", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "102.08664339756999`"}], " ", "t1"}]]}], "+", 
     RowBox[{"7.774113058301263`*^38", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.11664339756999`"}], " ", "t1"}]]}], "+", 
     RowBox[{"1.205006372122147`*^39", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.10664339756998`"}], " ", "t1"}]]}], "+", 
     RowBox[{"2.3388305815119494`*^39", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08764339756999`"}], " ", "t1"}]]}], "+", 
     RowBox[{"3.2438757090176548`*^38", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08676339756998`"}], " ", "t1"}]]}], "+", 
     RowBox[{"9.420323149399797`*^37", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08664339756999`"}], " ", "t1"}]]}], "+", 
     RowBox[{"5.505450609535848`*^8", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "24.086643397569993`"}], " ", "t1"}]]}], "-", 
     RowBox[{"24994.990609571523`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t1"}]]}], "+", 
     RowBox[{"2.3762620263035332`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240251`"}], " ", "t1"}]]}], "+", 
     RowBox[{"3.509467319332492`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240244`"}], " ", "t1"}]]}], "+", 
     RowBox[{"1.1504202247807256`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.8591877362402367`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.00013863078773737646`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567383186`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.0003853133404994862`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.1467904756738283`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.00029024096560830576`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567381764`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.0002703145046395253`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.092967307839366`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.0003581510811113339`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935535`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00012907924735945653`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0929673078393518`"}], " ", "t1"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qDailyFaecal", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "5.891481176209353`*^70"}], " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "200.08664339757`"}], " ", "t1"}]]}], "-", 
     RowBox[{"5.745480008379844`*^31", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110.08664339756999`"}], " ", "t1"}]]}], "-", 
     RowBox[{"2.263341795646082`*^28", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "102.08664339756999`"}], " ", "t1"}]]}], "-", 
     RowBox[{"4.528857329136862`*^27", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.11664339756999`"}], " ", "t1"}]]}], "-", 
     RowBox[{"7.023025517868472`*^27", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.10664339756998`"}], " ", "t1"}]]}], "-", 
     RowBox[{"1.3618322208822374`*^28", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08764339756999`"}], " ", "t1"}]]}], "-", 
     RowBox[{"1.8931705248943463`*^27", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08676339756998`"}], " ", "t1"}]]}], "-", 
     RowBox[{"5.490118630867796`*^26", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08664339756999`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.14494345672483466`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "24.086643397569993`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.000010907865643609925`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240251`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.000016109670388272612`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240244`"}], " ", "t1"}]]}], "+", 
     RowBox[{"5.280827243248124`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.8591877362402367`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.00002998406453637038`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975700045`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.00004255186746821415`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699939`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.000014445196762325877`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699903`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00009575079478537691`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.000053051102545999176`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567383186`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.0001474513553071915`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.1467904756738283`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.00011106914618926804`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567381764`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00009722419024187773`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.092967307839366`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00012881642770793192`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935535`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00004642601520140309`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0929673078393518`"}], " ", "t1"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qWholebody", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{
     RowBox[{"0.00010779094387247667`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "200.08664339757`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.000021900257755225194`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110.08664339756999`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00002071583016319961`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "102.08664339756999`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00002806556744617758`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.11664339756999`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00004393951546603769`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.10664339756998`"}], " ", "t1"}]]}], "+", 
     RowBox[{"2.710505431213761`*^-20", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.09664339756999`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00008691931179621165`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08764339756999`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.000012066016085432278`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08676339757`"}], " ", "t1"}]]}], "+", 
     RowBox[{"3.504431783422912`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08664339756999`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.020783816773193915`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "24.086643397569993`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.15357547367497448`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.15842569570924184`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240251`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.23397663872068403`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240244`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.07669866473117262`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.8591877362402367`"}], " ", "t1"}]]}], "-", 
     RowBox[{"5.937853037797325`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975700045`"}], " ", "t1"}]]}], "-", 
     RowBox[{"8.426700629716345`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699939`"}], " ", "t1"}]]}], "-", 
     RowBox[{"2.8606347005662244`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699903`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.3387553247322293`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.0030920059075871865`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567383186`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.008593986549031386`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.1467904756738283`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.00647350271128088`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567381764`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.057935322180423354`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.092967307839366`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.07676095036467757`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935535`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.027664988945251053`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0929673078393518`"}], " ", "t1"}]]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399282231575925*^9, 3.41783572629758*^9, 
  3.4798275864546075`*^9, 3.4798282496879797`*^9, 3.4798294474775143`*^9, 
  3.5185349983576903`*^9, 3.5916735083394876`*^9, 3.6434437360069504`*^9},
 CellLabel->"Out[50]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<Automatic\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", " ", 
   "fn1", ",", "t1", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[51]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qLungs", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{"0.0008082717969697772`", "\[VeryThinSpace]", "-", 
     RowBox[{"0.00009141324445065574`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110.08664339756999`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.00007826181866332336`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "102.08664339756999`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.00010306170107751148`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.11664339756999`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.00016132974394148116`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.10664339756998`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.0003190459566651189`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08764339756999`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.000044288931622718376`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08676339757`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.000010870400548968243`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08664339756999`"}], " ", "t1"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qDailyUrine", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{"0.31245257219193556`", "\[VeryThinSpace]", "-", 
     RowBox[{"3.892786243193521`*^80", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "200.08664339757`"}], " ", "t1"}]]}], "-", 
     RowBox[{"1.1778977863793403`*^41", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110.08664339756999`"}], " ", "t1"}]]}], "-", 
     RowBox[{"4.0306080830323397`*^37", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "102.08664339756999`"}], " ", "t1"}]]}], "-", 
     RowBox[{"7.765055633586994`*^36", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.11664339756999`"}], " ", "t1"}]]}], "-", 
     RowBox[{"1.2037226813574185`*^37", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.10664339756998`"}], " ", "t1"}]]}], "-", 
     RowBox[{"2.3367825458948886`*^37", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08764339756999`"}], " ", "t1"}]]}], "-", 
     RowBox[{"3.2410636520756865`*^36", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08676339756998`"}], " ", "t1"}]]}], "-", 
     RowBox[{"9.41216812714937`*^35", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08664339756999`"}], " ", "t1"}]]}], "-", 
     RowBox[{"2.2856861035652947`*^7", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "24.086643397569993`"}], " ", "t1"}]]}], "+", 
     RowBox[{"2067.9844508854085`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "12.086643397569993`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.8310968867781479`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240251`"}], " ", "t1"}]]}], "-", 
     RowBox[{"1.227435077050011`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240244`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.4023591071684926`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.8591877362402367`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.0009444126882279073`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567383186`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.002624920579695246`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.1467904756738283`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.001977246577313699`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567381764`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.0029076296917900923`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.092967307839366`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.0038524411369446065`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935535`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.0013884369716557488`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0929673078393518`"}], " ", "t1"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qDailyFaecal", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{"0.0008612410526644045`", "\[VeryThinSpace]", "-", 
     RowBox[{"3.8150225343206914`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240251`"}], " ", "t1"}]]}], "-", 
     RowBox[{"5.63435208681204`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240244`"}], " ", "t1"}]]}], "-", 
     RowBox[{"1.8469676462002047`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.8591877362402367`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.000015892809724927265`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975700045`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.000022554271529543514`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699939`"}], " ", "t1"}]]}], "+", 
     RowBox[{"7.656559146753112`*^-6", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699903`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.00008811611518507329`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.00036140698027219923`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567383186`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.0010045021969601886`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.1467904756738283`"}], " ", "t1"}]]}], "+", 
     RowBox[{"0.0007566509044910665`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567381764`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.0010457890252116298`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.092967307839366`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.0013856099601219085`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935535`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.0004993800108918783`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.0929673078393518`"}], " ", "t1"}]]}]}]}], ",", 
   RowBox[{
    RowBox[{"qWholebody", "[", "t1", "]"}], "\[Rule]", 
    RowBox[{"5.861735589759597`", "\[VeryThinSpace]", "+", 
     RowBox[{"9.054606023295442`*^-15", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "200.08664339757`"}], " ", "t1"}]]}], "-", 
     RowBox[{"5.4870906985291824`*^-11", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "110.08664339756999`"}], " ", "t1"}]]}], "-", 
     RowBox[{"5.543536464559188`*^-11", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "102.08664339756999`"}], " ", "t1"}]]}], "-", 
     RowBox[{"7.638071822431165`*^-11", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.11664339756999`"}], " ", "t1"}]]}], "+", 
     RowBox[{"1.3814605926212864`*^-14", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.10664339756998`"}], " ", "t1"}]]}], "-", 
     RowBox[{"4.235164736271502`*^-22", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.09664339756999`"}], " ", "t1"}]]}], "+", 
     RowBox[{"2.7337019366940885`*^-14", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08764339756999`"}], " ", "t1"}]]}], "-", 
     RowBox[{"4.9629336264808786`*^-11", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08676339757`"}], " ", "t1"}]]}], "-", 
     RowBox[{"9.539815760471033`*^-12", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "100.08664339756999`"}], " ", "t1"}]]}], "+", 
     RowBox[{"6.444107400471744`*^-11", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "24.086643397569993`"}], " ", "t1"}]]}], "-", 
     RowBox[{"3.469446951953614`*^-17", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240251`"}], " ", "t1"}]]}], "-", 
     RowBox[{"5.551115123125783`*^-17", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.859187736240244`"}], " ", "t1"}]]}], "-", 
     RowBox[{"1.734723475976807`*^-17", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "2.8591877362402367`"}], " ", "t1"}]]}], "-", 
     RowBox[{"8.470329472543003`*^-22", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.8866433975699903`"}], " ", "t1"}]]}], "-", 
     RowBox[{"0.31169342284452944`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "1.0866433975699932`"}], " ", "t1"}]]}], "+", 
     RowBox[{"1.0408340855860843`*^-16", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567383186`"}], " ", "t1"}]]}], "+", 
     RowBox[{"2.914335439641036`*^-16", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.1467904756738283`"}], " ", "t1"}]]}], "+", 
     RowBox[{"2.0816681711721685`*^-16", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.14679047567381764`"}], " ", "t1"}]]}], "-", 
     RowBox[{"5.551115123125783`*^-17", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.092967307839366`"}], " ", "t1"}]]}], "-", 
     RowBox[{"1.1102230246251565`*^-16", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.09296730783935535`"}], " ", "t1"}]]}], "-", 
     RowBox[{"5.550042166935279`", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "0.08664339756999316`"}], " ", "t1"}]]}]}]}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399282233734231*^9, 3.41783572842258*^9, 
  3.479827588860981*^9, 3.4798282517972336`*^9, 3.479829449555599*^9, 
  3.518535000107724*^9, 3.591673510273681*^9, 3.6434437365538173`*^9},
 CellLabel->"Out[51]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Continuous\>\"", ",", 
   "\"\<Automatic\>\"", ",", "inputs1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "t", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[52]:="],

Cell[BoxData["\<\"Option not available for inhalation\"\>"], "Output",
 CellChangeTimes->{3.399282233781151*^9, 3.41783572851633*^9, 
  3.4798275889703617`*^9, 3.479828251906602*^9, 3.479829449633723*^9, 
  3.518535000138974*^9, 3.591673510521706*^9, 3.6434437365850687`*^9},
 CellLabel->"Out[52]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IntakeWay\[Rule] \"Inhalation\",ShowReport\[Rule] \"BioassayTable\"", \
"SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[53]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Lung\\nretention\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "2.195056816483926`*^-45", "0.28179457831587534`", 
      "2.1153390345835146`*^-7", "0.27342835202852583`"},
     {"2", "0", "0.02313522518640039`", "2.936634448198939`*^-6", 
      "0.16136554335725237`"},
     {"3", "0", "0.001373787913224686`", "8.942278232346583`*^-6", 
      "0.12424723346569638`"},
     {"4", "0", "0.00014560797340870685`", "0.000015841589217686902`", 
      "0.1062364597360031`"},
     {"5", "0", "0.00008945487056583767`", "0.000022028349801909603`", 
      "0.09476509276690527`"},
     {"6", "0", "0.00009645797858416203`", "0.000026979045660501398`", 
      "0.08591876848900713`"},
     {"7", "0", "0.00010379490673891614`", "0.000030669910698076284`", 
      "0.07836402796671726`"},
     {"8", "0", "0.00010848142455396198`", "0.00003324426461242744`", 
      "0.07162078829856978`"},
     {"9", "0", "0.00011086388245907218`", "0.00003488117279961775`", 
      "0.06549787676511112`"},
     {"10", "0", "0.00011139531017714382`", "0.000035751189782175296`", 
      "0.0599035622689094`"},
     {"20", "0", "0.00007478289335303084`", "0.000025902711568391602`", 
      "0.02432768987833538`"},
     {"30", "0", "0.000036616011891964074`", "0.00001294056398463771`", 
      "0.009760087442683845`"},
     {"40", "0", "0.000016087716428630095`", "5.733483513320481`*^-6", 
      "0.00388862722701757`"},
     {"50", "0", "6.726492871715882`*^-6", "2.4071574393371554`*^-6", 
      "0.0015431814031032936`"},
     {"60", "0", "2.7416825131268363`*^-6", "9.832998932992249`*^-7", 
      "0.0006110041707903937`"},
     {"70", "0", "1.1021060866187824`*^-6", "3.957494110836964`*^-7", 
      "0.00024159911934972574`"},
     {"80", "0", "4.3959300348321887`*^-7", "1.5795990134517623`*^-7", 
      "0.00009545783571737636`"},
     {"90", "0", "1.745621205919175`*^-7", "6.275058581066526`*^-8", 
      "0.00003769925293406007`"},
     {"100", "0", "6.914142810561606`*^-8", "2.4860242370419786`*^-8", 
      "0.000014884703123033058`"},
     {"180", "0", "4.091150079531435`*^-11", "1.4714602835195082`*^-11", 
      "8.76890615304822`*^-9"},
     {"200", "0", "6.373246517167455`*^-12", "2.2922663077208047`*^-12", 
      "1.3659777710571156`*^-9"},
     {"300", "0", "5.845903707118989`*^-16", "2.1025998997649955`*^-16", 
      "1.2529270186400378`*^-13"},
     {"400", "0", "5.3620742488557055`*^-20", "1.9285806639974537`*^-20", 
      "1.1492298562041742`*^-17"},
     {"500", "0", "4.918287867195641`*^-24", "1.768963733197176`*^-24", 
      "1.0541150669769834`*^-21"},
     {"600", "0", "4.511230992047507`*^-28", "1.6225573273649164`*^-28", 
      "9.66872352275081`*^-26"},
     {"700", "0", "4.137863747119173`*^-32", "1.4882680923148334`*^-32", 
      "8.868501882576241`*^-30"},
     {"800", "0", "3.795397845933157`*^-36", "1.3650931632718269`*^-36", 
      "8.134509737111787`*^-34"},
     {"900", "0", "3.481275771572288`*^-40", "1.2521126764956433`*^-40", 
      "7.461265672522465`*^-38"},
     {"1000", "0", "3.193151677293286`*^-44", "1.148482899792346`*^-44", 
      "6.843741938371358`*^-42"},
     {"2000", "0", "0", "0", "0"},
     {"3000", "0", "0", "0", "0"},
     {"4000", "0", "0", "0", "0"},
     {"5000", "0", "0", "0", "0"},
     {"6000", "0", "0", "0", "0"},
     {"7000", "0", "0", "0", "0"},
     {"8000", "0", "0", "0", "0"},
     {"9000", "0", "0", "0", "0"},
     {"10000", "0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Lung\nretention", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992822411944633`*^9, 3.41783573636008*^9, 
  3.4798275964707456`*^9, 3.47982825914056*^9, 3.4798294565398407`*^9, 
  3.5185350038890467`*^9, 3.5916735119658504`*^9, 3.6434437369913225`*^9},
 CellLabel->"Out[53]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[54]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Thoracic\\nLung\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.0008082717969697772`", "0.1796279477717695`", 
      "3.950454232314049`*^-8", "0.6671756618778408`"},
     {"2", "0.0008082717969697772`", "0.30173803925845455`", 
      "1.2850048288510357`*^-6", "1.1592533946491708`"},
     {"3", "0.0008082717969697772`", "0.30939482460935874`", 
      "7.046241892964128`*^-6", "1.5701017876228383`"},
     {"4", "0.0008082717969697772`", "0.30989143145071996`", 
      "0.000019451913107893307`", "1.9332263610760823`"},
     {"5", "0.0008082717969697772`", "0.3099942526055739`", 
      "0.000038479589611799606`", "2.261616689524453`"},
     {"6", "0.0008082717969697772`", "0.3100866683524419`", 
      "0.00006309150404567275`", "2.5612013759166112`"},
     {"7", "0.0008082717969697772`", "0.31018701031607643`", 
      "0.00009201613680290092`", "2.835398663725158`"},
     {"8", "0.0008082717969697772`", "0.31029336034557176`", 
      "0.00012405885939627097`", "3.0866622255445937`"},
     {"9", "0.0008082717969697772`", "0.3104032052556107`", 
      "0.00015819231468646583`", "3.3170123994916834`"},
     {"10", "0.0008082717969697772`", "0.3105144718988986`", 
      "0.00019356581777978804`", "3.528224358714665`"},
     {"20", "0.0008082717969697772`", "0.3114776981928009`", 
      "0.0005173824584067867`", "4.880617476618223`"},
     {"30", "0.0008082717969697772`", "0.31201943462988213`", 
      "0.000707015192453149`", "5.44922623766681`"},
     {"40", "0.0008082717969697772`", "0.31227047508054406`", 
      "0.0007961057356540516`", "5.68829677204287`"},
     {"50", "0.0008082717969697772`", "0.31237813366833533`", 
      "0.0008345505715133903`", "5.788813549717678`"},
     {"60", "0.0008082717969697772`", "0.3124226009196436`", 
      "0.0008504803599604146`", "5.831075648727478`"},
     {"70", "0.0008082717969697772`", "0.31244060672255713`", 
      "0.0008569418240486869`", "5.848844672506697`"},
     {"80", "0.0008082717969697772`", "0.31244781821734646`", 
      "0.000859532201245192`", "5.85631562670595`"},
     {"90", "0.0008082717969697772`", "0.312450688643072`", 
      "0.0008605638289970706`", "5.859456776008287`"},
     {"100", "0.0008082717969697772`", "0.3124518271202308`", 
      "0.0008609731260617367`", "5.860777466602343`"},
     {"180", "0.0008082717969697772`", "0.31245257175186136`", 
      "0.0008612408943831137`", "5.8617346540924515`"},
     {"200", "0.0008082717969697772`", "0.3124525721233815`", 
      "0.0008612410280074926`", "5.861735424355452`"},
     {"300", "0.0008082717969697772`", "0.31245257219192935`", 
      "0.0008612410526621424`", "5.861735589731043`"},
     {"400", "0.0008082717969697772`", "0.31245257219193556`", 
      "0.0008612410526644063`", "5.861735589759592`"},
     {"500", "0.0008082717969697772`", "0.31245257219193556`", 
      "0.0008612410526644045`", "5.861735589759597`"},
     {"600", "0.0008082717969697772`", "0.31245257219193556`", 
      "0.0008612410526644045`", "5.861735589759597`"},
     {"700", "0.0008082717969697772`", "0.31245257219193556`", 
      "0.0008612410526644045`", "5.861735589759597`"},
     {"800", "0.0008082717969697772`", "0.31245257219193556`", 
      "0.0008612410526644045`", "5.861735589759597`"},
     {"900", "0.0008082717969697772`", "0.31245257219193556`", 
      "0.0008612410526644045`", "5.861735589759597`"},
     {"1000", "0.0008082717969697772`", "0.31245257219193556`", 
      "0.0008612410526644045`", "5.861735589759597`"},
     {"2000", "0.0008082717969697772`", "0.31245257219193556`", 
      "0.0008612410526644045`", "5.861735589759597`"},
     {"3000", "0.0008082717969697772`", "0.31245257219193556`", 
      "0.0008612410526644045`", "5.861735589759597`"},
     {"4000", "0.0008082717969697772`", "0.31245257219193556`", 
      "0.0008612410526644045`", "5.861735589759597`"},
     {"5000", "0.0008082717969697772`", "0.31245257219193556`", 
      "0.0008612410526644045`", "5.861735589759597`"},
     {"6000", "0.0008082717969697772`", "0.31245257219193556`", 
      "0.0008612410526644045`", "5.861735589759597`"},
     {"7000", "0.0008082717969697772`", "0.31245257219193556`", 
      "0.0008612410526644045`", "5.861735589759597`"},
     {"8000", "0.0008082717969697772`", "0.31245257219193556`", 
      "0.0008612410526644045`", "5.861735589759597`"},
     {"9000", "0.0008082717969697772`", "0.31245257219193556`", 
      "0.0008612410526644045`", "5.861735589759597`"},
     {"10000", "0.0008082717969697772`", "0.31245257219193556`", 
      "0.0008612410526644045`", "5.861735589759597`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Thoracic\nLung", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992822433058496`*^9, 3.41783573848508*^9, 
  3.4798275987833643`*^9, 3.479828261281062*^9, 3.479829458571051*^9, 
  3.5185350054672017`*^9, 3.5916735139840517`*^9, 3.643443737522586*^9},
 CellLabel->"Out[54]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Continuous\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "inputs1", ",", " ", "amad", ",", "class", 
    ",", " ", "fn1", ",", "180", ",", "lambda"}], "]"}], "//", 
  "Chop"}]], "Input",
 CellLabel->"In[55]:="],

Cell[BoxData["\<\"Option not available for inhalation\"\>"], "Output",
 CellChangeTimes->{3.3992822433527694`*^9, 3.41783573851633*^9, 
  3.4798275989083705`*^9, 3.4798282613904305`*^9, 3.4798294586335497`*^9, 
  3.518535005498452*^9, 3.591673514295083*^9, 3.6434437375382023`*^9},
 CellLabel->"Out[55]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<MultiInputs\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "inputs2", ",", " ", "amad", ",", "class", 
   ",", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[56]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nlast intake\"\>",
       HoldForm], 
      TagBox["\<\"Lung\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "1.536539771538759`*^-44", "1.9767872068575412`", 
      "0.000058977482719323`", "2.365104192563488`"},
     {"2", "0", "0.16249188164958311`", "0.00010132547340295667`", 
      "1.5198889710073458`"},
     {"3", "0", "0.009995743886729412`", "0.00016356216983173`", 
      "1.2195237893257016`"},
     {"4", "0", "0.001420025059790586`", "0.00022757945128752476`", 
      "1.0613150858879525`"},
     {"5", "0", "0.0010480321546529436`", "0.0002822122363342399`", 
      "0.9532293270727009`"},
     {"6", "0", "0.0011090413317111267`", "0.00032435330193810347`", 
      "0.8663832646917169`"},
     {"7", "0", "0.0011646030819132305`", "0.00035448038913435474`", 
      "0.7908330976950738`"},
     {"8", "0", "0.0011954084562743805`", "0.0003741973982231219`", 
      "0.7229107557224442`"},
     {"9", "0", "0.0012052270287987825`", "0.0003852806760754373`", 
      "0.6610797724367415`"},
     {"10", "0", "0.0011983487621275695`", "0.00038936701876657976`", 
      "0.6045435360018709`"},
     {"20", "0", "0.0007703907230639068`", "0.00026748876894334457`", 
      "0.2452178419329703`"},
     {"30", "0", "0.0003725885089440167`", "0.0001317976576346051`", 
      "0.09831169884996692`"},
     {"40", "0", "0.0001628437665948503`", "0.000058060577193207336`", 
      "0.0391540964079281`"},
     {"50", "0", "0.00006790964842529026`", "0.000024307703628940912`", 
      "0.015534587426095843`"},
     {"60", "0", "0.000027640994480758945`", "9.914603567714446`*^-6", 
      "0.00614992899768888`"},
     {"70", "0", "0.00001110255749708705`", "3.987031280029867`*^-6", 
      "0.002431578355585837`"},
     {"80", "0", "4.426487299429463`*^-6", "1.5906414576447481`*^-6", 
      "0.000960694474986194`"},
     {"90", "0", "1.7573111236639147`*^-6", "6.317223349054562`*^-7", 
      "0.0003793981916146422`"},
     {"100", "0", "6.959427220066832`*^-7", "2.5023392584834557`*^-7", 
      "0.0001497946005299834`"},
     {"180", "0", "4.1171190764154496`*^-10", "1.4808007880048457`*^-10", 
      "8.824546103190745`*^-8"},
     {"200", "0", "6.413689813176447`*^-11", "2.3068126899492575`*^-11", 
      "1.3746448358248385`*^-8"},
     {"300", "0", "5.8829951469961214`*^-15", "2.1159406020856304`*^-15", 
      "1.2608766601778727`*^-12"},
     {"400", "0", "5.396095835641939`*^-19", "1.940817229811718`*^-19", 
      "1.1565215536641866`*^-16"},
     {"500", "0", "4.949493693379235`*^-23", "1.780187552598144`*^-23", 
      "1.0608032748341484`*^-20"},
     {"600", "0", "4.539854101147898`*^-27", "1.632852219265769`*^-27", 
      "9.730070177076678`*^-25"},
     {"700", "0", "4.164117894974986`*^-31", "1.4977109384142968`*^-31", 
      "8.924771246168978`*^-29"},
     {"800", "0", "3.8194790971071346`*^-35", "1.3737544822362628`*^-35", 
      "8.186122026549867`*^-33"},
     {"900", "0", "3.503363963552279`*^-39", "1.2600571505889685`*^-39", 
      "7.508606325605433`*^-37"},
     {"1000", "0", "3.2134117635079353`*^-43", "1.1557698579194337`*^-43", 
      "6.887164492548317`*^-41"},
     {"2000", "0", "0", "0", "0"},
     {"3000", "0", "0", "0", "0"},
     {"4000", "0", "0", "0", "0"},
     {"5000", "0", "0", "0", "0"},
     {"6000", "0", "0", "0", "0"},
     {"7000", "0", "0", "0", "0"},
     {"8000", "0", "0", "0", "0"},
     {"9000", "0", "0", "0", "0"},
     {"10000", "0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nlast intake", "Lung", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.591673517082362*^9, 3.6434437382100916`*^9},
 CellLabel->"Out[56]//TableForm="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IntakeWay\[Rule] \"Inhalation\",ShowReport\[Rule] \"GraphicReport\"", \
"SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[57]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwBkQNu/CFib1JlAgAAADgAAAACAAAA2C12NM1yfD5Zq2fhILVZwH1iX+iS
GFo/MSMvyle/WcCR+cQCWhhqP/ruQ92SyVnAG8X3jz0Yej+qniKJFd5ZwOAq
kVYvGIo/yRR3J00HWsDC3d05KBiaPxAd3f6GWlrAMzeEqyQYqj9xSrJAMQRb
wOxjV+QiGLo/Mjr5rcNkXMD6A0a8FDHLPy7Cu9nKoV/A4qK9VhEz1D/ep61J
iH9hwFIVovturNo/c7mujBtTY8BNhiT/ItngPybFtt+8hmXA470+KhEg5D+Y
sxQqj89nwOY3OgQ8rec/Uk39x72QasCumlo00inrPxrzr3eDlW3AZ7lBDmtq
7j+OpaQqKltwwEcNhUug+PA/LTZcr+U9csDTm8xkDJ7yPw9+5MkvM3TAwZ4m
KS479D9v1hZrTlN2wOZC8URu+/U/rhdTeS/jeMADRZ+1r533P0HDmHtpi3vA
V+i9fQ9j+T/mAlQFmL9+wA0A7/AkIPs/tI/R/AshgcC8dQO5O7/8P2x87Wlg
8oLAGIqBjUTG/D9UMGsNrfqCwHOe/2FNzfw/VnbQV/0Cg8Aqx/sKX9v8P5D2
v+eoE4PAmBj0XIL3/D9CI14hLDWDwHW75ADJL/0/00pIZ+R4g8AuAcZIVqD9
P36JJ8EnA4TAihVEHV+n/T9FFYVs7AuEwOUpwvFnrv0/9kub87QUhMCcUr6a
ebz9Pxr4vJtRJoTAC6S27JzY/T+F5Y2DuUmEwOhGp5DjEP4/JfSiMUWRhMCh
jIjYcIH+P0JAbjFYI4XAdC5asgGI/j8SRJWM/SuFwEjQK4ySjv4/JMG8dKY0
hcDuE88/tJv+P2QC4/ECRoXAPJsVp/e1/j89OIfI5miFwBA954CIvP4/Km+o
tKhxhcDj3rhaGcP+P/x1hTlueoXAiiJcDjvQ/j9DFlwTBIyFwNiponV+6v4/
Tpz9MFuvhcCsS3RPD/H+P8cReww6uIXAf+1FKaD3/j+VcJaMHMGFwCYx6dzB
BP8/dZSjgOzShcD60rq2Ugv/PyM4lffZ24XAzXSMkOMR/z/igiQZy+SFwHS4
L0QFH/8/mpMiYrj2hcBIWgEeliX/P6Aoloy0/4XAG/zS9yYs/z9JA7FntAiG
wO6dpNG3Mv8/Rxj39LcRhsDCP3arSDn/P0XxxnH0G4bAluFHhdk//z8AAAAA
AAAAAPFeoMbRQf8/AAAAAAAAAAApVMVt
        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV13c8lV0cAPA7rJCMS8p+kL0ykzqnslJGEqIoRVKklFJIKDOkJCNZISRR
KuGeIiqkIVmVNxIh4nKH9Z7+8vl+nuus5/zGo+B1wtGbQiKREJlE+ve3WyvY
oP1U6OZ7nm2Kw9sY9DAvz5FUSTcw/R/NEW1l0K+xmyhukn5g/Ydqn3tbGPRp
+fvWhqlBQHeDdkMZZNClXjGTN0meB4pxSVYdgEHPN8gbI+wjQPWFFTJrsZ9c
sVylkhoF7q5LmU3ZzKC3dY+t1/h8BYQ9Dwkxxh5Qv+asIxkP4MuWS8LYjFCj
8/ruV0FYaYqVLHb0r4l3UvYpoHihJMYLOykFDdyeugYMN1y7/Q07Y8P1abnU
62Cb1lD6dTxf4Q9vrnz9NNB6aNwqEq+vIsFEQunzTfDdL8O2DK//qYGAalHw
LbAlvU5+Fd7vy69fN6hKZoJR9Q2SFeZ4fVcqd5Q+ywIfi4pPxFoy6F90ovZr
ut8G18Nbd+RYM+g/uvecqFjIATb2RMOkDYM+B29ASftc8G7kRUuoLYN+IS1s
e49cHiiB990tHBh00m8fx8ypPFCb1nBg+24Gnf/6hsPSqQXAXdhgHdWNQU/+
Rfh/9SoEtnEJ0U/3M+g0M8HgHP27IFCXmlpykEGX/fktRv5zEbikbl1q7Meg
F2x4nfLf3WJw4NhNua4ABl016WFGfnAJcNTRXVsRxKDrG0eXKUmWgv7WN+Yr
wvF+E/wf/RwpBe/ESPSEKAZ984BzfdGzMiASVrzbMo5Bt45T61B1vw+M1kVv
9UrD5+V/JETCvhL893yIpF7JoE+t7l8MflIJhHd/1/B6gsd/6RD5Re4hGEvM
1+lowONLmCbcmnoInt5q4rN8x6A30gVvr02tBluqdn/InGTQefwuKVzgVINP
cEOGPwvPR5u72+f1CLh1Jj0/SZ6lv/P9XpGt/xisb9LYKUibpXeLVCHZzzWg
2bNyZ/jGWfr4IZchQrIWHOH/6chInaWHGpUs2cTVgm7tJs+iO7N0wRVsySBO
LRB+m28VXz5L16zItG3sfw6S6tjJP5tn6f6srzWH8urBuGtpWt/iLP2sZZW5
YxoCXHs4w3tOz9FZvSarr8s2AbH7Su+3RzDp0PygkopLE5B02eJqk8qkx96P
03ue3AT2H9TeE1DIpEtG9O4YJL0CwgfTjeXeMOkmyqER+oOvAG/JYtlaGose
coI++qm4BayxZbRoVrLoHKplHU2vFdiStT/mLLHp5B5+xoh3K3Cv80lbEOXQ
+So6NOozWwHDbifvSRUOfbXr3ixvrjZgXDW/4bYDh25Qfvx8zZc2cC5qU9di
AYfu73TdxDX8HVjFy7P4zG6eHugY2Nv+8z34vlW/YlX1Av1Hfr2ziH4nmG3j
j42pXKY7iufPB5T3ghjiGSNEhopsrygtEz0DYEvJF/o1WV40WL9ZXUR+CDzn
/flpbrsAGjY25TK7/wuU/04KSVAVRhWZbgYf1cbAKOue4Z0RUXTk2RahY35/
gIBrlqcKXRxZrby8I5c1BcxWZw6JKqxBn7LaDgvmTIO16y4lsGOk0YucdWra
GxnAaJLg5I3KIcc3aWo6WxkgKqJl/BNTDv2Y4VLX3c4ALCJteokij7i2D6qv
d8HPyUHh0iLyyHLmjqZREAPsKTuSS2jJo7dWa3Q3lzHAOC1QFB6WR51TAsZ2
UrNA8wc7rr9dHh2WumBsT8yCy4//VJh0yqNZi9/GDmqzoOTcYnNirzySyHpt
4mg8C/4zn7OS/iWPXC0umzrvngVZp093dS7Lo68ZS5s8EmZBPUvxe5KOAhre
+tc8YH4WTNwPfrE9RgH94VTbMMlzwGDsU6NQogJiVgU7RPDNgX2bG0PepCgg
PsUF91TxOfA2YrJGLlMBqVN5g2p05gCvh2iqbbkC8m+Uzls6NAd8Pcwi8t4p
oOAL34ti/OaA9r0wy9qPCihcP79c+OQcIN8K7W/pUkBJBSpPifA5YJng5fTi
mwKqjFrfYXlrDoDYVfmafxQQY5v1YlLbHKi/8/LQAD+BFub5qZKf5sC75baj
24QIxP2onS+vZw7kph8mZ4kQSEJpN616eA5YXfgwoSJJIBMuD40vJCZQUPlP
5pkSgWCdvN4BXibgrni68oUKgbafHjQaXckEr+L7H9arE8htyHfr/FomcHNZ
MEjTJVBoU9BeOUMmuKDTItWwkUDRoUaeJRuZQHsuKef4ZgJdNWAf1tvKBM/Z
rxSEtxAopzA8cJs9E4wYctyMLAmEouNijhxlgtUdFFGyA4GoFnceP7jNBJ5G
GWK3DxIohU43eFXIBLl0vovthwgkazpQ3VvGBMphB7WnvfH6dRSquGuZwPxE
RYOkH4EC1hRUuHcxQX/a+bivJwk0f71R6+RXJqA66zKqgggUKzRUfmWICdiJ
28+HnSFQAVW57OE0E5zM/Lpj+hyBuieKinlXsYDnAyUzj4sE8vZtWScjwQJz
7fM13yMINP3j1931MizQIcgwdYkk0Mpu1cL9GiwQan6qR/Uygba+LM2ttmKB
2vHerr3xBHpv1ir3xo4FHrfELSclEGj/k7Gcb3tYIESqX/15IoHOlWveXnGY
BZxOXuNlJxHo/s2KDM8IFvhW6bdT6DqBTEU6JM/EsIDrbb7FJezXCZPp8Uks
cPOXVvmvGwT6EaF783E2C/DJT0Xm3SRQ4LyDeGsBC1DVa0dOpRNo8czJGwOl
LGBp7fnG7BaBJI9VpQo8Y4EBt3XBtRkEuvvzo4gCYgHRFPeLAZkEWn9gJsWo
hQXSXyWGSWURyHaPQfLBzyygJirz4UA2gXo7nITO9rMAx1Dai43ta3PmauIg
C4g0Onom3CZQJKhJePKXBS5b24tl5xBoVW0XfzuLBXp5mVSpOwTKNmDG/Vhm
gZZfaZ3XsZ+omcSuFGIDLu93V4JyCWRe6MqrKM4GyUp2ub3YH2VDrphIs8EF
i6QVZnkEGherjT6kzgY5h1VN/mCfT+qlhuixgW6AmT7IJxDvivnIJBM2yC+K
HI3HvhElRSkEbKD6Rv7MB2xiaeOlZ5ZssHDx76RoAYEenNtH6rBlg/TkqCB7
bLOZ0ItDTmwwJLJmTQz2W//bS2x3NtjfVsR+hu0yUh+26hAbzCd/0hrBrimP
/0T1YwNjFCouUkgg2kkXNVYgHm/cqdQQO8hQ6eL4WTyf2AeKM/ZH9lTnQDgb
RJpKG57C1muoV/98mQ389Fa7xGOnRMZHvElkg1Av1/Ac7ElLl67662xwrUoD
VWDbCShpVmWygXlAqt5z7PsdU5eK8tigFGz71YgteKP+S2YJG2gblc6+xvZz
jddKfsAGAb0jgW+x30i7REXV4PO26Dr+77nqf4o9Z+vZwGnH8sJL7Ct3p7SP
N7FBXEWRQS32z6P10Qda2UBz76t1/+Y3147vdfrIBjKF/MP/1lcw7ay7vYcN
7t3tj07EpjxRvLJpAO8vzlX8LPbBC1N9er/YwOOP4z0PbATq9db9wft1cHXc
hi3HFR+zdpYNdgTfV1DGDn/t/FVogQ3kR+xVubA37pqKZa7ggKwYEdlafN6Z
4vXfxoQ54JxQm9Y1bFZPnMHAag5YvidQ4/3vfXgpDrxW5gCJS24BvNjiKlOG
9Zoc4JY5UNeJ3//psbqEh/ocMPqiF93BXn/a2ThzCwcYpW5S1MG+ZqJ4Ncma
A8iXBXNm8P2aWpj8EWnPAb7nZHhrsCsuxyUd288BcutovQbYaul1P81COECQ
0J2Swvc11j1uo14EBxT4le34gO/3sJzzNeUYPJ6843w0dmHJpJlQGgfotldf
/oXjQ76WuPG9kgMsH8RGZOL4uRg+OfrpCQdEJT15ug3729Y68LqBA1qmbmeP
4XjLat0zVtnGAa6LR5KNsSW+xm6NHOGAbqdRzRc4fleSJqeU5OcBtfalQAGO
/6Fdq3bmrZsHyvZfdmzFri3QKZbRmgdquTl9Azhf+FoF7pcwnQd3X1wlS2O/
TPr7htdpHnQHJlMTcH45J8PI/x0zD8oP//ZzuIbHM2U7VU7Ogw8yv1bcwvmt
7gz12Ub6AhBnEDs+heL8En/pqnnzAkjuUyvYhx2Us3zQtn0BaNnzKAxfIJB6
yzy/Z98CCBEtT2OfJ9AtSca+SOYC8AMyN4gQAp3BfecbnUVQza9tF47zsza5
2do5dxFoXBxa7RNAoHhxcxnP4kUQ6GTNy/TH91Pt5d8jFYug1EvYMhY727Eh
M6RuEXS2Sj0uO04ggcKa8ezuRSDbRJyYw/VhxLI4ZVB4CQyut53JOkKgvMTY
7sBLS+BjvKqvBq43p7XdqsixS4AZclb73QECWb/XSExNWgKi40I2J7H/iHWA
R1lLQKLYPvKpJ84XWeLFzMdLQMjIYtnGA9ePe/lnwn8vgUaOx5EIdwIJt9SJ
Ju5eBovNv5K0nfH5+SaNS7stg90LL8/378H5j/9A8/0Dy4DeSDTGY3vYUc93
+C+DZD9xvxEnApV/3v6faOwyuPF+nXjJbryeoa4HGXXLoPrMDGnDLhxPEeeK
PomS4F/BTdL5O3F+XC/s4CVBgn1RD6nO2JI/i9lTa0jQLKNyHz/2ye1fdgop
kOAIb8+h0ztwPhQ1mrHWIcFHtPi3tjYEiiqYAQ07SDBAc7OEhDWBKvckjO60
J8Fg8UXlD1YE6udVvN7nSIJvRh3uJWIbHHccZu0lQe2L6wW4sYcMHibq+5Lg
Mwt9MG9BIMvmgJ6SaBJsuRoUubiNQKfO8UQZx5Kg+mBZDx07Rz1HszmBBHm4
XIsiseeS2i8OppJgY0hE7grsYhfNdbJ5JHg8douUzFYC8Y2OnrpeT4Jd4r+2
uUECtQp4C4bP4d9XlmpqbyLQwA9HhQU2CTa8i9hGwmY8g0bnF0lQVWNVx0cz
3D/4Sh8I5iLDB+lN5iHYp5o+VQeIkuEC7e79Vty/rA3b6u6pTYb6RlxJV0wJ
pOOkG/hVjwxr6FmLntjmGrKX3Q3J8KdV1eAG7IAedoWLGRke2/1ebHIDjh/D
hxQHGzJce4bE64l99I9cKfQhwxCxacc9Jji/vVpJbzhKhtfubjAxwk7Nnv9k
5k+GLvI9aaux62y+LJqcJkPD/27V9hnj+1OctEsvkgxFm0/cP4qtHB7q8+Ay
GXpveetqh226x++CVhwZssknw/SxD1Mt76qlkGGVqpz+shGBnnoushRyyDD3
t/fubOx2o7GVuXlk2NIe1xaN/WNlDyF7lwwJ1gzdH1uw7tHOteVkGNC7RmIL
9gHJ47mitWQ4KaYaNWGI43Ny7+OUejKceMX+0IMd32z1VugFXl+GSHYz9qPT
igz+12S42SktPw+b90OvFbWLDBnbwkP3Y3cHnPK06CHDLb+pj+2wSwT5z8b0
k2Fyz6O9ENvGekORwCAZcmy5RpSwpYbf19sOk6HNt+4Pq7HHo3w/J4/i9bwz
VxXATqKnc9GmyNDukb3UjAGBPPfrSDvPkOG+7cpPf2Hrzjfr35ojw88Xl1/0
Y380mvOSXiTD8O86Mq+xCzqvnvcgUeBOUB/QgH36lHJqLpUCV9+v13qMLV7h
9EKJnwIXJ68wCrCHd4x3+6ykQPvUmIUs7JrRqKkSYQqU+up36gZ2TIwU35gY
BSYN73S+iu2qXC2ntZoCE75sL7mCrdZoY3xiLQXajYX5RmBzDvyweyhDgTYn
udPPY7cuhfjMyFMgpXVB/wx2drZIuKESBSb6R4BAbH/Te2lnVShQfqD82THs
zd3w/jN1PF9DTv4R7FXB3U3zWhQ48vgU5xD2gFhg/yY9CgyKsXhxAPvhQ17G
RQMKfMtrwNyPHWl/R+ClMQU6yLhnu2M7Thgpcm2kwP2NXyr3YismvDO13EyB
CrwtBq7YDFUfx9gtFHhshaWqC3ZT8+LRt+YUSF06meCMnXY47ZKgNQW2afh6
/LMPRSvDbgcF2k5Y5P2zcW5TZYodBX57oOr07//5Nu97/XEXBfbPaJ39N35P
38x32h4KtLIL4nfDLg1JYDq7UuBGbwmhfdgXViuuynCnwPgZg0gP7J2Pa9f1
eVAgo3nc5yC2zG7HzTJeFBiB3OsOY/+ZGt3j6U2Bkp13In2x6UmX/PN8KTB1
xZdnx7FTNNdcHjxGgawLcl4nsQ+8rcxWPkGBanvTLwRj6/laPzpyigKLf+zj
CcWm8Ay03jtDgaSAJErkv/tUcHZw7BwF5nrZBMb+uz/fi0QDL1JgVlxf7k1s
i7DN6lWRFPhgYuJQDraEVNcWxmUKLJHhzijCfurMffJcIgW6r6nf+xQ7jpEd
W5uM78vDrJ8vsN1SDXIXUinQuoIz2Iq90H6oIyKDAvPMa0z+wwYWL7XiiihQ
VjXZQgTHg2MTX6RIKX6fFNc4OWyfbfZdGfcpUKdp0EkbO3FLf3jpIwqk1/+M
ssXu3TTX0fqSAs/lcVumYk/UmSk5NePzX+3SVohNMos61/+GAj9WPOx7gq1i
Kqww8Z4CwQGVm9+xTxupnxL6jt/flZxwQ5wvYh4HNt/8QYHJPC937cTONHiy
Vm6YApfzNj44hP1ivXmjzgQFzt7vWXEDW0jHg7ZrngIFo722zmPfU0mtub6a
CvcUCAwP4nxWV9TNLy1FhWmrYk9RcX58ryznWShLhTt/8iUqYs8plvM+VqbC
PMkWH29sc/lm1y59KnxzjwdNYn+T5HAkHahwNPi0qhzO13/ToX3ebiq8NMrJ
sMLmWh1ToOZChdYu9lmB2BritJ2mHlTYYSVp14R9TkT7tvtxKmwK1gg5heuD
GL8XyImlQl6FZyt/4/rxw97x5u8EKvx5wNJcEtebqrStE0bJVPjuXhXHEttB
QTGrI40KV6u8/HUX+6rJ0BypgApfi801H8Xfx7xHfCoO1VPhexZ6vgLXs65y
Z+5KhPdTGUiB2EXTlvsWGqmQaRrYGoxtHq7Cn/aWCj9/XRz6iX0pbcS7+QsV
Lt58aPoWf1/PN/rJqE1ToeS+qutluH6+XeF++swsFf6o0xH9jZ1pv6P1BYsK
x4cjxdXM8fdzn0aI2zIVspfsykqwz0yPdyYIcsGmWrJkBa7fk/InEv+s44Kl
t/TXfsT1fTAsaL7anQv6p28dvYj7ieyRZ/WTHlwwZkK2sR3baTcpQsOLC2qt
r1eQtsX5QfUqV4EvF7x6fci/FrvwU9HK1DNckB3sY7loh+uVWq9cYDIXXPhY
I52N+5mhTmiu2cgFJS9XXgEueHwQw+PbzAX/bjS1ycF2Km1/XfCGC4p87kxf
xG666GYr9Z4L+gyMfah3xeOrn3bm/8oFW8wCm83d8PgRxb4jc1wwICXxy/H9
eHwNoauF6tzwpoZS57rD+H6cpSau0+aGb2PP0XOxexpZ8SV63DB34s9uKW8C
vXMfjC034YZn3miHiPrgeE14Gv3IkhuqCIY+5/MlUMKYV2iTFzdUOFizWxz3
m+vLnhwbyuSGjhT2hcrTBNJklvv55HDDCM8IEsT9rMq2/KMjedyQ/+wbw/fY
0n2JR8ZLuOHKy9nV08EE4hHwOsSo4YbGYdpUiPvhHj9Bd65PeH2MIrWFMAJF
qB+0URLggTabNrksxBDIaBNpp58QD2wite5Kj8Xxa3/HtlKEB3pvtptYH4fz
x5mvDmaSPFB2ciXfcdyv66O9Lk7KPNC34PDHn4m4nu1xPBwNeGB4i/1vJu7v
d17aFj4UxAPjXf+UpuPvizXdylWF/TywXiGq70M1gUTbgqZ0B3gg+lzkXPyI
QPzohXb9IA+cK7p7J+wxzk/F+8s+/+aBMgJHsjWf4PpzNq2Qh80DxfUObr9R
i+/zau50X3FeqCr981H8C7wel6ELmna8MECXPif+nkC2XfkWj+i8UGXvt+dP
JnH/P2k5qdPIC698YJk2TOF+iG/sVlkzL9xQMXP91V8CdW7QH89v54Vxse2d
XTN4v7cbU6/18cL1jROZVBbOf4eHvgcweWFakXbEFZIiiphWPq+mwwdf+tKm
9EUVUZXQvYqcHD44u2lgAJgoIoc/c27f8vhgZdfeH0c3KKKJdnNe2bt80Pre
h+obpopI9eqA5+0yPrhrxbeWcTNFlCMgKZL9lA+mzO+vK9qiiOL5YoIyPvJB
96lZia07FNEhirfJDZ4V0KWJnS7pqYhoc/Iv4wJWwLbSO/Z74hSRiPYuMpcD
P9xhsStj919FxC8+8zucEMD1oNJ71EsJGRrJlnZOCcDmwk1heoNKaL6YnPbs
vSAsu2g4rBSljOpfO6vfyVsJ14TVX3ygtQ6tNT08JhYtBF+/F9MXIKmg026D
znEuq2Cy1Ct4/5sKutg723pcTBiqbOex6v6kikR1nSP7o4Shy7aE4RdLakhx
/+TVtnFhGNmqrHfPWANdqjqsE+0hAsdcz3n4V2siVmHORrV3IlBx4IF9zh5t
NBEgctvOSBQqbap+up5LF+kePHBjY7Eo7Gx0edrJr4f+qo8MlAiLwfrEA/HT
UutR6zWDW9RzYrBaST6n0FwfTcvv/6k8IgZd+fLLTpQaoPSYhpjXDjTY/kqw
N1/GCJ3bd4Ke5UiDxnUlcqeVjJCbnjwzwIkGlX/zRVlrGCHZvks+4q402NDV
UMIxMUKF2hYWXp74+eum9GgnI1T1uZWy4E+DT1YlmusmGqE2xZ4wnQQa/NO6
eXlq0QhVsOIeU67S4HIfo0WV2xglt5tOfE6iQasT5K+HBI2R49nsfaGpNHjm
juz04Fpj1PPWc+ObDBqMXnljWsDEGA2fHGZ5ldDgGl5a7sIpY/TaMl3XqJQG
KdFPBo+eN0alUta+K8pp8FgGd2LvJWPk/+relwcPaDD4aodwc4oxYkj61yzU
0ODqhWiJ5gpj1DUh86fjKQ3uzPhRaldjjJ68fKdcUEuDA7f2VvbWG6Pzx3XT
tjfQ4PyfbtpimzHat+W/NmlEg/RK7rPXO43RZolUrqkXNMhTfsNBq98YyY9t
NWtspMG1Y2sK3g4aIzKaCbr5igY3GKgHHhszRv8DDMA45A==
        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV1nk8VVsbB/Bz9j6OIWQ4cm6DqX3MDlKcpPZTUcYIEYUyhYoi0WSILpmK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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -778.2437934013956}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-778.2437934013956, 70.74943576376323}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Acute intake in t = 0\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Lungs\"", 11, StripOnInput -> False], 
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992822540348215`*^9, 3.417835748969455*^9, 
  3.4798276072525473`*^9, 3.4798282695462112`*^9, 3.4798294669458904`*^9, 
  3.518535010123541*^9, 3.591673524705124*^9, 3.643443738756962*^9},
 CellLabel->"Out[57]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[58]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQfUO3zORsUY1d0ZEvBxurZQ4Ym7esVpFYZQ/jv0kO
f6IksQvO/8XstkfE8DSc/2jR3jBB4ytwfpDoot95a27B+b5tKv+Vbj6A8x/v
tdMSVHgC5z8zt2KxWfsczl83K8rkkuZrOD99pyNfdtY7ON+dt9V7wY8PcP7l
2WdSeOZ9gvMPzlPT1LP+gjDf6aNL3u+vcD6z6/yt6+d+h/PDX+yt5U/+Cefz
Mrz/oKLwG87fU8q803r/Hzh/YU/HjYLGf3D+gYaKZZeFGBxg/NPcqTx13xB8
9ou33JmvMcL59q6HdDuXMcH5wlxJ9vM6mOH8x7XFvzdHs8D5T7T5epdoscL5
DVqJXircbHC+5A3VTUvuIPi+1xa5btnPDudv4lu5bt48Djhf5JvCoc48Tjhf
UC+QkSWAC87nEv38qk6JG843NZNbdeUDgv97OePUnRd44Py9J8K05i/khfOl
rFJeC7fwwfklUY/DOsP54fz6W19P5wgLwPlCBmFNd5oRfOXY971n3iD4jZtS
9FviBOH8H0vmWWueQ/Df5gnO9TMTgvMNEhOmWC9H8D9qvXiwQkAYET8TTWYw
VyD4nxRin6q+QPCnt+9rPxEgAuefUb5Zq9+N4DMe+Fw87SiCDwDAMK05
        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwd1Xk8VN8bB3A7WcbMHXuypUJkDdnOSSgiUZYUCaVN/IgUSbKTopKUihSV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        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwd1nk4Vd/3B3BDZXbvPedUqiNDCBEayHgXmZWiPpRSiDSIJFKRyJRQCkll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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -18.635204309381148`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-18.635204309381148`, 0.42505210988772024`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, -17.5}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Lungs\"", 11, StripOnInput -> False], 
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992822588362703`*^9, 3.417835753719455*^9, 
  3.4798276103777075`*^9, 3.479828272717903*^9, 3.479829472742654*^9, 
  3.5185350128423433`*^9, 3.5916735287895327`*^9, 3.6434437393975935`*^9},
 CellLabel->"Out[58]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Continuous\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "inputs1", ",", " ", "amad", ",", "class", 
   ",", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[59]:="],

Cell[BoxData["\<\"Option not available for inhalation\"\>"], "Output",
 CellChangeTimes->{3.39928225897703*^9, 3.41783575386008*^9, 
  3.479827610502714*^9, 3.479828272842896*^9, 3.479829472898901*^9, 
  3.5185350128735943`*^9, 3.5916735289815516`*^9, 3.6434437394288435`*^9},
 CellLabel->"Out[59]="]
}, Open  ]],

Cell["In version 8 It is used/Quiet to avoid  message", "Commentary",
 CellChangeTimes->{{3.518534536895705*^9, 3.5185345700213413`*^9}, {
  3.51853461344405*^9, 3.518534620522311*^9}, {3.5185347094458933`*^9, 
  3.5185347648688326`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<MultiInputs\>\"", 
    ",", "\"\<GraphicReport\>\"", ",", "inputs2", ",", " ", "amad", ",", 
    "class", ",", " ", "fn1", ",", "180", ",", "lambda"}], "]"}], "//", 
  "Quiet"}]], "Input",
 CellChangeTimes->{{3.5185364442917013`*^9, 3.518536448729287*^9}},
 CellLabel->"In[60]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwBoQNe/CFib1JlAgAAADkAAAACAAAA2C12NM1yfD7v4a4WlzhZwH1iX+iS
GFo/x1l2/81CWcCR+cQCWhhqP5AlixIJTVnAG8X3jz0Yej9A1Wm+i2FZwOAq
kVYvGIo/X0u+XMOKWcDC3d05KBiaP6ZTJDT93VnAMzeEqyQYqj8Hgfl1p4da
wOxjV+QiGLo/x3BA4znoW8D6A0a8FDHLP8T4Ag9BJV/A4qK9VhEz1D8pQ1Fk
Q0FhwFIVovturNo/vlRSp9YUY8BNhiT/ItngP3BgWvp3SGXA470+KhEg5D/j
TrhESpFnwOY3OgQ8rec/neig4nhSasCumlo00inrP2SOU5I+V23AZ7lBDmtq
7j8zc/a3BzxwwEcNhUug+PA/0wOuPMMecsDTm8xkDJ7yP7RLNlcNFHTAwZ4m
KS479D8UpGj4KzR2wOZC8URu+/U/U+WkBg3EeMADRZ+1r533P+aQ6ghHbHvA
V+i9fQ9j+T+L0KWSdaB+wA0A7/AkIPs/hnZ6w3oRgcC8dQO5O7/8Pz9jljDP
4oLAGIqBjUTG/D8mFxTUG+uCwHOe/2FNzfw/KF15HmzzgsAqx/sKX9v8P2Ld
aK4XBIPAmBj0XIL3/D8VCgfomiWDwHW75ADJL/0/pTHxLVNpg8AuAcZIVqD9
P1Bw0IeW84PAihVEHV+n/T8Y/C0zW/yDwOUpwvFnrv0/yDJEuiMFhMCcUr6a
ebz9P+zeZWLAFoTAC6S27JzY/T9YzDZKKDqEwOhGp5DjEP4/+NpL+LOBhMCh
jIjYcIH+PxQnF/jGE4XAdC5asgGI/j/kKj5TbByFwEjQK4ySjv4/9qdlOxUl
hcDuE88/tJv+Pzfpi7hxNoXAPJsVp/e1/j8PHzCPVVmFwBA954CIvP4//VVR
exdihcDj3rhaGcP+P89cLgDdaoXAiiJcDjvQ/j8W/QTacnyFwNiponV+6v4/
IIOm98mfhcCsS3RPD/H+P5r4I9OoqIXAf+1FKaD3/j9oVz9Ti7GFwCYx6dzB
BP8/R3tMR1vDhcD60rq2Ugv/P/YePr5IzIXAzXSMkOMR/z+0ac3fOdWFwHS4
L0QFH/8/bXrLKCfnhcBIWgEeliX/P3IPP1Mj8IXAG/zS9yYs/z8b6lkuI/mF
wO6dpNG3Mv8/Gv+fuyYChsDCP3arSDn/P3HilfwtC4bAluFHhdk//z+G5MYa
bhWGwGmDGV9qRv8/0aTRs3wehsBUVALMskn/P5dlVGUFI4bAd7fMIQ==
        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV13k8VF8bAPBZ7JGliTFX2dIvJLtEdU6SKFKyRSEkFMnWLkvZk0hlzRaS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        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV13k4VVsUAPB7z70umTJcUtE5xoyhuDzhrIr0SiqkQgmZMxSiDJlKMpVS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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -779.283680399033}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-779.283680399033, 71.58886826215401}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"MultiInputs\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Lungs\"", 11, StripOnInput -> False], 
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992822675007753`*^9, 3.41783576217258*^9, 
  3.479827617346814*^9, 3.479828279405018*^9, 3.479829479258092*^9, 
  3.5185350163424106`*^9, 3.5916735339420476`*^9, 3.643443740194475*^9},
 CellLabel->"Out[60]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IntakeWay\[Rule] \"Inhalation\",ShowReport\[Rule] \
\"CompartmentContent\"", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<CompartmentContent\>\"", ",", "1", ",", " ", "amad", ",", "class", 
   ",", " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[61]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["q", "ET1"], "[", "180", "]"}], "\[Rule]", 
    "3.833831653217919`*^-86"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "AI"], "[", "180", "]"}], "\[Rule]", 
    "2.724711040705032815821384361330444708881260408437677086`15.\
954589770191005*^-7826"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "bb1"], "[", "180", "]"}], "\[Rule]", 
    "1.51845445549338649125376404742231238345061173337687`15.954589770189909*^\
-7829"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "bb2"], "[", "180", "]"}], "\[Rule]", 
    "1.670441158731267965683610970772189906435954115729626`15.954589770191005*^\
-7829"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "bbseq"], "[", "180", "]"}], "\[Rule]", 
    "1.076719534860034723336045092061772884973832081207146`15.954589770191005*^\
-7829"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "BB1"], "[", "180", "]"}], "\[Rule]", 
    "3.08888759417712459681231786555273070771762133958971`15.954589770192099*^\
-7830"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "BB2"], "[", "180", "]"}], "\[Rule]", 
    "2.25608624563134990512258658562480115780467577120071`15.954589770191005*^\
-7829"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "BBseq"], "[", "180", "]"}], "\[Rule]", 
    "1.733192600802738693989861236380754453352906387935009`15.954589770191005*^\
-7829"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "LNth"], "[", "180", "]"}], "\[Rule]", 
    "1.5787126229116851999164891359023285657021561086730201`14.\
928144349374358*^-7828"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "ET2"], "[", "180", "]"}], "\[Rule]", 
    "3.1567770717968223806525997872159659231502652457928`15.954589770191005*^-\
7831"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "ETseq"], "[", "180", "]"}], "\[Rule]", 
    "1.405438586352082908027504856908920888115045271313629`15.954589770191005*^\
-7828"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "LNet"], "[", "180", "]"}], "\[Rule]", 
    "2.771768920304919921624208181333963431962536416122197`14.907661895699318*^\
-7829"}], ",", 
   RowBox[{
    RowBox[{"qLungs", "[", "180", "]"}], "\[Rule]", 
    "2.749061949689086248044697301923229210357477344544333761`15.\
954589770191005*^-7826"}], ",", 
   RowBox[{
    RowBox[{"qST", "[", "180", "]"}], "\[Rule]", 
    "2.699616877168942302237607201643999121696742`15.954589770191005*^-1884"}]\
, ",", 
   RowBox[{
    RowBox[{"qSI", "[", "180", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"qB", "[", "180", "]"}], "\[Rule]", "2.100196569164032`*^-11"}], 
   ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "2"], "[", "180", "]"}], "\[Rule]", 
    "7.464494676848972`*^-9"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "3"], "[", "180", "]"}], "\[Rule]", 
    "1.257245358025138`*^-9"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "4"], "[", "180", "]"}], "\[Rule]", 
    "3.3985291151225155`*^-12"}], ",", 
   RowBox[{
    RowBox[{"qURI", "[", "180", "]"}], "\[Rule]", "6.821987851891576`*^-8"}], 
   ",", 
   RowBox[{
    RowBox[{"qULI", "[", "180", "]"}], "\[Rule]", "8.097470635562059`*^-12"}],
    ",", 
   RowBox[{
    RowBox[{"qLLI", "[", "180", "]"}], "\[Rule]", "1.466815273178519`*^-11"}],
    ",", 
   RowBox[{
    RowBox[{"qFEC", "[", "180", "]"}], "\[Rule]", 
    "4.080595830917625`*^-9"}]}], "}"}]], "Output",
 CellChangeTimes->{3.399282269346283*^9, 3.41783576398508*^9, 
  3.4798276191750326`*^9, 3.479828281248662*^9, 3.479829481086147*^9, 
  3.518535017576809*^9, 3.591673535636217*^9, 3.643443740631979*^9},
 CellLabel->"Out[61]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<CompartmentContent\>\"", ",", "1", ",", " ", "amad", ",", "class", 
   ",", " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[62]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["q", "ET1"], "[", "180", "]"}], "\[Rule]", 
    "0.31169342284452944`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "AI"], "[", "180", "]"}], "\[Rule]", 
    "0.0005313944500743153`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "bb1"], "[", "180", "]"}], "\[Rule]", 
    "0.00006438169010523872`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "bb2"], "[", "180", "]"}], "\[Rule]", 
    "0.00004378892311232248`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "bbseq"], "[", "180", "]"}], "\[Rule]", 
    "7.713692225754938`*^-7"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "BB1"], "[", "180", "]"}], "\[Rule]", 
    "0.00010755246578955283`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "BB2"], "[", "180", "]"}], "\[Rule]", 
    "0.00005914101590968554`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "BBseq"], "[", "180", "]"}], "\[Rule]", 
    "1.24167100695224`*^-6"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "LNth"], "[", "180", "]"}], "\[Rule]", 
    "2.1174913459413576`*^-10"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "ET2"], "[", "180", "]"}], "\[Rule]", 
    "0.0019980236666473465`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "ETseq"], "[", "180", "]"}], "\[Rule]", 
    "1.9927534831419603`*^-6"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "LNet"], "[", "180", "]"}], "\[Rule]", 
    RowBox[{
    "-", "2.7695097437559846543115627446269792318847468471516`14.\
907685871806192*^-7831"}]}], ",", 
   RowBox[{
    RowBox[{"qLungs", "[", "180", "]"}], "\[Rule]", 
    "0.0008082717969697772`"}], ",", 
   RowBox[{
    RowBox[{"qST", "[", "180", "]"}], "\[Rule]", "0.008295151938226969`"}], 
   ",", 
   RowBox[{
    RowBox[{"qSI", "[", "180", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"qB", "[", "180", "]"}], "\[Rule]", "0.169279205599587`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "2"], "[", "180", "]"}], "\[Rule]", 
    "1.4773457160036754`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "3"], "[", "180", "]"}], "\[Rule]", 
    "0.08864073425386677`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "4"], "[", "180", "]"}], "\[Rule]", 
    "0.027181999223311295`"}], ",", 
   RowBox[{
    RowBox[{"qURI", "[", "180", "]"}], "\[Rule]", "3.7646714188044434`"}], 
   ",", 
   RowBox[{
    RowBox[{"qULI", "[", "180", "]"}], "\[Rule]", "0.0005427723703675045`"}], 
   ",", 
   RowBox[{
    RowBox[{"qLLI", "[", "180", "]"}], "\[Rule]", "0.000899090036638177`"}], 
   ",", 
   RowBox[{
    RowBox[{"qFEC", "[", "180", "]"}], "\[Rule]", "0.010376854800704678`"}]}],
   "}"}]], "Output",
 CellChangeTimes->{3.3992822713481903`*^9, 3.41783576592258*^9, 
  3.4798276213001413`*^9, 3.4798282832954187`*^9, 3.4798294831798162`*^9, 
  3.5185350190612125`*^9, 3.5916735375424075`*^9, 3.6434437411476088`*^9},
 CellLabel->"Out[62]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Continuous\>\"", ",", 
    "\"\<CompartmentContent\>\"", ",", "inputs1", ",", 
    RowBox[{"AMADAdultW", "[", "5", "]"}], ",", "amad", ",", " ", "fn1", ",", 
    "180", ",", "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[63]:="],

Cell[BoxData["\<\"Option not available for inhalation\"\>"], "Output",
 CellChangeTimes->{3.39928227139511*^9, 3.417835765969455*^9, 
  3.479827621425148*^9, 3.4798282833891635`*^9, 3.4798294832110653`*^9, 
  3.5185350191080885`*^9, 3.5916735377804317`*^9, 3.64344374116324*^9},
 CellLabel->"Out[63]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<MultiInputs\>\"", ",", 
   "\"\<CompartmentContent\>\"", ",", "inputs2", ",", "amad", ",", "class", 
   ",", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[64]:="],

Cell[BoxData["\<\"Option not available for MultiInputs intake\"\>"], "Output",
 CellChangeTimes->{3.3992822714263897`*^9, 3.41783576598508*^9, 
  3.479827621487651*^9, 3.479828283420412*^9, 3.4798294832266893`*^9, 
  3.5185350191549644`*^9, 3.591673537986452*^9, 3.643443741178859*^9},
 CellLabel->"Out[64]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["IntakeWay\[Rule] \"Inhalation\",ShowReport\[Rule] \"Disintegrations\"", \
"SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<Disintegrations\>\"", ",", " ", "1", ",", " ", "amad", ",", "class", 
   ",", " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[65]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["q", "ET1"], "[", "180", "]"}], "\[Rule]", 
    "26930.311733767343`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "AI"], "[", "180", "]"}], "\[Rule]", 
    "45.91248048642084`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "bb1"], "[", "180", "]"}], "\[Rule]", 
    "5.562578025092626`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "bb2"], "[", "180", "]"}], "\[Rule]", 
    "3.783362956904662`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "bbseq"], "[", "180", "]"}], "\[Rule]", 
    "0.06664630083052266`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "BB1"], "[", "180", "]"}], "\[Rule]", 
    "9.292533044217365`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "BB2"], "[", "180", "]"}], "\[Rule]", 
    "5.10978377459683`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "BBseq"], "[", "180", "]"}], "\[Rule]", 
    "0.10728037500067353`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "LNth"], "[", "180", "]"}], "\[Rule]", 
    "0.000018295125228995346`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "ET2"], "[", "180", "]"}], "\[Rule]", 
    "172.62924479833072`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "ETseq"], "[", "180", "]"}], "\[Rule]", 
    "0.17217390094346538`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "LNet"], "[", "180", "]"}], "\[Rule]", 
    "1.7202485276812673`*^-6"}], ",", 
   RowBox[{
    RowBox[{"qLungs", "[", "180", "]"}], "\[Rule]", "69.83468325818875`"}], 
   ",", 
   RowBox[{
    RowBox[{"qST", "[", "180", "]"}], "\[Rule]", "716.7011274628102`"}], ",", 
   RowBox[{
    RowBox[{"qSI", "[", "180", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"qB", "[", "180", "]"}], "\[Rule]", "14625.723363804314`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "2"], "[", "180", "]"}], "\[Rule]", 
    "127642.66986271756`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "3"], "[", "180", "]"}], "\[Rule]", 
    "7658.5594395340895`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "4"], "[", "180", "]"}], "\[Rule]", 
    "2348.524732894095`"}], ",", 
   RowBox[{
    RowBox[{"qURI", "[", "180", "]"}], "\[Rule]", "325267.6105847036`"}], ",", 
   RowBox[{
    RowBox[{"qULI", "[", "180", "]"}], "\[Rule]", "46.89553280642812`"}], ",", 
   RowBox[{
    RowBox[{"qLLI", "[", "180", "]"}], "\[Rule]", "77.68137916542535`"}], ",", 
   RowBox[{
    RowBox[{"qFEC", "[", "180", "]"}], "\[Rule]", "896.5602548004906`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.3992822735221367`*^9, 3.41783576801633*^9, 
  3.4798276235658827`*^9, 3.4798282855609136`*^9, 3.479829485210988*^9, 
  3.518535020686244*^9, 3.591673540293683*^9, 3.6434437417101145`*^9},
 CellLabel->"Out[65]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<Disintegrations\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[66]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["q", "ET1"], "[", "180", "]"}], "\[Rule]", 
    "4.822673085931743`*^6"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "AI"], "[", "180", "]"}], "\[Rule]", 
    "8263.7877905036`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "bb1"], "[", "180", "]"}], "\[Rule]", 
    "1001.2095260299964`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "bb2"], "[", "180", "]"}], "\[Rule]", 
    "680.9675426922857`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "bbseq"], "[", "180", "]"}], "\[Rule]", 
    "11.995668329956397`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "BB1"], "[", "180", "]"}], "\[Rule]", 
    "1672.5705361106588`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "BB2"], "[", "180", "]"}], "\[Rule]", 
    "919.7100411224964`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "BBseq"], "[", "180", "]"}], "\[Rule]", 
    "19.309395732164194`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "LNth"], "[", "180", "]"}], "\[Rule]", 
    "0.003292756972827291`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "ET2"], "[", "180", "]"}], "\[Rule]", 
    "31072.39701484766`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "ETseq"], "[", "180", "]"}], "\[Rule]", 
    "30.989581938483525`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "LNet"], "[", "180", "]"}], "\[Rule]", 
    "0.0003096103599676296`"}], ",", 
   RowBox[{
    RowBox[{"qLungs", "[", "180", "]"}], "\[Rule]", "12569.553793278132`"}], 
   ",", 
   RowBox[{
    RowBox[{"qST", "[", "180", "]"}], "\[Rule]", "128972.84810845446`"}], ",", 
   RowBox[{
    RowBox[{"qSI", "[", "180", "]"}], "\[Rule]", "0"}], ",", 
   RowBox[{
    RowBox[{"qB", "[", "180", "]"}], "\[Rule]", "2.624959751280221`*^6"}], 
   ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "2"], "[", "180", "]"}], "\[Rule]", 
    "2.1569470943413507`*^7"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "3"], "[", "180", "]"}], "\[Rule]", 
    "1.2411332211305734`*^6"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "4"], "[", "180", "]"}], "\[Rule]", 
    "421308.4617193143`"}], ",", 
   RowBox[{
    RowBox[{"qURI", "[", "180", "]"}], "\[Rule]", "5.459658857705544`*^7"}], 
   ",", 
   RowBox[{
    RowBox[{"qULI", "[", "180", "]"}], "\[Rule]", "7574.954387794204`"}], ",", 
   RowBox[{
    RowBox[{"qLLI", "[", "180", "]"}], "\[Rule]", "12476.251684021872`"}], 
   ",", 
   RowBox[{
    RowBox[{"qFEC", "[", "180", "]"}], "\[Rule]", "133647.7072000635`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399282275899401*^9, 3.41783577032883*^9, 
  3.4798276260035076`*^9, 3.479828288029521*^9, 3.4798294874765263`*^9, 
  3.5185350224675283`*^9, 3.5916735450841618`*^9, 3.6434437423195195`*^9},
 CellLabel->"Out[66]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Continuous\>\"", ",", 
    "\"\<Disintegrations\>\"", ",", "inputs1", ",", " ", "amad", ",", "class",
     ",", " ", "fn1", ",", "180", ",", "lambda"}], "]"}], "//", 
  "Chop"}]], "Input",
 CellLabel->"In[67]:="],

Cell[BoxData["\<\"Option not available for inhalation\"\>"], "Output",
 CellChangeTimes->{3.399282275946321*^9, 3.417835770375705*^9, 
  3.4798276261285143`*^9, 3.4798282881545143`*^9, 3.479829487492151*^9, 
  3.518535022498779*^9, 3.5916735453191853`*^9, 3.64344374233512*^9},
 CellLabel->"Out[67]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<MultiInputs\>\"", ",", 
   "\"\<Disintegrations\>\"", ",", "inputs2", ",", "amad", ",", "class", ",", 
   "fn1", ",", " ", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[68]:="],

Cell[BoxData["\<\"Option not available for MultiInputs intake\"\>"], "Output",
 CellChangeTimes->{3.399282275977601*^9, 3.41783577039133*^9, 
  3.479827626191017*^9, 3.4798282881857624`*^9, 3.4798294875077753`*^9, 
  3.518535022545655*^9, 3.591673545454199*^9, 3.643443742350745*^9},
 CellLabel->"Out[68]="]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["ICRP 30 Models: Cobalt, Caesium and others", "Section"],

Cell[CellGroupData[{

Cell["The models", "SubsubsectionIcon"],

Cell[TextData[StyleBox["All these elements have the same pattern, that it is \
shown in fig. 1. All elements have compartments B, LLI, ULI, BL and URI \
however the number of systemic compartments changed depending on the elements \
(the maximum is three: a, b and c). The same happen of the flow. Fig 1 \
represents a diagram flow where are included all ICRP 30 elements.",
 FormatType->StandardForm]], "Text"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0002El0@0006`000000000000005/1001K0@00
00000000001P=P0003L00215CDH00040O2D00;/100050000000000000000000080<005P200100@00
l0000000000000000000003R1020Z@<0600000`0000000006@0000`0003oool0500000`0000=0000
4P0000`0000200008@0000P0000:0000400005P1000<00002@000100001L0@00H04001@0000<0000
3@000300000<00003`00P4H0000X0000700004M4BD<20000F04000`0002d0P00K0400000000W0000
6000004000000000oooo0000000U000030000040000V000070000080000000000@00000000000002
9@0000`000020000:P0001P0002K0@00]`000=P1003`00009@0000`000000020:00000`000010000
9@0000`000070020:00000`0000200008@0000P0000N000060000:L100310000c@400>L0001B0000
L0400080003eoooo0000000000000000T04000000000000P@@1b06T0H@1/00000000000000000000
000000000000000000000000000000000000000000000000000000004P0>00002`0000<000030000
000000D0000N0000T040000000000000;ASdMbB^4P010000F0@:ZER]4P2DcjP02`0005R]4P0dD@4`
7<nX08R]4P0<0000h1>X042g4P080000mOooo`0000000000000009010000000000008440LP1Y0640
K0000000000000000000000000000000000000000000000000000000000000000000000000170000
A:dB06l<0C3/F>5gm;3QM`02001l[180FEKdMeP42ZUL0000R:`B01c?Z01/[180LR@1<5P42ZUTMP08
000002D0000<00000P0002D0000<00000P0002D0000<00000P000180000<00000@0005@000240000
C`000;D0001d0000`P00004000000212000P@ZL1003100002@0004`00000000000000000003ooooo
ooooof0000120200K`1b0200E01b02h0800000L0000300001P0000@0000300001P0000@000030000
0`0005@0001/0000C`000<@0001/0000d@00004000000212000P@ZL1003@00001@0004`000000000
00000000003ooooooooooeP0001306l0K@1`02h0000700001P0000P0000600000`000280000<0000
ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J00004@0000d3002<0@00
8P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`0000000209`0001P000010000
00000?ooo`0000009@0000`0000100009P0001`000030000000000400000000000000RD0000<0000
0`0002X0000H0000F04001<1001g0@00<04002D0000<00000000P2P0000<00000@0002D0000<0000
1`00P2P0000<00000`000240000800007P0001P0001P0@006@400701000[0@00DP00070100030000
loooo`0000000000000009010000000000000440LP1Y0640K0000000000000000000000000000000
0000000000000000000000000000000000000000000000001>dB06Af00P0000040800040001h0P@0
000006d<0C1B0@H0?>hB029@0C1/kQ80b0000000002l0P00B:Z600d0000lkQ80=541<=2YQP1/kQ80
300005S_4P0dl18000000??oool0000000000000002l0P000000000000110780J@1Q06`000000000
00000000000000000000000000000000000000000000000000000000000000001P0002<000000000
400000d0000300000`0005UFm7Od0@X4G00006c]4P1HZHH0D>dB078T0C3d0@X4I7H02000000U0000
300000<0000U0000300000<0000D0000300000d0000B000030000040001D0000E00000P0000=0@00
3P0001`100010000000P@P00849P0@006@400040001<00000000000000000000oooooooooom@0000
H@0000L0000R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H0000
6P000140000=0`00S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<0000
0000P2L0000H00000@000000003oool0000002D0000<00000@0002H0000L00001000000000010000
00000000008U0000300000@0000Z000060000:/1000C0@00bP400301000U000030000000080X0000
30000040000U0000300000L0080X0000300000@0000Q0000200001h0000H0000/`4001T100330@00
:`4002D0000<00000`0002D0000<00000`0001@0000<00003@000180000<00000@0005@0001D0000
F`0000d1001Q00007040004000000212000P@[<1000I0@000@0004`00000000000000000003ooooo
oooooe00001R00001`000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000000209`0001P00004000000000?ooo`0000009@0000`0000400009P0001`000010000
000000400000000000000RD0000<00000@0002X0000H0000n`4001<1000J0P00<04002D0000<0000
0000P2P0000<0000100002D0000<00001`00P2P0000<00000@000240000800007P0001P000030P00
6@4001<2000[0@009@0000`0000300009@0000`000030000500000`0000=00004P0000`000010000
E00005@0002[00003@400;40000L0@000@000000848002120`8001T100010000C000000000000000
00000?ooooooooooD00006<0000700008P0000`0003ooooo8@0000P0000I000030000?ooo`0H0000
30000000000N0000600001X0000A00003@<008`1000R000030000?oooolH000030000000000I0000
30000?ooo`0U000030000000080W00006000004000000000oooo0000000U000030000040000V0000
700000@0000000000@000000000000029@0000`000040000:P0001P0000l0P00A0400602001V0@00
9@0000`000000020:00000`0000100009@0000`000070020:00000`0000400008@0000P0000N0000
600004D2001:0@00F0800641000U0000300000<0000U0000300000<0000D0000300000d0000B0000
30000040001D0000F0000>d0000n0@00o00004d100010000000P@P0084950P00BP400080001<0000
0000000000000000oooooooooom@0000@P1<00T0000700008P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R000030000?oooolH0000
30000000000I000030000?ooo`0U000030000000080W0000600000@000000000oooo0000000U0000
300000@0000V000070000040000000000@000000000000029@0000`000010000:P0001P0002X0@00
Q`000<P1002V00009@0000`000000020:00000`0000400009@0000`000070020:00000`000010000
8@0000P0000N000060000;01002=0000`@400:40000U000030000080000U000030000080000D0000
300000d0000B000030000040001D0000H00005P000210000IP0008h000010000000P@P0084:`0@00
S@0000<0001<00000000000000000000oooooooooomD0000E@1<04T0000700001P000080000R0000
30000?oooolQ0000200001T0000<0000oooo01P0000<0000000001h0000H00006P000140000=0`00
S0400280000<0000oooooaP0000<0000000001T0000<0000oooo02D0000<00000000P2L0000H0000
0@000000003oool0000002D0000<00000@0002H0000L0000100000000001000000000000008U0000
300000@0000Z000060000:P1001D0000b04007<0000U000030000000080X000030000040000U0000
300000L0080X0000300000@0000Q0000200001h0000H0000/04005X000310@00KP0002D0000<0000
0`0002D0000<00000`0001@0000<00003@000180000<00000@0005@0001P0000F00004h0001X0000
G@00004000000212000P@[01001J00000`0004`00000000000000000003ooooooooooe@0001<04`0
B@0000L0000700000`000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000000209`0001P00004000000000?ooo`0000009@0000`0000400009P0001`000010000
000000400000000000000RD0000<00000@0002X0000H0000Y04000`0003<0@00;`0002D0000<0000
0000P2P0000<0000100002D0000<00001`00P2P0000<00000@000240000800007P0001P0002]0@00
4P000<@1000Z00009@0000`0000200009@0000`000020000500000`0000=00004P0000`000010000
E0000600001E00001P0006L0000C00000@00000084800212[@40018000030000C000000000000000
00000?ooooooooooE00004H0A@1300001P0000H0000700008P0000`0003ooooo8@0000P0000I0000
30000?ooo`0H000030000000000N0000600001X0000A00003@<008`1000R000030000?oooolH0000
30000000000I000030000?ooo`0U00003000000008160000:00001`00017A4U30P000681003C0000
W@4001D100000000G`0003P000010000>0000000000h0000000000000@0100000000000000000000
00000000000U000030000040000U0000300000D0081G0000:00000h000360000A@00004100030000
V`7D06P1e01X0@/19@0000`000080020:00000`0000100009`0001P0000100000000000000000000
9@0000`000010000EP0002P0000;0000o@0001H000080@000`0006<12@5X0A@1KP490BD0000<0000
1`00P2D0000<00000000P2P0000<00000@0004H0000D0000200004M4BD<30000AP0002P0000L0000
AdA9@`80002e0@00k`000<81000E0@00000005l0000h00000@0003P000000000>000000000000040
0@0000000000000000000000000000009@0000`0000100009@0000`000050020E`0002@0001P0000
hP0006D000010@000P000;X1l02k0@/19@0000`000080020:00000`0000100009`0001P000010000
00000000000000009@0000`000010000EP0002P0001N0000o@0006T000080@000`000;H12@6l0A@1
`@490BD0000<00001`00P2D0000<00000000P2P0000<00000@0004H0000D0000200004M4BD<30000
AP0002P0000L0000AdA9@`80003F0@00e0000142000F0@00000005l0000h00000@0003P000000000
>0000000000000400@0000000000000000000000000000009@0000`0000100009@0000`000050020
E`0002P0001m0000a`000;@000020@000`000=L1e@0:0]D02P8<0BD0000<00002000P2P0000<0000
0@0002L0000H00000@00000000000000000002D0000<00000@0005H0000X0000[@000?h0002h0000
204000<000050PX12P8D0A022P4U0000300000L0080U000030000000080X00003000004000160000
500000P00017A4U30`0004H0000X0000700004M4BD<20000G0400940002Z0@006@400000001O0000
>0000040000h0000000003P00000000000010040000000000000000000000000000002D0000<0000
0@0002D0000<00001@00P5L0000X00000`0008T0001:00003@4000<0001M0AL1G@6G0:01U`0U0000
300000P0080X000030000040000W0000600000400000000000000000000U000030000040001F0000
:00004H000260000D000094000030000WP6M0:P1V02N0I809@0000`0000700209@0000`000000020
:00000`000010000AP0001@000080000AdA9@`<000160000:00001`00017A4U30P0007l1002M0000
[`4002@100000000G`0003P000010000>0000000000h0000000000000@0100000000000000000000
00000000000U000030000040000U0000300000D0081G0000<00002H0002E0000E@0001P100050000
Z`4R0H018P600J<0Y@6S0:D1X`0U0000300000P0080X000030000040000W00006000004000000000
00000000000U000030000040001F0000:00004X0002B0000EP0009d000030000Y06Y0:h1XP2R0Ih0
9@0000`0000700209@0000`000000020:00000`000010000AP0001@000080000AdA9@`<000160000
:00001`00017A4U30P000<L1002A00005`8001T100000000G`0003P000010000>0000000000h0000
000000000@010000000000000000000000000000000U000030000040000U0000300000D0081G0000
:00007H000290000_`0000d1000300005@8G0AD2U`3@0IL09@0000`000080020:00000`000010000
9`0001P00001000000000000000000009@0000`000010000EP0002P0001`0000QP0007/0002A0000
0`000=<1TP380IP0d`6M02D0000<00001`00P2D0000<00000000P2P0000<00000@0004H0000D0000
200004M4BD<30000AP0002P0000L0000AdA9@`80002b0@00LP000;l100290000000005l0000h0000
0@0003P000000000>0000000000000400@0000000000000000000000000000009@0000`000010000
9@0000`000050020E`0002@0001N0000K@000680001m00000P000;P1Q`2h0G/09@0000`000080020
:00000`0000100009`0001P00001000000000000000000009@0000`000010000EP0002P0001K0000
J00006H0001b00000`000;h1OP2h0G@0/`5n02D0000<00001`00P2D0000<00000000P2P0000<0000
0@0004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80002b0@00;P000;l1001F0000
000005l0000h00000@0003P000000000>0000000000000400@000000000000000000000000000000
9@0000`0000100009@0000`000050020E`0002@0001N0000:@000680001:00000P000;P1E02h0CL0
9@0000`000080020:00000`0000100009`0001P00001000000000000000000009@0000`000010000
EP0002P0001K0000900006H0000^00000`000;h1>P2h0C00/`4j02D0000<00001`00P2D0000<0000
0000P2P0000<00000@0004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80001W0@00
;`4004<2001X0@00000005l0000h00000@0003P000000000>0000000000000400@00000000000000
00000000000000009@0000`0000100009@0000`000050020E`0002`0000>00008P400><0001G0@00
100006P1<05X0F41>@9Q0CT2H@4U0000300000P0080X000030000040000W00006000004000000000
00000000000U000030000040001F0000:0000=l0001@0@00jP0005/100030000=`9W0D82HP4g0U`1
9@0000`0000700209@0000`000000020:00000`000010000AP0001@000080000AdA9@`<000160000
:00001`00017A4U30P000;X1000_0@00?P8005`100000000G`0003P000010000>0000000000h0000
000000000@010000000000000000000000000000000U000030000040000U0000300000D0081G0000
:0000640000R0@00gP0004/100030000^`4`0K/1E@4d0UD19@0000`000080020:00000`000010000
9`0001P00001000000000000000000009@0000`000010000EP0002P0003J0000A0400>@0001?0@00
0`000382F`4l0UH1<P9@0BD0000<00001`00P2D0000<00000000P2P0000<00000@0004H0000D0000
200004M4BD<30000AP0002P0000L0000AdA9@`80000:0P00;`4004<2001@0@00000005l0000h0000
0@0003P000000000>0000000000000400@0000000000000000000000000000009@0000`000010000
9@0000`000050020E`0002`0002a00008P400><0000o0@00100000/2<04;0TT1>@990CT2B@4U0000
300000P0080X000030000040000W0000600000400000000000000000000U000030000040001F0000
:0000=l0000h0@00jP0004<100030000=`9?0D82BP4g0T@19@0000`0000700209@0000`000000020
:00000`000010000AP0001@000080000AdA9@`<000160000:00001`00017A4U30P000<h1002N0000
E@8004H100000000G`0003P000010000>0000000000h0000000000000@0100000000000000000000
00000000000U000030000040000U0000300000D0081G0000;00007D0002A0000n000038100040000
c`6o0<l1W`1>0Yl0CP8l0BD0000<00002000P2P0000<00000@0002L0000H00000@00000000000000
000002D0000<00000@0005H0000X0000l@0002h1003l0000>04000<000190SX1CP940E@2>P4U0000
300000L0080U000030000000080X00003000004000160000500000P00017A4U30`0002L0000H0000
0@000000003oool0000002D0000<00000@0002H0000L0000100000000001000000000000008U0000
300000@0000Z00006000090200150@00/`8006L1000U000030000000080X000030000040000U0000
300000L0080X0000300000@0000Q0000200001h0000H0000V08004/1002/0P00HP4002D0000<0000
0P0002D0000<00000P0001@0000<00003@000180000<00000@0005@0001P0000@04003l1001?0@00
C040004000000212000P@YP2001;0@000`0004`00000000000000000003ooooooooooe@0001E0580
B@0000L0000700000P000280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@0000d3002<0@008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`000000020AP0002P0000L0000AdA9@`80001O0P00CP400982001K0@00000005l0000h0000
100003P000000000>0000000000000400@0000000000000000000000000000009@0000`000040000
9@0000`000050020E`0002@000060@00AP400381001;0@000P000602E@680U@19@0000`000080020
:00000`0000400009`0001P00004000000000000000000009@0000`000040000EP0002P0000^0@00
@`4003P1001>0@000`0008H2FP6@0U@1QP9?0BD0000<00001`00P2D0000<00000000P2P0000<0000
100004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80002d0@00Y@000;d1002i0000
00000180000<00000@0005l0000h0000100003P000000000>0000000000200400@00000000000000
00000000000000009@0000`0000400009@0000`000050020E`0002@0001N0000W0000680002]0000
0P000;P1]`2h0JX09@0000`000080020:00000`0000400009`0001P0000400000000000000000000
9@0000`000040000EP0002P0001M0000VP0006@0002Q00000`000;`1[@2h0JH0]@6]02D0000<0000
1`00P2D0000<00000000P2P0000<0000100004H0000D0000200004M4BD<30000AP0001@000080000
AdA9@`<0000<00004000000000000000600000`0000000006@0000`0003oool09@0000`000000020
8P0000`0003ooooo3P0001@000000000400001@0
\>"], "Text",
 ImageSize->{347, 347},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Cobalt", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["The model", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompartNumbers", "[", "cobalt", "]"}]], "Input",
 CellLabel->"In[69]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "\<\"Blood\"\>"},
    {"2", "\<\"Systemic A\"\>"},
    {"3", "\<\"Systemic B\"\>"},
    {"4", "\<\"Systemic C\"\>"},
    {"5", "\<\"Bladder\"\>"},
    {"6", "\<\"Urine\"\>"},
    {"7", "\<\"ULI\"\>"},
    {"8", "\<\"LLI\"\>"},
    {"9", "\<\"FEC\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.3992822760088806`*^9, 3.417835770406955*^9, 
  3.4798276262535205`*^9, 3.4798282882326345`*^9, 3.4798294875233994`*^9, 
  3.5185350225925303`*^9, 3.643443742381995*^9},
 CellLabel->"Out[69]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
TableForm[TransferRates[cobalt], TableHeadings -> 
   {None, {\"From\", \"to\", \"Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\"}}]\
\>", "Input",
 CellLabel->"In[70]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"From\"\>",
       HoldForm], 
      TagBox["\<\"to\"\>",
       HoldForm], 
      TagBox["\<\"Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\"\>",
       HoldForm]},
     {"1", "2", "0.4158883083359672`"},
     {"1", "3", "0.13862943611198905`"},
     {"1", "4", "0.13862943611198905`"},
     {"1", "5", "0.5941261547656673`"},
     {"1", "7", "0.09902102579427789`"},
     {"2", "5", 
      FractionBox[
       RowBox[{"Log", "[", "2", "]"}], "7"]},
     {"3", "5", 
      FractionBox[
       RowBox[{"Log", "[", "2", "]"}], "70"]},
     {"4", "5", 
      FractionBox[
       RowBox[{"3", " ", 
        RowBox[{"Log", "[", "2", "]"}]}], "2800"]},
     {"2", "7", 
      FractionBox[
       RowBox[{"Log", "[", "2", "]"}], "42"]},
     {"3", "7", 
      FractionBox[
       RowBox[{"Log", "[", "2", "]"}], "420"]},
     {"4", "7", 
      FractionBox[
       RowBox[{"Log", "[", "2", "]"}], "5600"]},
     {"5", "6", "12"},
     {"7", "8", 
      SubscriptBox["k", "ULI"]},
     {"8", "9", 
      SubscriptBox["k", "LLI"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"From", "to", "Tranfer Rates(\!\(days\^\(-1\)\))"}}]]]], "Output",
 CellChangeTimes->{3.39928227604016*^9, 3.41783577042258*^9, 
  3.479827626316024*^9, 3.4798282882795067`*^9, 3.4798294875390244`*^9, 
  3.518535022623781*^9, 3.643443742397621*^9},
 CellLabel->"Out[70]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "element", ",", " ", "lambda", ",", " ", "fn1", ",", " ", "amad", ",", " ", 
   "class"}], "]"}]], "Input",
 CellLabel->"In[71]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsubsectionIcon"],

Cell["\<\
Here are shown whole body and daily urine an faecal excretion as function of \
the time for a single intake of 1 Bq and for a chronic intake 1 Bq/day of \
Co-57 (decay constant: \[Lambda]  = 271 days) into compartment 1 (Blood) in t \
=0 .\
\>", "MathCaption"],

Cell["\<\
Whole body and daily urine values from day 1 to 10 are the same that Table \
A.3.9 of ICRP 78 (Faecal and values higher that 10 days are not included in \
ICRP ).\
\>", "Commentary"],

Cell[BoxData[
 RowBox[{
  RowBox[{"element", "=", " ", "cobalt"}], ";", 
  RowBox[{"lambda", " ", "=", " ", 
   RowBox[{
    RowBox[{"Log", "[", "2", "]"}], "/", "271"}]}], ";"}]], "Input",
 CellLabel->"In[72]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[73]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.31844900957063005`", "0.01113223133838262`", 
      "0.6678642886438788`"},
     {"2", "0.11373713571269223`", "0.025987746287051954`", 
      "0.5264333670561147`"},
     {"3", "0.04664655696239576`", "0.021201535360309384`", 
      "0.45724051625489276`"},
     {"4", "0.02795621523208943`", "0.013262896099553272`", 
      "0.4148533975372563`"},
     {"5", "0.021552455823926227`", "0.00804366820060073`", 
      "0.38419754276883783`"},
     {"6", "0.01840564937710846`", "0.005279658100159083`", 
      "0.35953081402271564`"},
     {"7", "0.016242655765783317`", "0.003877260474713429`", 
      "0.33849248694297307`"},
     {"8", "0.01447753669489979`", "0.0031199574684619463`", 
      "0.32003032372514706`"},
     {"9", "0.012947204513597403`", "0.0026536075555612442`", 
      "0.30361200365185403`"},
     {"10", "0.011595904885240312`", "0.0023219960835031517`", 
      "0.28891853479239443`"},
     {"20", "0.004097299682829941`", "0.0007921752871493926`", 
      "0.2017943461250369`"},
     {"30", "0.0017293357965421463`", "0.0003230103187478821`", 
      "0.16641397142150097`"},
     {"40", "0.0009447619320778313`", "0.0001692125142327346`", 
      "0.14783971790575381`"},
     {"50", "0.0006537523132394278`", "0.00011349833231461637`", 
      "0.13523706452190412`"},
     {"60", "0.0005207303550055923`", "0.00008899187786800708`", 
      "0.12517955301183378`"},
     {"70", "0.00044182132231768666`", "0.0000750174245392504`", 
      "0.1165281199219256`"},
     {"80", "0.00038439988560537436`", "0.00006510270343152616`", 
      "0.10885722504604964`"},
     {"90", "0.0003378124517755833`", "0.00005715260586949982`", 
      "0.10197016103494011`"},
     {"100", "0.0002982349668863727`", "0.0000504301062302652`", 
      "0.09574896330225637`"},
     {"180", "0.00011943894259480115`", "0.000020142908849518594`", 
      "0.06202012342374923`"},
     {"200", "0.00009728439775546267`", "0.000016393888754231505`", 
      "0.056480755111037416`"},
     {"300", "0.00004120113744310281`", "6.91443266992267`*^-6", 
      "0.03729845834616165`"},
     {"400", "0.000022456180591138655`", "3.7569408826843656`*^-6", 
      "0.02579951869263614`"},
     {"500", "0.00001428687117657194`", "2.3864941397609947`*^-6", 
      "0.018152094092146822`"},
     {"600", "9.739997958961018`*^-6", "1.625968833967862`*^-6", 
      "0.012848221681167294`"},
     {"700", "6.817267473743379`*^-6", "1.1377993782776784`*^-6", 
      "0.009112975635854456`"},
     {"800", "4.81655663016917`*^-6", "8.038179627414512`*^-7", 
      "0.006468263917472746`"},
     {"900", "3.4141376758619903`*^-6", "5.697576922230626`*^-7", 
      "0.004592212276731455`"},
     {"1000", "2.4227838069347168`*^-6", "4.043148967993762`*^-7", 
      "0.003260564846415283`"},
     {"2000", "7.890075314230796`*^-8", "1.3166916745994325`*^-8", 
      "0.00010621442873563723`"},
     {"3000", "2.5702884164650104`*^-9", "4.289283972731761`*^-10", 
      "3.4600647871309106`*^-6"},
     {"4000", "8.373028554731683`*^-11", "1.3972866606318248`*^-11", 
      "1.127158379514252`*^-7"},
     {"5000", "2.7276163534527698`*^-12", "4.55183201763581`*^-13", 
      "3.6718561375918547`*^-9"},
     {"6000", "8.885543531803427`*^-14", "1.482814894072714`*^-14", 
      "1.1961519995957679`*^-10"},
     {"7000", "2.8945743691478023`*^-15", "4.830450687919841`*^-16", 
      "3.896611284654825`*^-12"},
     {"8000", "9.429429666885257`*^-17", "1.5735783300846016`*^-17", 
      "1.2693687348121822`*^-13"},
     {"9000", "3.0717519228552938`*^-18", "5.126123670210353`*^-19", 
      "4.135123745250374`*^-15"},
     {"10000", "1.0006607195660013`*^-19", "1.669897416601517`*^-20", 
      "1.3470670829988203`*^-16"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992822761965594`*^9, 3.417835770563205*^9, 
  3.479827626534785*^9, 3.479828288466996*^9, 3.4798294876796436`*^9, 
  3.518535022733158*^9, 3.6434437424601216`*^9},
 CellLabel->"Out[73]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[74]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVx3k81PkfwHFXB+P2rabLTxmVqXGU2JDPJ4Vi2dhCosNRbVHoIIttcqXI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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV0ns4lHkfBvDnmXlmJodxfMxOmyR0MCWUeEPz+zml2pct62J3FJJsJ6dQ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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -6.221372413200389}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-6.221372413200389, 0.25478969876467206`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992822780264273`*^9, 3.41783577239133*^9, 
  3.4798276275660877`*^9, 3.4798282894669385`*^9, 3.479829488851474*^9, 
  3.51853502412381*^9, 3.643443742569496*^9},
 CellLabel->"Out[74]="]
}, Open  ]],

Cell["\<\
Even, it can applied input variable in the time. In this example is evaluted \
the retention the 5 days after the start a continuous  intake I = 6 +4.3 \
Cos[-0.5 t] Bq/day of Co-57  into compartment 1 (Blood).\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "cobalt", ",", "\"\<Injection\>\"", ",", "\"\<Continuous\>\"", ",", 
   "\"\<CompartmentContent\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"6", "+", 
      RowBox[{"4.3", " ", 
       RowBox[{"Cos", "[", 
        RowBox[{
         RowBox[{"-", "0.5"}], " ", "t"}], "]"}]}]}], ",", " ", "t"}], "}"}], 
   ",", "1", ",", "5", ",", 
   RowBox[{
    RowBox[{"Log", "[", "2", "]"}], "/", "271"}]}], "]"}]], "Input",
 CellLabel->"In[75]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"qB", "[", "5", "]"}], "\[Rule]", "2.708024303547506`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "2"], "[", "5", "]"}], "\[Rule]", 
    "7.27100203950426`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "3"], "[", "5", "]"}], "\[Rule]", 
    "3.1241010171397465`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "4"], "[", "5", "]"}], "\[Rule]", 
    "3.2098227523961222`"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["q", "5"], "[", "5", "]"}], "\[Rule]", 
    "0.201664943164724`"}], ",", 
   RowBox[{
    RowBox[{"qURI", "[", "5", "]"}], "\[Rule]", "15.710406698570523`"}], ",", 
   RowBox[{
    RowBox[{"qULI", "[", "5", "]"}], "\[Rule]", "0.25469031554988686`"}], ",", 
   RowBox[{
    RowBox[{"qLLI", "[", "5", "]"}], "\[Rule]", "0.533355934989611`"}], ",", 
   RowBox[{
    RowBox[{"qFEC", "[", "5", "]"}], "\[Rule]", "1.8639656897497616`"}], ",", 
   RowBox[{
    RowBox[{"qWB", "[", "5", "]"}], "\[Rule]", "17.302661306291895`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.39928229020991*^9, 3.417835786906955*^9, 
  3.4798276463170476`*^9, 3.4798283056535063`*^9, 3.4798295042258835`*^9, 
  3.518535034811515*^9, 3.6434437465382833`*^9},
 CellLabel->"Out[75]="]
}, Open  ]],

Cell["\<\
Here is represented the predicted values (Bq per Bq/day intake) for a chronic \
intake of 1 Bq/day.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "cobalt", ",", "\"\<Injection\>\"", ",", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "1", ",", "180", ",", 
   RowBox[{
    RowBox[{"Log", "[", "2", "]"}], "/", "271"}]}], "]"}]], "Input",
 CellLabel->"In[76]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVx3k81PkfwHFXB+P2rabLTxmVqXGU2JDPJ4Vi2dhCosNRbVHoIIttcqXI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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV0ns4lHkfBvDnmXlmJodxfMxOmyR0MCWUeEPz+zml2pct62J3FJJsJ6dQ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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -6.221372413200389}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-6.221372413200389, 0.25478969876467206`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992822920710583`*^9, 3.417835788750705*^9, 
  3.479827647598363*^9, 3.479828307715887*^9, 3.479829505663328*^9, 
  3.5185350359052863`*^9, 3.6434437467414093`*^9},
 CellLabel->"Out[76]="]
}, Open  ]],

Cell["\<\
 Here is assumed a variable intake I = {2.3 Exp[-0.05 t] Bq/day of Co-57  \
into compartment 1 (Blood).\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "cobalt", ",", "\"\<Injection\>\"", ",", "\"\<Continuous\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"2.3", " ", 
      RowBox[{"Exp", "[", 
       RowBox[{
        RowBox[{"-", "0.05"}], " ", "t"}], "]"}]}], ",", " ", "t"}], "}"}], 
   ",", "1", ",", "180", ",", 
   RowBox[{
    RowBox[{"Log", "[", "2", "]"}], "/", "271"}]}], "]"}]], "Input",
 CellLabel->"In[77]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVV3c41f8Xx7VXxiWKJCpk11eSOp9klJJRIS2rSMi+qOy9iowIJcpIQrL1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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV13lcTc0fB/Bz723Tvtzopkjbo7QqRaoZVLJTaZUISRtKIqQF0YY8okWJ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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -7.364645072828002}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-7.364645072828002, 0.6757882493517279}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Continuous intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282294573442*^9, 3.417835791219455*^9, 
  3.479827648832801*^9, 3.4798283090126877`*^9, 3.479829506960153*^9, 
  3.518535036967807*^9, 3.643443746960162*^9},
 CellLabel->"Out[77]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsubsectionIcon"],

Cell[TextData[{
 StyleBox["Here is computed the retention all compartment  ",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"],
 "for a single intake by ingestion ",
 Cell[BoxData[
  SubscriptBox["I", "0"]]],
 "= 1 of Co-60 (\[Lambda] = 5.27 y) ",
 StyleBox["f1 = 0.05 ",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"],
 "in t =0",
 StyleBox[".",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"],
 StyleBox["\:f35f",
  FormatType->StandardForm]
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"lambda", " ", "=", " ", 
   RowBox[{
    RowBox[{"Log", "[", "2", "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"5.27", "*", "365.24"}], ")"}]}]}], ";", 
  RowBox[{"fn1", " ", "=", " ", "0.05"}], ";"}]], "Input",
 CellLabel->"In[78]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[79]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.013624951907567117`", "0.2719943288386952`", 
      "0.7140206729830297`"},
     {"2", "0.007254805597013336`", "0.3696619743191493`", 
      "0.3368468125863517`"},
     {"3", "0.002761807850018189`", "0.1866976804736686`", 
      "0.14726604382399355`"},
     {"4", "0.0015322156830239208`", "0.07726230016902738`", 
      "0.06841850538206162`"},
     {"5", "0.0011365834388528584`", "0.029958321848542486`", 
      "0.0372989662669561`"},
     {"6", "0.0009590033866396809`", "0.011367394927771222`", 
      "0.02495913859883955`"},
     {"7", "0.0008444877783174565`", "0.004319360518802397`", 
      "0.019786303856947123`"},
     {"8", "0.000753366232309855`", "0.0016831473847287888`", 
      "0.01734266625499371`"},
     {"9", "0.0006748899167574732`", "0.0006987045920523357`", 
      "0.015962827583874666`"},
     {"10", "0.0006056291246357999`", "0.0003275571942317364`", 
      "0.015023893908465617`"},
     {"20", "0.00021818715757101066`", "0.00004221609415138822`", 
      "0.010592576004313303`"},
     {"30", "0.00009370472153103933`", "0.000017516985259220096`", 
      "0.00890916013264853`"},
     {"40", "0.00005204784822717432`", "9.329435695106524`*^-6", 
      "0.008083176027764948`"},
     {"50", "0.00003667330643387536`", "6.369820910746024`*^-6", 
      "0.0075557033747081954`"},
     {"60", "0.000029802842266282317`", "5.094286006549901`*^-6", 
      "0.007148073988986085`"},
     {"70", "0.000025828137215563128`", "4.385742166937367`*^-6", 
      "0.006801324168039252`"},
     {"80", "0.00002296359985052474`", "3.889281577988477`*^-6", 
      "0.006494383085242017`"},
     {"90", "0.000020626249725629805`", "3.4896895741531307`*^-6", 
      "0.006218360015534415`"},
     {"100", "0.000018613078429592573`", "3.1474084875324493`*^-6", 
      "0.0059684421520834734`"},
     {"180", "8.883893275729588`*^-6", "1.4982450095749914`*^-6", 
      "0.004607790312002112`"},
     {"200", "7.560372823670639`*^-6", "1.2740470736297666`*^-6", 
      "0.004384583613393248`"},
     {"300", "3.986656285953466`*^-6", "6.690514396355266`*^-7", 
      "0.003606600224415847`"},
     {"400", "2.7057984912317755`*^-6", "4.52684777265593`*^-7", 
      "0.0031076835317966774`"},
     {"500", "2.144112779552918`*^-6", "3.5815557331258666`*^-7", 
      "0.0027238628563417294`"},
     {"600", "1.8208528502335635`*^-6", "3.039684551910611`*^-7", 
      "0.002401819382960374`"},
     {"700", "1.587650515199475`*^-6", "2.649783420357016`*^-7", 
      "0.0021222584649381203`"},
     {"800", "1.3973924386581826`*^-6", "2.332058624843498`*^-7", 
      "0.0018765805113348506`"},
     {"900", "1.2339651858883681`*^-6", "2.0592642854724602`*^-7", 
      "0.001659751457051989`"},
     {"1000", "1.0908819180536975`*^-6", "1.8204670738998446`*^-7", 
      "0.0014681000615082301`"},
     {"2000", "3.1986113167998956`*^-7", "5.3378259691803906`*^-8", 
      "0.0004305898996216266`"},
     {"3000", "9.381660372994716`*^-8", "1.5656066151063127`*^-8", 
      "0.0001262938139293229`"},
     {"4000", "2.751680128036877`*^-8", "4.591989519800865`*^-9", 
      "0.00003704250252798872`"},
     {"5000", "8.070792616656589`*^-9", "1.3468496841095743`*^-9", 
      "0.000010864720534166096`"},
     {"6000", "2.3671971461142713`*^-9", "3.9503663145661516`*^-10", 
      "3.186667860691637`*^-6"},
     {"7000", "6.943087989904656`*^-10", "1.1586589211387506`*^-10", 
      "9.346629784384452`*^-7"},
     {"8000", "2.0364366742621028`*^-10", "0", "2.741405510249254`*^-7"},
     {"9000", "0", "0", "8.040656734025024`*^-8"},
     {"10000", "0", "0", "2.3583581660103857`*^-8"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282295152118*^9, 3.417835791781955*^9, 
  3.4798276494578333`*^9, 3.4798283097157717`*^9, 3.479829507600754*^9, 
  3.5185350373271885`*^9, 3.643443747100789*^9},
 CellLabel->"Out[79]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[80]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVz3k4lesaBvBlaPrW9C2+WA27y0GdCIuIirxvZoWiDp21pUhpQm07HBlS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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV13c81u0XB/B7GGXTrYdCRIrKiFRS11UhRGYkQpIkyYinKamUWelpiESp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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -5.632252512797589}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-5.632252512797589, 0.4625201544163534}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282297591943*^9, 3.417835794219455*^9, 
  3.479827651520439*^9, 3.4798283111688137`*^9, 3.4798295091163206`*^9, 
  3.5185350386709642`*^9, 3.643443747335165*^9},
 CellLabel->"Out[80]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["Here is computed the whole body retention and the urine and faecal \
excretion for f1 = 0.1 using the function ",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"],
 StyleBox["BioassayReport ", "Input"],
 "for a single intake ",
 Cell[BoxData[
  SubscriptBox["I", "0"]]],
 "= 1 of Co-60 (\[Lambda] = 5.27 y) in t =0 ",
 StyleBox[".",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"],
 " ",
 StyleBox[" ",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"],
 StyleBox["\:f35f",
  FormatType->StandardForm]
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"lambda", " ", "=", " ", 
   RowBox[{
    RowBox[{"Log", "[", "2", "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"5.27", "*", "365.24"}], ")"}]}]}], ";", 
  RowBox[{"fn1", " ", "=", " ", "0.1"}], ";"}]], "Input",
 CellLabel->"In[81]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[82]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.027485139147156747`", "0.2614094898383677`", 
      "0.7107453247437683`"},
     {"2", "0.014354447482729127`", "0.35055895510657914`", 
      "0.3455760209508634`"},
     {"3", "0.005478742339908321`", "0.17676272228078682`", 
      "0.16321013297257897`"},
     {"4", "0.003051622416906469`", "0.07332823231221247`", 
      "0.08677151504374168`"},
     {"5", "0.002268557087468656`", "0.02858780152508444`", 
      "0.0558839146707935`"},
     {"6", "0.0019155995350097477`", "0.010970603526486874`", 
      "0.04297759081422713`"},
     {"7", "0.0016872554414738758`", "0.004272115333820033`", 
      "0.03700274611763659`"},
     {"8", "0.0015053058033398928`", "0.0017536763402771973`", 
      "0.03373044127327392`"},
     {"9", "0.0013485349314794365`", "0.0008031275467793444`", 
      "0.03156663427542538`"},
     {"10", "0.0012101553367287498`", "0.0004362576617184274`", 
      "0.029908855828028557`"},
     {"20", "0.0004360239938439245`", "0.00008435266029207473`", 
      "0.021180949371012812`"},
     {"30", "0.00018729506602911382`", "0.00003501136574595643`", 
      "0.01781651326441198`"},
     {"40", "0.00010405586396315509`", "0.00001865110993671278`", 
      "0.01616534536228958`"},
     {"50", "0.00007333061451108016`", "0.000012736613112319205`", 
      "0.015110695895126355`"},
     {"60", "0.0000595975557492502`", "0.000010187094663478256`", 
      "0.014295569677581534`"},
     {"70", "0.00005165096109995218`", "8.770552467786528`*^-6", 
      "0.013602146940440847`"},
     {"80", "0.0000459230768251977`", "7.777854508005304`*^-6", 
      "0.012988320305490925`"},
     {"90", "0.00004124902261143388`", "6.978786740987819`*^-6", 
      "0.012436319518048461`"},
     {"100", "0.00003722312463788983`", "6.294302053852646`*^-6", 
      "0.011936522867184265`"},
     {"180", "0.00001776660507295328`", "2.996289825339325`*^-6", 
      "0.009215408070665957`"},
     {"200", "0.000015119806553641175`", "2.5479350447622537`*^-6", 
      "0.008769020369809893`"},
     {"300", "7.97300283767571`*^-6", "1.338050465713521`*^-6", 
      "0.007213122980144541`"},
     {"400", "5.411481288867548`*^-6", "9.053500272789352`*^-7", 
      "0.006215314469436709`"},
     {"500", "4.2881713141559445`*^-6", "7.163020273006811`*^-7", 
      "0.005447684030357493`"},
     {"600", "3.6416723299124786`*^-6", "6.079313211772526`*^-7", 
      "0.004803603365857324`"},
     {"700", "3.175275951793613`*^-6", "5.299524927853894`*^-7", 
      "0.004244486062968405`"},
     {"800", "2.794764042588446`*^-6", "4.664082462021399`*^-7", 
      "0.0037531338545384353`"},
     {"900", "2.467912351907703`*^-6", "4.1184984937752635`*^-7", 
      "0.0033194789232681723`"},
     {"1000", "2.181748020826735`*^-6", "3.640907753607006`*^-7", 
      "0.00293617891399697`"},
     {"2000", "6.397176437831979`*^-7", "1.0675574847113434`*^-7", 
      "0.0008611735804729281`"},
     {"3000", "1.8763185251893292`*^-7", "3.1311906190274794`*^-8", 
      "0.00025258580386736525`"},
     {"4000", "5.503320515088661`*^-8", "9.183912720051366`*^-9", 
      "0.00007408447007172146`"},
     {"5000", "1.614146867134521`*^-8", "2.693679916418899`*^-9", 
      "0.00002172928415521687`"},
     {"6000", "4.7343601041177715`*^-9", "7.900675576189581`*^-10", 
      "6.373289698111593`*^-6"},
     {"7000", "1.3886075704650616`*^-9", "2.3173011084100878`*^-10", 
      "1.8693124580592041`*^-6"},
     {"8000", "4.0728439374014137`*^-10", "0", "5.482771427902792`*^-7"},
     {"9000", "1.1945821188973243`*^-10", "0", "1.6081197341314207`*^-7"},
     {"10000", "0", "0", "4.716682271564436`*^-8"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282298186259*^9, 3.41783579479758*^9, 
  3.4798276521923485`*^9, 3.4798283118094015`*^9, 3.479829509756921*^9, 
  3.518535039077222*^9, 3.643443747475792*^9},
 CellLabel->"Out[82]//TableForm="]
}, Open  ]],

Cell["\<\
Whole body and daily urine values from day 1 to 10 are the same that Table \
A.3.26 of ICRP 78 (Faecal and values higher that 10 days are not included in \
ICRP ).\
\>", "Commentary"]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsubsectionIcon"],

Cell[TextData[{
 "Here is shown the Report for an inhalation  acute intake\"1\" of Co-60 (\
\[Lambda] = 5.27 y) with ",
 Cell[BoxData[
  SubscriptBox["f", "1"]]],
 "=0.05 (Type S), AMAD 5."
}], "MathCaption",
 CellTags->"ICRP 78"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"lambda", " ", "=", " ", 
    RowBox[{
     RowBox[{"Log", "[", "2", "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"5.27", "*", "365.24"}], ")"}]}]}], ";", 
   RowBox[{"fn1", " ", "=", " ", "0.05"}], ";", "  ", 
   RowBox[{"amad", "=", " ", 
    RowBox[{"AMADAdultW", "[", "5", "]"}]}], ";", 
   RowBox[{"class", " ", "=", " ", "S"}], ";"}], " "}]], "Input",
 CellLabel->"In[83]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[84]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Lung\\nretention\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.06425238283930051`", "0.0056541577318486025`", 
      "0.10988429321780167`", "0.4897186792181673`"},
     {"2", "0.06264865081239229`", "0.003134074326897863`", 
      "0.15498702461867106`", "0.2527153514339645`"},
     {"3", "0.06186826342790703`", "0.0012083109164636283`", 
      "0.07965195288415691`", "0.142820237832646`"},
     {"4", "0.0612122377374881`", "0.000673650777509798`", 
      "0.03353474991682559`", "0.09791639749726647`"},
     {"5", "0.0605857455508689`", "0.0005018324323583243`", 
      "0.01340582930524449`", "0.08005917565535349`"},
     {"6", "0.05997563184726287`", "0.0004256845652169087`", 
      "0.005449566169940888`", "0.07271562558689512`"},
     {"7", "0.059379798538629264`", "0.0003771433497867419`", 
      "0.002417748987819595`", "0.06936518970723331`"},
     {"8", "0.05879765175896909`", "0.0003386947290380301`", 
      "0.001274250103266084`", "0.06753259850946637`"},
     {"9", "0.05822880940571218`", "0.000305599764331281`", 
      "0.0008390548216669767`", "0.06629203893448571`"},
     {"10", "0.05767292607702852`", "0.0002763635108601747`", 
      "0.0006672528758903097`", "0.06529822709169424`"},
     {"20", "0.052757951780823216`", "0.00011125934252084686`", 
      "0.0004353587938424133`", "0.058360322375177985`"},
     {"30", "0.04882400678617338`", "0.0000561696824429236`", 
      "0.00033971052801219507`", "0.053596011326339364`"},
     {"40", "0.045650083877093114`", "0.00003617506078680623`", 
      "0.00027014225171079014`", "0.049975039417926435`"},
     {"50", "0.043066724885656216`", "0.000027657743516708918`", 
      "0.00021749655640918193`", "0.04708989202730984`"},
     {"60", "0.04094368035059834`", "0.00002311436320482539`", 
      "0.00017689588716751474`", "0.044731429960230024`"},
     {"70", "0.039180588395192825`", "0.000020118763740152544`", 
      "0.00014527786908564676`", "0.04277116780726427`"},
     {"80", "0.03769992093625987`", "0.000017853425101700284`", 
      "0.0001205085957112977`", "0.04112002207325952`"},
     {"90", "0.03644163520995515`", "0.000016017383850456096`", 
      "0.0001010181272889415`", "0.03971209389772524`"},
     {"100", "0.03535911000499482`", "0.00001448084698064649`", 
      "0.00008562104317638438`", "0.03849708992198986`"},
     {"180", "0.02996620703529719`", "7.826845641814561`*^-6", 
      "0.00003451014457180519`", "0.03242768355909543`"},
     {"200", "0.02904928817229443`", "7.002084355913039`*^-6", 
      "0.000030385152375418935`", "0.031405818282614704`"},
     {"300", "0.025289330212555944`", "4.749125877628223`*^-6", 
      "0.000021550761314423323`", "0.027288322711885214`"},
     {"400", "0.022209050849659163`", "3.792673904430003`*^-6", 
      "0.000018066890729569245`", "0.023980558624462734`"},
     {"500", "0.019549847285393145`", "3.2356193689007835`*^-6", 
      "0.000015569876271551742`", "0.021143456388198274`"},
     {"600", "0.017235397422902265`", "2.8288754864909923`*^-6", 
      "0.00001348152891194791`", "0.018676166665913343`"},
     {"700", "0.015217370728911016`", "2.495873865418818`*^-6", 
      "0.000011685811481583839`", "0.016522122592465757`"},
     {"800", "0.01345616677261069`", "2.2102244982806154`*^-6", 
      "0.00001013378072367115`", "0.014638419878652253`"},
     {"900", "0.011917794749566318`", "1.960889942506834`*^-6", 
      "8.79080297438708`*^-6", "0.012989314539479324`"},
     {"1000", "0.010572866837372649`", "1.7418381047748837`*^-6", 
      "7.62826760153618`*^-6", "0.01154419432552997`"},
     {"2000", "0.003541098239098354`", "5.653282731561881`*^-7", 
      "1.8908293046428738`*^-6", "0.003911670903877166`"},
     {"3000", "0.001449783097775712`", "2.0837572270691147`*^-7", 
      "5.037898798381338`*^-7", "0.001600768423288537`"},
     {"4000", "0.0007002869318362227`", "8.842501915658284`*^-8", 
      "1.526957557905813`*^-7", "0.0007682541562206018`"},
     {"5000", "0.00037397327495628793`", "4.245990342632823`*^-8", 
      "5.536797296818273`*^-8", "0.0004080021508355185`"},
     {"6000", "0.00021008103857197123`", "2.226247955731015`*^-8", 
      "2.4024776610117593`*^-8", "0.00022867275297225063`"},
     {"7000", "0.0001208792663472174`", "1.232136378416932`*^-8", 
      "1.1865604787913248`*^-8", "0.0001316527894565067`"},
     {"8000", "0.00007038938236121361`", "7.033877258877947`*^-9", 
      "6.303043883627254`*^-9", "0.00007685381408118603`"},
     {"9000", "0.00004127322040572003`", "4.086985948806501`*^-9", 
      "3.469379674413519`*^-9", "0.0000452273883030919`"},
     {"10000", "0.000024319780787619006`", "2.400136117861927`*^-9", 
      "1.9414265409037485`*^-9", "0.000026763707859817925`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Lung\nretention", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992823028000293`*^9, 3.41783580004758*^9, 
  3.47982765672383*^9, 3.4798283164341354`*^9, 3.4798295153660803`*^9, 
  3.5185350418429003`*^9, 3.6434437485695505`*^9},
 CellLabel->"Out[84]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[85]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAA2C12NM1yfD51nKxBcIIFwH1iX+iS
GFo/zr5I51p/BcCR+cQCWhhqP89YhYlFfAXAG8X3jz0Yej/4gdnDGnYFwOAq
kVYvGIo/o33AD8VpBcDC3d05KBiaP0XoHQMZUQXAMzeEqyQYqj/gIqRMvh8F
wOxjV+QiGLo/53YRDv68BMD6A0a8FDHLPxX/26Cr5gPA4qK9VhEz1D/y7+CJ
RR4DwFIVovturNo/P6+vs4RZAsBNhiT/ItngP7+adOO/gwHA470+KhEg5D9j
s9ky67sAwOY3OgQ8rec/2jynPAHG/7+umlo00inrP8QRqUtmG/6/Z7lBDmtq
7j/EWVyZ6Yz8v0cNhUug+PA/TjhSOkzc+r/Tm8xkDJ7yP/xxaWIOSPm/wZ4m
KS479D/WBx98ibv3v+ZC8URu+/U/jb167jMN9r8DRZ+1r533PyfG8mS2e/S/
V+i9fQ9j+T8qOu+Wvcjyvw0A7/AkIPs/koLIuCMe8b+8dQO5O7/8P99pll6o
Ie+/oYyI2HCB/j9LdXEtXcXrv8CAeKbTEgBAj09mpDOk6L/LC2UMfvYAQKFA
qwh4QuW/B9HaRwPWAUAr179mVfPhvz9Fwi2JpgJAjfhUf+m/3b8TCmI/nogD
QA8xJu3GG9e/431z+7NbBEDrbOzEBfDQv+QrDo2kKgVANpWA/mHWxb+AKmFK
JAsGQOBMeYhgtbG/GdglsqTcBkCaqFZNYHiZP03WokW0vwdA34pfAX4jwD+y
Dqmunp4IQO1vXwitwcw/FPYgwoluCUCuK+ns/DbUPxEuUQEEUApAI6MVLRt9
2j8KFfPqfiILQJg7OmgtJeA/NTYeqtTwC0DxHSlLUPbiP/unAZW50AxA4p0P
3N/85T+9yFYqn6ENQMeiwVPrx+g/Gjpk6xOEDkAYu5oro8brP3Ra41aJVw9A
AFeNt6eK7j9/2vXLbBMQQBPO6LK6nPA/EjBWgtyDEEDjwL7JOA3yPyNd743M
7BBA9/p9yYth8z+BsmQvhF4RQPLcmh2qzvQ/+KSeOynOEUCDLaOKsjH2P+1u
EZ1ONhJAZhIpDh169z8wYWCUO6cSQPY9nfqH2/g/8Sro4KgQE0DEvhf7QyP6
P8uRNJgDeBNAE37iCr1i+z/yIF3lJegTQAuClWSKu/w/l4e+h8hQFEBUL3P7
t/v9P3hcb7+bUhRAn0qCSkoB/j9aMSD3blQUQOl7JXzcBv4/HtuBZhVYFEDb
yxyHABL+P6QuRUViXxRA8dB1O0co/j+y1csC/G0UQGb0bxrPVP4/zCPZfS+L
FEAAHO2MyK3+P674ibUCjRRA5qeXJVez/j+PzTrt1Y4UQEz7IqDluP4/Unec
XHySFEDhKLk6AsT+P9nKXzvJmRRAwWHlBDra/j/mceb4YqgUQNdPrOSjBv8/
yEaXMDaqFEC/ueqWMAz/P6obSGgJrBRAtbBoKr0R/z9txanXr68UQL1J9PTV
HP8/9Bhttvy2FEDEf/YWBjP/P9btHe7PuBRA5ADf0ZE4/z+3ws4lo7oUQJoV
pG0dPv8/emwwlUm+FEAK0o5HNEn/P1xB4cwcwBRA32mZhb9O/z8+FpIE8MEU
QGp1SqRKVP8/IOtCPMPDFECC8JOj1Vn/PwHA83OWxRRAPaVng2Bf/z9GkFg/

        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV0Hs0lPkfB3CGVuX2zPM8w7hlKoTKpUJFvl9EbamkDb8piZQSynaTomQQ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        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV1Xk01Pv7APCxlezL5I4l2epGWYoo5P3RpdBCEl1rpLJERH3LRYhImcq9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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -6.817231562519426}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-6.817231562519426, 2.758786943826105}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Lungs\"", 11, StripOnInput -> False], 
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282314420475*^9, 3.41783581264133*^9, 
  3.479827663099157*^9, 3.479828322699399*^9, 3.4798295228657923`*^9, 
  3.518535047452383*^9, 3.64344375002269*^9},
 CellLabel->"Out[85]="]
}, Open  ]],

Cell["\<\
Whole body and daily urine values from day 1 to 10 are the same that Table \
A.3.25 of ICRP 78 (Values higher that 10 days are not included in ICRP ).\
\>", "Commentary"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Caesium", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["The model", "SubsubsectionIcon"],

Cell["Biokinetic model for caesium (ICRP 78)", "Text"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@001AgX0@0005P00000000000000:H100270@00
000000000023:`00=2P00215CDH00040j1d501400002000000000000002k000080<005P2003C0000
WP0004H0000TS@8068d204M4BD<1002000<002S5e]/0000008d200402@000g=60@0104I40@0000<0
000N00D0000;0P000005000030:40J@11@800?L000<00@00003oool0K`020000000Y30P03@P10:h5
0000>_P0_`DX000Y000008P0n;l505@mg`050000l000002L4P0204<00Oko00009P000000003V01oJ
1P1lQll05S[h0<03;`03b0`0@`4X08L1MP1O1:h01Nh50=X60P00O8L0k`6^00GXVP37GR/0Fc5K03J7
T`01?8L0IUng01MNQ`0G:m`07`/00<d:c`0FQ8L0gc9>08LG:`00000004L00?`2o002<0@0o?ol0?lX
0`140V@0P00004j75`0[0000A`3l00;l0P1700000000000000000000000C0?Q_003Dmfl00<@n0?No
7`000000Md;g0;oPn@3k_i00[ONo0>3in`2oFQl0m[oo0?M_000100000;3g06l0000000000OQ_003R
4`3g_cL00@000<DBm`2oCW40K`0F0000003G@OL0_aci06l0000000000@000004n@1_03@0H_No0?og
K`005P00000L0?U_001J7oH0_`0000000@0000000000003XPP180000051403YLA011E4l0Dea<06UR
LP1_G4T0@e9@05a3H@1ULfT0MFd^06MYIP0020000<lF07:8:P0l=?P0K`00000000170?`00_`20000
<0040000o?oo0?olo`3oobP00`0004@20000I800000>0000000005h0R==i0?ooO`0ZLXP0@Cc_01Ko
o`1o:P00000007lZ700m0000UXP00003001@GTD000h?0;LG0000;XT0ObX00017003l0Q`0?@800000
0P00caH0gXR501V_5`01000002j907lZ0000A`00b`bg01NW6P2_5`000000000000000000003l0898
001PnVl00<@n0?No7`000000Md;g0;oPn@3k_i00[ONo0>3in`2oFQl0m[l00000000100000>8C0?No
=`010000aA;g0;nQL@000000000004]Sm`2o000000010000001<iFL0PCa;04<01@02K`00FQof0;l0
0000020000000>1[n@1D/7D0`0400=R/^`0?ML000@0`09=D/01e`04000D000201@0=06P0nDl001`1
0000ah80mkl0001=0024nTl0080500d000000000J?U?0000001=0440000000`0C@00d0D000000000
0010000008:40?No@@000000VHCg0;l0001=0000000000000000000000000000003T_D@008Si04l0
n02QCP00S?U?0008P`180?l0oooo06ciC`00C[h0A0280?U?00040000=08000<0000e00@000070@<0
AT@104<?803<0000Q@6U0@0000250JD1000002P0002U0@00Q@40004020000000B8@20<@>00343P00
0040000000000000oooo0080K`00000020`Y00483@001Jh0n3X002P5_`00:@00R00000Fon03O?E@0
00050000l00BW000@`020?on0@0V000000000>H00006fQl0chMl0?Pj5P0_0l003<P302P1@`1f0HL0
[PAO00G^1@021]X0Qg`00:h1k`2Jj0D0:ek705/aF`2CQcH0Qc`10;MOIP27GQL0g2/G000;7`3?2/d0
Qh@F04hbg`0[5hL000000017003l0_`013020?coo003:?l0I0940000P00GQdh0000[0?`0A`02o080
0017000000000000000001<00000KoP0KoOD03k4000O_oL000000?M2M`3ih;l0T;ok0;og[@3knN00
7eZo0?nomP00KoL000010?N`000006l0000006oh0@0ChP00=kog00000@3g4/D0LDjo01H0K`000000
md7G0?TL_`0006l0000000000@3i1000=01_0;ogHP1_mol001H001`00000KoT0mQmJ0000_`010000
000000000022j000001804A@0014G3X0CeA104aLD`1bHVT0BEa_051B@`1Q@e`0JG=U02i]M@1VJFL0
00P001K?000ZR780n3@l0000K`000000o01700;l0P0`000000040?ooo03oo?l0:?oo00000`000T@0
P6@000h000000000GP0007WCR01oool0R78Z0>ll@@3ooaH002Yo0000000L:Wl0000m0028UP000`00
AEi@00l>00005kL0RBh0000ZO`00A`0070;l0002?@0200005/l008F8gP0G[aT0000108T^0000:Wl0
04L00;L<b`0JYaL001N_00000000000000000?`00000B880KoYP03k4000O_oL000000?M2M`3ih;l0
T;ok0;og[@3knN007eZo002omP000000000101?R000g_oL000010?LBa@1aXKl000000000003gHd/0
002o004000000000InE<04/lP@0504<006l20?HOFP000;l080000000003iJn00MK1D0001`02k[=P0
`7D?03000@2`E9<00L1e00050005P000J00=001?n@000A`0P/L0002om`00C@00CoZ400F0000000d0
000004oiJ0000000@@1=0000001=00`01M00000000000000001008B20011_oL000000?N4V@000;l0
001=0000000000000000000000000000A;gT0?V8003h04l004jQ04oiS0232000o`180?ooo`1?nF`0
_Th008P0A000CoT00@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@010@410@4000000041000000410000004100000041000000410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@400@410@4100410@0100410@400@010@410@010@400@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100410@410@010@400@010@410@400@410@400@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@0000000@41000000400000000100410@41000000010000
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@400@410@4100410@0100410@400@010@410@010@40
0@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100410@410@4000000@4000000@4000000@40
00000@4000000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@40000000010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41000000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400000
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
000000000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410000000000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410000000000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@000@400@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410001
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000000000
0000000000000000000000000000000000000000000000000000000000010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@4100010@41004100400@400@40
00010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@40004100410@010@010041
00400@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@4100410@010@400@40
0@010@0100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@010@400@41
004100400@400@0000000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@400@41
00410@000@01004100400@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
00410@010@4000000@0000410@0000410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@010@400@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@0000000@00000000400@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@400@410@400@410@4100410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@4100410@4100410@410@010@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@010@410@010@410@400@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@400@410@400@410@4100410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@4100410@4100410@410@010@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@010@410@010@410@40
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@400@410@400@41
0@4100410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000041
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
00010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@0000000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@00000000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@40000000000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410000000000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@0100010@010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@000000000000000000000000000000000000000000
00000000000000000000000000010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@0000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4000000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@41000000010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410000000000410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@00000000010@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@00000000000@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@40004100410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410001
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@00
000000000000000000000000000000000000000000000000000000000000000000000@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4000000000000000000000000000000000000000000000000000000000000000000000
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100010@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@41000000000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@40000000410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410041000000000@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@000@410@4100410@4100010@410@41000000410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@41000000000@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@0000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000010@410@41
0@410@410@410@410@410@410@410@010@010@410@010@41004100410@410@010@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@0000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000@41
0@410@410@410@410@410@410@410@410@410@400@410@0100410@410@010@410@400@410@010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410000000000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@4100410@400@010@410@010@410@4100410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41000000000@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@0000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@010@4100400@410@010@410@410@01
0@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000041
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@4100010@41004100410@010@410@41
0@40000000410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@00
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@4100410@410@010@010@400@40
0@410@41004100410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@010@410@400@400@41
0@000@410@410@010@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@400@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@4100410041
0@410@410@410@410@410@4100410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@40
00410@410@410@410@410@410@410@0000010@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000000@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41000000010@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000000@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000000041
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400000
00010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0000004000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@00
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@0000410@4000010@010@010@40
0@4000010@41000000400@410000004100410@010@4000410@010@010@000@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@010@400@400@400@400@40
0@410041004100410041000100410@010@010@010@400@400@400@400@400@400@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@4100010@410@0100410@01
004100410@010@010@400@010@400@010@400@400@400@41004100410@010041004100410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@010@410@410@01
0@400@010@010@400@400@410041000100400@410041004100410@010@0000000@010@010@010@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@400@410@41
0@400@4100400@400@41004100410@010@41000100410@010@010@010@400@400@4100400@400@40
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@40000000010@01000000010@000000
0@4000000@4000000@010@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410041
0@410@4100410001000100010@010@010@000@000@400@000@400@40004000410041004100010041
004100410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@40
00000@410000000100410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@4100410@4100400@010@400@40
0@4100400@4100400@4100400@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@010@410@410@4000010@00000100010@4000010@4100000@4000000@000000004000410@400041
0@00000100400@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@400@4100410@010@410@010@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@010@410@0100400001
004100410@0100410@010000000100410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@4100010@4000410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@400@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@4100410@400@400@410@400@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@400@410@010@01
0@4100010@010@400@010@400@010@400@010@410@410@000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@010@41004100410@4100410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@4100000000
0@400@010@400@400@400040004000400041004000410@410@4000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@400@410@010@010@410@010@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@01
0@410@01004100000@410@000@010@0000010@00004100400@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@4100410@400@400@410@400@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@400@410@000@010@410@410@410@400@410@400@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@010@41004100410@4100410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@41000000000@400@410@410@410@4100410@4100410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@010@4100410@0000400@010@010@40
00010@010@4100010@400@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@400@410@010@010@410@010@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@400@410@010@010@4000400@40
0@41004100400@410041000100410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@4100410@400@400@410@400@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@4100410@400@400@410@01
004100410@410@0100410@010@410@010@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@010@4100410@00
00400@010@010@4000010@010@40000000400@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@400@410@01
0@010@0000400@400@4100410@400@4100410@0100410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410041
0@40004100410@01004100410@010@0100410@010@010@010@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@010@4100000@4000010@0000410@40000100000@4100010@4000010@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@400@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410000000000410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@00
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@00
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@000@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400000004000410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@00000000410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@40000000010@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000000@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@40000000410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41000000410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@4000000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@0000010@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@00000000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@4000410@410@010@410@000@410@4100410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@41000000010@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@000000000000410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@400@400@410@400@410@010@010@410@010@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@00000000000@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000@41
0@410@410@410@410@410@410@410@410@410@4100410@400@010@410@400@410@4100410@010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@41000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00410@410@410@410@410@410@410@410@410@410@410@010@4100400@410@400@410@410@010@40
0@410@410@410@410@410@410@410@410@410@410@410@410@410@41000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000001
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41000000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@400@410@0100410@400@410@410@40
000000410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000001
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@400000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@000@410@010@010@400@410@41
0@4100410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@00
00010@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@010@410@400@400@410041
00410@410@400@010@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@400@410@4100410041
0@4000410@410@4100400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@0100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@010@01
0@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
00010@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410000000000000000000000000000000000000000
000000000000000000000000000000010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@00000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@00000000000000000000000000
000000000000000000000000000000000000000000010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@40000400009`7oo`<000000000000000000000000000000000000000004@0000`000080000
2`000100002V0@00Q`4000T0000@0000YP4008L1000Q0000200000X0000@00000000000000090000
40000:@100240@00<@0001040001000000<00@00003oool0K`020000000Y30P03@P10:h50000>_P0
_`DX000Y000008P0n;l505@mg`050000l000002L4P0204<00Oko00009P000000003V01oJ1P1lQll0
5S[h0<03;`03b0`0@`4X08L1MP1O1:h01Nh50=X60P00O8L0k`6^00GXVP37GR/0Fc5K03J7T`01?8L0
IUng01MNQ`0G:m`07`/00<d:c`0FQ8L0gc9>08LG:`00000004L00?`2o002<0@0o?ol0?lX0`140V@0
P00004j75`0[0000A`3l00;l0P1700000000000000000000000C0?Q_003Dmfl00<@n0?No7`000000
Md;g0;oPn@3k_i00[ONo0>3in`2oFQl0m[oo0?M_000100000;3g06l0000000000OQ_003R4`3g_cL0
0@000<DBm`2oCW40K`0F0000003G@OL0_aci06l0000000000@000004n@1_03@0H_No0?ogK`005P00
000L0?U_001J7oH0_`0000000@0000000000003XPP180000051403YLA011E4l0Dea<06URLP1_G4T0
@e9@05a3H@1ULfT0MFd^06MYIP0020000<lF07:8:P0l=?P0K`00000000170?`00_`20000<0040000
o?oo0?olo`3oobP00`0004@20000I800000>0000000005h0R==i0?ooO`0ZLXP0@Cc_01Koo`1o:P00
000007lZ700m0000UXP00003001@GTD000h?0;LG0000;XT0ObX00017003l0Q`0?@8000000P00caH0
gXR501V_5`01000002j907lZ0000A`00b`bg01NW6P2_5`000000000000000000003l0898001PnVl0
0<@n0?No7`000000Md;g0;oPn@3k_i00[ONo0>3in`2oFQl0m[l00000000100000>8C0?No=`010000
aA;g0;nQL@000000000004]Sm`2o000000010000001<iFL0PCa;04<01@02K`00FQof0;l000000200
00000>1[n@1D/7D0`0400=R/^`0?ML000@0`09=D/01e`04000D000201@0=06P0nDl001`10000ah80
mkl0001=0024nTl0080500d000000000J?U?0000001=0440000000`0C@00d0D00000000000100000
08:40?No@@000000VHCg0;l0001=0000000000000000000000000000003T_D@008Si04l0n02QCP00
S?U?0008P`180?l0oooo06ciC`00C[h0A0280?U?000`000030000040000d0000200001D0000<0000
0`0005400030R08000000000002V0@00Q`4000000000000000000000002U0@00Q@400500000X1000
N0@004R40P000000803<0:D100250@00:0000:D100250@000@0800000018Q080a0h00<@>00000@00
00000000003oool00P1_0000000832T00@P=0005[P3h>P00:0Fo000Y002800001Koh0=lmE00000D0
003`01:L00130080ooh102H000000000iP0000KJ7`3?Qg`0n3XF02l3`00<b0<0:05307H1Q`2^15l0
1Nh50086fP27O000[P7_09[X1@0[G/L0Fc5K09>7=P27?040]emV08MN5`3L:aL000/O0<l:c@27Q1H0
CS;O02/GQ`00000004L00?`2o004<080o?ol00<Xo`1T0T@0002001N7CP0002/0o01700;l0P0004L0
00000000000000004`00001_n01_mm@0?/@001nom`000000md9g0?WP_`2@_o/0_oN]0?_ih00OF[l0
okof001_m`000040mk000000K`000000KoP101?R000g_oL000010?LBa@1aC[l05P1_0000003g@ML0
nAbo0000K`00000000010?T4000d06l0_oMR06ogo`005P007000001_n@3f7eX0002o004000000000
000008;X000004P0A50004AL>P1?E440C5aC079RJ@19G6l0D5930653G01YLfD0;Vee06IYI`002000
5/l002Z8LP3h=3`0001_0000003l04L00_`20300000000@0oool0?olo`0Xool000030002A020I000
3P000000001N0000NM>807ooo`28LRX0kca10?oo5P00:Wl0000001`ZO`0003d008RF00030015GU00
3`h0000G]`29;P0002Yo0017000L0_`0008m0080000Fc`00QHSN01N_6@000040RBh0000ZO`00A`00
]`c;01ZW5`005jl00000000000000000o0000018PP1_nV00?/@001nom`000000md9g0?WP_`2@_o/0
_oN]0?_ih00OF[l00;of0000000000404n8003Nom`000040ma;5076Q_`00000000000?MSB`000;l0
0@000000001WiD`0Bcb100D0@`00K`80mQmJ0000_`0P000000000?U[h01e/5@000700;^/f030M@l0
<0010;1DT`01`7D000D000F0001X00d004oi00017022a`000;og001=001?nX@01H0000003@000000
CoUX0000001104d0000004d03005d0000000000000000400Q880046om`000000mhBI0000_`0004d0
0000000000000000000000000014_N@0nHP00?P0C`00CZ40CoV<08<8003o04P0oooo04oiK02nCP00
R014001?n@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100410@410@0000000@4000000@4000000@4000000@4000000@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@010@410@400@4100400@410@0100410@4100410@010@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@400@410@4100410@0100410@410@010@410@010@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@41000000010@4000000@00000000400@410@400000004000000@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@010@410@400@4100400@410@0100410@4100410@010041
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@400@410@410@0000010@0000010@0000010@000001
0@0000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@00000000410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41000000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000000@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000000
00010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
000000000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400000000000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@41004100010@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410001
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410000000000000000
000000000000000000000000000000000000000000000000000000410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@4000410@400@400@010@010@000041
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@000@400@41004100400@400@01
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@400@4100410@010@010041
00400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@4100410@010@400@40
0@010@01000000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@010@400@41
000100400@400@010@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@400@41
00410@00000100000@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
00410@010@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@4100000001000000000@010@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@010@410@010@410@400@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@400@410@400@410@4100410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@4100410@4100410@410@010@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@010@410@010@410@400@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@400@410@400@410@4100410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@4100410@4100410@410@010@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@010@410@010@410@40
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100000@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000041
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
00010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@41000000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410000000000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@00000000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@40000000000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410040004100410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@41000000000000000000000000000000000000000000000000
0000000000000000000000410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
000000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@0000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@40000000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@40000000000@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410000000000410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410000000000010@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@000@400@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410001
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100000000
00000000000000000000000000000000000000000000000000000000000000010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@00000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@00000000000000000000000000000000000000000000000000000000000000000000010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4000410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@40000000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@0000000@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@40000000010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@4100010@410@400@410@4000410@410@4000000@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@40000000010@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000410@410@410@41
0@410@410@410@410@410@41004100410@4100410@400@400@410@4100410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@0000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000010@410@41
0@410@410@410@410@410@410@410@410@010@4100400@410@4100410@410@010@4100410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@0000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@40000000000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@400@410@0100410@4100410@410@400@410@010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40000000010@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41000000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@4100410@400@010@4100410@410@4100410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100000@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@4000410@400@400@4100410@410@410@00
00000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@400@410@41004100410@010@010@41
0@400@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@4100410@410@010@010@410001
0@410@4100410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@010@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@400@400@410@41
0@410@410@410@410@400@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@000@41
0@410@410@410@410@410@41000000410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@40000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@41000000410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@40000000410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41000000010@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41000000000@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000000041
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000000
0@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@00
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@00000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@4100000@410@000041004100410@010@00
00410@4000000@010@4000000@400@4100410@000@410041004100010@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@4100410@010@010@010@010@010@40
0@400@400@400@4000400@410041004100410@010@010@010@010@010@010@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@4000410@4100400@4100400@40
0@41004100410@0100410@0100410@010@010@010@400@400@4100400@400@400@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@4100410@410@4100410@01
004100410@010@010@400@4000400@010@400@400@400@410041000000010041004100410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@010@410@410@01
0@400@010@010@400@400@4100410@4000400@410041004100410@010@010@400@010@010@010@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@0000000041004000000041000000010@00
00010@00000100410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@400@410@41
0@400@4000400040004100410041000100010@0100010@010@000@000@400@400@4000400@400@40
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@000001
0@40000000400@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@400@410@400@0100410@010@010@40
0@010@400@010@400@010@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410041
0@410@410@0000410000004000410@0000410@4000010@000001000000000@000@410@000@410000
00400@010@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@01
0@400@4100410@4100410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@4100410@4100400@0000400@40
0@4100400@410040000000400@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@4000410@000@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@400@410@010@010@410@010@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@010@41004100410@40
004100410@0100410@0100410@0100410@410@4100010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@4100410@400@400@410@400@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@40000000010@01
00410@010@010@000@000@000@000@400@000@410@410@000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@010@41004100410@4100410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@4100410@41
00400@4000010@41000100410000004100000@400@010@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@400@410@010@010@410@010@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@01
0@41000100410@410@410@410@010@410@010@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@4100410@400@400@410@400@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@40000000010@010@410@410@410@400@410@400@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@4100410@400@4100000@01004100410@000041
00410@4000410@010@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@010@41004100410@4100410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@010@41004100410@000@010@010@40
0@400@010@400@4000400@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@400@410@010@010@410@010@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@400@410@010@010@4100400@40
0@410@4100400@4100410@4100410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@4100410@400@4100000@01
004100410@00004100410@0000000@010@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@010@4100410041
00000@010@010@400@410@010@400@4100400@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@400@410@00
0@400@4100400@400@41004100400@410041004100410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410041
0@4000010@00004100000@410@00004000010@4000410@0000410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@010@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@40000000000@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@40000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@00
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@00
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@41004100010@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@0000000@000@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@41000000000@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@00000000410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@41000000010@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000000@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000000@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@0000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@41000000410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@41000000000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@000@410@4100410@4100010@410@400@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@40000000410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410000000000000@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@010@010@410@010@41004100410@4100410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100000000000100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@0000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000010@410@41
0@410@410@410@410@410@410@410@410@400@410@0100410@410@010@410@400@4100410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@0000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000@41
0@410@410@410@410@410@410@410@410@410@4100410@400@010@410@010@410@4100410@010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@40000000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@010@4100400@410@010@410@410@000000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41000000410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@0000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@4100010@41004100410@010@410@410@40
0@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100000041
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@4100410@410@010@010@400@400@41
0@410@0100410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@010@410@400@400@410@00
0@410@410@400@010@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@4100400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@41004100410@41
0@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@400041
0@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
00410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@010@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@400@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@40
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@01
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@010@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@4100410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@010@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@400@410@410@410@410@410@410@410@410@410@410@410@41
0@0000410@410@410@410@410@410@410@4000000000000000000000000000000000000000000000
00000000000000000000000000410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@4100000000000000000000000000000000
00000000000000000000000000000000000000410@410@410@410@410@410@410@410@410@410@41
0@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4100000@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@0000410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@4000010@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410000
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@410@41
0@000280000<0000oooood/0000@0000000000D0000X000030000040000>000000<00;/0000@0000
00000?ooo`1_0080:@`800d80@2^1@0003[h0;l5:000:@0000280?Ro1@1D?Ml01@000?000000W180
0P13007no`0002H0003V01oJ1P1lQll05S[h0<03;`03b0`0@`4X08L1MP1O1:h01Nh50=X60P00O8L0
k`6^00GXVP37GR/0Fc5K03J7T`01?8L0IUng01MNQ`0G:m`07`/00<d:c`0FQ8L0gc9>08LG:`00A`00
o0;l008`103loo`0obP304@2I0200000CXLG02/000170?`00_`204L0000001<0n6l00=CgK`00a3h0
mklO07M2m`2oh?T0nkn@0:gg_`3PnO/0_eXO0?Joo`3gK`000@00002`m`1_00000OQ_003R4`3g_cL0
aA;g0;m>L@1_01H0ed7g0;lLn@001?T0K`0d06;g_`3omfl001H00000703iK`00FQof0;l000000040
0>R204P00000D4@0>Ua4045DC`1CG4`0JF9b06mLB@13DU00G4=Q06EcJ@1eKBh0IfUV00080000caH0
LXPZ03`dn000030010000?coo`3oo?l0oolX00<000140P0006B000003P0005h0R==i0?ooO`0ZLXP0
@Cc_01Koo`1o:P00ObXL03d0002FR00000<0051NA@003Pl0]aL0000^R@3l0Q`0?@8000000P3NR8D0
6JlG0</<]`0GYaX0[aL00000o022B000H?Y_0?Jo002oXG40Bf?g04cUI`21?4/0@`05009_00000200
h6_i05B`M@300@00f:bk00me`0010300TeB`07G00@001@00080500d0J03iC`0070400037PP3g_`00
04d008CjC`0=0000J?U?04d0@@0<04d00=0504000000PX@0mkm109V4m`1=0000i;e40028n@1?0?P0
XDh008ciC`0028<0B03o06ciC`00C[h0A0280003
\>"], "Graphics",
 ImageSize->{422, 391},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}},
 CellTags->"ICRP 78"],

Cell[TextData[{
 "Compartmental matrix could be obtained using  ",
 StyleBox["ICRP30Model", "Input",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"],
 " function, however in this case the rate transfer are included in Humorap"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompartNumbers", "[", "caesium", "]"}]], "Input",
 CellLabel->"In[86]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "\<\"Blood\"\>"},
    {"2", "\<\"Systemic A\"\>"},
    {"3", "\<\"Systemic B\"\>"},
    {"4", "\<\"Bladder\"\>"},
    {"5", "\<\"Urine\"\>"},
    {"6", "\<\"ULI\"\>"},
    {"7", "\<\"LLI\"\>"},
    {"8", "\<\"FEC\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.3992823145299544`*^9, 3.417835812750705*^9, 
  3.4798276632866664`*^9, 3.4798283228868885`*^9, 3.4798295229595385`*^9, 
  3.5185350474836335`*^9, 3.6434437500695643`*^9},
 CellLabel->"Out[86]//TableForm="]
}, Open  ]],

Cell[TextData[{
 "Their transfer coeffs are: ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    SubscriptBox["k", "12"], "\[Rule]", 
    RowBox[{
     SubscriptBox["f", "SYA"], " ", 
     SubscriptBox["k", "B"]}]}], ",", " ", 
   RowBox[{
    SubscriptBox["k", "13"], "\[Rule]", 
    RowBox[{
     SubscriptBox["f", "SYB"], " ", 
     SubscriptBox["k", "B"]}]}]}]]],
 ",",
 Cell[BoxData[
  RowBox[{"  ", 
   RowBox[{
    RowBox[{
     SubscriptBox["k", "24"], "\[Rule]", 
     RowBox[{"0.8", " ", 
      SubscriptBox["k", "SYA"]}]}], ",", 
    RowBox[{
     SubscriptBox["k", "26"], "\[Rule]", 
     RowBox[{"0.2", " ", 
      SubscriptBox["k", "SYA"]}]}], ","}]}]]],
 Cell[BoxData[
  RowBox[{" ", 
   RowBox[{
    RowBox[{
     SubscriptBox["k", "34"], "\[Rule]", 
     RowBox[{"0.8", " ", 
      SubscriptBox["k", "SYB"]}]}], ",", 
    RowBox[{
     SubscriptBox["k", "36"], "\[Rule]", 
     RowBox[{"0.2", " ", 
      SubscriptBox["k", "SYB"]}]}]}]}]]],
 " where",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{
     SubscriptBox["k", "B"], " ", "\[Rule]", "  ", 
     RowBox[{
      RowBox[{"Log", "[", "2", "]"}], "/", "0.25"}]}], ",", 
    RowBox[{
     SubscriptBox["f", "SYA"], "->", "0.1"}], ",", 
    RowBox[{
     SubscriptBox["f", "SYB"], "->", "0.9"}], ",", " ", 
    RowBox[{
     SubscriptBox["k", "SYA"], "\[Rule]", " ", "0.346"}], ",", " ", 
    RowBox[{
     SubscriptBox["k", "SYB"], "\[Rule]", " ", 
     RowBox[{"6.3", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "3"}]]}]}]}], "}"}]]],
 ". They are included in",
 StyleBox["TransferRates[caesium]", "Input"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"TransferRates", "[", "caesium", "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<From\>\"", ",", " ", "\"\<to\>\"", ",", 
        "\"\<Tranfer Rates(\!\(\*SuperscriptBox[\(days\), \(-1\)]\))\>\""}], 
       "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[87]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"From\"\>",
       HoldForm], 
      TagBox["\<\"to\"\>",
       HoldForm], 
      TagBox["\<\"Tranfer Rates(\\!\\(\\*SuperscriptBox[\\(days\\), \\(-1\\)]\
\\))\"\>",
       HoldForm]},
     {"1", "2", "0.27726`"},
     {"1", "3", "2.49533`"},
     {"2", "4", "0.2768`"},
     {"2", "6", "0.0692`"},
     {"3", "4", "0.00504`"},
     {"3", "6", "0.00126`"},
     {"4", "5", "12"},
     {"6", "7", 
      SubscriptBox["k", "ULI"]},
     {"7", "8", 
      SubscriptBox["k", "LLI"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"From", "to", 
       "Tranfer Rates(\!\(\*SuperscriptBox[\(days\), \(-1\)]\))"}}]]]], \
"Output",
 CellChangeTimes->{3.399282314561234*^9, 3.41783581279758*^9, 
  3.479827663333544*^9, 3.4798283229337606`*^9, 3.4798295229751635`*^9, 
  3.518535047546135*^9, 3.6434437501008153`*^9},
 CellLabel->"Out[87]//TableForm="]
}, Open  ]],

Cell[TextData[{
 "We are going to evaluate the whole body content and the daily urine and \
faecal excretion for a single intake ",
 Cell[BoxData[
  SubscriptBox["I", "0"]]],
 "= and  in t =0 an chronic intake of 1 Bq/day of Cs-137. It has been taken \
into account that for caesium 137: ",
 Cell[BoxData[
  SubscriptBox["f", "1"]]],
 "=1 (Type F) and .\[Lambda] = Log (2)/ ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]],
 " , with  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]],
 " = 30 year"
}], "MathCaption",
 CellTags->"ICRP 78"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "element", ",", " ", "lambda", ",", " ", "fn1", ",", " ", "amad", ",", " ", 
   "class"}], "]"}]], "Input",
 CellLabel->"In[88]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"element", "=", " ", "caesium"}], ";", 
   RowBox[{"lambda", " ", "=", " ", 
    RowBox[{
     RowBox[{"Log", "[", "2", "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"30", "*", "365.24"}], ")"}]}]}], ";", " ", 
   RowBox[{"fn1", " ", "=", " ", "1"}], ";", " ", 
   RowBox[{"amad", "=", " ", 
    RowBox[{"AMADAdultW", "[", "5", "]"}]}], ";", 
   RowBox[{"class", " ", "=", " ", "F"}], ";"}], " "}]], "Input",
 CellLabel->"In[89]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[90]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.01698339895645577`", "0.0005621195272561324`", 
      "0.9823912240000477`"},
     {"2", "0.022986170405686002`", "0.00294584110367518`", 
      "0.9563970688618807`"},
     {"3", "0.018192479580942462`", "0.00435874838227177`", 
      "0.933785341595551`"},
     {"4", "0.014191869664899472`", "0.004375833755073408`", 
      "0.9151585692341675`"},
     {"5", "0.011315877049776319`", "0.0038190677962797195`", 
      "0.8999657337300561`"},
     {"6", "0.009270782278032868`", "0.0031767746246050975`", 
      "0.8874612472304012`"},
     {"7", "0.007815772988658242`", "0.0026232281430828455`", 
      "0.8769661075044013`"},
     {"8", "0.0067784185778915085`", "0.0021927855148420198`", 
      "0.8679394287138803`"},
     {"9", "0.006036600686604862`", "0.0018725388803736628`", 
      "0.8599753854543946`"},
     {"10", "0.005503916136741384`", "0.0016389101437979704`", 
      "0.852778159266944`"},
     {"20", "0.004056176154176963`", "0.0010314751985862447`", 
      "0.7962924194774619`"},
     {"30", "0.0037712962346301586`", "0.0009518839961143924`", 
      "0.7470778240971316`"},
     {"40", "0.003537701106357629`", "0.000892697476862925`", 
      "0.7010163840133992`"},
     {"50", "0.003319566389714114`", "0.0008376466151863045`", 
      "0.6577983856423469`"},
     {"60", "0.00311491301522358`", "0.0007860049462043273`", 
      "0.6172449077132129`"},
     {"70", "0.002922877629614411`", "0.0007375474823607019`", 
      "0.5791915679426864`"},
     {"80", "0.0027426813178024157`", "0.0006920774512496442`", 
      "0.5434842284656793`"},
     {"90", "0.0025735941654307566`", "0.0006494106621072782`", 
      "0.509978257525561`"},
     {"100", "0.002414931288382185`", "0.0006093742937394372`", 
      "0.47853794006699374`"},
     {"180", "0.0014515182437787864`", "0.00036627042305834793`", 
      "0.2876299436299438`"},
     {"200", "0.001278062019037178`", "0.0003225011593301677`", 
      "0.2532582060658339`"},
     {"300", "0.0006763929608944575`", "0.00017067834800032903`", 
      "0.13403267237432634`"},
     {"400", "0.0003579696687115365`", "0.00009032866280736438`", 
      "0.07093455151117042`"},
     {"500", "0.00018944946373775914`", "0.00004780493495607806`", 
      "0.037540925723232116`"},
     {"600", "0.00010026296205405767`", "0.00002529996277071886`", 
      "0.019867907446137825`"},
     {"700", "0.00005306249678155634`", "0.000013389582410012423`", 
      "0.010514757925748724`"},
     {"800", "0.000028082439487221375`", "7.086212684945478`*^-6", 
      "0.005564759879057504`"},
     {"900", "0.000014862161703394357`", "3.7502596181584254`*^-6", 
      "0.002945056151576885`"},
     {"1000", "7.865550661949834`*^-6", "1.9847622176895734`*^-6", 
      "0.0015586217418980255`"},
     {"2000", "1.3558156340716306`*^-8", "3.421212017203047`*^-9", 
      "2.6866570645741208`*^-6"},
     {"3000", "2.337072269441595`*^-11", "5.8972765414084`*^-12", 
      "4.631095530488431`*^-9"},
     {"4000", "4.0285025893897884`*^-14", "1.0165365499411242`*^-14", 
      "7.982799924600568`*^-12"},
     {"5000", "6.94408697793413`*^-17", "1.752243684199651`*^-17", 
      "1.3760263466100845`*^-14"},
     {"6000", "1.1969793462238752`*^-19", "3.0204107555147`*^-20", 
      "2.3719102626261103`*^-17"},
     {"7000", "2.063279967318495`*^-22", "5.2063997800687326`*^-23", 
      "4.0885541965172957`*^-20"},
     {"8000", "3.5565561235105794`*^-25", "8.974474289745682`*^-26", 
      "7.047600274452006`*^-23"},
     {"9000", "6.130574454299004`*^-28", "1.5469651233050504`*^-28", 
      "1.214822336726374`*^-25"},
     {"10000", "1.0567510207757314`*^-30", "2.666564096633294`*^-31", 
      "2.0940366257138366`*^-28"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282314701993*^9, 3.417835812938205*^9, 
  3.4798276635523047`*^9, 3.4798283230900016`*^9, 3.4798295231001587`*^9, 
  3.518535047655512*^9, 3.6434437501633153`*^9},
 CellLabel->"Out[90]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[91]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAA2C12NM1yfD4sEBnJ+zsUwH1iX+iS
GFo/hmTKJKA3FMCR+cQCWhhqP35z8+VEMxTAG8X3jz0Yej+smm6ZjyoUwOAq
kVYvGIo/S426yykZFMDC3d05KBiaPwgasMlx9hPAMzeEqyQYqj//CxojVrET
wOxjV+QiGLo/HZHSAbsoE8D6A0a8FDHLPwsidedMCxLA4qK9VhEz1D8IPjGH
3hIRwFIVovturNo/mkKureAyEMBNhiT/ItngP6S7her3qw7A470+KhEg5D/q
RXqvzjYNwOY3OgQ8rec/DNcnvDzJC8Cumlo00inrP+N0ZsV5hQrAZ7lBDmtq
7j+RFB3vUnMJwEcNhUug+PA/94S1t/NkCMDTm8xkDJ7yP5OGpCUDfwfAwZ4m
KS479D+BYN+1ZbAGwOZC8URu+/U/exdfHR7jBcADRZ+1r533P9yLV1CRMwXA
V+i9fQ9j+T9Zskmp+4QEwA0A7/AkIPs/AhzK5eHnA8C8dQO5O7/8P3UfO1TD
YAPAoYyI2HCB/j95PyavKNkCwMCAeKbTEgBAsHS+SXZjAsDLC2UMfvYAQHwm
Vg306wHAB9HaRwPWAUBdWlUFA30BwD9Fwi2JpgJAHNg4MaYZAcATCmI/nogD
QLWGF5y6sADA431z+7NbBECbA6mC6U8AwOQrDo2kKgVAQaLNspfh/7+AKmFK
JAsGQMQ2ZnRXEP+/GdglsqTcBkCB3Onvjkj+v03WokW0vwdAkRlq5qdp/b+y
Dqmunp4IQL9EWBp8h/y/FPYgwoluCUAHduA8pK37vxEuUQEEUApA7l6sUe+5
+r8KFfPqfiILQLGBxfLBz/m/NTYeqtTwC0BgnXoebuT4v/unAZW50AxAcikN
rlXf97+9yFYqn6ENQKCpsAwc5/a/Gjpk6xOEDkAD04508NX1v3Ra41aJVw9A
3oU4pfrT9L9/2vXLbBMQQIQgJOhR1fO/EjBWgtyDEECKoH4hPcDyvyNd743M
7BBAkudZFO298b+BsmQvhF4RQDzaHjSXp/C/+KSeOynOEUC1pL9EiDLvv+1u
EZ1ONhJALskniuFB7b8wYWCUO6cSQPNTimBzMuu/8Sro4KgQE0DNWqNw/FLp
v8uRNJgDeBNATNivcHSL57/yIF3lJegTQITy1s4csOW/l4e+h8hQFED0myXe
tQjkv3hcb7+bUhRACtazCIMB5L9aMSD3blQUQJbwYOVR+uO/HtuBZhVYFECX
1Rq49Ovjv6QuRUViXxRAhFER2E7P47+y1csC/G0UQAILdqlVluO/zCPZfS+L
FEDb+vXCsiXjv674ibUCjRRAKFOTorce47+PzTrt1Y4UQO11+0u+F+O/Unec
XHySFEDIkBT/0Anjv9nKXzvJmRRAA0Kq+gvu4r/mceb4YqgUQBYiq+jYtuK/
yEaXMDaqFEDtwIe7+q/iv6obSGgJrBRAWOeuYx6p4r9txanXr68UQJ8VsjZr
m+K/9Bhttvy2FECuxWb7GoDiv9btHe7PuBRApn1rjEt54r+3ws4lo7oUQFE5
Yfh9cuK/emwwlUm+FEB2I/Fj6GTiv1xB4cwcwBRAS5TxZCBe4r8+FpIE8MEU
QM7HsUNaV+K/IOtCPMPDFEDcquIAllDivwHA83OWxRRAXwM4ndNJ4r/tkF2Q

        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAA2C12NM1yfD50BVuPd9EhwH1iX+iS
GFo/jz+NbhPOIcCR+cQCWhhqP8jBuYqvyiHAG8X3jz0Yej8+eTB66MMhwOAq
kVYvGIo/PC5mN122IcDC3d05KBiaP9w20jpSmyHAMzeEqyQYqj8qlrzxamUh
wOxjV+QiGLo/8Lj981z6IMD6A0a8FDHLP/u0b78RFiDA4qK9VhEz1D9VspyP
X40ewFIVovturNo/4NqzS5cEHcBNhiT/ItngPyWYSMBrbRvA470+KhEg5D/C
Fd1Y2AUawOY3OgQ8rec/uD4ob5uYGMCumlo00inrP5flgT4fTBfAZ7lBDmtq
7j+EDJ6o3S0WwEcNhUug+PA/jw+iAJQRFcDTm8xkDJ7yPxXheb1bIBTAwZ4m
KS479D9Dcz0A60kTwOZC8URu+/U/tqL4b+54EsADRZ+1r533PwpNmq//yhHA
V+i9fQ9j+T8mKIMd5yMRwA0A7/AkIPs/8nNRWM+TEMC8dQO5O7/8PzaUvR6J
HRDAoYyI2HCB/j8Zv4dAtVkPwMCAeKbTEgBA4wI+Kd6gDsDLC2UMfvYAQLBe
9+cO8A3AB9HaRwPWAUDVszX64lUNwD9Fwi2JpgJALHVumKfTDMATCmI/nogD
QGvUmlpuUQzA431z+7NbBECr45xs594LwOQrDo2kKgVACQCP/o5yC8CAKmFK
JAsGQIi3WVXn/grAGdglsqTcBkBUqSny3ZIKwE3WokW0vwdAE1WpRxwcCsCy
Dqmunp4IQMha8HrRpAnAFPYgwoluCUBg5G2FozIJwBEuUQEEUApAst4Ob3Sz
CMAKFfPqfiILQM5tKwukOQjANTYeqtTwC0BSLjpUir8HwPunAZW50AxAVIHq
smI4B8C9yFYqn6ENQK2/jcAruAbAGjpk6xOEDkCkznEfXCsGwHRa41aJVw9A
boNjuqWmBcB/2vXLbBMQQJm+YePcIwXAEjBWgtyDEEBEdpQlzpUEwCNd743M
7BBARw3sI5URBMCBsmQvhF4RQDSCRC1TgwPA+KSeOynOEUC4xXwxXPkCwO1u
EZ1ONhJAXMOCr8h6AsAwYWCUO6cSQCvmmX+F9AHA8Sro4KgQE0BPd5YNmnoB
wMuRNJgDeBNAj0iFvuAGAcDyIF3lJegTQLG8Qpo6jgDAl4e+h8hQFECjH0nD
2SIAwHhcb7+bUhRAf+OhlAYhAMBaMSD3blQUQLQDgtUzHwDAHtuBZhVYFEAx
8JamjxsAwKQuRUViXxRAxiw/i0wUAMCy1csC/G0UQLuKyIfbBQDAzCPZfS+L
FEBd1gQqn9L/v674ibUCjRRANaxyZBXP/7+PzTrt1Y4UQFqcmImMy/+/Unec
XHySFEBPfnqVfcT/v9nKXzvJmRRAQDKOvWq2/7/mceb4YqgUQG7dYZ5xmv+/
yEaXMDaqFEDHM+2u9pb/v6obSGgJrBRAw4zZr3yT/79txanXr68UQOG8O4SL
jP+/9Bhttvy2FEC7TOeAtH7/v9btHe7PuBRAU4c+HkF7/7+3ws4lo7oUQEYg
v67Od/+/emwwlUm+FEB7Up+q7HD/v1xB4cwcwBRAQkCvFn1t/78+FpIE8MEU
QJ3hSXcOav+/IOtCPMPDFEB0msbMoGb/vwHA83OWxRRASMp9FzRj/79k4kPU

        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -9.742875620975783}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-9.742875620975783, 0.26224828740246886`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, -9.}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992823170636177`*^9, 3.417835815781955*^9, 
  3.479827664364846*^9, 3.479828323839958*^9, 3.4798295238501296`*^9, 
  3.5185350488274093`*^9, 3.6434437502570724`*^9},
 CellLabel->"Out[91]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsubsectionIcon"],

Cell["\<\
Whole body and daily urine values from day 1 to 10 are the same that Table \
A.7.13 of ICRP 78 (Values higher that 10 days are not included in ICRP ).\
\>", "Commentary"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[92]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.015959500948009443`", "0.0004970801147211075`", 
      "0.9834801614210295`"},
     {"2", "0.023142393556863688`", "0.002848848446932975`", 
      "0.9574267069049499`"},
     {"3", "0.01838707651109369`", "0.00433214316551818`", 
      "0.9346469227928774`"},
     {"4", "0.014335110477669546`", "0.004390990012024794`", 
      "0.9158616988602861`"},
     {"5", "0.011417876638511201`", "0.003845923162263124`", 
      "0.9005399639232224`"},
     {"6", "0.009343296287636449`", "0.003202386043375688`", 
      "0.8879373156708178`"},
     {"7", "0.007867405632881682`", "0.0026439374820691423`", 
      "0.8773698038467007`"},
     {"8", "0.006815275038828987`", "0.002208459139793672`", 
      "0.8682905694334627`"},
     {"9", "0.006063001319611511`", "0.001884058268059205`", 
      "0.8602885839409948`"},
     {"10", "0.005522917537182463`", "0.0016472701527056061`", 
      "0.8530639765320371`"},
     {"20", "0.0040577926195817`", "0.0010319994579765742`", 
      "0.7965034480623664`"},
     {"30", "0.0037723037804804813`", "0.0009521418915526127`", 
      "0.7472740446711211`"},
     {"40", "0.003538630540771292`", "0.0008929321215106744`", 
      "0.7012004510521279`"},
     {"50", "0.0033204380217784013`", "0.0008378665630104517`", 
      "0.6579711031172478`"},
     {"60", "0.003115730895120048`", "0.0007862113269242496`", 
      "0.6174069770466`"},
     {"70", "0.00292364508646632`", "0.000737741139417546`", 
      "0.5793436456497483`"},
     {"80", "0.0027434014606861497`", "0.0006922591692817827`", 
      "0.5436269305349675`"},
     {"90", "0.0025742699112824142`", "0.0006495811771662461`", 
      "0.5101121619680996`"},
     {"100", "0.00241556537429298`", "0.0006095342964922653`", 
      "0.478663589259197`"},
     {"180", "0.0014518993673627385`", "0.0003663665942893492`", 
      "0.28770546631487603`"},
     {"200", "0.0012783975984067882`", "0.00032258583811268365`", 
      "0.25332470380060557`"},
     {"300", "0.0006765705606666551`", "0.0001707231628305761`", 
      "0.1340678651889575`"},
     {"400", "0.00035806366042244074`", "0.00009035238030720498`", 
      "0.07095317672007286`"},
     {"500", "0.00018949920727970667`", "0.00004781748704643683`", 
      "0.03755078280372696`"},
     {"600", "0.00010028928799216465`", "0.000025306605754732875`", 
      "0.019873124141230537`"},
     {"700", "0.0000530764293442692`", "0.000013393098098265414`", 
      "0.010517518774430492`"},
     {"800", "0.000028089813063157242`", "7.088073304189365`*^-6", 
      "0.005566221012075277`"},
     {"900", "0.000014866064045212662`", "3.7512443197939817`*^-6", 
      "0.002945829431803985`"},
     {"1000", "7.867615911130212`*^-6", "1.9852833545710694`*^-6", 
      "0.0015590309875329884`"},
     {"2000", "1.3561716291255496`*^-8", "3.4221103211654645`*^-9", 
      "2.68736249723218`*^-6"},
     {"3000", "0", "0", "4.632311512266951`*^-9"},
     {"4000", "0", "0", "0"},
     {"5000", "0", "0", "0"},
     {"6000", "0", "0", "0"},
     {"7000", "0", "0", "0"},
     {"8000", "0", "0", "0"},
     {"9000", "0", "0", "0"},
     {"10000", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282317470256*^9, 3.41783581617258*^9, 
  3.479827664771117*^9, 3.4798283242618093`*^9, 3.4798295241782417`*^9, 
  3.518535049030538*^9, 3.643443750335207*^9},
 CellLabel->"Out[92]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[93]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAA2C12NM1yfD5afzq0LK0UwH1iX+iS
GFo/rJDi05moFMCR+cQCWhhqP4aAL3IHpBTAG8X3jz0Yej+0YLMq5JoUwOAq
kVYvGIo/zv2giqOIFMDC3d05KBiaPxDpzA46ZBTAMzeEqyQYqj9Oh7u1xxsU
wOxjV+QiGLo/ZzWwZ4uME8D6A0a8FDHLP8TeHsRnYBLA4qK9VhEz1D9sDH8r
a1oRwFIVovturNo/5/cAVVNuEMBNhiT/ItngP9QW4DtbDA/A470+KhEg5D+G
veZYx4UNwOY3OgQ8rec/tVv4Q9UIDMCumlo00inrP7vi+XH0uArAZ7lBDmtq
7j8Il3QDrJ0JwEcNhUug+PA/dAkuVE2HCMDTm8xkDJ7yP5g1SgRUmwfAwZ4m
KS479D8AEqIp38cGwOZC8URu+/U/5ADjBk72BcADRZ+1r533PxizEK18QwXA
V+i9fQ9j+T9YYmHbAZIEwA0A7/AkIPs/j33LqZnyA8C8dQO5O7/8P+y8U5q5
aQPAoYyI2HCB/j9hnhU7k+ACwMCAeKbTEgBAwI98l7dpAsDLC2UMfvYAQPsH
JIg08QHAB9HaRwPWAUBsmnjDfYEBwD9Fwi2JpgJACTMz8Y8dAcATCmI/nogD
QG11rWgptADA431z+7NbBEC1EZGE/lIAwOQrDo2kKgVAybgs5TTn/7+AKmFK
JAsGQHBY3HN4Ff+/GdglsqTcBkDf0y+rTk3+v03WokW0vwdAZocOmgtu/b+y
Dqmunp4IQC7k2SWOi/y/FPYgwoluCUDXQbkfb7H7vxEuUQEEUApAcFLjz3C9
+r8KFfPqfiILQIgzFLwB0/m/NTYeqtTwC0CdTmzhb+f4v/unAZW50AxA1MKn
zxbi97+9yFYqn6ENQNwVEX2j6fa/Gjpk6xOEDkBErpRVPNj1v3Ra41aJVw9A
VQKV0RHW9L9/2vXLbBMQQK8HSjU41/O/EjBWgtyDEEA/NqSZ8cHyvyNd743M
7BBAVkbNCHa/8b+BsmQvhF4RQLgnrT70qPC/+KSeOynOEUCD0teU8jTvv+1u
EZ1ONhJAbiASEwdE7b8wYWCUO6cSQM+SSkxUNOu/8Sro4KgQE0C9JlK1olTp
v8uRNJgDeBNAzJynE+aM57/yIF3lJegTQI712I5aseW/l4e+h8hQFECPMLve
xwnkv3hcb7+bUhRAw/LVT5QC5L9aMSD3blQUQPhjZnNi++O/HtuBZhVYFEBL
D+XUA+3jv6QuRUViXxRA/0NiFlvQ47+y1csC/G0UQO0utzpcl+O/zCPZfS+L
FECD6Bc5ribjv674ibUCjRRAh4rHabIf47+PzTrt1Y4UQJtIlWS4GOO/Unec
XHySFEB/7HG7yQrjv9nKXzvJmRRAYBNuAgLv4r/mceb4YqgUQHqoqZbJt+K/
yEaXMDaqFEDiqb6/6rDiv6obSGgJrBRAX4Rvvg2q4r9txanXr68UQEgFfD9Z
nOK/9Bhttvy2FEAzyxJkBoHiv9btHe7PuBRAR7vaTTZ64r+3ws4lo7oUQNDj
5BJoc+K/emwwlUm+FEBq/ZAx0WXiv1xB4cwcwBRA5raZjAhf4r8+FpIE8MEU
QKZYscVBWOK/IOtCPMPDFEAdvIvdfFHivwHA83OWxRRAD0Ha1LlK4r87nlnT

        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAA2C12NM1yfD6PMnVmoyYiwH1iX+iS
GFo/4lTBzBgjIsCR+cQCWhhqP53Otn6OHyLAG8X3jz0Yej8FbvHDehgiwOAq
kVYvGIo/C69v2FYKIsDC3d05KBiaP66s7jEd7iHAMzeEqyQYqj/5PcoL47Uh
wOxjV+QiGLo/qHAxGldGIcD6A0a8FDHLP06uQs/nWCDA4qK9VhEz1D8L8Lx0
GwMfwFIVovturNo/UHcKk5xrHcBNhiT/ItngP2Jy3tmVxRvA470+KhEg5D+K
x+26U1EawOY3OgQ8rec//PXKNsHXGMCumlo00inrP8wyOUaggBfAZ7lBDmtq
7j+423xouFkWwEcNhUug+PA/tlMIc101FcDTm8xkDJ7yP50DRlG+PRTAwZ4m
KS479D8QClsD+2ETwOZC8URu+/U/UPH3tCqMEsADRZ+1r533P79sNc+C2hHA
V+i9fQ9j+T9EfiWGHTARwA0A7/AkIPs/AJOBrmudEMC8dQO5O7/8P6kA8J8z
JRDAoYyI2HCB/j83RCO3s2UPwMCAeKbTEgBARpBvmm6qDsDLC2UMfvYAQNF0
iRGZ9w3AB9HaRwPWAUDYdZmX7lsNwD9Fwi2JpgJAxBH3JqfYDMATCmI/nogD
QBOFzQKWVQzA431z+7NbBEBlE7yUeuILwOQrDo2kKgVAuU8vGrV1C8CAKmFK
JAsGQJSO8DC0AQvAGdglsqTcBkCpJYYkapUKwE3WokW0vwdAdrFyhG8eCsCy
Dqmunp4IQBP01BH1pgnAFPYgwoluCUA2I44vnzQJwBEuUQEEUApApkfv60e1
CMAKFfPqfiILQLsY+xdUOwjANTYeqtTwC0CJpOE3GcEHwPunAZW50AxAVshf
P885B8C9yFYqn6ENQJRyzMt5uQbAGjpk6xOEDkCJ8O/OiiwGwHRa41aJVw9A
cEDoxbinBcB/2vXLbBMQQLbusmTWJAXAEjBWgtyDEEDSNu+yrZYEwCNd743M
7BBAf3FAGl4SBMCBsmQvhF4RQAyDC2kFhAPA+KSeOynOEUBc17nX+fkCwO1u
EZ1ONhJAiyzeoVR7AsAwYWCUO6cSQIvghNP/9AHA8Sro4KgQE0Bsl0ZaBXsB
wMuRNJgDeBNAKg15lT4HAcDyIF3lJegTQBGjUTKLjgDAl4e+h8hQFEA6rf80
HyMAwHhcb7+bUhRA3sUd10shAMBaMSD3blQUQHGg2eh4HwDAHtuBZhVYFEDG
e+db1BsAwKQuRUViXxRAOrCJhZAUAMCy1csC/G0UQNaeHxAeBgDAzCPZfS+L
FEBmRWSTHtP/v674ibUCjRRA0szKdJTP/7+PzTrt1Y4UQE2oE0ELzP+/Unec
XHySFEDXurub+8T/v9nKXzvJmRRAawJbY+e2/7/mceb4YqgUQKnHN4vrmv+/
yEaXMDaqFED3sWFFcJf/v6obSGgJrBRAEpcX8PWT/79txanXr68UQLPMiRgE
jf+/9Bhttvy2FEAxv0y/K3//v9btHe7PuBRAlLCSB7h7/7+3ws4lo7oUQMiI
K0NFeP+/emwwlUm+FEBOq7iVYnH/v1xB4cwcwBRA4cRdrfJt/78+FpIE8MEU
QI/ytrmDav+/IOtCPMPDFEDv8Ru7FWf/vwHA83OWxRRALdHksahj/7+9mUMh

        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -9.925849752821163}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-9.925849752821163, 0.2787625435640544}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, -9.5}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992823199413595`*^9, 3.41783581920383*^9, 
  3.479827665724291*^9, 3.4798283252773757`*^9, 3.4798295251000814`*^9, 
  3.5185350503274384`*^9, 3.643443750507078*^9},
 CellLabel->"Out[93]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsubsectionIcon"],

Cell["\<\
Whole body and daily urine values from day 1 to 10 are the same that Table \
A.7.12 of ICRP 78 (Values higher that 10 days are not included in ICRP ).\
\>", "Commentary"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[94]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Lung\\nretention\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "2.3935750108266578`*^-45", "0.007893096956297935`", 
      "0.00025276015340755704`", "0.5972909716104436`"},
     {"2", "0", "0.011095594236306865`", "0.0013907287632242233`", 
      "0.5060142165321193`"},
     {"3", "0", "0.008800256051273292`", "0.0020889841196176555`", 
      "0.46612331934145906`"},
     {"4", "0", "0.0068627344330042216`", "0.0021083110833293155`", 
      "0.4464661243284612`"},
     {"5", "0", "0.005468736056426272`", "0.0018436757091239702`", 
      "0.4352053507332963`"},
     {"6", "0", "0.004477433783257226`", "0.0015344710764185379`", 
      "0.4277238757218674`"},
     {"7", "0", "0.003772184705293595`", "0.0012669724588861128`", 
      "0.42212719844392704`"},
     {"8", "0", "0.003269404385285367`", "0.001058638226185578`", 
      "0.41757731889301547`"},
     {"9", "0", "0.0029098929308249886`", "0.0009035306397984005`", 
      "0.41366569909106027`"},
     {"10", "0", "0.0026517640214948277`", "0.0007903412384646195`", 
      "0.4101710211622821`"},
     {"20", "0", "0.001950943567135836`", "0.00049615015363684`", 
      "0.38297313836284685`"},
     {"30", "0", "0.0018137895549330742`", "0.0004578056862933061`", 
      "0.35930313568938566`"},
     {"40", "0", "0.0017014387395431492`", "0.00042933818618353054`", 
      "0.33715011443900694`"},
     {"50", "0", "0.0015965278632548484`", "0.00040286170145198506`", 
      "0.316364646717009`"},
     {"60", "0", "0.0014981009032085288`", "0.0003780249124687053`", 
      "0.29686066645825826`"},
     {"70", "0", "0.0014057425023068582`", "0.00035471955203384884`", 
      "0.2785591144092012`"},
     {"80", "0", "0.00131907804132538`", "0.0003328509815976105`", 
      "0.26138585876605186`"},
     {"90", "0", "0.0012377564716933875`", "0.00031233061552867066`", 
      "0.24527133965166664`"},
     {"100", "0", "0.0011614484020209498`", "0.0002930753363879101`", 
      "0.23015028562956813`"},
     {"180", "0", "0.0006981000051020413`", "0.0001761558184347025`", 
      "0.13833409671292973`"},
     {"200", "0", "0.0006146771532735362`", "0.0001551052230578176`", 
      "0.12180319173001777`"},
     {"300", "0", "0.00032530760910174115`", "0.0000820868467347709`", 
      "0.06446230329471922`"},
     {"400", "0", "0.00017216361463234415`", "0.000043443091560792874`", 
      "0.034115596537658645`"},
     {"500", "0", "0.00009111471534625152`", "0.000022991530061539333`", 
      "0.018055109228708743`"},
     {"600", "0", "0.00004822094012347996`", "0.000012167882983901806`", 
      "0.009555364769915762`"},
     {"700", "0", "0.00002552012655207135`", "6.439648684260405`*^-6", 
      "0.00505701708749381`"},
     {"800", "0", "0.000013506100411274426`", "3.408076428049152`*^-6", 
      "0.002676341766011914`"},
     {"900", "0", "7.1478778895242655`*^-6", "1.8036674838820953`*^-6", 
      "0.0014164091448719154`"},
     {"1000", "0", "3.7828948969535253`*^-6", "9.545608677196927`*^-7", 
      "0.0007496108647836495`"},
     {"2000", "0", "6.520723422629488`*^-9", "1.6454137844214968`*^-9", 
      "1.2921334737025516`*^-6"},
     {"3000", "0", "1.1240025195696368`*^-11", "2.8362638921412382`*^-12", 
      "2.2273008467459982`*^-9"},
     {"4000", "0", "1.9374869659620723`*^-14", "4.8889786520734825`*^-15", 
      "3.839285308274144`*^-12"},
     {"5000", "0", "3.339721822608071`*^-17", "8.427323115686863`*^-18", 
      "6.617925773190645`*^-15"},
     {"6000", "0", "5.756808715800872`*^-20", "1.452650542175153`*^-20", 
      "1.1407576677115678`*^-17"},
     {"7000", "0", "9.923235631777768`*^-23", "2.50399037596445`*^-23", 
      "1.966368468069622`*^-20"},
     {"8000", "0", "1.710506814887`*^-25", "4.31622583745044`*^-26", 
      "3.389505993832261`*^-23"},
     {"9000", "0", "2.9484672866230613`*^-28", "7.440046758445923`*^-29", 
      "5.842623632743309`*^-26"},
     {"10000", "0", "5.0823880177648015`*^-31", "1.2824698672523796`*^-31", 
      "1.0071158149891722`*^-28"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Lung\nretention", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992823215991893`*^9, 3.417835820844455*^9, 
  3.4798276673962517`*^9, 3.4798283269179063`*^9, 3.4798295267093945`*^9, 
  3.518535051405584*^9, 3.643443750882086*^9},
 CellLabel->"Out[94]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[95]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQfUO3zORsUY1dbif3moVVMgeMzVtWq0issofx3ySH
P1GS2AXn/2J22yNieBrOf7Rob5ig8RU4P0h00e+8NbfgfN82lf9KNx/A+Y/3
2mkJKjyB85+ZW7HYrH0O56+bFWVySfM1nJ++05EvO+sdnO/O2+q94McHOP/y
7DMpPPM+wfkH56lp6ll/QZjv9NEl7/dXOJ/Zdf7W9XO/w/nhL/bW8if/hPN5
Gd5/UFH4DefvKWXeab3/D5y/sKfjRkHjPzj/QEPFsstCDA4w/mnuVJ66bwg+
+8Vb7szXGOF8e9dDup3LmOB8Ya4k+3kdzHD+49ri35ujWeD8J9p8vUu0WOH8
Bq1ELxVuNjhf8obqpiV3EHzfa4tct+xnh/M38a1cN28eB5wv8k3hUGceJ5wv
qBfIyBLABedziX5+VafEDeebmsmtuvIBwf+9nHHqzgs8cP7eE2Fa8xfywvlS
VimvhVv44PySqMdhneH8cH79ra+nc4QF4Hwhg7CmO80IvnLs+94zbxD8xk0p
+i1xgnD+jyXzrDXPIfhv8wTn+pkJwfkGiQlTrJcj+B+1XjxYISCMiJ+JJjOY
KxD8TwqxT1VfIPjT2/e1nwgQgfPPKN+s1e9G8BkPfC6edhTBBwBdonLt
        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAA2C12NM1yfD7OmFwjlGcXwH1iX+iS
GFo/9sTWwBpjF8CR+cQCWhhqPzkwENGhXhfAG8X3jz0Yej95ZcdJsVUXwOAq
kVYvGIo/wpz6nNVDF8DC3d05KBiaP5J/Qe8zIBfAMzeEqyQYqj+z+QGCStkW
wOxjV+QiGLo/0tqIMBZNFsD6A0a8FDHLP72cgO+kJxXA4qK9VhEz1D/BSnzU
1CcUwFIVovturNo/cCDIcz9BE8BNhiT/ItngP+48dwI3XhLA470+KhEg5D+Q
he+w354RwOY3OgQ8rec/J7NPkuDjEMCumlo00inrP685Qr+rPhDAZ7lBDmtq
7j/WBJxJK2YPwEcNhUug+PA/FB04i2RTDsDTm8xkDJ7yP3AGsC0gag3AwZ4m
KS479D+5igOT1pgMwOZC8URu+/U/T5Q/jzDJC8ADRZ+1r533P5+dSCzVFwvA
V+i9fQ9j+T8Ic4xnpWcKwA0A7/AkIPs/ZGzOvkTJCcC8dQO5O7/8P/5P4DIt
QQnAoYyI2HCB/j/soOVFt7gIwMCAeKbTEgBAO39bHWBCCMDLC2UMfvYAQK9K
MXtPygfAB9HaRwPWAUDdIivJ8FoHwD9Fwi2JpgJAqJPYhkP3BsATCmI/nogD
QDdZ1bkTjgbA431z+7NbBEAJT4TLEC0GwOQrDo2kKgVAWf/VDMzNBcCAKmFK
JAsGQBrQ7XIJZQXAGdglsqTcBkCm33QuCgEFwE3WokW0vwdA+GJmGn2RBMCy
Dqmunp4IQErSpoVQIATAFPYgwoluCUAALivSULMDwBEuUQEEUApAIW2L+GE5
A8AKFfPqfiILQBYWhQc5xALANTYeqtTwC0CnAIXhfU4CwPunAZW50AxAVyD9
s9/LAcC9yFYqn6ENQNUrZduyTwHAGjpk6xOEDkDR03KCDMcAwHRa41aJVw9A
2axm9QJGAMB/2vXLbBMQQLHiQwRCjf+/EjBWgtyDEEAw8WiLEXj+vyNd743M
7BBA3FTSTql1/b+BsmQvhF4RQAK0OAY7X/y/+KSeOynOEUBsVUTJ0VD7v+1u
EZ1ONhJAokmtTmtY+r8wYWCUO6cSQInULSihUPm/8Sro4KgQE0AbjDRj1WD4
v8uRNJgDeBNAwG2JwgJ997/yIF3lJegTQJ745IVIj/a/l4e+h8hQFEDKw9/k
iLv1v3hcb7+bUhRAGwOcRu+39b9aMSD3blQUQPiOf4FWtPW/HtuBZhVYFED1
kj2EJ631v6QuRUViXxRAfkgWyNOe9b+y1csC/G0UQIV47ZxVgvW/zCPZfS+L
FEBwgXoTAUr1v674ibUCjRRA4mOrUoNG9b+PzTrt1Y4UQD7w13YGQ/W/Unec
XHySFED4rZpvDzz1v9nKXzvJmRRAElvmLCwu9b/mceb4YqgUQHazMSeREvW/
yEaXMDaqFEBtcXDhIQ/1v6obSGgJrBRAQCZqhrML9b9txanXr68UQGDr/ZHZ
BPW/9Bhttvy2FEArh4m5MPf0v9btHe7PuBRA1deQ08jz9L+3ws4lo7oUQIv6
Jtth8PS/emwwlUm+FEAfpWm0lun0v1xB4cwcwBRAz93IhjLm9L8+FpIE8MEU
QJMkHkjP4vS/IOtCPMPDFEAzhML4bN/0vwHA83OWxRRA0ZkPmQvc9L88GUuf

        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVj2s01HkchzH+bsNczH8yEmfMGFtTSRGi7ferdWnXZuXU6Aw1NaptbZR0
3+wikorJHCVkikTNFicbxZKviY7dkdpuRi6VEdZthBoZ1doXn/O8eZ4XH2fp
nrAdJkZGRutm9z81iw96Ptx3bJVzhNbn5kE+JEglA3KOGD1jdpzxjOdD1sdG
EzEnGnV/cBHU7uGDQ5Ne9jXnKOpWtfFadvHhtTBLtIRzCuWoqRt0Yj6ourpW
zOfkIUGiKH8N4oOHd8rvLhwlmpBJljla8GE4KryXx6lBidrFPqV5PJimBNaS
S9Uov+iePu6WM/QU1YmYHs8QMixMU3VxIYxdZIi98RL52kVEStlcWHfC5Quv
/TWqHdlfnXbaCbR1q4RMbi/KYnuVWTs6Qp+3r+nKm/1oy2BLFnndAcryxJ5P
Fgwhsr1J3ySaCz9Wr6b9HD2KBJ3hVQ887CHIJjX48tQYssu4PEZjceBpfst2
a8U4cnpQs2K9kx00KFwXuPlNoo+8IP07/znQt+adf6zhPVrOkmiD49hACbhU
WV6gR923VP0hDSSED9Ql0KM+Ijl7Mj2KQ4KNkW7MhWtAPXnZOzpOsKD2AKXa
r34GOZYMKZPoLCg8c1KzN+kzKkkZPt9XYAuQeLjkqa0RVm1UNLRiW1BTd1j/
+sEIH7y6PLWtnwnm/7wMorwwxn78X1LD85iAAlSL00tMsPSWJFm3iQksKylS
nKTghsp4So4dE7QJ8YY/Ikyxp/2oWNjNgN6FtIxiIYHZ1Hk9r0oZkCjc9p0L
1Qwfl21dOxHDAHuNoKK40wwrXfde6fRmwLoXRQG3683x8Ysh021TdKigXS9T
KCww1/tx5b4kOpAfuKr0WEvcpe3PcqPTgem23tg01Aq3jdye/6+MBlbsicFf
eVS8UlbDIubQYLmXk/LZGBWfnZbqNPk2YCg1Plf92Br7+Ch9FKQN1DWLhJcK
bbAn51CYKNsa5vpuH2Kl0PCk9fg3B8ytYb9YK0oPp+MjezcmlydT4beX79W7
WQwsZ8uOaL5Yga27KLnzOAPf+d75hz/jrIC/WZfRMszA+uig+gMjlpBUsX1J
yhYmbhtQuH4lsYSpYoXfglYm9rcfrXZ5bgEjscyCEC9brGsw3pYmsgD3bVuz
/UptMcGy2On72BzeCQdeX2OwcHFXZm6gyBzUWZ4XKIdZ+PPkokepPWYwzt38
VjDAwv77GSGan8wgJ+1eWnMoibdQDvnHfSbgcOSe+vwwEtu/zzQUzBAgXsrV
x24gcVCrL089TYBTR9JO9iYSuyZS6131BBS7BQRIJSQ++6XOT6sjoOK52mQm
hsQdmUXRcW8IaOG3Jyw5TeJlbvlvtY0ElE2lV5pkkDhkM2vQ6T4Bsoe+I88z
Z/3GiShxAwFhhy5GHpOTeNeTortP6gho/1vi91cuic99qhpsriKgL65vSnqN
xMFD0bnqawQ0B+a4eylJvLuxzJJWSoDSYe0uyxskrk12Gw+9SkBM0/W28nIS
F4rOL9IUEjDJiamaqSKx16ne4OE8Al6MOI4+ukvi5itDyctyCbijahVcqZn9
Nyn3OJJDwNHd7ue+vTfbB8SbWGQTELn6Tcs8IPGnV6bOoXICVs2Rm441kHhi
aX/1hbMEcIfWrLx/n8TRgsCHbzIJMIaJ+PNNJHaghkQszCDgP1yVOus=
        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -10.574597163905455`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-10.574597163905455`, -0.46091516486014217`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, -10.}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Lungs\"", 11, StripOnInput -> False], 
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282325806322*^9, 3.41783582564133*^9, 
  3.479827670240147*^9, 3.479828329902109*^9, 3.479829529412416*^9, 
  3.5185350542806387`*^9, 3.643443751428952*^9},
 CellLabel->"Out[95]="]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Californium", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["The model", "SubsubsectionIcon"],

Cell[TextData[{
 StyleBox["Transfer coeffs  are taken from Table A.15.1 of ICRP 78 are",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"],
 StyleBox["\:f35f",
  FormatType->StandardForm]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"TransferRates", "[", "californium", "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<From\>\"", ",", " ", "\"\<to\>\"", ",", 
        "\"\<Tranfer Rates(\!\(\*SuperscriptBox[\(days\), \(-1\)]\))\>\""}], 
       "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[96]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"From\"\>",
       HoldForm], 
      TagBox["\<\"to\"\>",
       HoldForm], 
      TagBox["\<\"Tranfer Rates(\\!\\(\\*SuperscriptBox[\\(days\\), \\(-1\\)]\
\\))\"\>",
       HoldForm]},
     {"1", "2", "1.8021826694558578`"},
     {"1", "3", "0.6931471805599453`"},
     {"1", "4", "0.0009704060527839234`"},
     {"1", "5", "0.13814423308559712`"},
     {"1", "7", "0.13814423308559712`"},
     {"2", "5", "0.000018990333713971105`"},
     {"3", "5", "0.00004747583428492776`"},
     {"4", "5", "0"},
     {"2", "7", "0.000018990333713971105`"},
     {"3", "7", "0.00004747583428492776`"},
     {"4", "7", "0"},
     {"5", "6", "12"},
     {"7", "8", 
      SubscriptBox["k", "ULI"]},
     {"8", "9", 
      SubscriptBox["k", "LLI"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"From", "to", 
       "Tranfer Rates(\!\(\*SuperscriptBox[\(days\), \(-1\)]\))"}}]]]], \
"Output",
 CellChangeTimes->{3.3992823259314413`*^9, 3.41783582573508*^9, 
  3.4798276703495283`*^9, 3.4798283300895987`*^9, 3.4798295295217867`*^9, 
  3.5185350543587656`*^9, 3.6434437514602036`*^9},
 CellLabel->"Out[96]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "element", ",", " ", "lambda", ",", " ", "fn1", ",", " ", "amad", ",", " ", 
   "class"}], "]"}]], "Input",
 CellLabel->"In[97]:="],

Cell[TextData[{
 " Cf-252: \[Lambda] = Log (2)/ ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]],
 " , with  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]],
 " = 2.64 y: and ",
 Cell[BoxData[
  SubscriptBox["f", "1"]]],
 "=",
 Cell[BoxData[
  RowBox[{
   StyleBox[" ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"], 
   FormBox[
    RowBox[{"5", " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "4"}]]}],
    TraditionalForm]}]]]
}], "MathCaption",
 CellTags->"ICRP 78"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"element", "=", " ", "californium"}], ";", 
   RowBox[{"lambda", " ", "=", " ", 
    RowBox[{
     RowBox[{"Log", "[", "2", "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"365", "*", "2.64"}], ")"}]}]}], ";", " ", 
   RowBox[{"fn1", " ", "=", " ", 
    RowBox[{"5", " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "4"}]]}]}], ";", " ", 
   RowBox[{"amad", "=", " ", 
    RowBox[{"AMADAdultW", "[", "5", "]"}]}], ";", 
   RowBox[{"class", " ", "=", " ", "M"}], ";"}], " "}]], "Input",
 CellLabel->"In[98]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsubsectionIcon"],

Cell["\<\
Whole body and daily urine values from day 1 to 10 are the same that Table \
A.15.7 of ICRP 78 (Values higher that 10 days are not included in ICRP ).\
\>", "Commentary"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[99]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.045756583098840606`", "0.011407708370696738`", 
      "0.9421166363643565`"},
     {"2", "0.003814606482862507`", "0.019310480629817866`", 
      "0.9183140994012409`"},
     {"3", "0.00026089448743220675`", "0.011136022981227622`", 
      "0.9062568478239584`"},
     {"4", "0.00003892368636048593`", "0.004868767326263166`", 
      "0.9006974927367214`"},
     {"5", "0.000025042724555303778`", "0.00193653059134413`", 
      "0.8980882529237131`"},
     {"6", "0.000024158039724506445`", "0.0007492180930706242`", 
      "0.8966690865255335`"},
     {"7", "0.000024085052075351898`", "0.0002943183120518162`", 
      "0.895705913379078`"},
     {"8", "0.000024062772959475317`", "0.00012401499984949517`", 
      "0.8949137584149411`"},
     {"9", "0.00002404367477559888`", "0.000060889646604862406`", 
      "0.8941853175188188`"},
     {"10", "0.000024024789173764114`", "0.00003758800172761241`", 
      "0.8934807209547488`"},
     {"20", "0.00002383687788695453`", "0.00002383980232701663`", 
      "0.8865919569530687`"},
     {"30", "0.000023650439141255212`", "0.00002365273337777985`", 
      "0.8797641382448099`"},
     {"40", "0.000023465460518625807`", "0.000023467736503472407`", 
      "0.8729889591380953`"},
     {"50", "0.000023281930568929862`", "0.000023284188474577128`", 
      "0.8662660130014124`"},
     {"60", "0.000023099837931982718`", "0.00002310207790221349`", 
      "0.8595948966985375`"},
     {"70", "0.000022919171336895855`", "0.000022921393514296794`", 
      "0.8529752102082417`"},
     {"80", "0.00002273991960105771`", "0.000022742124127239523`", 
      "0.8464065566001773`"},
     {"90", "0.000022562071629966127`", "0.000022564258645203832`", 
      "0.8398885420109677`"},
     {"100", "0.000022385616416113855`", "0.000022387786059568355`", 
      "0.8334207756204817`"},
     {"180", "0.000021022821266788008`", "0.00002102485681808098`", 
      "0.7834416670282642`"},
     {"200", "0.000020695305191015242`", "0.000020697308536130227`", 
      "0.7714229115493904`"},
     {"300", "0.00001913278250072113`", "0.00001913463230629327`", 
      "0.7140416779249108`"},
     {"400", "0.000017688375736600884`", "0.000017690083781728278`", 
      "0.66093294526929`"},
     {"500", "0.00001635314531648178`", "0.000016354722475759617`", 
      "0.6117782631474059`"},
     {"600", "0.000015118829066167188`", "0.000015120285379233006`", 
      "0.5662829419084274`"},
     {"700", "0.00001397779082645055`", "0.00001397913556197118`", 
      "0.5241742778829163`"},
     {"800", "0.000012922972963850446`", "0.000012924214679041363`", 
      "0.4851999112950277`"},
     {"900", "0.000011947852488006411`", "0.000011948999083097011`", 
      "0.44912630695451333`"},
     {"1000", "0.000011046400501542875`", "0.000011047459270402256`", 
      "0.4157373485378536`"},
     {"2000", "5.043398726306578`*^-6", "5.043876120970112`*^-6", 
      "0.192076871326704`"},
     {"3000", "2.3044968396361423`*^-6", "2.304712246532004`*^-6", 
      "0.08879727554137236`"},
     {"4000", "1.05384665381091`*^-6", "1.0539439181195422`*^-6", 
      "0.04107572474588617`"},
     {"5000", "4.82308447403369`*^-7", "4.823523980324129`*^-7", 
      "0.01901184440862376`"},
     {"6000", "2.2091010392397047`*^-7", "2.209299785891581`*^-7", 
      "0.008804587713760293`"},
     {"7000", "1.01261921077649`*^-7", "1.0127091528416725`*^-7", 
      "0.004079734046524586`"},
     {"8000", "4.645288909876928`*^-8", "4.6456962515088204`*^-8", 
      "0.0018914071536353413`"},
     {"9000", "2.132607478075471`*^-8", "2.1327921036775896`*^-8", 
      "0.0008773257062863099`"},
     {"10000", "9.797966692121562`*^-9", "9.798804155730552`*^-9", 
      "0.00040714741477475356`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.39928232608784*^9, 3.41783582592258*^9, 
  3.4798276706151667`*^9, 3.4798283302770877`*^9, 3.4798295296624064`*^9, 
  3.518535054483768*^9, 3.6434437515227027`*^9},
 CellLabel->"Out[99]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[100]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV1Xk4Vdv/B/DDwd7nHGQ4lUplSEVliFDKZ6eolCG5SOoWihsivgkhypDS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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV1nk01N0bAPAZS9/vzCDLmBeVFClSVJYi7k0UaZWlFCLJEslS6i0iUVkS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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -5.860304754190506}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-5.860304754190506, -2.654740286819928}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, -5.7}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992823277613096`*^9, 3.41783582773508*^9, 
  3.4798276715683403`*^9, 3.4798283311676617`*^9, 3.4798295305373726`*^9, 
  3.5185350556556654`*^9, 3.6434437516320786`*^9},
 CellLabel->"Out[100]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsubsectionIcon"],

Cell[TextData[{
 StyleBox["Values are the same that  the table A.15.7 of ICRP 78",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"],
 StyleBox["\:f35f",
  FormatType->StandardForm]
}], "Text"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[101]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.00002078914351769364`", "0.28206224844846817`", 
      "0.7171978902419075`"},
     {"2", "3.853668371986566`*^-6", "0.38833572465625543`", 
      "0.3283425948768168`"},
     {"3", "2.6042364535074976`*^-7", "0.19646315397141598`", 
      "0.1316430784608324`"},
     {"4", "2.760048683696748`*^-8", "0.08111059650702894`", 
      "0.050437793479734865`"},
     {"5", "1.3029868287711833`*^-8", "0.031285607427377495`", 
      "0.019115904609077996`"},
     {"6", "1.2110933808033264`*^-8", "0.011743570462576618`", 
      "0.007358576320633234`"},
     {"7", "1.2044674148291866`*^-8", "0.004357176557403056`", 
      "0.002996096371141694`"},
     {"8", "1.2031675439554861`*^-8", "0.0016083873472468389`", 
      "0.0013855425827119555`"},
     {"9", "1.2022010110885788`*^-8", "0.0005923677114765283`", 
      "0.0007921665441191331`"},
     {"10", "1.2012559926995986`*^-8", "0.00021795132870276672`", 
      "0.0005736335779436424`"},
     {"20", "1.1918602491045943`*^-8", "2.1749907708662253`*^-8", 
      "0.00044330666338136403`"},
     {"30", "1.1825381819042258`*^-8", "1.182697203156655`*^-8", 
      "0.0004398869947176571`"},
     {"40", "1.1732891218907051`*^-8", "1.1734029249770136`*^-8", 
      "0.00043649936638359433`"},
     {"50", "1.1641124965482163`*^-8", "1.1642253936663853`*^-8", 
      "0.00043313785509407844`"},
     {"60", "1.1550077378585582`*^-8", "1.1551197381922875`*^-8", 
      "0.00042980225902080704`"},
     {"70", "1.145974282270879`*^-8", "1.1460853929530253`*^-8", 
      "0.0004264923781508066`"},
     {"80", "1.1370115706535553`*^-8", "1.1371217987525653`*^-8", 
      "0.00042320801401657447`"},
     {"90", "1.128119048257066`*^-8", "1.1282284007979723`*^-8", 
      "0.00041994896968411194`"},
     {"100", "1.119296164710036`*^-8", "1.1194046486518358`*^-8", 
      "0.0004167150497410609`"},
     {"180", "1.051155458931989`*^-8", "1.0512572381525704`*^-8", 
      "0.0003917252116350686`"},
     {"200", "1.0347794273803855`*^-8", "1.0348795962641711`*^-8", 
      "0.0003857157656885369`"},
     {"300", "9.566522070192789`*^-9", "9.567446987966382`*^-9", 
      "0.00035702482347202224`"},
     {"400", "8.844308662700607`*^-9", "8.845162699159065`*^-9", 
      "0.0003304701563382628`"},
     {"500", "8.176684196308162`*^-9", "8.177472788761833`*^-9", 
      "0.00030589253720797693`"},
     {"600", "7.559517524798772`*^-9", "7.560245693132646`*^-9", 
      "0.000283144619535103`"},
     {"700", "6.988990514123208`*^-9", "6.989662892778268`*^-9", 
      "0.0002620900498946469`"},
     {"800", "6.46157429713555`*^-9", "6.4621951647770154`*^-9", 
      "0.00024260264692889283`"},
     {"900", "5.9740073322074825`*^-9", "5.974580639028096`*^-9", 
      "0.00022456564168426565`"},
     {"1000", "5.523275127868435`*^-9", "5.523804520840528`*^-9", 
      "0.00020787097474345248`"},
     {"2000", "2.5217331249600272`*^-9", "2.521971826110043`*^-9", 
      "0.00009603948597894081`"},
     {"3000", "1.152263653607512`*^-9", "1.1523713587644328`*^-9", 
      "0.00004439911769470794`"},
     {"4000", "5.269302055386021`*^-10", "5.269788384578366`*^-10", 
      "0.000020538081842182278`"},
     {"5000", "2.4115733193947096`*^-10", "2.4117930759391944`*^-10", 
      "9.506022647611924`*^-6"},
     {"6000", "1.1045645752074141`*^-10", "1.1046639500670988`*^-10", 
      "4.402339862570637`*^-6"},
     {"7000", "0", "0", "2.039888111583426`*^-6"},
     {"8000", "0", "0", "9.45713250870321`*^-7"},
     {"9000", "0", "0", "4.3866729440644106`*^-7"},
     {"10000", "0", "0", "2.0357574786308158`*^-7"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992823282930665`*^9, 3.41783582829758*^9, 
  3.479827672162121*^9, 3.4798283317145047`*^9, 3.4798295310686026`*^9, 
  3.5185350559212956`*^9, 3.6434437517570896`*^9},
 CellLabel->"Out[101]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[102]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV13k4VVsUAHBjeaYMN1Fmzs0QriJKrIMoSoVCMpRURCgNKKQMEYmSInki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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV13c8Vl8cB/BnPzLKeCqVX7Qj2SHJORVSKCRk9iCEjFCohBQyikiEEmVk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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -12.645421930097024`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-12.645421930097024`, 1.147291528867156}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992823316712847`*^9, 3.417835831969455*^9, 
  3.4798276734903135`*^9, 3.4798283332144184`*^9, 3.479829532349803*^9, 
  3.5185350575932026`*^9, 3.643443751991457*^9},
 CellLabel->"Out[102]="],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellLabel->"Out[34]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[103]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Lung\\nretention\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.05758416272963008`", "0.0013011188021246674`", 
      "0.10848929273681754`", "0.49524933718443037`"},
     {"2", "0.05585235511920013`", "0.00012482147324950125`", 
      "0.15489734147932668`", "0.26122167171999167`"},
     {"3", "0.05486730692377238`", "0.000021535611532944173`", 
      "0.07972272508132601`", "0.1523768878744479`"},
     {"4", "0.054000766483623064`", "0.000014845153980711598`", 
      "0.03346748739028863`", "0.1081562506378102`"},
     {"5", "0.053167724600421094`", "0.000014229052679536952`", 
      "0.013294281237661632`", "0.09086268655351308`"},
     {"6", "0.0523562339545934`", "0.000014001425285640765`", 
      "0.00533622582030032`", "0.084010747199672`"},
     {"7", "0.0515641944424301`", "0.000013803174892073625`", 
      "0.002311758203899602`", "0.08109674277546469`"},
     {"8", "0.05079084628980008`", "0.000013611226159035676`", 
      "0.0011755789913966397`", "0.07965512496726539`"},
     {"9", "0.05003562484789138`", "0.000013423941365377143`", 
      "0.000746286389736573`", "0.07876677767538427`"},
     {"10", "0.04929800601835656`", "0.000013241085801503903`", 
      "0.0005792087480442163`", "0.07809145587243183`"},
     {"20", "0.04278630600287194`", "0.000011629493624032085`", 
      "0.0003694073649115038`", "0.07314931494776124`"},
     {"30", "0.037567282659630934`", "0.000010341855904592895`", 
      "0.0002803071476579141`", "0.06934540057889833`"},
     {"40", "0.033325559081909685`", "9.298556718385952`*^-6", 
      "0.00021436236154981508`", "0.06633525129772158`"},
     {"50", "0.029828898008642944`", "8.441028142805555`*^-6", 
      "0.0001653521570592364`", "0.06391606943964312`"},
     {"60", "0.026905541689334556`", "7.726005175129385`*^-6", 
      "0.00012876510255522912`", "0.06193915856336151`"},
     {"70", "0.024427853953733408`", "7.121380129073177`*^-6", 
      "0.00010131930957414844`", "0.06029514690125255`"},
     {"80", "0.022300484543285117`", "6.603204342078613`*^-6", 
      "0.00008062127371616119`", "0.05890332102537465`"},
     {"90", "0.020451784853615755`", "6.153514499966808`*^-6", 
      "0.00006492082372696441`", "0.05770390766350978`"},
     {"100", "0.018827566195422633`", "5.758752858732728`*^-6", 
      "0.0000529347531008319`", "0.056652475854983675`"},
     {"180", "0.010476123883197767`", "3.7227014073081574`*^-6", 
      "0.000016092229813926442`", "0.05089216592002581`"},
     {"200", "0.009141623746447189`", "3.393237993291485`*^-6", 
      "0.00001319224500109269`", "0.04980710704144948`"},
     {"300", "0.004703489345049705`", "2.270752840666286`*^-6", 
      "6.387343979393596`*^-6", "0.045208490884729224`"},
     {"400", "0.0024412250935426346`", "1.6590719046353862`*^-6", 
      "3.702738002486362`*^-6", "0.04141609352437378`"},
     {"500", "0.0012700364515294794`", "1.3059943081477725`*^-6", 
      "2.347378609423274`*^-6", "0.038116679455348676`"},
     {"600", "0.0006617426227325305`", "1.0890797181496277`*^-6", 
      "1.621876292058583`*^-6", "0.03516925750550779`"},
     {"700", "0.00034530464233540996`", "9.453175965902066`*^-7", 
      "1.2181356358391122`*^-6", "0.03249584461575383`"},
     {"800", "0.00018045924942480178`", "8.419019325680772`*^-7", 
      "9.816569688536902`*^-7", "0.030049541257709065`"},
     {"900", "0.00009446016002622502`", "7.616360694432555`*^-7", 
      "8.332603451641176`*^-7", "0.027799806860453236`"},
     {"1000", "0.000049526829528338984`", "6.954225693533421`*^-7", 
      "7.321528494031914`*^-7", "0.025724983303746094`"},
     {"2000", "8.624533968479738`*^-8", "3.1226811586507964`*^-7", 
      "3.123444183522428`*^-7", "0.01188001850946105`"},
     {"3000", "1.835906631626667`*^-10", "1.4266681027403746`*^-7", 
      "1.4268022352802686`*^-7", "0.005491849546825586`"},
     {"4000", "4.610770193731106`*^-13", "6.523709642241292`*^-8", 
      "6.524312405140835`*^-8", "0.002540284526972063`"},
     {"5000", "1.2802297621982334`*^-15", "2.985470530103915`*^-8", 
      "2.985742877907683`*^-8", "0.0011757098800900111`"},
     {"6000", "3.739246571516095`*^-18", "1.3673335914859615`*^-8", 
      "1.3674567405082212`*^-8", "0.0005444579976480911`"},
     {"7000", "1.1186621926660215`*^-20", "6.267240437566365`*^-9", 
      "6.26779770792158`*^-9", "0.0002522709863461921`"},
     {"8000", "3.3869142099882056`*^-23", "2.8748458522799916`*^-9", 
      "2.8750982197992582`*^-9", "0.00011695027003365085`"},
     {"9000", "1.032559995306636`*^-25", "1.3197290831682194`*^-9", 
      "1.3198434599368298`*^-9", "0.000054244843089684245`"},
     {"10000", "3.1634173415717997`*^-28", "6.062926015988118`*^-10", 
      "6.063444795418367`*^-10", "0.000025172788830327294`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Lung\nretention", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992823359096975`*^9, 3.41783583611008*^9, 
  3.479827677756157*^9, 3.4798283375579185`*^9, 3.4798295375371037`*^9, 
  3.5185350609370165`*^9, 3.6434437530070925`*^9},
 CellLabel->"Out[103]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[104]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVkXs0lGkcgOfCKLcwr3Z2yZmKNrZculAmfm9OqKQkZ7STVg3WZsNKRRY1
GYVSKJeaGpEkitYWq9L3RbXaIRUJse6TO+MyHxHb/vGc5+/nPEuFwe5+DBqN
5vqV/924+vi6miOR9ttDSgclAhYZJfTuTeEIAHINyuM9WWTy9HOGgBMAR0uu
JYR5sEiDF9RFO04EWKsoDPfsZJHtZsl8C04C8MWVRuoOLLKitXXjSs5VYJtx
0sJMWeRaG3GBMScf/IfuurhNqZKDPp7dyziPYM5D7dJUqir5men0BFnJIDjG
OCOZVCE7s8v5umvrIdM/yAVNM0l3/eyZoLvN4BNTy3NazyRdzxjPL2tqB4Mb
z8ckBxhkV7m9mS63G9rKH9V3XaGTchtblU33PoHR8AaFcwWNLLwqWPfOdACS
zAsYlS3zhH/ZZu1fA4ZBlN8xuHT3HOGsFetyY2oUJuwqFvffnCXqJNW+mtIx
8FuDfFayZ4hn0hWm5rwJCKyaPyRMmCbkDootQTOT4Is0Hp9ppwimY+bDousU
1OXh9Jw9SsKztzxqkc80kB8r7SxzJwgt2sioMXcG0j3qVTLo48STY8wyHjEL
/FSRT3iEgsg6H9f4m2gO3ItcT0beHiHIU+G5dXo0rGXAQ7mpg4RMw08zWknD
9b7VElenPkLtbbMzs4GOEwt5VTYacgIcK1bH5zJwtF3GnFizi2CrC0Eax8Sx
DmJnUW4b0RUVOvPnPhXs1dZE/3Kviej+QTsxx0wVF1/tWHOivY44ZXZwu7EG
Cw/377aVbZMR3zaaFOe0sLB96CWGWzJBuDZkOz4g1HB72qvm+XIJUax9p1Aq
XYC1JRLF9r77gJTcivighdg/OqBgQ0Al6Jrvpqu4qeMHelZpyLAW1PXH+6OX
aeB9D9w6pvvrYb21UX79qAYuNV+hEKFmmLlNTy17o4kPH096l5HcBuVVfLPM
LC1cllSjObutE76z9R1gi7XxKZvTDwtHu+GooIsf77kIn23EFgLBJzjZPCk7
zNbBrhEcW15eH+hZ8k+3xOhgeSja1ak/CMv3jyRWD+pg6zLb2pCtX78X+1qI
f9LFcfK2Mq7LKEzlSHmmr3XxkQVFS/lCBQwF6V7faa2H1XoXvN6xfwwsDx64
zLuthzvZhl+eCsdBYdbbnqfDxsH3vU1O7JgAWfK6DGY4G+/1YB2L/34Sxrj7
e0x62fjilh6d8IVKSD/79GyVG8I7N7bsevlGCeFewYTEHeEnzshiRb0SBFZc
KsgD4YCSGpPYD0ow+ij6WX8vwn+8p/+I/1VCjrmjo9Ab4QuKb94WDCih+L2M
MRuIsM8H/VY+i4Lq5U1RFucQPihKV5+1paBwKv4hIxHhQy+zIuztKbhYYzv0
/gLCS2LmZk5upsA97JpXZArCfqVyK9pWCpr+8ea9uoJw5olx30kPCuQh8ilh
HsKbPo88Lg6ioMop3dI6H+HPg+dN5SEU5Bts/WXhXYSTlvNvcY5REPjizoei
IoR7erJfRvxOwQQnsGS2BOE+L0n+2jgKGoaWDNf+hbBgvY7Y+xwFpRWvTW4+
QpjZZRCQcIGCiMOWqdueItxfvGpf62UKvDZ3VBuSX3udqv1UMyiwX5yiMvoM
4VspNpGrJBRwBxw2VVYi3PA3T+oupYBOjoemvUB4gp0rC8ui4D8+m1A1
        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV1Hk01dsXAHBTvYyJq3vvuTdJIxkzNBj2tyJFKBXSKDSQoYcG4alkeI0o
pKhUElIpMiQbKXFNReIi8zyWDPH4fX9/nHXWZ52z9jp7r73PkiPuVk5CAgIC
GfT6//5d9bR22d++hn1vI/j5blz0O3KoO5xlB9Fe/M3KJ7kYNvlByI7lDKKC
Zn9FnOAip2j8hgHLBxYfdkp3cuRis3KYtTrrX2gt2JMgbcfFgsbG9atYMSC/
0uhZkDEXtdYGJi9jJYHK+2oHahEXM6+4vunoToLJVu+8T4SLhs3WuQlZySAH
q5/vYHFxa6hSxap9z+Fsjq/dMVkuproeO7fQ8iWUiFekJYpysTBPIpaEvwZj
xvNjAWMc7HewaVdkZUOYaqTZoyoO+uomzpiGZkPn/TvluhUclBCdZHn+yQb/
D/KlPB4HVVJjzAsbcsD45Z0NAsUcdJ1ozHB4mAtKN0o1Lr/n4JktaUZWtxFI
8tD4vBQOTtSvY0bIfwCLCj3BmRAOUkb2y1bafIACM+O1bUEcDHkeqplz4wP8
qMicKQnkICug3qxNoAi0tBQhPoCD65b7Bmi10faOcnc/y8Fz7nk9X59+AnFS
lHrpOAf/CG95x9AsBWmej+W/phwUrBMb7XYqhXvdz4obt3JwXmrF6tyYUhiy
qLLVMuEg03bvXScRHoixv75t38xB7ZSTPhm1PLBvtDc6bEDnsztina1/OVDb
XZSzNDjoYeVRX9ZRCXlNUzqdLA6OvrMaWytQBdw/v3adY9L5rtSRiSdV4BTN
tpJayEH/6cltpy2rIGrXsy4DWQ5eTbiUJZ9VBYWH641eS3Lw2Z/IaPerX6Dk
wDq130IcbI3PtV6gVQ3V03eGigcJpmjvLBvbXg0rl3iHxwwQPP2xfXPD0WqY
5Xwpce0nKNorrvk0pho2JJr+ZvUS1NC0EzcQqoH4LyOCFzsI+ueN5R2vqoE0
2RsXYxsIkgZ1JXSvBYeVNbcGSwm2uxbefxJaC8yWzhdDJQRTZ60XXnlUC2F6
/63++ZngxqX+wta1tfDv+UFq6hPB4868xj7D77C5ZkXaog8EMyaOhzOl6iBS
s8cm/h1BK7n4KbeUevjUm6HwIJWg+qsUm6Dieqiv9LbNfE5Qwvzt69j2epA/
JTJelULwYyDPhcflQ7foHnvRZIJ6o2N8pWt80Pa6kBnylOCyr2bv2l0bgNl7
r/3TA4JjN3/72qk3wV5yV1n/FsGvKgJ1p8yaoMvwE98vguDLYjGd0GNNUKe8
MhfDCToLKAy8vd8EvKWLxUzDCP5wNz0gJ/0D5vEiHjhfJ1hscd+gcvgHZB+Y
tm8NIWgetGxWsa4Z7hp/u/fQn6DKUOVbw85mOPVlPFWatpitn4fdL/qcCQ8C
/Oj3K31rCZNsgSn1FI6DL0GqLPiDwKYWqJxjZr3Gh+AaRl9oU1ILZLU5Nk94
E2TFv2LE+LaC05LDqfJudD5iB8vSQ1thvu2uS09dCdZ4igVVRbZCYV0/Q5N2
uLHD+LxXrbD8xzznLScJivcw6s90tEJ0clneOWeCM+pn7++xaANjKSl9oWME
23INlRcotMPV8tjciMMEeckJNcZq7bC9wVxRmfabO1IXfPTboaAllso/RDDQ
u6m2zbYdVr0OfzJykK63qv/ljLB2SL6+ccTuAEHHe7nN+4Q7QHpyfZSFHd0v
PvpRCZ0dYH+PE522m45//PEm/mgHSNzPkT1I+421xOB84U4IN2lZIUY7cE2D
0bnFnWD48eN8x110/N7zP81sO+F2tW+lvBVBp7055iOfO+F13UadF5YEO9du
ENF/3gWapiZCOmYET2X92a+W0wXZ48FVP00JTm/ISVf43AVOlSYLX9GWMdQ/
NqejC77pzv1PjTYYGZaUc7thL+fPKo1tBKN3bLppf7Ubtl7O2WZiQtD0hCk3
2KUHnB2lbQo30/XuFfM+d64HOln79lynffhkaZlLcA/ELvj5ci/t0+7b/9nx
qAfu3l3nN7KJ4CNvi1Y2vwck79VYL6c9fcEqMcW0F1oO+p+Opej5ibHT/qLU
B1Xru2tKDAgqrS2Iqtbtg2Q/8/mPaD/+qjT1bXMfWP7sCT5PO0ZiMp9/oA+4
Sxq0VWlf9o+y7Ajrg/xRK48IfYL7j1Q7T0z2gUXNsIiLHt1/yhYP5Uv6YTL9
/D+b19P3P6aLLKntB8kT+E6RtoDDouNL2/sh/MqMshDtsbv9aqtm+sH81cfo
/HUEWySvvNNcMwDBsDF1E+3MkU+1RjEDYEmCjpuvJXgsa6OUi/MgFEnt8bqo
Q7C/3tEx6OwgDOk8LnSk7TEdnP0waBAEb7sYmtD2gfKj3+MHIdHp6RsJ2leL
7PKM+YOgHf8j6o42PY9Vnh4K24fAq/w3P1uL4H+jVj29C4dBJi0zgrWGoInk
ZbMHE8Pgd+JMioo6wYure6d0ZodhQ3y1JYv2u22WKaVzRiDW1n2OCG2NILbk
uMwILPxyJoGvRs/T7PNyc9URuOYan3WFdu/wt51T9iPwblB+dFCV4LXqVbbW
pSPAPGq5HVXo/+Iuz1Ei7idsdSnbFahMMD9uhZKa3igo2iXwnFbQ/bdpxMht
6jdsELiz89cSgsLG99NfxI7DXo+G3PBFBG26c/3mO0xC0+qja9xYBCUFhoaX
KUzBZYO1vHYZ+r3ewll6edOQpFPEMpQk+PBqyHePCzNweem2pJC5BDHgbMJX
GQEquz4p4cUsG0vFnST8xwSot6pyl2+Ns/GvqnoT4W+ClHfbpGLLIBvBuEA1
NEGIag2a5ynVyUZZsSMQFyJMZRheeZLCZ2Obn+fU630ilPjuag+VKja2r5a6
9lh5DqWSYD0s95GNAcr2psvE51IDWPlgSRYb2d+Xpz1umEud8snzWpbCRvNv
8cZv8v6irvbubpCMZWOa1LPUuLh51M2datw119jIGFMoCHUTpdT8Gv/z8mPj
ArWdgiI7xCjDsTifvS5sFJP71euvKE5Nnr7JPLeXjTq68knVw+LUr1HjaXET
Nk49FbydVSlBveyZspVew8bcYmvl+w8lqZpE3S2Ri9hINjj2yQZKUcldVxZ7
zmWjl12bdajNfMrST2y70DAL/6n/XXpSVpqKi19+YEsdC2U0rC82XJKmFqWl
evDzWLj0wNA1Xr80JeqtXuD7lIUX0hzVAw8uoCyyLPZ5XmXhxOM4PaXyBZSM
T3yl3SkWDrgtiLXQlaFwQEY5yYaFGvaHb+k9laG8dvdX/q3HwhHl7uZEaVmq
rCPgKF+BhaVh2tHCZ2WpaP8UoSdzWfhT4UDH8m5ZKm4mvHZFLxOjgt8HF+9g
UIIXZ/vjKph4dr973l0rBnX6wgpcRdtOU2HcbTeDsvONjkwrZ6I8/8JROVsG
tarpkvnHMiY+VjM2PnKIQaW9CG4fKGViWk2p0LQrg/q+A/MMipnIW1rnp36F
Qe17IuXejExMnQhNF7rGoOT2Ob13pn2jbMNAzXUGddHSUOZ3HhOtztzb7xvO
oJJC4j6J0q4rOaT3+Q6DmnVQctbKZWLnqc6JI4kMakfFRGRwFhOLt0Rp6CYx
qEiOuJYM7STO1uOiKQxKVUe/+l4mE12LntW+eMGgSt0VV6S9ZeIoyzVjOoNB
7fwiLdqYzsRvA4sGKzIZlG+kSsUx2m8Lypc/ymZQD0PSY36+YaLPSY3b294z
qKO3dTfNo71/YwuPiwyq589G+YjXTDRcGC4ynM+goodaZhfRVujbpF9YyKDy
pxZ3JaYxURB/eUYWMSiO0NxqLdr/A1XBeAU=
        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV1Xk01N0fB/BhbKGyDM9UKqKFhEoU8vm2EJIkEVlKuyKVNmVJUdkqQqWU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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -7.966669610529336}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-7.966669610529336, 2.3354291135237597`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Lungs\"", 11, StripOnInput -> False], 
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282346232032*^9, 3.417835846438205*^9, 
  3.479827683725213*^9, 3.479828343729438*^9, 3.479829548552306*^9, 
  3.5185350660464897`*^9, 3.643443754382104*^9},
 CellLabel->"Out[104]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BioassayReport", "[", 
   RowBox[{
    RowBox[{"compartMatrix", "[", "californium", "]"}], ",", " ", "1", ",", 
    RowBox[{"AMADAdultW", "[", "5", "]"}], ",", " ", "M", ",", 
    StyleBox[
     RowBox[{" ", 
      StyleBox["  ",
       FormatType->StandardForm,
       FontFamily->"Times New Roman"]}]], 
    FormBox[
     RowBox[{"5", " ", 
      SuperscriptBox["10", 
       RowBox[{"-", "4"}]]}],
     TraditionalForm], ",", " ", "180", ",", "  ", 
    RowBox[{
     RowBox[{"Log", "[", "2", "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"2.64", "*", "365"}], ")"}]}], ",", " ", 
    RowBox[{"IntakeWay", "\[Rule]", " ", "\"\<Inhalation\>\""}], ",", " ", 
    RowBox[{"ShowReport", "\[Rule]", " ", "\"\<BioassayTable\>\""}]}], "]"}], 
  "//", "Chop"}]], "Input",
 CellLabel->"In[105]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Lung\\nretention\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.05758416272963008`", "0.0013011188021246674`", 
      "0.10848929273681754`", "0.49524933718443037`"},
     {"2", "0.05585235511920013`", "0.00012482147324950125`", 
      "0.15489734147932668`", "0.26122167171999167`"},
     {"3", "0.05486730692377238`", "0.000021535611532944173`", 
      "0.07972272508132601`", "0.1523768878744479`"},
     {"4", "0.054000766483623064`", "0.000014845153980711598`", 
      "0.03346748739028863`", "0.1081562506378102`"},
     {"5", "0.053167724600421094`", "0.000014229052679536952`", 
      "0.013294281237661632`", "0.09086268655351308`"},
     {"6", "0.0523562339545934`", "0.000014001425285640765`", 
      "0.00533622582030032`", "0.084010747199672`"},
     {"7", "0.0515641944424301`", "0.000013803174892073625`", 
      "0.002311758203899602`", "0.08109674277546469`"},
     {"8", "0.05079084628980008`", "0.000013611226159035676`", 
      "0.0011755789913966397`", "0.07965512496726539`"},
     {"9", "0.05003562484789138`", "0.000013423941365377143`", 
      "0.000746286389736573`", "0.07876677767538427`"},
     {"10", "0.04929800601835656`", "0.000013241085801503903`", 
      "0.0005792087480442163`", "0.07809145587243183`"},
     {"20", "0.04278630600287194`", "0.000011629493624032085`", 
      "0.0003694073649115038`", "0.07314931494776124`"},
     {"30", "0.037567282659630934`", "0.000010341855904592895`", 
      "0.0002803071476579141`", "0.06934540057889833`"},
     {"40", "0.033325559081909685`", "9.298556718385952`*^-6", 
      "0.00021436236154981508`", "0.06633525129772158`"},
     {"50", "0.029828898008642944`", "8.441028142805555`*^-6", 
      "0.0001653521570592364`", "0.06391606943964312`"},
     {"60", "0.026905541689334556`", "7.726005175129385`*^-6", 
      "0.00012876510255522912`", "0.06193915856336151`"},
     {"70", "0.024427853953733408`", "7.121380129073177`*^-6", 
      "0.00010131930957414844`", "0.06029514690125255`"},
     {"80", "0.022300484543285117`", "6.603204342078613`*^-6", 
      "0.00008062127371616119`", "0.05890332102537465`"},
     {"90", "0.020451784853615755`", "6.153514499966808`*^-6", 
      "0.00006492082372696441`", "0.05770390766350978`"},
     {"100", "0.018827566195422633`", "5.758752858732728`*^-6", 
      "0.0000529347531008319`", "0.056652475854983675`"},
     {"180", "0.010476123883197767`", "3.7227014073081574`*^-6", 
      "0.000016092229813926442`", "0.05089216592002581`"},
     {"200", "0.009141623746447189`", "3.393237993291485`*^-6", 
      "0.00001319224500109269`", "0.04980710704144948`"},
     {"300", "0.004703489345049705`", "2.270752840666286`*^-6", 
      "6.387343979393596`*^-6", "0.045208490884729224`"},
     {"400", "0.0024412250935426346`", "1.6590719046353862`*^-6", 
      "3.702738002486362`*^-6", "0.04141609352437378`"},
     {"500", "0.0012700364515294794`", "1.3059943081477725`*^-6", 
      "2.347378609423274`*^-6", "0.038116679455348676`"},
     {"600", "0.0006617426227325305`", "1.0890797181496277`*^-6", 
      "1.621876292058583`*^-6", "0.03516925750550779`"},
     {"700", "0.00034530464233540996`", "9.453175965902066`*^-7", 
      "1.2181356358391122`*^-6", "0.03249584461575383`"},
     {"800", "0.00018045924942480178`", "8.419019325680772`*^-7", 
      "9.816569688536902`*^-7", "0.030049541257709065`"},
     {"900", "0.00009446016002622502`", "7.616360694432555`*^-7", 
      "8.332603451641176`*^-7", "0.027799806860453236`"},
     {"1000", "0.000049526829528338984`", "6.954225693533421`*^-7", 
      "7.321528494031914`*^-7", "0.025724983303746094`"},
     {"2000", "8.624533968479738`*^-8", "3.1226811586507964`*^-7", 
      "3.123444183522428`*^-7", "0.01188001850946105`"},
     {"3000", "1.835906631626667`*^-10", "1.4266681027403746`*^-7", 
      "1.4268022352802686`*^-7", "0.005491849546825586`"},
     {"4000", "0", "6.523709642241292`*^-8", "6.524312405140835`*^-8", 
      "0.002540284526972063`"},
     {"5000", "0", "2.985470530103915`*^-8", "2.985742877907683`*^-8", 
      "0.0011757098800900111`"},
     {"6000", "0", "1.3673335914859615`*^-8", "1.3674567405082212`*^-8", 
      "0.0005444579976480911`"},
     {"7000", "0", "6.267240437566365`*^-9", "6.26779770792158`*^-9", 
      "0.0002522709863461921`"},
     {"8000", "0", "2.8748458522799916`*^-9", "2.8750982197992582`*^-9", 
      "0.00011695027003365085`"},
     {"9000", "0", "1.3197290831682194`*^-9", "1.3198434599368298`*^-9", 
      "0.000054244843089684245`"},
     {"10000", "0", "6.062926015988118`*^-10", "6.063444795418367`*^-10", 
      "0.000025172788830327294`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Lung\nretention", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282350423525*^9, 3.417835851031955*^9, 
  3.4798276879598045`*^9, 3.4798283479635687`*^9, 3.4798295529740114`*^9, 
  3.5185350693746786`*^9, 3.643443755397738*^9},
 CellLabel->"Out[105]//TableForm="]
}, Open  ]],

Cell[TextData[{
 StyleBox["Values are the same that  the table A.15.6 of ICRP 78",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"],
 StyleBox["\:f35f",
  FormatType->StandardForm]
}], "Text"]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Model for strontium, barium, uranium,  radium , and lead", "Section"],

Cell[CellGroupData[{

Cell["\<\
Biokinetic model for alkaline earth elements, lead and uranium \
\>", "SubsubsectionIcon"],

Cell["GI include ST,SI,ULI,LLI (not represented)", "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .88324 
%%ImageSize: 531 469 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00179356 0.0210295 0.00179356 [
[ 0 0 0 0 ]
[ 1 .88324 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 0 m
1 0 L
1 .88324 L
0 .88324 L
closepath
clip
newpath
% Start of colorimage (RGB)
p
.02381 .02103 translate
.95238 .84118 scale
1593 string
531 469 8 [531 0 0 469 0 0] {
\tcurrentfile
\t1 index
\treadhexstring
\tpop
}  false 3 Mcolorimage
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFEFEFEFFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFEFEFE000000FCFCFC
FFFFFFFCFCFCFDFDFDFFFFFFFCFCFCFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFAFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBFCFCFCFCFCFCFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFBFBFB050505FDFDFD
FDFDFDFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFF2F2F2FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFEFEFEFEFEFEFAFAFAFFFFFF000000FFFFFF
FAFAFAFFFFFFFBFBFBFFFFFFFEFEFEFEFEFEFEFEFEFDFDFDFDFDFDFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9FFFFFFF4F4F4070707FFFFFFFFFFFFFFFFFF030303000000020202000000000000
040404020202000000050505000000090909020202000000FFFFFFFCFCFCFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7F7FFFFFF000000000000020202000000FBFBFBFCFCFCFEFEFE000000FFFFFF
FFFFFFFFFFFFFCFCFCFEFEFEFFFFFFFCFCFC000000FFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFBFBFBFCFCFC010101FFFFFFFEFEFEFFFFFFFFFFFFF7F7F7030303FFFFFF
F9F9F9FAFAFAFFFFFFFFFFFFFFFFFF010101FFFFFFFEFEFEFBFBFBFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF6F6F6FDFDFDFFFFFF010101FCFCFCFCFCFCFEFEFEFBFBFBFFFFFF000000FFFFFF
FFFFFFFFFFFFFBFBFBFEFEFEFFFFFF000000FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFFFFFFFFFFFFFDFDFD000000FFFFFFFFFFFFFFFFFFFFFFFF020202FAFAFA
FEFEFEFCFCFCFFFFFFFFFFFF000000FFFFFFFEFEFEFDFDFDFFFFFFFCFCFCFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFFFFFFFF9F9F9040404FFFFFFFEFEFEFFFFFFFFFFFF030303FDFDFD
FFFFFFF9F9F9FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFBFBFB000000FFFFFF
FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9FFFFFFFFFFFFFAFAFAFFFFFFFFFFFF000000FFFFFFFEFEFE090909000000FFFFFF
FEFEFEF6F6F6000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF000000F8F8F8FFFFFF000000F6F6F6
FFFFFF060606FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFCFCFCFFFFFFFFFFFFFAFAFAFEFEFE000000FFFFFFFCFCFC000000FFFFFF
000000FFFFFFF8F8F8FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFFFFFFFAFAFAFFFFFFFFFFFFFEFEFEFFFFFF010101FDFDFD030303000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFBFBFBFEFEFEF9F9F9FFFFFFF8F8F8FFFFFF000000FFFFFF000000010101
FFFFFFFFFFFFFAFAFAFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFF000000010101FFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFBFBFBFFFFFF
FAFAFAFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFEFEFEFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC000000010101FBFBFB
FFFFFFFDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFF8F8F8FFFFFFFDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F5F5FFFFFFFFFFFFFBFBFB
FFFFFFF5F5F5FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFEEEEEEFFFFFFFFFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFEFEFEFFFFFFFBFBFBFFFFFFF5F5F5FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF040404FFFFFF
FBFBFBFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF7F7F7FFFFFFFFFFFFF9F9F9FFFFFFF6F6F6
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF5F5F5000000FFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFFFFFFFFCFCFCFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FEFEFEFFFFFF
FFFFFFFEFEFEFEFEFEFAFAFAFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFEFEFEFEFEFEFDFDFDFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF5F5F5FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FCFCFCFBFBFBFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFFAFAFAFCFCFCFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFA000000000000
000000050505050505010101000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000020202FBFBFBFEFEFEFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBF7F7F7FFFFFFFCFCFCFFFFFFFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEF9F9F9FFFFFFF8F8F8FCFCFC
FFFFFFFFFFFFFCFCFCFFFFFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF050505FFFFFF
FCFCFCFCFCFCF6F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFE020202FFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFFFFFF020202020202060606010101000000
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101060606000000000000010101
010101000000000000040404010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
000000FFFFFFF8F8F8F4F4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFD000000FDFDFD
FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FDFDFDFCFCFCFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC000000F9F9F9FFFFFFF9F9F9FFFFFF
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFAFAFAFFFFFFFFFFFFFEFEFE
FEFEFEFFFFFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
030303FDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFF000000FFFFFF
FBFBFBFEFEFEFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFE000000FFFFFFFEFEFEFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFBFBFB
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FEFEFEFDFDFDFEFEFEFFFFFFFEFEFEFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFDFDFDFFFFFFFAFAFAFFFFFFFFFFFFFDFDFDFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FCFCFCFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
F9F9F9FFFFFFFFFFFFFAFAFAFFFFFFFBFBFBFFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFBFBFBFCFCFCFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFEFEFEFDFDFDF7F7F7010101000000
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
020202000000000000000000010101FEFEFEFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFDFDFDFFFFFFFBFBFBFFFFFFFFFFFF000000010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101020202060606000000000000
FEFEFEFBFBFBFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFCFCFCFEFEFEFFFFFFF8F8F8FFFFFF000000FFFFFF
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFCFCFCFCFCFCFFFFFF010101F9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFEFEFEFEFEFEFFFFFFFFFFFFF7F7F7020202FEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEF8F8F8FDFDFDFFFFFF070707
FCFCFCFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFFFFFF000000FCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFDFDFDFDFDFD000000FDFDFDFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FCFCFCFDFDFDFFFFFFFFFFFFFBFBFBFFFFFFFEFEFE030303FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFAFAFA000000
FDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6040404FEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF4F4F4FFFFFFFEFEFE000000FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFBFBFBFEFEFE000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF000000
FEFEFEFFFFFFF0F0F0FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFDFDFDFDFDFDFFFFFFFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFF8F8F8FFFFFF030303FBFBFBFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFF8F8F8FFFFFFFDFDFDF9F9F9FFFFFFFBFBFB030303FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF000000
FFFFFFFCFCFCFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFEFEFE050505FBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFF000000FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFDFDFDFEFEFEFFFFFFFBFBFBFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFEFEFE010101
FEFEFEFEFEFEFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFBFBFBFFFFFFFDFDFDFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFF
FAFAFAFFFFFFFFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFDFDFDFFFFFFFCFCFC
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFDFDFDFFFFFFFCFCFCFFFFFF
FFFFFFF9F9F9FFFFFFFBFBFBFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFF
FFFFFFFCFCFCFFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFBFBFBFDFDFDFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFEFEFEFFFFFF
FAFAFAFFFFFFFFFFFFF8F8F8050505FEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFEFFFFFFFAFAFAFFFFFFFFFFFF000000F7F7F7FFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFF000000FEFEFEFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFAFAFAFFFFFFFEFEFEFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FDFDFDFFFFFFFCFCFC
FFFFFF060606FEFEFEFFFFFF000000FFFFFFF9F9F9FFFFFF000000FFFFFF000000FFFFFF
FFFFFFF6F6F6030303FFFFFFFFFFFF000000FDFDFDFFFFFFFCFCFC000000FFFFFF000000
FFFFFFFCFCFCFFFFFFFCFCFC000000020202FFFFFFFEFEFEFBFBFBFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFF000000FFFFFF000000FFFFFFFFFFFFFFFFFFFBFBFB020202FFFFFF
010101FFFFFFFFFFFF000000FFFFFFF4F4F4FFFFFF040404F5F5F5FFFFFFFDFDFDFEFEFE
FFFFFFFBFBFBFFFFFFFFFFFF000000FFFFFFFFFFFFFEFEFE040404000000010101000000
000000030303FFFFFFFDFDFDFFFFFF060606FCFCFCFDFDFDFFFFFFFDFDFDFEFEFEFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF010101FDFDFDFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFDFDFDFFFFFF
FFFFFF030303FDFDFDFFFFFFFBFBFBFFFFFFFEFEFEF9F9F9050505FFFFFFFFFFFFFAFAFA
FFFFFFFDFDFDFFFFFFFCFCFCFCFCFCFFFFFFFDFDFDFFFFFFF5F5F5FFFFFFFEFEFEFEFEFE
FFFFFFFDFDFDFCFCFCFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFFFFFFFAFAFAFFFFFF
FFFFFFFCFCFCFEFEFEFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFF7F7F7FFFFFFFCFCFCFFFFFF
FFFFFFFDFDFDF8F8F8020202FEFEFEFEFEFEFEFEFEFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFD010101FFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
FFFFFFFDFDFDFAFAFAFCFCFCFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBFFFFFFFDFDFDFDFDFDFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFBFBFBFBFBFBFFFFFFFDFDFD000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFEFEFEFFFFFF010101FDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFDFDFDFEFEFEFEFEFEFDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFAFAFAFFFFFFFAFAFAFEFEFEFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFFFFFFFCFCFCFFFFFFFAFAFAFFFFFFFCFCFCFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFDFDFDFDFDFDFEFEFEFFFFFF
FFFFFF000000FFFFFFF9F9F9FFFFFFFCFCFC000000FFFFFFFEFEFEFFFFFF050505F4F4F4
FFFFFF000000FFFFFFFCFCFC010101FFFFFFFBFBFB040404FBFBFBFBFBFB030303FFFFFF
FFFFFFFAFAFAF9F9F9FFFFFF010101FEFEFEF9F9F9FFFFFF000000FFFFFFF9F9F9000000
F8F8F8FFFFFFFDFDFDFBFBFBFFFFFF000000FFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFCFCFC010101000000000000010101010101
000000040404000000080808000000000000010101000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000040404000000
000000020202000000030303000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000050505000000000000000000000000010101000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000040404000000030303FFFFFFFFFFFFFCFCFCFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFF020202020202FFFFFFFBFBFBFFFFFF
FEFEFE040404FEFEFEFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFEFEFEFCFCFC
FCFCFCFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFBFBFBFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FFFFFFFCFCFC000000FEFEFEFFFFFFFFFFFFFFFFFFFAFAFAFAFAFAFFFFFFFDFDFDFFFFFF
FFFFFFFCFCFCFFFFFFFCFCFCFEFEFEF9F9F9FFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FBFBFBFDFDFDFEFEFEFCFCFCFFFFFFFFFFFFFBFBFBFBFBFBFFFFFFFFFFFFFEFEFEFAFAFA
FBFBFBFFFFFFFCFCFCFAFAFAF9F9F9FFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFFFFFF000000
010101FFFFFFF9F9F9FFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFEFEFE
040404FFFFFFFCFCFC000000000000030303000000FFFFFFFFFFFF000000020202050505
F4F4F4FEFEFE000000FFFFFFFAFAFAFDFDFD000000FFFFFF020202000000010101010101
000000010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFF000000FFFFFF040404000000000000020202000000000000
000000FFFFFFFFFFFFF8F8F8FBFBFB070707FFFFFFFBFBFBFFFFFFF6F6F6FDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFAFAFAFFFFFF000000FFFFFFFAFAFAFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFF7F7F7
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFF7F7F7FFFFFFF9F9F9FFFFFF
FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFBFBFBFFFFFFFFFFFFFEFEFE
FFFFFFFAFAFAFFFFFF030303FFFFFFF6F6F6FFFFFFFCFCFCFFFFFF000000FDFDFDFFFFFF
010101FFFFFFF8F8F8FFFFFF000000FFFFFFFBFBFB000000FDFDFDFFFFFF000000FBFBFB
FFFFFF000000050505000000FFFFFF000000FCFCFC000000FFFFFFFEFEFEFFFFFF000000
FFFFFFFFFFFF040404F9F9F9FFFFFFFEFEFEFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
F8F8F8FFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFF8F8F8FDFDFDFCFCFCFAFAFAFEFEFEFFFFFFFBFBFBF7F7F7FFFFFFFEFEFEFFFFFF
FFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFEFEFEF9F9F9FCFCFCFDFDFDFEFEFEFFFFFFFEFEFE
FEFEFEFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFF9F9F9FFFFFF
FEFEFEFCFCFCFCFCFCFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFF8F8F8FEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFFFFFFFFFFFF
FDFDFDF9F9F9FEFEFEFDFDFDFFFFFFFAFAFAFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFDFDFD010101FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFDFDFD
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFF7F7F7000000000000070707000000FFFFFFFEFEFEFFFFFFFBFBFB
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFF050505FFFFFFFCFCFCFFFFFFFEFEFE
FFFFFFFBFBFB000000020202000000FFFFFFFDFDFDF7F7F7FEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFFFFF8F8F8010101FFFFFF
FFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFBFBFBFFFFFF000000000000000000FFFFFF
FFFFFFF8F8F8FFFFFFFFFFFFFBFBFBFFFFFF000000FFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFF9F9F9FCFCFCFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFBFBFBFFFFFFFFFFFF
F8F8F8FFFFFF060606FDFDFDFEFEFEFFFFFFFDFDFD000000FFFFFFFFFFFFF6F6F6FFFFFF
FAFAFAFFFFFF010101FCFCFCFDFDFDFFFFFFFEFEFEFAFAFAFDFDFDFFFFFFF8F8F8FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFAFAFAFFFFFFFFFFFFFBFBFBFDFDFDFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFEFEFEFEFEFE000000FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFFFFFCFCFC030303050505
000000FCFCFCFFFFFFFBFBFBFFFFFFFFFFFFFFFFFF050505F5F5F5FFFFFFF7F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBFFFFFFFAFAFAFFFFFF000000FBFBFBFFFFFFFCFCFCFEFEFEFDFDFDFFFFFF
FFFFFFFBFBFBFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF010101FDFDFDFFFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFFFFFFF8F8F8FFFFFFFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFFFFFFFFFF000000FEFEFE
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FDFDFDFFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFEFEFE
FFFFFFFFFFFFFCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFCFCFCFFFFFFFCFCFC
FFFFFFFBFBFBFEFEFEFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFCFCFC
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFDFDFDFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
FAFAFAFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFDFDFDFDFDFDFFFFFFF9F9F9FFFFFFFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFFFFFF000000FFFFFFFEFEFEFDFDFDFFFFFFFAFAFAFFFFFF
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFFFFFBFBFBFFFFFFFFFFFF
FDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFEFEFEFFFFFF000000FDFDFDFFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFFFFFFFCFCFCFDFDFD000000FFFFFFFDFDFDFCFCFCFFFFFFFFFFFFFBFBFB
FFFFFFFEFEFEFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFD010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFD010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFB000000020202000000020202040404000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000010101000000010101000000FFFFFFFDFDFDFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFBFBFBFDFDFDFFFFFFFDFDFDFFFFFF040404000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000040404020202000000000000FFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFAFAFAFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFDFDFDFFFFFFFEFEFEFAFAFAFDFDFDFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFAFAFAFFFFFFFEFEFEFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFEFEFEF8F8F8FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFCFCFCFFFFFFFDFDFDFCFCFCFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFBFBFBFDFDFDFFFFFFFFFFFFF9F9F9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFAFAFAF8F8F8FFFFFFFFFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFF8F8F8FDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEF8F8F8FFFFFFFDFDFDFCFCFCFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAF8F8F8FFFFFFFCFCFCFFFFFFFFFFFFFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFDFDFDFEFEFEFFFFFFF5F5F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFAFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFF7F7F7FFFFFFFEFEFEFCFCFCFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFF4F4F4FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFEFEFEFCFCFCFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFBFBFBFFFFFFF9F9F9FFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFBFBFBFFFFFFFAFAFAFFFFFFFFFFFFFDFDFDFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFBFBFBFFFFFFFDFDFDFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFBFBFBFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFEFEFEFFFFFFFCFCFCFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFFFFFF
FEFEFEFDFDFDFCFCFCFFFFFFFFFFFFFDFDFDFEFEFEFCFCFCFFFFFFFFFFFFFFFFFFFDFDFD
FEFEFEFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFFFFFF
FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFDFDFDFFFFFF
F8F8F8FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFFEFEFEFFFFFF030303FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFBFBFB
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFF
F3F3F3FDFDFDFFFFFFFCFCFCFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFF9F9F9
FCFCFCFFFFFFFBFBFBFFFFFFFEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFAFAFAFFFFFFFAFAFA
FCFCFCFFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF000000
010101010101FBFBFBFBFBFBFFFFFFFFFFFFF8F8F8FFFFFFF9F9F9FFFFFFFDFDFDFDFDFD
FFFFFFFEFEFEFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFAFAFAFFFFFF
FFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF9F9F9FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFBFBFBFFFFFF
FFFFFFFEFEFEFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFCFCFC
FFFFFFFFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFF9F9F9FCFCFCFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFAFAFAFFFFFFF8F8F8F6F6F6FFFFFFFFFFFFFFFFFFFAFAFAFFFFFF
FFFFFFF2F2F2FFFFFFFFFFFFFDFDFDFEFEFEFFFFFFF9F9F9FEFEFEFCFCFCFFFFFF040404
030303000000FFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFCFCFC
FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFCFCFC010101FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFF
FFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFC
FAFAFAF8F8F8FEFEFE010101000000F6F6F6FFFFFFFFFFFFFFFFFF000000000000FDFDFD
000000FFFFFFFCFCFCFFFFFF060606000000FFFFFF000000FFFFFF010101000000FFFFFF
FBFBFBFFFFFF000000FFFFFFFFFFFFFFFFFF020202050505FFFFFFFBFBFBFEFEFEFBFBFB
FBFBFB000000070707F8F8F8FCFCFC060606000000000000000000FBFBFBFFFFFFFBFBFB
FFFFFFFFFFFFFCFCFCFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFC
FAFAFAFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFB
FFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFF000000030303FFFFFFFFFFFFFDFDFD010101000000000000FFFFFF
020202FDFDFDFFFFFF000000000000020202000000000000FDFDFD000000020202FFFFFF
FFFFFFFCFCFC010101FFFFFFF7F7F7050505000000000000020202FEFEFEFFFFFFFFFFFF
FFFFFF000000000000FFFFFFFEFEFE000000010101000000010101070707FDFDFDFFFFFF
F9F9F9F6F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FFFFFFFFFFFFFAFAFAF9F9F9FFFFFF010101FFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEF8F8F8FEFEFEFDFDFD
FFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFF8F8F8FFFFFF
FFFFFFF9F9F9FFFFFF000000000000FCFCFCFFFFFFFBFBFB000000010101FFFFFFF8F8F8
020202FAFAFA030303000000050505FFFFFF000000070707FAFAFA090909000000FAFAFA
FEFEFEFFFFFF000000FFFFFF020202000000050505FDFDFD000000FFFFFFFFFFFFFDFDFD
000000060606040404000000FEFEFE000000FFFFFF020202000000000000FFFFFFFBFBFB
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F4F4F4F8F8F8FFFFFF000000010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
000000000000020202080808000000000000060606000000010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101000000010101FFFFFFFFFFFF
FAFAFAFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFDFDFD
FAFAFAFFFFFFFFFFFF000000050505000000FFFFFFFEFEFE020202FFFFFFFDFDFDFFFFFF
000000FFFFFF000000000000FFFFFFFBFBFBFCFCFC000000FFFFFF000000000000FAFAFA
FFFFFFFFFFFF020202FFFFFF040404000000010101010101000000FAFAFAFFFFFFFFFFFF
000000050505000000020202FFFFFF000000000000010101010101FDFDFDFFFFFFFEFEFE
FFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFDFDFD030303FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FFFFFFFBFBFBFFFFFFFFFFFFFBFBFBFFFFFFFEFEFEFFFFFFFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFFFF000000FFFFFFF6F6F6
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFF
FFFFFFF7F7F7FFFFFF010101000000050505000000020202000000FBFBFBFFFFFFFEFEFE
010101FDFDFD050505000000000000FFFFFF040404000000FFFFFF000000050505030303
FCFCFCFFFFFF000000FFFFFF000000040404000000010101000000FFFFFFFFFFFF000000
010101FFFFFFFFFFFF020202FBFBFB000000020202010101000000000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFEFEFEFFFFFF
FEFEFEFDFDFDFEFEFE000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFFBFBFBFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FDFDFDFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFFFFFF
FDFDFDFFFFFFFFFFFF000000000000FFFFFF030303000000FFFFFFFCFCFCFFFFFFFFFFFF
000000FFFFFFFBFBFB040404000000020202000000020202FFFFFF000000000000040404
040404000000000000FFFFFFFFFFFF000000000000020202000000FFFFFF000000000000
FFFFFFFFFFFFFFFFFF000000040404000000000000010101010101000000FFFFFFFDFDFD
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFF
FFFFFFFEFEFEFDFDFD000000000000FAFAFAFFFFFF000000000000FFFFFFFDFDFDFFFFFF
000000FFFFFFFFFFFFFBFBFB050505000000FBFBFB010101FCFCFC020202020202000000
000000020202020202FCFCFCFFFFFFFFFFFF010101000000FFFFFFFFFFFF000000020202
FFFFFFF8F8F8FFFFFF010101030303000000080808000000000000F8F8F8FFFFFFFCFCFC
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFBFBFB
FDFDFDFFFFFFFFFFFF020202000000FFFFFFFDFDFDF9F9F90000000B0B0BF9F9F9FFFFFF
000000FAFAFAFAFAFAFEFEFEFEFEFEFEFEFEFFFFFF000000FFFFFFFEFEFEFBFBFBFFFFFF
FFFFFFFBFBFBFEFEFEFFFFFFFAFAFAFDFDFDFFFFFFFFFFFFFCFCFCF9F9F9FEFEFEFFFFFF
FFFFFFFFFFFFFCFCFCFFFFFFFBFBFBFFFFFFFBFBFBFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFFFFFF
FAFAFAFCFCFCFFFFFF000000000000FBFBFBFEFEFEFFFFFFFFFFFF000000030303FEFEFE
000000FFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FDFDFD020202FAFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFE
FFFFFFFCFCFCFFFFFFFCFCFCFCFCFCFFFFFFFFFFFFFAFAFAFEFEFEFFFFFFFBFBFBFFFFFF
FCFCFCFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFF8F8F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFBFBFBFFFFFFFDFDFDFDFDFD
FBFBFBFDFDFDFFFFFFFEFEFEF7F7F7FFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFCFCFCFEFEFE
FEFEFEFCFCFCFFFFFFFFFFFFFCFCFCF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFA
FDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8
FFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFDFDFDFFFFFF
FFFFFFFCFCFCFFFFFFFCFCFCFCFCFCFBFBFBFBFBFBFFFFFFFDFDFDFFFFFFFFFFFFFEFEFE
FFFFFFFEFEFEFEFEFEFEFEFEFFFFFFFEFEFEFFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFF8F8F8FDFDFDFFFFFFFAFAFAFFFFFFFFFFFF
FBFBFBFFFFFFFAFAFAF8F8F8FFFFFFFCFCFCFFFFFFF6F6F6FDFDFDFCFCFCF9F9F9FFFFFF
FFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFEFEFEFEFEFE
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFDFDFDF8F8F8FCFCFCFFFFFF
FFFFFFFEFEFEFBFBFBFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFF
FFFFFFFDFDFDFDFDFDFFFFFFFDFDFDFEFEFEFFFFFFFFFFFFF9F9F9FFFFFFFCFCFCFFFFFF
FFFFFFFDFDFDFFFFFFFCFCFCFEFEFEFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFF4F4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFEFEFE
FFFFFFFFFFFFFDFDFDFDFDFDFBFBFBFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFFEFEFEFDFDFD
FDFDFDFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFCFCFCFFFFFFFDFDFD
FDFDFDFFFFFFFCFCFCFFFFFFFFFFFFF7F7F7FFFFFFFCFCFCFFFFFFFEFEFEFFFFFFFBFBFB
FDFDFDFFFFFFFBFBFBFFFFFFFFFFFFF8F8F8FFFFFFFCFCFCFFFFFFFCFCFCFFFFFFFAFAFA
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFB000000020202
000000020202040404000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000040404FFFFFFFDFDFDFFFFFFFDFDFDFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFCFCFCFEFEFEFFFFFFFFFFFFFEFEFEFFFFFF
FDFDFDFFFFFFFFFFFFFCFCFCFBFBFBFFFFFFFBFBFBFFFFFFFFFFFFFDFDFDFFFFFFFDFDFD
FCFCFCFFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFBFBFBFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFDFDFDFFFFFFFCFCFCFFFFFFFEFEFEFEFEFEFEFEFEFFFFFFFDFDFDFEFEFE
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFCFCFCFFFFFFFEFEFEFFFFFF
FEFEFEFEFEFEFDFDFDFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFF9F9F9
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFF8F8F8FFFFFFFAFAFAFFFFFFFFFFFFFBFBFBFBFBFB
FFFFFFFDFDFDFDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFCFCFCFAFAFAFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFAFAFAFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFDFDFDFAFAFAFEFEFEFFFFFFFDFDFDFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFDFDFDFFFFFFFEFEFEFFFFFFF8F8F8
FEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFDFDFDF7F7F7FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9FFFFFFFFFFFFFCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FEFEFEF7F7F7FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFEFEFEFFFFFFFFFFFFFCFCFCFCFCFC
FFFFFFF9F9F9FFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFF9F9F9FBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFDFDFDF9F9F9FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFEFEFEFDFDFDFFFFFFFFFFFF
F9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFAFAFAFFFFFFFFFFFFFFFFFFFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFAFAFAFFFFFFFEFEFE
FFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFF8F8F8FEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFAFAFAFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFF6F6F6FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFBFBFBFDFDFDFEFEFE
FAFAFAFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFEFEFEFCFCFCFCFCFCFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFFFFFFFFFFFFFCFCFCFEFEFEFDFDFDFFFFFFFAFAFAFFFFFFF7F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFFFFFFFEFEFEF7F7F7FFFFFFFFFFFFF9F9F9FFFFFF
F7F7F7FFFFFFFDFDFDFFFFFFFFFFFFFDFDFDFAFAFAFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7F7FFFFFFFCFCFCFEFEFEFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFDFDFDFAFAFA
FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFDFDFDFAFAFA
FFFFFFFDFDFDFBFBFBFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFBFBFBFDFDFD
FFFFFFFFFFFFF9F9F9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFF8F8F8FAFAFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFDFDFDFAFAFAFFFFFFFFFFFFF9F9F9FDFDFDFFFFFF
F5F5F5FFFFFFFFFFFFF5F5F5FFFFFFF9F9F9FEFEFEFFFFFFF8F8F8FFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFEFEFEFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFDFDFDF8F8F8FFFFFFFFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEF9F9F9FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFF9F9F9FCFCFCFFFFFFF6F6F6
FFFFFFF8F8F8FDFDFDFDFDFDFFFFFFF8F8F8FFFFFFFEFEFEFCFCFCFFFFFFFBFBFBFFFFFF
FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFEFEFEFFFFFFFDFDFDFFFFFFFFFFFF
F7F7F7FFFFFFFFFFFFF8F8F8FFFFFFFFFFFFF9F9F9FFFFFFF9F9F9FFFFFFFEFEFEFFFFFF
FCFCFCFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFEFEFEFAFAFAFEFEFEFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF8F8F8FFFFFFFDFDFD
FCFCFCFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFBFBFB
FFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFF
FFFFFFFAFAFAFFFFFFFBFBFBFFFFFFF9F9F9FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF8F8F8FEFEFEFDFDFDFFFFFFFAFAFAFDFDFDFFFFFFFDFDFDFFFFFF
FAFAFAFFFFFFFFFFFFF9F9F9FFFFFFF8F8F8FBFBFBFFFFFFFFFFFFFFFFFFF8F8F8FFFFFF
FCFCFCFCFCFCFFFFFFFFFFFFF7F7F7FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFAFAFA
FFFFFFFFFFFFFCFCFCFBFBFBFDFDFDFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFF9F9F9FCFCFC
FFFFFFFCFCFCFFFFFFFEFEFEFBFBFBFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF8F8F8FDFDFDFFFFFFF9F9F9FFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFCFCFCFEFEFEFFFFFFF7F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFAFAFAFFFFFFFFFFFFFEFEFEFEFEFEFFFFFF
FDFDFDFFFFFFFFFFFFFDFDFDFFFFFFF9F9F9FFFFFFF9F9F9FDFDFDF9F9F9FFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFFFFFFFEFEFEFBFBFBFFFFFFFFFFFFFBFBFBFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFFFFFFFEFEFEFDFDFDFFFFFFFEFEFEF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFEFEFEFBFBFBFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
FEFEFEF8F8F8FFFFFFFEFEFEFFFFFFFAFAFAFAFAFAFEFEFEFFFFFFF9F9F9FFFFFFFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFF9F9F9FFFFFFF6F6F6FDFDFD
FFFFFFFBFBFBFFFFFFFFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFE
FCFCFCFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFAFAFAFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFCFCFCF6F6F60B0B0B000000
000000010101FFFFFFFFFFFFFFFFFFFDFDFD090909010101FFFFFFFFFFFFFFFFFFFDFDFD
010101FDFDFD020202FFFFFFFFFFFF000000030303000000FFFFFFFEFEFEFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFD020202000000FDFDFD010101FFFFFFFEFEFEFFFFFF000000060606010101
FFFFFF040404F7F7F7FFFFFF010101000000000000FFFFFF010101000000030303FFFFFF
FBFBFBFDFDFDFFFFFFFAFAFAFBFBFB030303070707FDFDFDFCFCFCFFFFFF030303000000
010101FFFFFFF8F8F8010101FCFCFCFFFFFF070707FEFEFEFDFDFD030303020202000000
FBFBFBFFFFFF000000010101FFFFFFFFFFFFFFFFFF000000FEFEFEFFFFFF000000FFFFFF
F8F8F8030303000000FEFEFEFFFFFF000000020202000000FDFDFDFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFBFBFBFFFFFFFDFDFDFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFDFDFDFFFFFF000000000000FFFFFF
FFFFFFFEFEFE000000000000FFFFFF000000FCFCFCFDFDFD000000020202FDFDFDFFFFFF
000000FCFCFC030303FDFDFD020202FFFFFFFFFFFFFFFFFF000000FFFFFFFAFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF010101FEFEFEFFFFFF000000FEFEFEFFFFFFFFFFFF050505FEFEFEFBFBFB
000000000000FFFFFF000000000000FFFFFF020202FFFFFF000000FFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFF000000050505FEFEFEF7F7F7040404FDFDFD010101000000FFFFFF
040404000000FFFFFF030303FFFFFFFCFCFC000000FFFFFFFFFFFF010101F7F7F7FFFFFF
FFFFFF010101FFFFFFFCFCFC000000000000FDFDFD020202FFFFFFFCFCFC030303FFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFCFCFCF9F9F9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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFE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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000000000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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFA000000FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF000000FDFDFD
FFFFFFF9F9F9FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF020202FFFFFFF9F9F9FFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFDFDFDFDFDFDFFFFFFFEFEFE000000000000020202000000010101000000
FFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFBFBFBFFFFFFFFFFFFFCFCFCFDFDFDFFFFFF
FBFBFBFEFEFEFFFFFFFDFDFDFBFBFBFFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFFFFFFFEFEFE
FDFDFDFFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFF6F6F6FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
020202010101000000040404000000050505010101000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000090909020202000000000000000000000000020202050505000000000000
000000010101030303000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF9F9F9FEFEFEFFFFFFFAFAFAFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FEFEFEFFFFFFFFFFFFF9F9F9FFFFFFF9F9F9FFFFFFFFFFFFFCFCFCFFFFFFFCFCFCFFFFFF
FFFFFFFDFDFDFDFDFDFCFCFCFFFFFFFFFFFFF5F5F5FFFFFFFFFFFFFBFBFBFAFAFAFFFFFF
FEFEFEFCFCFCFFFFFFFFFFFFFFFFFFFEFEFEFBFBFBFFFFFFFFFFFFFAFAFAFFFFFFFCFCFC
FFFFFFFFFFFFFAFAFAF8F8F8FFFFFFF8F8F8FFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFAFAFA
FFFFFFFEFEFEF9F9F9FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFAFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFD000000FFFFFF
FEFEFEFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FDFDFDFFFFFFFBFBFBFBFBFBFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFDFDFDFFFFFFFBFBFBFEFEFEFFFFFF000000000000030303000000030303
000000FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFAFAFAFDFDFDFFFFFFFEFEFE
FEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFBFBFBFEFEFEFFFFFFFAFAFAFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000020202020202000000040404010101000000050505000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
040404010101000000030303000000030303040404000000000000000000070707010101
000000010101FCFCFC010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFFEFEFEFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFBFBFBFFFFFFFAFAFA
FFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFBFBFB
FCFCFCFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFDFDFDFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFBFBFBFFFFFFFDFDFD
FEFEFEFDFDFDFEFEFEFFFFFFF9F9F9FFFFFFFFFFFFFCFCFCFFFFFFFEFEFEFFFFFFFEFEFE
FEFEFEFFFFFFFCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFEFEFEFFFFFFFDFDFDFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFAFAFAF8F8F8FEFEFE010101
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000010101040404040404000000000000
000000000000040404040404010101000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000030303000000000000000000
010101010101000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010101FEFEFEF8F8F8FAFAFA
FCFCFCFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF010101FFFFFFFFFFFFFBFBFBFFFFFFFCFCFCFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFCFCFCFFFFFFFBFBFBFFFFFF
FFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFAFAFAFFFFFFFFFFFFF8F8F8FFFFFF
FFFFFFFFFFFFFEFEFEFCFCFCFEFEFEFEFEFEFFFFFFFDFDFDFFFFFFF9F9F9FDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFBFBFBFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFF6F6F6FFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFAFAFAFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFF9F9F9
FFFFFFFBFBFBFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFF
FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFAFAFAFFFFFFFFFFFFFFFFFF000000000000000000000000010101060606
FAFAFAFFFFFFFEFEFE040404FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFF5F5F5FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFC000000FFFFFFFBFBFBFFFFFF080808FBFBFBFEFEFEFBFBFBFFFFFF010101
FFFFFFFFFFFFF8F8F8FEFEFE020202000000060606000000FAFAFAFFFFFF020202010101
000000FCFCFCFFFFFFFFFFFFFFFFFF000000020202FEFEFEFBFBFBFCFCFCFBFBFB0B0B0B
000000000000FFFFFFFAFAFAFBFBFB090909000000FBFBFB000000FFFFFF000000FFFFFF
FFFFFF000000000000030303FFFFFF020202FFFFFF010101FFFFFFFEFEFEFFFFFFFFFFFF
FFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFCFCFCFDFDFD
FDFDFDFFFFFFFFFFFF000000000000FFFFFFFFFFFFFEFEFE000000000000FFFFFFFDFDFD
000000000000020202050505000000030303030303000000000000000000000000FFFFFF
FDFDFDFFFFFF000000000000020202000000FEFEFEFFFFFF000000060606000000060606
000000FDFDFD060606020202000000000000060606FCFCFCFFFFFF020202000000FFFFFF
000000030303000000010101030303000000010101000000FFFFFFFFFFFFFFFFFFFAFAFA
FEFEFEF8F8F8FFFFFFFFFFFF030303030303FFFFFFFEFEFEFFFFFFFAFAFA040404000000
000000070707FFFFFFFDFDFD000000030303FBFBFB050505000000040404000000000000
010101FCFCFC020202030303F6F6F6040404000000FFFFFFFDFDFD040404FCFCFCFFFFFF
FFFFFF000000000000000000000000FFFFFFFAFAFAFEFEFEFDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000030303000000020202
000000000000010101030303010101F8F8F8FFFFFFFFFFFFFBFBFBFFFFFFFEFEFEFFFFFF
FEFEFEFFFFFF000000FFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FEFEFEFFFFFF
F9F9F9000000FFFFFF010101000000040404000000000000050505040404000000FFFFFF
FDFDFD000000FFFFFFFCFCFCFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF000000FFFFFFFAFAFAFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFAFAFA
FFFFFFFBFBFBFFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFAFAFAFFFFFFFDFDFDF9F9F9FEFEFEFFFFFF040404
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7
FFFFFFFFFFFFF2F2F2070707FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFEFEFEFFFFFF
FCFCFCFCFCFCFDFDFDFEFEFEFCFCFCFFFFFFFCFCFCFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF040404FFFFFFFEFEFEF9F9F9
FDFDFDFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFA000000FFFFFFF9F9F9FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBF9F9F9
FFFFFF000000FAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFBFBFBFEFEFEFFFFFFF9F9F9FBFBFB
FFFFFFFBFBFBFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFEFEFE
FAFAFAFEFEFEFFFFFF040404FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCF6F6F6FFFFFFFFFFFFFDFDFD
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFEFEFEFCFCFCFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFDFDFDFFFFFF
FBFBFBFFFFFFFBFBFBFFFFFFFFFFFFFBFBFBFFFFFFFBFBFBFFFFFFFDFDFDFFFFFFFCFCFC
FFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFBFBFBFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFDFDFD
FEFEFEFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFEFEFEFEFEFEFDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFF
FEFEFEFEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFBFBFBFFFFFFFDFDFDFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFCFCFCFEFEFEFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFF
FEFEFEFCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000020202000000000000040404000000000000000000050505000000
020202000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
030303030303000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF020202FEFEFEFEFEFEFFFFFFFFFFFFFDFDFD
000000FFFFFFFAFAFA030303FFFFFF000000FFFFFFFEFEFE000000FFFFFFFCFCFCFEFEFE
FFFFFFFEFEFE000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FEFEFEFDFDFDFEFEFEFFFFFFFEFEFEFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFD000000000000000000090909020202000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000030303060606000000060606000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000020202000000010101000000000000000000000000000000010101020202010101
000000000000010101050505030303FFFFFFFAFAFA040404FAFAFAFEFEFEFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFF5F5F5FFFFFFFFFFFFFEFEFEFCFCFCFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
F5F5F5FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FBFBFBFAFAFAFDFDFDFFFFFFFCFCFC
FFFFFFFFFFFFFAFAFAFDFDFDF8F8F8FFFFFFF9F9F9FEFEFEFFFFFFFCFCFCFFFFFFFBFBFB
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
020202F7F7F7FFFFFFFFFFFFFEFEFEFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF000000000000FFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFAFAFAF7F7F7FFFFFFFFFFFFFEFEFEFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD010101FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFAFAFA030303000000050505000000
000000010101040404FFFFFFFDFDFDFEFEFEFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFDFDFDFDFDFDFCFCFCFFFFFFFFFFFF
FFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFD000000000000000000040404030303FDFDFD000000
FEFEFEFBFBFBFFFFFF000000FEFEFEFFFFFFFEFEFEFFFFFFFBFBFB010101020202FCFCFC
FFFFFFFFFFFF000000FCFCFCFEFEFEF6F6F6FFFFFFFFFFFFFFFFFF000000040404000000
000000090909FFFFFFFFFFFFFCFCFCFDFDFDFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000020202020202030303000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FBFBFBFFFFFFFFFFFFFFFFFFFBFBFB000000FFFFFFFFFFFF020202F8F8F8FEFEFE010101
FFFFFFFFFFFF000000FFFFFFF7F7F7FFFFFF000000FFFFFF000000FCFCFCFFFFFF010101
FBFBFBFFFFFFF9F9F9FEFEFEFDFDFDFFFFFF070707FAFAFAFFFFFFFCFCFC070707FCFCFC
FFFFFF010101FCFCFC030303FCFCFCFFFFFF020202FFFFFFFFFFFFFDFDFDFFFFFFFBFBFB
020202FFFFFFF8F8F8FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFDFDFDFDFDFD070707000000010101000000000000000000FFFFFFFFFFFF020202
FAFAFA030303FFFFFFFEFEFE000000FFFFFFFEFEFEFCFCFCFFFFFFFFFFFF080808F8F8F8
FFFFFF000000FEFEFEFEFEFE000000FDFDFDFFFFFFFEFEFE080808FFFFFFF9F9F9030303
FCFCFCFFFFFF010101FFFFFFFFFFFF010101FFFFFFF2F2F2FFFFFF010101FCFCFCFFFFFF
FEFEFEF6F6F6FEFEFEFFFFFFFBFBFBFFFFFFF9F9F9FFFFFF030303FAFAFAFEFEFEFFFFFF
FFFFFFFDFDFDFFFFFFF9F9F9FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
000000020202F6F6F6FFFFFFFDFDFDFEFEFEFFFFFFFBFBFBFFFFFFFDFDFD000000FFFFFF
FFFFFFFDFDFDFAFAFAFFFFFFFDFDFD020202FFFFFFFFFFFFFFFFFF000000F8F8F8FEFEFE
000000FFFFFF000000000000FFFFFFFFFFFF000000FFFFFFFDFDFDFFFFFF000000F8F8F8
FFFFFF000000FFFFFFF6F6F6060606000000FFFFFFFCFCFC000000FFFFFFFFFFFF000000
FCFCFCFDFDFD050505FDFDFDFEFEFE080808FAFAFAFFFFFFFDFDFDFCFCFCFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FDFDFD000000FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFFFF000000020202FFFFFF
FBFBFBFBFBFBFFFFFFFBFBFBFFFFFFFEFEFEFEFEFE000000FFFFFFFCFCFCFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFC020202FFFFFFFDFDFD000000FFFFFFFFFFFFFBFBFB
060606F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC050505000000FEFEFE
FFFFFFFFFFFFF9F9F9FFFFFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEF9F9F9FFFFFFFDFDFDFFFFFF
FFFFFFFEFEFEFAFAFA030303FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF060606FFFFFFFAFAFAFFFFFFFEFEFEFBFBFB000000
FFFFFFFEFEFEFFFFFFFFFFFFFCFCFCFFFFFFF8F8F8FFFFFFFDFDFDFDFDFDFEFEFEFBFBFB
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFF4F4F4FFFFFFFFFFFFF8F8F8FFFFFF050505000000
000000FFFFFFF8F8F8FBFBFBFEFEFEFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFBFBFBFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFF000000000000020202000000000000020202000000060606000000000000
070707000000030303040404010101010101010101010101010101010101010101010101
000000000000030303000000010101FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFCFCFCFEFEFEFEFEFEFFFFFFFFFFFFFEFEFE
F6F6F6FFFFFFFCFCFCFFFFFFFEFEFEFEFEFEFFFFFFFDFDFDF9F9F9FFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFBFBFBFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFF3F3F3FFFFFFFEFEFE
F9F9F9FFFFFFFFFFFFF1F1F1FFFFFFFFFFFFFBFBFBFEFEFEFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFAFAFAFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFAFAFA
FFFFFFFBFBFBFFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFEFEFEFAFAFAFFFFFF020202000000
000000000000040404000000FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFD
FFFFFFFDFDFDFDFDFDFFFFFFF8F8F8070707FEFEFEFCFCFCFFFFFF050505F8F8F8FFFFFF
FFFFFFFBFBFBFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFBFBFBFFFFFFFAFAFAFFFFFFFDFDFD
FEFEFE050505FFFFFF000000FFFFFFFFFFFF030303000000FEFEFEFFFFFFFCFCFCFFFFFF
030303000000FEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFDFDFDFBFBFB040404000000FBFBFB
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFAFAFAFFFFFFFFFFFF
FEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFDFDFDFFFFFFFFFFFFFBFBFB
FFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFBFBFBFDFDFD
FEFEFEFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFDFDFDFEFEFEFFFFFFFFFFFFFDFDFD
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFFFFFFFFFF000000FEFEFE
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFF
FBFBFB000000FCFCFCFFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFF000000FFFFFFFEFEFEFDFDFDFFFFFFFAFAFAFFFFFFFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFFFFFF
FCFCFCFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFF
F9F9F9FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFAFAFAFFFFFFFFFFFFFEFEFEFEFEFEFCFCFC
FCFCFCFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFCFCFCFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFAFAFA
FFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FFFFFFFDFDFDFCFCFCFFFFFFFDFDFD000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFEFEFE
FFFFFFFDFDFDFAFAFAFFFFFFF8F8F8FFFFFFFFFFFFFAFAFAF9F9F9FFFFFFFCFCFCFCFCFC
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFEFEFE
F5F5F5FFFFFFFAFAFAFFFFFFFFFFFFFDFDFDFFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFFFFFF
FCFCFCFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFFFFFF
F5F5F5FFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFBFBFBFCFCFCFFFFFFFCFCFCFCFCFCFEFEFEFFFFFFFFFFFFFBFBFB
FDFDFDFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFF5F5F5FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9F9F9F9FFFFFF000000010101FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFF000000000000FEFEFEFFFFFF000000000000030303FFFFFF
000000060606000000000000FFFFFFFEFEFE040404000000000000010101050505FCFCFC
030303000000FFFFFFFFFFFF020202000000030303000000000000FFFFFF000000010101
FFFFFF000000020202FFFFFFFEFEFEFFFFFF000000FFFFFF000000010101FEFEFEFFFFFF
000000000000FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFDFDFDFFFFFF
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FEFEFEFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFFFFFF000000000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFF020202000000FBFBFBFFFFFF000000030303000000FFFFFF
000000000000FEFEFEFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFAFAFAFCFCFC
040404000000FFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFEFEFEFEFEFE080808000000
F5F5F5FFFFFFFAFAFAFFFFFFFFFFFFFDFDFDFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101FFFFFF
FFFFFFF6F6F6FDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFF000000FFFFFFFDFDFDFFFFFFFFFFFF
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFFFFFEFEFEFFFFFFFCFCFCFEFEFEFCFCFCFFFFFF
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
000000FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF000000000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFAFAFAFFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFFFFFFFFFFFF
F6F6F6FDFDFDFFFFFFFEFEFEFFFFFFFAFAFAFFFFFFFFFFFFFAFAFAFFFFFFFCFCFCF9F9F9
FFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFBFBFBFFFFFFFAFAFAF8F8F8
FFFFFFF8F8F8FDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFF8F8F8
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000020202FDFDFD
FEFEFEFBFBFBFBFBFBFFFFFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFF7F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFAFAFAFFFFFFFDFDFD050505FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFF000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF000000000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF000000FFFFFF
FFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000FFFFFFFFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101FEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD010101FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFFFFFF000000020202010101
000000FFFFFFFFFFFFFCFCFCFFFFFFFEFEFEFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF000000000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF010101FFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF000000000000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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFDFDFDFFFFFF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FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFF8F8F8
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFBFBFBFFFFFFFFFFFFFEFEFEFDFDFDFEFEFEFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101FEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD010101FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF8F8F8FEFEFE020202FCFCFCFFFFFF030303020202
FFFFFFFFFFFF000000FDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF000000000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFEFEFEFFFFFFFBFBFBFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000010101FEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD010101FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFF000000000000
FEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF000000000000FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFBFBFBFEFEFEFFFFFFFCFCFCFDFDFDFFFFFFFFFFFF030303000000FFFFFF
FFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFF010101FCFCFCFFFFFFFAFAFA
FFFFFFFDFDFDFFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFDFDFD010101020202FEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFCFCFCFFFFFFFCFCFC000000FEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
FFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFF6F6F6FFFFFF
FFFFFFFCFCFC000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFCFCFCFFFFFF000000070707FFFFFF
F8F8F8FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFF7F7F7FDFDFD080808FDFDFDFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFF8F8F8FBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFF6F6F6FFFFFFFFFFFFFCFCFC000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7F7FFFFFF000000000000FFFFFFF6F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F8F8F8FFFFFFFFFFFFFDFDFDFDFDFD050505FBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFF
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FFFFFFFAFAFA
FDFDFDFFFFFF030303030303FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFBFBFBFAFAFAFFFFFFFDFDFDFBFBFBFFFFFFFFFFFF000000000000FFFFFF
FBFBFBFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000FFFFFFFBFBFBFCFCFC
FFFFFFFAFAFAFCFCFCF8F8F8FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FFFFFFFAFAFAFDFDFDFFFFFF030303030303
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F7F7F7FFFFFFFDFDFD040404000000FFFFFFFFFFFFF6F6F6FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBFFFFFFFAFAFAFFFFFF000000FFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFDFDFDFFFFFFFDFDFD000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000060606030303020202
020202000000000000010101000000000000000000000000000000000000000000000000
010101000000010101000000040404050505000000000000000000080808000000000000
090909000000000000030303000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000030303000000010101000000030303000000070707000000
000000000000070707000000000000000000000000000000000000000000000000000000
000000000000000000000000000000060606030303020202020202000000000000010101
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
030303000000000000000000090909000000030303020202000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
050505000000020202040404000000000000020202000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000FDFDFDFFFFFF
FDFDFDFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFF050505FFFFFF
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFFFFFEFEFEFFFFFFFCFCFC
FFFFFFFFFFFF020202020202FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FFFFFFF8F8F8FFFFFFFFFFFFFCFCFCFBFBFB040404030303040404020202000000FFFFFF
000000050505FDFDFDFFFFFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFE060606FFFFFFFCFCFC000000FFFFFFFCFCFCFFFFFF
060606F7F7F7FFFFFFFEFEFEFEFEFEFFFFFFFEFEFEFFFFFFFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFFFFFF020202020202
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
000000FFFFFFFFFFFF000000000000FEFEFEF7F7F7060606FEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFCFCFCFFFFFFFFFFFFFFFFFF000000FEFEFEFCFCFCFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFFFF050505FFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFBFBFBFFFFFFFEFEFEFAFAFA000000FCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFBFBFB
FFFFFFFDFDFD020202000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFF9F9F9FFFFFFF8F8F8FFFFFFFFFFFF000000000000000000010101020202
040404F6F6F6FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFC020202000000FFFFFF020202FFFFFF040404000000
000000FFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFBFBFBFFFFFFFDFDFD020202000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
040404000000000000040404000000FFFFFF010101000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFAF9F9F9FFFFFF030303F7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC000000FAFAFAFEFEFE
FFFFFFFBFBFBFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFFFFFFF9F9F9FFFFFF020202FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFF000000030303FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFFAFAFAFFFFFFFFFFFFFFFFFF050505010101000000000000000000
060606FFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF070707000000000000000000000000080808
FFFFFFFAFAFAFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF000000030303
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000020202040404000000040404000000010101FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFBFBFBFFFFFFFFFFFFFFFFFF000000FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF020202FFFFFFF9F9F9
FFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFBFBFBFBFBFBFFFFFFFDFDFD000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFEFEFE
FDFDFDFDFDFD020202000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFCFCFCFEFEFE010101000000000000000000
000000FFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000010101010101000000040404000000
FAFAFAFFFFFFFCFCFCFEFEFEFFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFEFEFEFDFDFDFDFDFD020202000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF010101000000020202000000000000000000010101FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFCFCFCFEFEFEFAFAFA020202FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FDFDFDFFFFFF
FBFBFBFBFBFBFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFF9F9F9FFFFFF
FFFFFFFBFBFBFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFA000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF050505000000000000020202
000000FFFFFFFBFBFBFFFFFFFCFCFCFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF010101000000000000010101010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFAFAFA000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFFFFFFF8F8F8FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFF010101020202000000010101040404FCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFBFBFBFFFFFFFCFCFCFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFF8F8F8
FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFEFEFEFDFDFD
FBFBFBFFFFFFF4F4F4FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF
FEFEFEFFFFFF010101010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000050505070707000000
FFFFFFFDFDFDFBFBFBFCFCFCFFFFFFFFFFFFFAFAFAFEFEFEFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7070707030303000000020202000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFEFEFEFFFFFF010101010101
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFBFEFEFEFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFF000000020202000000020202000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFF000000FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFCFCFCFFFFFF
FFFFFFFBFBFBFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFDFDFDFFFFFF
FEFEFEFDFDFDFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFFFFFF
FBFBFBFFFFFF000000030303FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000020202000000000000
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFDFDFDFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFAFAFAFFFFFFFFFFFFFAFAFAFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF6F6F6000000040404060606000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFBFBFBFFFFFF000000030303
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFAFAFAF8F8F8FFFFFFF9F9F9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFF3F3F3FEFEFEFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFFFFFF000000010101000000010101FEFEFEFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFCFCFCFEFEFEF9F9F9040404FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFAFAFA
F8F8F8FFFFFFF9F9F9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFEFEFE
FFFFFFFEFEFEFFFFFFFDFDFDFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFFFFF4F4F4FFFFFFFFFFFF
FFFFFFFFFFFF0A0A0A000000FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFFFF000000000000FFFFFF
FFFFFFFFFFFFFFFFFFF7F7F7FBFBFBFDFDFDFFFFFFFFFFFFF6F6F6FFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FFFFFFFFFFFFFFFFFFFAFAFAFCFCFCFFFFFFFFFFFF
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFFFFFF000000000000FFFFFFFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFFFFFFF4F4F4FFFFFFFFFFFFFFFFFFFFFFFF0A0A0A000000
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FDFDFDFDFDFDFDFDFDFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF7F7F7FFFFFFFFFFFFFDFDFDFFFFFFFAFAFAFFFFFFFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FFFFFFFFFFFFFFFFFF000000040404000000FFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFF000000FFFFFFF8F8F8FEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFDFDFDFDFDFDFDFDFDFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFE
FDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF
FBFBFBFDFDFD000000050505FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000070707FFFFFF
F9F9F9FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFF6F6F6FFFFFFFFFFFFFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFF7F7F7FFFFFFFFFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEF9F9F9FDFDFDFFFFFF000000010101FFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFBFBFBFDFDFD000000050505
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF8F8F8FDFDFDFEFEFEFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFF5F5F5030303000000000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFEFEFEFBFBFBFDFDFD010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFEFEFE
FDFDFDFDFDFDFEFEFEFFFFFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFCFCFCFAFAFAFFFFFFFFFFFF
FFFFFFFFFFFF000000000000FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFFFFFDFDFD000000FAFAFA
FFFFFFFAFAFAFFFFFFF8F8F8FEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFF9F9F9FBFBFBFFFFFFFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF040404FFFFFFFFFFFFFDFDFD
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFCFCFCFAFAFAFFFFFFFFFFFFFFFFFFFFFFFF000000000000
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FFFFFFFBFBFBFCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFBFBFBFFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFBFBFBFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FCFCFCFFFFFFFFFFFFFCFCFCFFFFFF050505F6F6F6FFFFFFFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFFFFFFFBFBFBFCFCFCFFFFFF
FDFDFDFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFCFCFC050505
010101000000000000020202010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101040404000000000000000000
030303000000090909000000010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101000000020202000000020202
000000010101000000060606000000040404F4F4F4FFFFFFF8F8F8FFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD030303000000020202080808000000000000
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101020202000000000000000000000000000000060606000000
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101040404000000000000000000030303000000090909000000
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
000000FCFCFCFFFFFFF9F9F9FFFFFFFBFBFBFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000000000040404000000000000000000000000010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
0000000000000000000101010202020000000A0A0A000000010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
040404000000030303020202000000000000050505000000010101010101010101010101
010101010101010101010101010101010101010101010101010101010101010101010101
010101010101010101010101010101010101010101010101000000FCFCFCFFFFFFF9F9F9
FFFFFFFBFBFBFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFEFEFE010101
FCFCFCFEFEFEFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFFFFFFFDFDFD
FFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFF
FFFFFFFCFCFCFFFFFFFCFCFCFFFFFF000000FFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF010101FAFAFAFFFFFFF5F5F5FFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFFFFFFFDFDFDFFFFFFFFFFFFF7F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
020202FAFAFAFFFFFFFFFFFFFBFBFBFDFDFDFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFCFCFCFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFEFEFEFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF020202FAFAFAFFFFFFFFFFFF
FBFBFBFDFDFDFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFCFCFCFDFDFDFCFCFCFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFF
FBFBFBF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFEFEFE
F8F8F8FFFFFFFBFBFBFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFBFBFBFFFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFBFBFBFFFFFFF9F9F9FFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFBFCFCFCFFFFFFFFFFFFFDFDFDFDFDFDFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFFBFBFBFBFBFBFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFF
FEFEFEFFFFFFF9F9F9FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFEFEFEFFFFFFF8F8F8
FFFFFFFFFFFFFCFCFCFAFAFAFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFAFAFA
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFAFAFAFFFFFFFAFAFAFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFF8F8F8
FEFEFEFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFCFCFCFFFFFF
FAFAFAF7F7F7FEFEFEFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F2F2F2FFFFFFFAFAFAFDFDFDFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7F2F2F2FFFFFFFAFAFAFDFDFDFFFFFFFCFCFC
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F6F6F6FFFFFFFFFFFFFCFCFCFFFFFFFBFBFBFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFDFDFDFAFAFAFFFFFFF2F2F2F7F7F7FFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFCFCFCFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFF9F9F9FFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFDFDFDFFFFFFFFFFFFF6F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFDFDFD000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
F6F6F6FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFCFCFCFEFEFE
FDFDFDFFFFFFFEFEFEFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFF8F8F8FFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFF8F8F8FFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFBFBFBFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFF8F8F8FFFFFFFCFCFC000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
010101FFFFFFFFFFFFFCFCFCFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFF7F7F7FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFAFAFA
000000FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFF
F8F8F8020202FBFBFBFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFFFFFF000000FFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFFFFFF000000FFFFFFFEFEFEFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFEFEFEFFFFFFFBFBFBFFFFFF000000FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFF000000FFFFFFFFFFFFFCFCFCFDFDFD000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFF000000
FFFFFFFFFFFFF8F8F8010101000000FFFFFF020202000000000000040404FBFBFBFFFFFF
000000FFFFFFFFFFFFFFFFFF000000FFFFFFFDFDFD000000FDFDFDFEFEFEFDFDFD070707
030303000000FFFFFFFFFFFFFEFEFEFFFFFF000000FFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
000000000000FFFFFFFFFFFFF8F8F8050505FCFCFCFEFEFEFFFFFFFDFDFDFFFFFFFDFDFD
010101FDFDFDFCFCFCFFFFFF010101000000000000010101FDFDFDFFFFFFFFFFFFFDFDFD
FFFFFF010101FCFCFCFFFFFFFFFFFFFAFAFAFFFFFFFFFFFF000000000000FCFCFCFFFFFF
FDFDFD000000FFFFFFFAFAFAFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFF000000FFFFFFFEFEFEFEFEFEFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFDFDFD
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFEFEFE
FFFFFFF8F8F8FFFFFFFFFFFFFEFEFEFFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFFFFFFFBFBFB
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF000000FFFFFFFFFFFFFAFAFA
FEFEFEFEFEFEFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFFBFBFBFFFFFFFEFEFEFFFFFFFFFFFFF9F9F9FFFFFF000000FDFDFDFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFAFAFAFFFFFFFDFDFDF9F9F9FFFFFFFDFDFDFEFEFEFFFFFFFEFEFE
FEFEFEFFFFFFFDFDFDFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFDFDFDFFFFFFFCFCFCF9F9F9FFFFFFFDFDFDF9F9F9
FFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFEFEFEFDFDFD
FFFFFFFEFEFEFFFFFFFFFFFF000000FFFFFFFFFFFFFAFAFAFFFFFFFBFBFBFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFBFBFB
F9F9F9FEFEFEFFFFFFFFFFFF000000FBFBFBFFFFFFFAFAFA000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFDFDFD040404
F9F9F9FAFAFAFFFFFF000000FCFCFCFEFEFE000000FBFBFB040404000000FFFFFFFEFEFE
040404FBFBFBF7F7F7FFFFFF060606FBFBFBFFFFFF050505FFFFFFFDFDFDFFFFFF000000
FCFCFCFFFFFF010101FCFCFCFFFFFFFFFFFF000000FFFFFFFAFAFAFFFFFFFFFFFF000000
FFFFFFFFFFFF000000FAFAFAFFFFFF000000FFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFDFDFD000000FFFFFFFDFDFDFFFFFF010101FAFAFAFFFFFFFFFFFF
FAFAFA000000FFFFFFFCFCFCFBFBFBFFFFFFFFFFFF000000FFFFFFFEFEFE010101FFFFFF
FEFEFEFFFFFF000000FFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000FFFFFFFFFFFFFFFFFFF1F1F1FFFFFF
FFFFFFFEFEFEFDFDFDFFFFFFF6F6F6FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFCFCFCFAFAFA
FEFEFEF7F7F7FFFFFFFEFEFEFFFFFFFDFDFDFDFDFDFEFEFEFFFFFFFFFFFFFAFAFAFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
F9F9F9FFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFDFDFDFFFFFF000000F6F6F6FFFFFFFFFFFF
FDFDFDFFFFFFF5F5F5FFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFDFDFDFFFFFFFDFDFD
FDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFAFAFA030303FFFFFFF9F9F9
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
070707F8F8F8FFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFDFDFDFFFFFF
FFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFFBFBFBFFFFFFFFFFFFF9F9F9
F9F9F9FEFEFEFFFFFFFCFCFCFAFAFAFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFF8F8F8FFFFFF
FBFBFBF8F8F8FFFFFFFDFDFDFBFBFBFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFDFDFDFFFFFF
FDFDFDFDFDFDFDFDFDFFFFFF000000F6F6F6FFFFFFFFFFFFF8F8F8FFFFFFFEFEFEFDFDFD
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFDFDFDFEFEFEFEFEFEF4F4F4FFFFFF
FFFFFFFFFFFFFEFEFEFCFCFC000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFF000000
FFFFFFFFFFFFFBFBFB000000FFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFDFDFD
030303FFFFFFFFFFFFFAFAFA020202FCFCFCFDFDFD000000FAFAFAFFFFFF000000FEFEFE
FFFFFFFFFFFF000000FFFFFFF9F9F9FFFFFF040404000000FFFFFFF8F8F8040404FFFFFF
FEFEFEFFFFFFFBFBFB080808FBFBFB000000F9F9F9FDFDFDFEFEFEFFFFFFFFFFFFFAFAFA
020202FFFFFFFFFFFF000000FEFEFEFFFFFFFFFFFFF7F7F7FFFFFF000000FBFBFBFFFFFF
FFFFFF000000FEFEFEFEFEFEFEFEFEFCFCFC030303FFFFFFFEFEFEFFFFFF000000FBFBFB
FFFFFFFFFFFF000000FFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFF020202FDFDFDFFFFFFFFFFFF070707000000
000000030303000000010101060606FCFCFCFEFEFEF8F8F8070707F7F7F7FFFFFF080808
FFFFFFFFFFFFFBFBFB000000FEFEFEFFFFFF000000000000070707000000FFFFFFFFFFFF
F9F9F9FFFFFF000000F6F6F6FFFFFFFEFEFEFFFFFF000000000000000000FFFFFFFFFFFF
000000FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF040404020202FFFFFFF9F9F9000000
000000000000000000000000FFFFFFFBFBFBFCFCFCFFFFFF000000FBFBFBFDFDFDFFFFFF
FFFFFFF9F9F9FFFFFFFEFEFE000000FFFFFFFFFFFFFBFBFBFFFFFF000000FFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FEFEFEFFFFFFF9F9F9000000FFFFFFFFFFFFFCFCFCFEFEFE000000000000070707
FBFBFBFBFBFB010101020202F9F9F9040404000000050505000000FFFFFFFFFFFF040404
FFFFFFFFFFFF000000FFFFFFFEFEFEFAFAFA010101020202FDFDFD000000FFFFFFF7F7F7
0000000A0A0A000000010101FFFFFFFDFDFD000000FDFDFDFFFFFF000000FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF040404020202FFFFFFF9F9F9000000000000000000010101000000
000000FFFFFFFEFEFEFEFEFE020202F9F9F9FFFFFFFFFFFFFFFFFF030303050505000000
000000010101FBFBFBFEFEFE030303000000F9F9F9FEFEFE000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC040404
FEFEFEFAFAFAFFFFFF050505F9F9F9FFFFFF080808F9F9F9FDFDFD020202FEFEFEFBFBFB
000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFBFBFB010101FFFFFF
FFFFFFFDFDFD030303FFFFFFFFFFFFFEFEFE000000000000FCFCFCFFFFFF000000000000
010101000000010101000000FFFFFF010101FFFFFFFFFFFFFFFFFFF2F2F2FFFFFFFFFFFF
000000FEFEFEFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFF000000FFFFFFFBFBFB
FAFAFA000000FFFFFFFBFBFBFEFEFEFFFFFF000000FBFBFBFFFFFFFDFDFD040404FFFFFF
F9F9F9FFFFFF080808FFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFDFDFD000000FCFCFC
FFFFFF000000FFFFFFFAFAFA000000FFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF000000
FFFFFFFCFCFCFEFEFE010101FBFBFBFCFCFC020202FFFFFFF3F3F3FFFFFF010101FDFDFD
FFFFFF010101FFFFFF040404FAFAFAFCFCFC000000FFFFFFFFFFFFFFFFFF030303FDFDFD
030303FFFFFFFCFCFCFFFFFFFBFBFBFDFDFDFEFEFE000000FDFDFDFFFFFFFFFFFF000000
FFFFFFFEFEFEFFFFFFFFFFFF000000FFFFFFFFFFFFFCFCFC030303FFFFFFFFFFFFF9F9F9
FCFCFCFFFFFFFFFFFFFEFEFE020202F8F8F8FFFFFFFFFFFFFEFEFE000000FEFEFEFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
070707FCFCFCFAFAFAFFFFFF010101FBFBFBFCFCFCFFFFFF030303FFFFFFFFFFFFFCFCFC
010101FFFFFF000000FDFDFDFFFFFF000000FFFFFFFBFBFBFFFFFF000000FAFAFA000000
FBFBFBFEFEFE060606FDFDFDFFFFFFFEFEFE000000FCFCFCFBFBFB000000FFFFFF040404
FCFCFCFCFCFCFEFEFEFFFFFF010101FFFFFF010101FFFFFFFEFEFE050505F8F8F8FFFFFF
FBFBFBFDFDFDFEFEFE000000FDFDFDFFFFFFFFFFFF000000FBFBFBFFFFFFFAFAFAFFFFFF
090909FCFCFCFFFFFFFEFEFE000000FFFFFFFCFCFCF7F7F7FFFFFFFBFBFBFFFFFF020202
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFF000000FFFFFFFEFEFE000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC020202
FFFFFFFFFFFFFDFDFD000000FFFFFFFFFFFF000000F7F7F7FFFFFF000000FAFAFAFFFFFF
010101FFFFFFFFFFFFFFFFFF000000FAFAFAFEFEFE000000FEFEFEFFFFFF000000FFFFFF
FFFFFFFDFDFD000000FFFFFFFFFFFF000000FFFFFFFDFDFD030303FFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFF000000FFFFFF010101F6F6F6FFFFFFFFFFFFFFFFFFFCFCFCFFFFFF
030303FEFEFEFFFFFFFFFFFF020202020202000000060606040404FFFFFFF6F6F6FFFFFF
FFFFFF000000FDFDFDFEFEFEFFFFFFFDFDFD040404FFFFFFFFFFFFFDFDFD000000FEFEFE
FFFFFFFFFFFF000000FFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF020202FEFEFEFBFBFBFBFBFB050505FFFFFF
FEFEFE000000FFFFFFFCFCFC090909F7F7F7FFFFFFFCFCFC000000FCFCFCFCFCFC030303
FDFDFDFFFFFFFFFFFF000000FFFFFFFFFFFF000000FFFFFFFFFFFFFEFEFE020202FFFFFF
FFFFFF000000FBFBFB040404FCFCFCFFFFFF030303000000020202000000000000FFFFFF
000000FFFFFFFBFBFBFFFFFFFFFFFFFDFDFDFFFFFF010101FDFDFDFDFDFDFFFFFFFFFFFF
FBFBFBFFFFFFF9F9F9FFFFFF000000FCFCFCFFFFFFFEFEFE000000FCFCFCFFFFFFFDFDFD
FBFBFBFFFFFFFDFDFDFFFFFF030303FFFFFFFFFFFFFCFCFCFFFFFF010101FEFEFEFBFBFB
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFCFCFC000000FFFFFFFFFFFFFEFEFE000000030303000000030303
000000FBFBFB000000FFFFFFFFFFFF000000000000050505000000000000FFFFFF000000
FBFBFBFFFFFF000000FBFBFBFAFAFAFFFFFF000000FFFFFFFFFFFF030303FBFBFB000000
FFFFFFFFFFFFFEFEFEFFFFFF000000FAFAFA030303FEFEFEFBFBFB050505FFFFFFFEFEFE
FFFFFFFDFDFDFFFFFF010101FDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFBFBFBFEFEFEFCFCFC
000000FFFFFFFFFFFFFFFFFF010101FEFEFEFFFFFFFFFFFFFEFEFEFDFDFDFBFBFB000000
030303F8F8F8FFFFFFFFFFFFFFFFFF020202F9F9F9FFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFBFBFB000000
FFFFFFFFFFFFFFFFFF040404FFFFFFFFFFFF000000FFFFFFFFFFFF010101FFFFFFF8F8F8
000000040404FCFCFCF6F6F6000000080808FAFAFA010101FFFFFFFFFFFFFFFFFF000000
FFFFFFF9F9F9050505FDFDFD000000F9F9F9FEFEFEFFFFFF000000FFFFFFFFFFFF000000
FDFDFDFFFFFF000000FFFFFFFDFDFD000000FFFFFFFEFEFEFBFBFBFFFFFFFBFBFBFFFFFF
000000FDFDFDFEFEFEFFFFFF000000FFFFFFFFFFFFFAFAFAF8F8F8FBFBFBFFFFFFFFFFFF
FEFEFE000000FDFDFDFFFFFFF7F7F7FFFFFF000000FFFFFFFBFBFBFFFFFF030303FBFBFB
FDFDFDFBFBFB060606FFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFA000000FFFFFFFFFFFFFFFFFF060606F8F8F8
FFFFFF030303FFFFFFFCFCFC000000FFFFFFFFFFFFFEFEFE010101FDFDFDFFFFFF000000
FFFFFFF8F8F8FDFDFD010101F8F8F8FFFFFF000000FFFFFFFEFEFEFCFCFC040404FFFFFF
050505FFFFFFFCFCFC000000FFFFFFF7F7F7000000FFFFFFFFFFFFF8F8F80C0C0CFBFBFB
000000FFFFFFFFFFFFFBFBFBFBFBFBFFFFFFFFFFFF000000FFFFFFFFFFFFF8F8F8FFFFFF
FEFEFEFFFFFF000000070707FDFDFDFFFFFFFBFBFBFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFFFFFFFDFDFD000000FFFFFFFBFBFBFFFFFFFFFFFF000000FFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
020202FDFDFDFFFFFFFCFCFC000000FFFFFFFDFDFDFFFFFF040404FAFAFAFCFCFCFEFEFE
000000FFFFFF000000FFFFFFFCFCFC020202F6F6F6FFFFFFFFFFFF000000FFFFFF000000
FFFFFFFAFAFA000000FFFFFFFFFFFFFFFFFF000000FFFFFFFAFAFA000000FFFFFF040404
FFFFFFFDFDFDFCFCFCFFFFFF040404FFFFFF000000FFFFFFFFFFFF030303F6F6F6FFFFFF
FBFBFBFFFFFFFFFFFF000000FFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFAFAFA080808010101
060606FDFDFDFDFDFDFFFFFF000000FFFFFFFBFBFBFDFDFDFFFFFFFFFFFFFFFFFFFCFCFC
FEFEFE060606FFFFFFF3F3F3FFFFFF020202FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF030303
F6F6F6FFFFFF000000020202000000FFFFFF020202FEFEFEFAFAFA000000FEFEFEFFFFFF
000000FBFBFB000000FFFFFF000000000000050505010101FFFFFFFAFAFAFDFDFD000000
000000020202FFFFFFFEFEFE000000FFFFFFFAFAFAFFFFFF000000FCFCFCFFFFFFFFFFFF
010101000000FFFFFFFDFDFDFFFFFF050505000000010101FFFFFFFFFFFFFAFAFAFCFCFC
020202FDFDFDFFFFFF000000FFFFFFFFFFFFF9F9F9FFFFFFFFFFFF000000FFFFFFFAFAFA
FDFDFD060606FEFEFEF8F8F8FFFFFFFFFFFF010101FCFCFCFFFFFFFFFFFF000000FFFFFF
FCFCFC070707FDFDFDFDFDFDFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFF000000FCFCFCFFFFFFF6F6F6000000FFFFFF
FCFCFC000000FFFFFFFCFCFC030303FAFAFAFCFCFCFFFFFF030303010101F7F7F7000000
000000FFFFFFFBFBFB030303FFFFFFFFFFFF040404FCFCFCFFFFFF020202000000FFFFFF
000000F8F8F8FFFFFF010101000000FFFFFF060606000000FFFFFF060606000000FDFDFD
040404000000FFFFFFFEFEFEFFFFFFFBFBFBFFFFFF000000FCFCFCFFFFFFFEFEFE010101
020202000000FFFFFFFFFFFFFFFFFFF6F6F6FFFFFFF6F6F6010101FAFAFAFFFFFFFCFCFC
FCFCFCFFFFFFFFFFFFFBFBFB030303FCFCFCFFFFFFFAFAFAFDFDFD030303F9F9F9FFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFF9F9F9FFFFFF010101FDFDFDFFFFFFFCFCFC0000000C0C0CFFFFFF000000
000000FFFFFF000000FFFFFFFDFDFD020202FFFFFFFAFAFA000000040404FFFFFF040404
000000F8F8F8050505FFFFFFFAFAFAFCFCFC080808FEFEFEFFFFFF010101FBFBFB040404
000000FFFFFFFFFFFF010101000000FFFFFF000000FAFAFAFFFFFF000000FFFFFFFDFDFD
FFFFFFFBFBFBFFFFFF000000FCFCFCFFFFFFFEFEFE010101000000000000030303FCFCFC
FEFEFEFAFAFAFFFFFFFEFEFE000000FFFFFFF9F9F9FFFFFFFEFEFEFFFFFFF7F7F7FFFFFF
FFFFFF000000FFFFFFFFFFFFFFFFFF000000FDFDFDFEFEFE000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFF020202
FFFFFFFCFCFCFFFFFF000000FEFEFEFFFFFFFAFAFAFFFFFFFFFFFFFAFAFAFFFFFFFDFDFD
FFFFFFFDFDFDFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFEFEFEFEFEFEFFFFFFFDFDFDFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFF9F9F9FFFFFF
FDFDFDFFFFFFFBFBFBFFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
000000FEFEFEFFFFFFFEFEFE000000FDFDFDFFFFFFFAFAFA000000FFFFFFF9F9F9FFFFFF
FFFFFF000000FFFFFFFFFFFFFDFDFDFEFEFEFFFFFF000000FFFFFFFEFEFE000000FFFFFF
FFFFFF000000FEFEFEFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9030303FFFFFFFFFFFFFFFFFF000000020202
010101060606F9F9F9FFFFFF030303FCFCFCFFFFFFFAFAFA000000030303050505000000
FFFFFF000000050505FCFCFCFFFFFFFEFEFEFDFDFD020202000000FEFEFEFFFFFFFFFFFF
060606FDFDFDFDFDFDFFFFFF000000FCFCFCFFFFFF020202000000030303FFFFFFFFFFFF
020202FDFDFD020202FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF030303FEFEFEFFFFFF000000
FFFFFFFCFCFCFFFFFFFDFDFDFCFCFCFFFFFFFDFDFDFFFFFF020202FEFEFEFDFDFDFFFFFF
FEFEFEFEFEFE030303FEFEFE000000FFFFFFFAFAFAFFFFFFFEFEFE000000FFFFFFFDFDFD
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
030303FAFAFAFFFFFFFDFDFD000000040404000000FFFFFFFFFFFF000000000000000000
FFFFFF000000FFFFFF000000FFFFFFFCFCFC000000000000040404FFFFFFFAFAFA010101
000000060606010101F9F9F9FFFFFF060606F9F9F9000000FFFFFF000000FFFFFFFEFEFE
FDFDFD040404000000FFFFFFFFFFFFFAFAFA030303010101000000FFFFFFFDFDFDFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFF030303FEFEFEFFFFFF000000FFFFFFFDFDFDFEFEFEFFFFFF
FDFDFDFFFFFFFDFDFDFFFFFF000000FCFCFCFDFDFDFFFFFFFFFFFFFEFEFEFFFFFFFEFEFE
FDFDFD000000FDFDFDFFFFFF000000FFFFFFFFFFFFFEFEFE000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFDFDFDFFFFFFFEFEFEFEFEFEFEFEFEFFFFFFFFFFFFF9F9F9FCFCFCFFFFFF
FEFEFEFDFDFDFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFBFBFBFFFFFFFFFFFFF8F8F8FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFEFEFEFDFDFD
FFFFFF000000FCFCFCFFFFFF000000010101010101000000FEFEFEFEFEFE000000020202
010101000000010101000000FFFFFFFDFDFDFFFFFFFDFDFD000000000000FFFFFFFFFFFF
000000FDFDFDFFFFFFFEFEFEFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE010101FEFEFEFEFEFEFDFDFD000000FEFEFE
FFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFDFDFDFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFCFCFCFDFDFDFFFFFFFBFBFBFBFBFBFFFFFFFCFCFCFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFCFCFCFFFFFF
FFFFFFFCFCFCFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFF7F7F7060606FFFFFFFEFEFE000000
FFFFFFFDFDFDFFFFFF040404000000FFFFFFFFFFFFFDFDFD060606FCFCFCFFFFFFFFFFFF
FDFDFDFFFFFFFDFDFD000000030303FCFCFCFBFBFBFFFFFFFBFBFB000000FFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF6F6F6FFFFFFFFFFFF
FBFBFBFFFFFF030303FDFDFDFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFF
FFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFFFFFF000000FFFFFFFFFFFFFDFDFDFFFFFFFEFEFE
FCFCFCFFFFFFFDFDFDFEFEFEFFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFEFEFEFFFFFF
FFFFFFF8F8F8FFFFFFFFFFFF000000FFFFFFFEFEFE000000FFFFFFFCFCFCFFFFFFFFFFFF
000000FDFDFDFFFFFFFDFDFD010101FFFFFFF9F9F9FFFFFFFFFFFF000000000000FFFFFF
FFFFFF000000FFFFFFFFFFFF000000FBFBFBFFFFFFFEFEFE000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF6F6F6FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFDFDFD
FEFEFEFFFFFFFEFEFEFBFBFBFFFFFFFCFCFCFBFBFBFFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
FEFEFEFDFDFDFFFFFFFBFBFBFFFFFFFCFCFCFBFBFBFFFFFFF7F7F7FFFFFFFFFFFFFFFFFF
FEFEFEFEFEFEFFFFFFF6F6F6FFFFFFFCFCFCFFFFFFFCFCFCFFFFFFFAFAFAFFFFFFFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFBFBFBFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9040404FFFFFFFEFEFEFFFFFFFFFFFFFEFEFE
FFFFFFF6F6F6FFFFFFFFFFFFFDFDFDFFFFFFFEFEFEFDFDFDFEFEFEF6F6F6FFFFFFFFFFFF
FEFEFEFBFBFBFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFBFBFBFEFEFEFFFFFFF9F9F9
F8F8F8FFFFFFFDFDFDFFFFFFFCFCFCFAFAFAFFFFFFFBFBFBFCFCFCFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCF6F6F6FFFFFFFAFAFAFFFFFF000000FBFBFBFFFFFFFFFFFF
040404020202000000000000FFFFFF0101010000000505050000000505050000000B0B0B
FEFEFEFBFBFBF8F8F8FFFFFF000000FFFFFFFFFFFFF5F5F5080808FCFCFCFFFFFFFCFCFC
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFAFAFAFCFCFC
FFFFFFFFFFFFF8F8F8FEFEFEFEFEFEFDFDFDFBFBFBFFFFFFFFFFFFF9F9F9FFFFFFFCFCFC
F9F9F9FFFFFFFFFFFFF8F8F8FAFAFAFFFFFFFCFCFCFFFFFFFFFFFF000000FEFEFEFFFFFF
FBFBFBFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFDFDFDFFFFFFFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000FFFFFFFFFFFF000000010101010101020202
F8F8F8FFFFFF000000020202000000010101030303000000FFFFFFFEFEFEFFFFFF000000
000000000000FDFDFD020202F8F8F8FFFFFFFBFBFBFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFDF6F6F6FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFF6F6F6FEFEFE
FFFFFFF9F9F9FFFFFFFFFFFFF5F5F5FFFFFFFFFFFFFFFFFFFFFFFF000000F9F9F9FCFCFC
FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFF6F6F6FFFFFFF9F9F9
FEFEFEFFFFFFFAFAFAFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFF
FCFCFCFDFDFDFDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF020202FCFCFCFFFFFFFFFFFFF8F8F8FAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFCFCFCFEFEFEFFFFFFFFFFFFFCFCFC
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFAFAFAFDFDFDFFFFFFFCFCFCFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFFBFBFBFFFFFFFFFFFFF3F3F3FFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFF5F5F5FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFCFCFC
F7F7F7FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFF3F3F3FFFFFFFFFFFFFFFFFFFEFEFEF4F4F4
FFFFFFFDFDFDFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFCFCFCFCFCFCFFFFFFFBFBFBFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FCFCFCFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFBFBFBFFFFFF
FFFFFFFBFBFBFAFAFAFFFFFFFEFEFEFBFBFBFFFFFFF7F7F7FDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFFBFBFBFDFDFDFFFFFFFEFEFEFCFCFCFEFEFEFFFFFFFCFCFCFFFFFF
FBFBFBFFFFFFFAFAFAFFFFFFFEFEFEFFFFFFFFFFFFFDFDFDFCFCFCFDFDFDFEFEFEFFFFFF
FFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFF9F9F9
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFCFCFCFFFFFFFAFAFA000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFEFEFEFCFCFCFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFF8F8F8FFFFFFF6F6F6
FFFFFFFFFFFFFEFEFEFCFCFCFFFFFFF8F8F8FFFFFFFAFAFAFFFFFF040404FEFEFEFFFFFF
FFFFFFF7F7F7FBFBFBFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FEFEFEFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFFFFFFFBFBFBFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF000000FFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFDFDFDFFFFFFFEFEFEFFFFFFF8F8F8FFFFFF
FDFDFDFEFEFEFFFFFFFBFBFBFBFBFBFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFFFFFF
FFFFFFFFFFFFFDFDFDFCFCFCFCFCFCFFFFFFFCFCFCFEFEFEFEFEFEFFFFFFFFFFFFFEFEFE
FEFEFEFFFFFFFFFFFFFEFEFEFBFBFBFFFFFFFFFFFFFCFCFCFFFFFFFCFCFCFEFEFEFFFFFF
FFFFFFFFFFFFFCFCFCFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFFFFFF
FDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFAFAFAFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFEFEFE
FFFFFFF9F9F9FBFBFBFFFFFFF8F8F8FFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFF5F5F5FFFFFF
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFDFDFDFFFFFFFDFDFDF7F7F7
FFFFFFFCFCFCFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFDFDFD
FFFFFFFEFEFEFFFFFFFDFDFDF7F7F7FFFFFFFDFDFDFEFEFEFCFCFCFFFFFFF6F6F6FFFFFF
FDFDFDFFFFFFFFFFFFFEFEFEFFFFFFFDFDFDFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFEFEFEFFFFFF000000FFFFFFFEFEFEFFFFFFFFFFFF080808
F8F8F8FDFDFDFFFFFF040404000000000000020202FFFFFFFFFFFF000000000000000000
040404FFFFFFFBFBFB000000FBFBFBFCFCFCFFFFFF000000000000FFFFFF000000FCFCFC
FFFFFFFFFFFFF8F8F8FFFFFFFCFCFCFEFEFEFAFAFAFFFFFFFFFFFFFCFCFCFFFFFFFDFDFD
FFFFFFFAFAFAF8F8F8FFFFFFFCFCFCFFFFFFFFFFFFFAFAFAFFFFFFF7F7F7FFFFFFFFFFFF
FCFCFCFAFAFAFCFCFCFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF070707F6F6F6FAFAFAFFFFFFFEFEFEFCFCFC
FBFBFBFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFCFCFCFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFCFCFCFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFBF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFF
FFFFFFFBFBFBFFFFFFFFFFFFFCFCFCFFFFFFFBFBFBFEFEFEFFFFFFFDFDFDFCFCFCFFFFFF
FFFFFFFBFBFBFFFFFFFBFBFBFFFFFFFFFFFFFEFEFEF8F8F8FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFBFBFBFFFFFFFDFDFDFBFBFBF7F7F7FEFEFEFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FEFEFEFFFFFFFDFDFDF9F9F9FFFFFFFBFBFBFEFEFEFFFFFFFFFFFFF9F9F9FDFDFDFFFFFF
FFFFFFFCFCFCFFFFFFF6F6F6FFFFFFF6F6F6FFFFFFFFFFFFFCFCFCFDFDFDFFFFFFFBFBFB
FFFFFFFFFFFFF7F7F7FFFFFFFEFEFEFFFFFFFBFBFBFEFEFEFFFFFFFAFAFAFFFFFFFFFFFF
FFFFFFF9F9F9FDFDFDFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFBFBFBFCFCFCFCFCFCFFFFFF
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFDFDFDFFFFFFFFFFFFFDFDFDFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFF6F6F6FFFFFFFCFCFCFBFBFB000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFAFAFAFEFEFEFFFFFFF5F5F5FFFFFF000000FFFFFFFDFDFDFFFFFF000000000000
FFFFFFFFFFFF020202FAFAFAFEFEFEFFFFFF000000FFFFFFFFFFFF000000080808FFFFFF
F6F6F6000000FFFFFF060606FDFDFD000000050505FDFDFDFFFFFF010101020202FFFFFF
FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFEFEFEFEFEFEFFFFFFFDFDFDFDFDFD
FBFBFBFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFAFAFAFFFFFFF5F5F5FFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFDFDFDFDFDFDFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC000000FFFFFFFFFFFFFDFDFDFEFEFEFCFCFC
FFFFFF030303FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF030303FCFCFCFAFAFA000000
050505FFFFFFFFFFFFF8F8F8010101000000FDFDFDFFFFFF000000FEFEFEFAFAFAFCFCFC
040404FFFFFFF9F9F9010101FAFAFAFCFCFCFDFDFD000000FEFEFEFFFFFFFDFDFD020202
020202FDFDFDFFFFFFFEFEFEFFFFFF000000000000FFFFFF000000FFFFFFFFFFFF000000
F9F9F90B0B0B000000000000FEFEFE000000FFFFFF040404020202FBFBFBFEFEFEFFFFFF
010101000000FFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFBFBFB
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFBFBFB
FEFEFEFEFEFEFFFFFF050505FAFAFAFFFFFFF9F9F9FFFFFFFFFFFFFFFFFF000000000000
FEFEFEFFFFFF000000FFFFFFFFFFFFFEFEFE020202F8F8F8FFFFFF000000000000030303
FFFFFF000000FFFFFFFEFEFE000000000000000000FFFFFFFCFCFC000000FFFFFFF9F9F9
FBFBFB020202000000FDFDFDFFFFFFFFFFFF050505000000FFFFFF050505FFFFFFFAFAFA
FBFBFB040404000000000000FFFFFFFFFFFFFEFEFEFFFFFFF6F6F6FFFFFFFCFCFCFDFDFD
FFFFFFFBFBFBFFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF010101FDFDFDFDFDFDFFFFFF030303FFFFFF
FFFFFFFAFAFA060606FFFFFFFFFFFFFCFCFC040404F6F6F6FFFFFF000000FEFEFEFCFCFC
FFFFFF010101FFFFFF000000FEFEFE070707F9F9F9FFFFFFFFFFFFF5F5F5010101FEFEFE
FCFCFCFFFFFFFFFFFFFCFCFCF9F9F9FFFFFFF9F9F9FAFAFAFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFEFEFEFBFBFBFFFFFFF9F9F9FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFF7F7F7
FFFFFFF9F9F9FFFFFFFDFDFDFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF020202F9F9F9FFFFFFF8F8F8FFFFFFFFFFFF
FFFFFF000000FFFFFFF5F5F5070707FFFFFFFEFEFEFAFAFA010101FFFFFFFCFCFC050505
FFFFFFF9F9F9FFFFFF010101FFFFFFF7F7F7000000FDFDFD060606FDFDFDFFFFFFFFFFFF
000000FFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF000000FEFEFEFEFEFE050505F9F9F9
F9F9F9050505FEFEFEFEFEFE000000FFFFFFFFFFFF000000000000FFFFFFFDFDFD010101
FFFFFF000000FCFCFCFFFFFF000000000000FFFFFF010101FEFEFEFFFFFFFFFFFF000000
FFFFFFFBFBFB000000FEFEFEFFFFFFFDFDFDFBFBFBFFFFFFFEFEFEFFFFFFFFFFFFFDFDFD
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFF9F9F9FFFFFF
F9F9F9FCFCFCFFFFFF000000FFFFFFFEFEFEFFFFFFFFFFFFFCFCFC000000FAFAFAFFFFFF
020202FCFCFC000000FFFFFFFBFBFBFFFFFF000000FFFFFFF9F9F9060606FDFDFDFEFEFE
000000000000FEFEFEFFFFFF030303FFFFFF000000FFFFFFFFFFFF020202FFFFFFFFFFFF
040404FAFAFAFFFFFF000000FCFCFC010101F8F8F8FFFFFF000000000000FFFFFFFFFFFF
000000FFFFFFFEFEFEFFFFFF000000FEFEFEFFFFFFFEFEFEFDFDFDFEFEFEFFFFFFFFFFFF
FDFDFDFFFFFFFBFBFBFFFFFFFFFFFFF9F9F9FBFBFBFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFCFCFC030303000000020202000000000000FFFFFF
FEFEFEFFFFFFFFFFFF000000000000000000060606FFFFFFFDFDFD020202FFFFFFFDFDFD
FFFFFF000000FFFFFF040404FFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFF
F9F9F9FFFFFFFDFDFDFFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFFBFBFBFFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFFFFFF
FFFFFFFDFDFDFDFDFDFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF000000FFFFFFFAFAFAFFFFFFFFFFFFFBFBFB
FDFDFD000000FFFFFFFFFFFF000000FCFCFCFFFFFFFFFFFF000000FFFFFFFFFFFF000000
FEFEFEFFFFFF000000FFFFFFFBFBFBFFFFFF020202FEFEFE000000FFFFFFFEFEFEFBFBFB
040404FBFBFBFAFAFA080808F9F9F9FFFFFFFFFFFF000000FFFFFF000000FAFAFAFFFFFF
FFFFFFFAFAFA000000FFFFFF000000FFFFFFFEFEFEFFFFFF040404F9F9F9FFFFFF000000
FFFFFF000000FFFFFFFEFEFEFDFDFD070707F9F9F9000000FEFEFEFDFDFD020202FDFDFD
FEFEFEFFFFFF000000FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFEFEFE
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFF
FFFFFFFEFEFEFFFFFF000000FDFDFDFEFEFEFFFFFFFEFEFE000000FFFFFFFEFEFEFEFEFE
000000FFFFFF000000FAFAFAFFFFFFFEFEFE000000FFFFFFFFFFFF000000FFFFFFFFFFFF
FDFDFD040404FAFAFA000000FEFEFEFEFEFEFFFFFFFFFFFFFBFBFB000000FFFFFF000000
FDFDFDFFFFFFFFFFFF000000FFFFFF000000FEFEFEFFFFFFFFFFFF030303F6F6F6FFFFFF
FAFAFAFDFDFDFFFFFFFDFDFD030303FFFFFFFCFCFCFFFFFFFEFEFEFDFDFDFFFFFFFBFBFB
FFFFFFFBFBFBFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFEFEFE000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFF000000
FFFFFFFFFFFF000000FFFFFFFFFFFFFEFEFE000000FFFFFFFFFFFF000000FEFEFEFFFFFF
FDFDFD040404FBFBFB000000FFFFFF000000FFFFFFFEFEFEFFFFFFFCFCFC000000F9F9F9
FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFF000000FDFDFDFEFEFE040404FCFCFCFFFFFFFEFEFE000000FEFEFEFFFFFF000000
FFFFFFFEFEFE010101000000040404000000010101FFFFFF040404F9F9F9FFFFFFFFFFFF
000000FEFEFEFDFDFD060606FAFAFAFFFFFFFFFFFF000000FFFFFF020202000000000000
000000000000020202FFFFFF000000FFFFFFFEFEFEF8F8F8020202FFFFFFF8F8F8030303
FEFEFE020202010101000000FFFFFF000000FFFFFF000000FFFFFFFFFFFF000000010101
030303000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFDFDFDFFFFFF
FDFDFDFCFCFCFFFFFF000000FFFFFFFFFFFFFAFAFAFEFEFE010101050505000000030303
000000FDFDFD030303FFFFFFFCFCFCFFFFFF040404FBFBFBFFFFFF000000000000010101
FFFFFF000000FFFFFF000000FFFFFFFCFCFCFDFDFDFFFFFFFEFEFE000000FFFFFF000000
FFFFFFFFFFFFFFFFFF030303FFFFFF000000FFFFFFFDFDFDFFFFFF000000FFFFFFFFFFFF
FEFEFE000000040404000000FCFCFCFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFDFDFD000000FFFFFFFFFFFFF9F9F9FFFFFF000000
FFFFFFFFFFFFFFFFFF000000000000020202040404FDFDFDFDFDFD040404020202000000
020202000000FFFFFF000000F9F9F9FFFFFF000000020202000000050505000000FFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFF000000FFFFFFFFFFFF000000FEFEFEFFFFFFFEFEFE020202FEFEFEFFFFFF000000
FFFFFFFFFFFF000000FFFFFFF9F9F9FDFDFD020202FBFBFB050505FFFFFFFFFFFFF8F8F8
010101FEFEFEFFFFFF000000FFFFFFFFFFFFFEFEFE010101FEFEFE000000FEFEFEFFFFFF
FFFFFFFEFEFE000000FEFEFE000000FCFCFCFCFCFCFFFFFF000000F9F9F9FFFFFF000000
FDFDFD000000FFFFFF000000040404010101FEFEFE050505FAFAFAF9F9F9030303FEFEFE
FEFEFEFFFFFF000000FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFEFEFE
FCFCFCFFFFFFF8F8F8070707FBFBFBFDFDFDFFFFFFFFFFFF000000FFFFFFFDFDFDFFFFFF
020202FDFDFD010101FFFFFFFFFFFFFCFCFC000000FFFFFFFAFAFA000000FFFFFF000000
000000060606FEFEFE020202F9F9F9FFFFFFFDFDFDFFFFFFFFFFFF020202F4F4F4060606
FFFFFFFBFBFBFEFEFE000000FFFFFF010101FBFBFBFFFFFFFFFFFF020202FFFFFFF9F9F9
050505FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFF9F9F9FEFEFEFFFFFFFFFFFFF8F8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFFFFFF020202FEFEFEFCFCFCFFFFFFFFFFFF020202
FFFFFFFCFCFCFBFBFBFFFFFFFFFFFFFDFDFDFBFBFBFFFFFFFFFFFFFBFBFBFDFDFDFFFFFF
FFFFFFFBFBFBFBFBFBFFFFFFFFFFFFFCFCFCF8F8F8FFFFFFFFFFFFFAFAFA020202FFFFFF
F8F8F8FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FCFCFC030303FFFFFFF5F5F5030303000000FCFCFCFFFFFF000000FFFFFFFFFFFF000000
FFFFFFFEFEFEFFFFFF000000FFFFFFFFFFFF020202FFFFFF000000020202FAFAFAFFFFFF
000000FFFFFFFFFFFF060606000000FFFFFFFFFFFF000000FFFFFFFFFFFF000000FDFDFD
FDFDFD000000FFFFFFFFFFFF040404FFFFFFFEFEFE000000000000FFFFFFFFFFFF000000
FFFFFF000000FFFFFFFCFCFCF5F5F5060606FEFEFE000000FFFFFFFFFFFFFFFFFF030303
FCFCFCFFFFFF000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF
FFFFFFFCFCFCFFFFFF000000FEFEFEFFFFFFFAFAFAFCFCFCFFFFFF000000FFFFFFFBFBFB
000000FFFFFF000000050505FBFBFBFFFFFF000000FFFFFFFFFFFF000000FFFFFFFEFEFE
FFFFFF000000FFFFFFFBFBFB010101FFFFFF000000FEFEFEFFFFFF000000FFFFFFFCFCFC
030303FFFFFFFFFFFF070707FEFEFE000000FFFFFFFBFBFBFFFFFF000000FFFFFFFEFEFE
010101FDFDFDFAFAFAFFFFFF030303FDFDFDFBFBFBFFFFFFF5F5F5FFFFFFFEFEFEFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFFFFFFFFFFFFFEFEFEFBFBFB020202000000020202030303000000000000
FFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFF9F9F90C0C0CF7F7F7FFFFFFFFFFFFF9F9F9F9F9F9FFFFFF000000FFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFF000000FFFFFFFFFFFF050505FEFEFE060606000000FFFFFFFEFEFE000000030303
010101FFFFFFFEFEFEFFFFFF000000000000FDFDFDFDFDFD020202F9F9F9050505FBFBFB
060606000000000000010101FFFFFF000000010101FAFAFAFDFDFDFCFCFCFFFFFF020202
020202FFFFFFFCFCFCFDFDFDFBFBFB000000020202F9F9F9000000FCFCFCFFFFFF010101
FCFCFCFFFFFF020202040404060606FBFBFB0000000A0A0A000000FCFCFCFFFFFFFFFFFF
000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFFFFFF
FBFBFBFFFFFFFFFFFF000000FFFFFFFEFEFEFCFCFCFFFFFFFDFDFDFFFFFF000000010101
FCFCFCFEFEFE000000FFFFFF040404020202FFFFFFFFFFFFFDFDFDFEFEFE000000000000
000000FFFFFFFBFBFBFFFFFF000000000000000000FFFFFFFEFEFE000000FAFAFAFFFFFF
F8F8F8000000080808F6F6F6FFFFFF000000FCFCFCFFFFFFFFFFFF000000FFFFFFFFFFFF
FFFFFF000000000000000000FFFFFFFDFDFDFFFFFFF9F9F9FFFFFFF9F9F9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFDFDFDFEFEFEFEFEFEFFFFFFFFFFFFFCFCFCFCFCFCFFFFFFFEFEFE
FCFCFCFDFDFDF7F7F7FFFFFFFFFFFFFEFEFEFCFCFCFEFEFEFEFEFEFCFCFCFEFEFEFFFFFF
FFFFFFFEFEFEFFFFFFFEFEFEFDFDFDFCFCFCFDFDFDFFFFFFFFFFFFFBFBFBFFFFFFFCFCFC
FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FCFCFC000000F7F7F7FFFFFFFAFAFAFCFCFCFFFFFFFCFCFCFFFFFFFFFFFFFFFFFF060606
FBFBFBF6F6F6FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFCFCFC
F9F9F9FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF010101FFFFFFFBFBFBFDFDFD
FFFFFFF8F8F8FFFFFFFCFCFCFFFFFFFFFFFFFCFCFC000000FDFDFDFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFDFDFD
FEFEFEFFFFFFF9F9F9030303FDFDFDFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFFFFFFF8F8F8
FFFFFFFEFEFEFFFFFFFDFDFDF5F5F5FFFFFFFFFFFFFDFDFDFFFFFFFCFCFCFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFDFDFDFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFBFBFBF9F9F9FFFFFFF7F7F7FFFFFFFDFDFD
FEFEFEFFFFFFFFFFFFFCFCFCFAFAFAFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFAFAFA
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFDFDFDFEFEFEFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFFFFFFFAFAFAFFFFFFFFFFFFFEFEFEFFFFFFFDFDFDF9F9F9FFFFFFFFFFFFFEFEFE
FFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFF000000FFFFFFFCFCFCFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFF6F6F6FFFFFFFFFFFFF9F9F9FFFFFFFBFBFBFFFFFFFFFFFFFAFAFAFFFFFFFBFBFB
FBFBFBFFFFFFFAFAFAFFFFFFFCFCFCFFFFFFFFFFFFFBFBFB000000F6F6F6FFFFFF000000
FDFDFDFFFFFFFBFBFBFFFFFFFDFDFDFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFBFBFBFEFEFE
FFFFFFF9F9F9FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDF9F9F9FDFDFD
FFFFFF010101000000040404000000000000000000FAFAFAFFFFFFFFFFFFFFFFFFFFFFFF
FBFBFBFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FBFBFBFBFBFBFFFFFFFFFFFFFBFBFBFCFCFCFFFFFFFEFEFEFCFCFC000000FFFFFFFFFFFF
FFFFFFFDFDFDFDFDFDFFFFFFFFFFFFF5F5F5FFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFF9F9F9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFFFFFFFEEEEEEFFFFFFFEFEFEFEFEFEFFFFFFF3F3F3FFFFFFFEFEFE
FDFDFDFFFFFFFFFFFFFEFEFEFEFEFEFFFFFFF9F9F9FFFFFFFFFFFFF9F9F9FFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFEFEFEFDFDFD
FFFFFFFBFBFBFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FAFAFAFFFFFFF9F9F9FFFFFFFFFFFFFAFAFAFFFFFFFBFBFBFFFFFFFFFFFFFEFEFEFFFFFF
F9F9F9FFFFFFF9F9F9FFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFDFDFDFFFFFFFAFAFAFEFEFE
FBFBFBFFFFFFFCFCFCFCFCFCFFFFFFFEFEFEFFFFFFFBFBFBFFFFFFFCFCFCFFFFFFFFFFFF
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFF
FFFFFFFCFCFCFFFFFFFDFDFDFFFFFFFBFBFBFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFFFFFF
FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFCFCFC
FFFFFFFCFCFCFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFF8F8F8F9F9F9FFFFFFFDFDFDF6F6F6FFFFFFFFFFFFFDFDFD
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFF7F7F7FFFFFF
FFFFFFF8F8F8FFFFFFFFFFFFF4F4F4FFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFCFCFCFFFFFF
FDFDFDFBFBFBFEFEFEFFFFFFFAFAFAFAFAFAFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FDFDFDFFFFFFFEFEFEFFFFFFFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFAFAFAFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFDFDFDFFFFFFFDFDFDFFFFFF
FEFEFEFCFCFCFFFFFFFFFFFFFBFBFBFDFDFDFFFFFFFFFFFFFDFDFDFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFBFBFBFFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFEFEFEFFFFFFFCFCFC
FFFFFFFDFDFDFFFFFFFEFEFEFEFEFEFFFFFFF4F4F4FFFFFFFEFEFEFFFFFFFCFCFCFFFFFF
FFFFFFFCFCFCFFFFFFFEFEFEFDFDFDFFFFFFFDFDFDFFFFFFFCFCFCFFFFFFFFFFFFFAFAFA
FFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFCFCFCFFFFFFFEFEFEFFFFFFFAFAFAFFFFFFFDFDFD
FDFDFDFFFFFFFEFEFEFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFFFFFF
FAFAFAFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFBFBFBFFFFFFFDFDFDFBFBFBFFFFFFFFFFFF
FEFEFEFFFFFFFEFEFEFAFAFAFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFDFDFDFDFDFDFCFCFC
FFFFFFFCFCFCFFFFFFFEFEFEFCFCFCFFFFFFFAFAFAFFFFFFFAFAFAFFFFFFFFFFFFFDFDFD
FFFFFFFEFEFEFCFCFCFEFEFEFFFFFFFCFCFCFDFDFDFFFFFFFFFFFFFAFAFAFFFFFFFCFCFC
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFCFCFCFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFD010101
FFFFFFFEFEFEFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FDFDFDFFFFFFFBFBFBFBFBFBFFFFFFFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFD000000FFFFFFFEFEFEFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
010101FFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFEFEFEFCFCFCFFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFF7F7F7FFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFBFBFB000000
FFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF020202FFFFFFF9F9F9FFFFFFFFFFFFF7F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF000000FDFDFDFFFFFFF9F9F9FFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFFFFFFFAFAFAFDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FEFEFEFEFEFEFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFFFAFAFA
FDFDFDFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFF000000
FBFBFBFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFC000000FAFAFAFEFEFEFFFFFFFBFBFBFFFFFFF9F9F9
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFF9F9F9FFFFFFF7F7F7FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFF9F9F9FFFFFFFFFFFFF8F8F8FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
010101FFFFFFFFFFFFFCFCFCFAFAFAFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFF9F9F9FFFFFF
FFFFFFF8F8F8FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FEFEFE000000
FEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFFFFFF050505FFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFAFAFA000000FFFFFFFFFFFFFFFFFFFEFEFEFAFAFA
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
000000FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000FFFFFFFDFDFDFBFBFBFFFFFFFFFFFFFFFFFFFBFBFBFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE
FEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFEFE000000FFFFFFFCFCFCFFFFFF
FFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFF040404
020202010101020202000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000FDFDFDFFFFFFFDFDFDFFFFFFFEFEFEFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE000000000000000000000000030303020202
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
010101FEFEFEF8F8F8FAFAFAFCFCFCFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
000000000000010101010101000000000000000000030303000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000010101FEFEFEF8F8F8FAFAFA
FCFCFCFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFEFEFEFAFAFA
FFFFFFFAFAFAFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFEFEFEFEFEFEFFFFFFF8F8F8FBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFF
FCFCFCFFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFCFCFCFFFFFFFAFAFA
FFFFFFFCFCFCFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFCFCFCFBFBFBFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FCFCFCFFFFFFFDFDFDF3F3F3FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFDFDFDFCFCFCFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFDFDFDF3F3F3
FFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
F8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFDFDFDFFFFFFFDFDFD
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFCFCFCF9F9F9FFFFFFFFFFFFF9F9F9FEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFDFDFDFFFFFFFFFFFFFEFEFEFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFDFDFDFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
F3F3F3FFFFFFFDFDFDFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFF9F9F9FFFFFFFEFEFEFFFFFF
FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFDFDFDFFFFFFFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFBFBFB
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFDFDFDF9F9F9FFFFFFFFFFFFF9F9F9FFFFFFFFFFFF
FBFBFBFEFEFEFFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFCFCFCFDFDFDFFFFFFFFFFFF
FAFAFAFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFAFAFAFFFFFFFCFCFCFFFFFFFFFFFFF9F9F9
FFFFFFFFFFFFF3F3F3FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF3F3F3FEFEFEFFFFFFFFFFFFF9F9F9FFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFCFCFCFEFEFEFFFFFFFEFEFEFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFFFFFFFCFCFCF8F8F8FFFFFFFDFDFDFFFFFFFCFCFC
FFFFFFFFFFFFFBFBFBFDFDFDFCFCFCFFFFFFF9F9F9FFFFFFFBFBFBFFFFFFFBFBFBFFFFFF
FFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFCFCFCFFFFFFFDFDFDFFFFFF
FEFEFEFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFEFEFEF9F9F9FFFFFFFEFEFEFFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFEFEFEFFFFFF
FFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFEFEFEFCFCFCFFFFFF
FCFCFCFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFBFBFBF9F9F9090909070707000000FFFFFFFFFFFFFAFAFA
FFFFFFFDFDFD000000090909000000000000FBFBFBFFFFFFFFFFFF000000F9F9F9FFFFFF
FFFFFF000000000000FFFFFFF9F9F9FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FAFAFAFFFFFF000000070707000000000000FFFFFFFFFFFFFFFFFF000000000000040404
010101FEFEFEFFFFFF020202000000FFFFFFFBFBFB030303020202FCFCFCFCFCFCFFFFFF
FFFFFFFFFFFF000000060606F7F7F7000000000000FFFFFFFCFCFC000000000000000000
030303FCFCFCFFFFFF000000000000040404070707F7F7F7FFFFFFFFFFFF000000010101
000000020202000000FFFFFFF9F9F9FCFCFC020202010101F5F5F5FFFFFFFDFDFD000000
000000040404000000FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFD020202000000000000090909000000020202FFFFFF
FFFFFF000000040404000000030303020202FFFFFFFFFFFFFFFFFF000000FFFFFF000000
000000000000070707000000080808FBFBFB010101000000FFFFFFF9F9F9FCFCFCFFFFFF
FFFFFF000000030303000000000000010101F8F8F8FFFFFF000000050505050505000000
040404010101FFFFFF000000000000FEFEFE000000010101000000FFFFFFFFFFFFFCFCFC
FCFCFC000000030303000000FFFFFF010101000000FFFFFF080808000000000000000000
010101FFFFFF000000020202030303000000000000020202FBFBFB040404000000000000
040404000000000000FFFFFF010101030303000000010101030303FFFFFF000000070707
000000010101000000010101FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF040404020202FFFFFFFFFFFFFAFAFAFFFFFF000000FEFEFE
F9F9F9060606020202FEFEFE000000010101FFFFFFFDFDFDFDFDFD040404FCFCFC040404
040404FFFFFFFBFBFBFEFEFEF8F8F8FDFDFD000000030303FBFBFBFFFFFFFFFFFFF9F9F9
FAFAFAFFFFFFFFFFFF000000000000090909FEFEFEFFFFFF020202000000F8F8F8FFFFFF
000000070707FFFFFF000000070707FFFFFF000000000000FEFEFEFFFFFFFAFAFAFFFFFF
FDFDFD030303000000FBFBFBFFFFFF000000000000FDFDFDFAFAFAFBFBFB030303030303
000000FAFAFAFFFFFFFBFBFB020202000000000000030303FDFDFD040404000000FFFFFF
F9F9F9000000070707F8F8F8040404000000FFFFFFFAFAFAFFFFFFFEFEFEFCFCFCF4F4F4
FFFFFF040404040404000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF080808FEFEFE
FFFFFF000000000000FFFFFF000000040404FFFFFFFFFFFFFFFFFF000000FFFFFF000000
000000000000000000080808040404FFFFFF000000000000FFFFFFFFFFFFFFFFFFFFFFFF
FFFFFF000000000000060606000000000000FFFFFFFEFEFE010101000000FFFFFFFFFFFF
000000000000FCFCFC020202000000F8F8F8060606040404FEFEFEFFFFFFFBFBFBFFFFFF
FFFFFF000000020202FFFFFFFBFBFB000000030303FFFFFF080808000000000000000000
000000FFFFFF000000040404000000060606000000FDFDFDFFFFFF000000020202FEFEFE
FEFEFE030303000000FEFEFE010101010101000000030303000000FFFFFF000000070707
000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF000000060606FEFEFEFFFFFFFBFBFBFFFFFF000000FDFDFD
FAFAFA000000030303FEFEFE060606010101000000FDFDFDFEFEFE030303FFFFFF000000
030303FFFFFFFCFCFC000000000000FDFDFD040404000000000000FFFFFFFFFFFFFAFAFA
FFFFFF000000000000FFFFFFFFFFFF010101FFFFFFFAFAFA000000080808F8F8F8FCFCFC
030303000000FFFFFF000000040404FFFFFF000000000000FFFFFFFBFBFBFFFFFFF8F8F8
FDFDFD0A0A0A000000FFFFFFFFFFFF000000000000FDFDFD000000000000FFFFFFFBFBFB
030303FBFBFB050505000000FFFFFFFCFCFC000000020202F9F9F9060606050505FDFDFD
FFFFFF000000050505FFFFFF000000020202FFFFFFFAFAFA000000FDFDFD000000020202
FEFEFEFEFEFE040404000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF020202000000FFFFFFF9F9F9FFFFFFFCFCFC000000FFFFFF
010101030303000000020202000000000000060606000000010101000000FDFDFDFFFFFF
000000000000070707000000FBFBFBFFFFFF000000020202060606000000FFFFFFFFFFFF
FFFFFF000000000000000000010101000000F9F9F9FFFFFFFFFFFF000000000000000000
010101F9F9F9060606000000000000010101030303000000020202FFFFFFF4F4F4FFFFFF
FFFFFF000000020202010101FFFFFF010101000000FFFFFF000000030303000000000000
000000FFFFFF000000030303000000070707000000000000FFFFFF030303000000FFFFFF
FDFDFD010101000000FFFFFFFFFFFF000000030303000000040404FDFDFD010101000000
000000000000000000000000FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFCFCFC000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFF010101000000FFFFFFFFFFFFFCFCFC050505000000FFFFFF
020202000000000000020202000000000000FFFFFF000000020202000000FAFAFAFEFEFE
FFFFFF000000000000FFFFFFFDFDFDFFFFFF000000010101010101000000FFFFFFFDFDFD
FDFDFDFFFFFF000000010101010101000000FFFFFFFDFDFDFDFDFD000000000000040404
000000FFFFFF000000010101000000000000030303020202000000FFFFFFFDFDFDFFFFFF
FDFDFD000000030303000000FFFFFF000000030303FEFEFEFFFFFF000000080808000000
060606FDFDFDFFFFFF010101010101030303000000FEFEFEFFFFFF000000010101FFFFFF
FFFFFF000000000000FFFFFFFEFEFEFAFAFA000000020202FFFFFFFCFCFCFFFFFF010101
000000000000010101FDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FCFCFCFFFFFF
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFCFCFCFFFFFFF9F9F9FFFFFFFFFFFFFFFFFF000000FBFBFB
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000000000000000000000000000050505FFFFFF
FBFBFB050505030303FFFFFF090909000000F6F6F6FFFFFFFCFCFCFFFFFFFEFEFEFDFDFD
FFFFFFFFFFFFFFFFFFFAFAFAFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFE
FEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFEFEFE
FDFDFDFDFDFDF9F9F9030303030303000000000000010101FFFFFFFFFFFFFEFEFEFFFFFF
FFFFFF000000000000FFFFFFFDFDFD010101000000FFFFFFFFFFFFFAFAFAFDFDFDFFFFFF
FEFEFEFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFFDFDFDFFFFFFFCFCFCFCFCFCFDFDFDFFFFFF
FAFAFAFFFFFFFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFCFCFCFEFEFEFEFEFEFBFBFBFEFEFE
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFB000000FFFFFFFFFFFF
FFFFFFF9F9F9FFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFFFEFEFEF2F2F2FFFFFF050505FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFF000000030303040404FAFAFAF7F7F7FFFFFF
FFFFFFFCFCFC020202FEFEFE000000060606FFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFF
FCFCFCFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFFFFFFFFFFFF
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFAFAFAFFFFFFF4F4F4FCFCFC
FFFFFFFEFEFEFFFFFFFEFEFE0000000404040000000A0A0AF7F7F7FCFCFCFFFFFFFEFEFE
FFFFFFFBFBFB020202FDFDFDFEFEFE000000090909FFFFFFFEFEFEFFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFDFDFDFFFFFFFBFBFBFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFCFCFCFFFFFFFFFFFFFDFDFDFFFFFFFEFEFEFFFFFFFEFEFEFFFFFF
FEFEFEF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF050505FFFFFFF2F2F2
FEFEFEFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF8F8F8FFFFFFFCFCFCFFFFFFFFFFFF000000FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFFFFFFFBFBFB
FFFFFFFFFFFFFDFDFDFCFCFCFFFFFFF9F9F9FFFFFFF6F6F6FCFCFCFFFFFFFDFDFDF6F6F6
FFFFFFFFFFFFFBFBFBFFFFFFFDFDFDFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFDFDFD
FDFDFDFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFDFDFDFFFFFFFDFDFDFFFFFFFFFFFF
F9F9F9FFFFFFFCFCFCFEFEFEFEFEFEF7F7F7FFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFEFEFE
FCFCFCFFFFFFFFFFFFFCFCFCFFFFFFFAFAFAFAFAFAFCFCFCFCFCFCF9F9F9FFFFFFFDFDFD
FAFAFAFFFFFFFDFDFDFFFFFFFFFFFFFFFFFFF4F4F4FFFFFFFFFFFFFBFBFBFFFFFFFBFBFB
FFFFFFFBFBFBFFFFFFFFFFFFF6F6F6FDFDFDFFFFFFFCFCFCFFFFFFFCFCFCFFFFFFF3F3F3
FFFFFFFDFDFDFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF000000FFFFFFFFFFFF
FCFCFCFFFFFFF8F8F8FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFEFEFEFBFBFB070707FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFBFBFBFFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFFFFFF
FFFFFFFCFCFCFFFFFFFFFFFFFBFBFBFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFF9F9F9FFFFFF
FFFFFFFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFCFCFCFFFFFF
FAFAFAFFFFFFFFFFFFFBFBFBFFFFFFFCFCFCF7F7F7FFFFFFFFFFFFF7F7F7FFFFFFFEFEFE
FFFFFFFAFAFAFDFDFDFCFCFCFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFCFCFCFBFBFBFFFFFF
FCFCFCF6F6F6FFFFFFFFFFFFFAFAFAFBFBFBFFFFFFFFFFFFF8F8F8FFFFFFFEFEFEFEFEFE
FFFFFFFFFFFFFDFDFDFFFFFFFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF070707FBFBFBFEFEFE
FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFDFDFDFFFFFFFAFAFAFFFFFF000000FCFCFC
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFBFBFBFFFFFFFFFFFFFEFEFEFFFFFFFAFAFA
FEFEFEFBFBFBFFFFFFFBFBFBFFFFFFFFFFFFFDFDFDFCFCFCFEFEFEF3F3F3FFFFFFFFFFFF
FBFBFBFCFCFCFFFFFFFFFFFFFEFEFEFDFDFDFFFFFFFEFEFEFEFEFEFFFFFFFDFDFDFEFEFE
FEFEFEFDFDFDFFFFFFFEFEFEFEFEFEFFFFFFFDFDFDFEFEFEFFFFFFFAFAFAFFFFFFFEFEFE
FFFFFFFAFAFAFFFFFFFFFFFFF7F7F7FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFDFDFD
FCFCFCFFFFFFFFFFFFFCFCFCFBFBFBFFFFFFFFFFFFFBFBFBF9F9F9FFFFFFFDFDFDFDFDFD
FFFFFFFFFFFFFFFFFFFAFAFAFFFFFFFFFFFFFFFFFFF4F4F4FFFFFFFFFFFFFBFBFBFFFFFF
FFFFFFFFFFFFFCFCFCFBFBFBFFFFFFFFFFFFF3F3F3FEFEFEFFFFFFFDFDFDFFFFFFFEFEFE
F9F9F9FFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFCFCFC000000FFFFFFFAFAFA
FFFFFFFDFDFDFDFDFDFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFEFEFEFFFFFFFFFFFF010101FFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFDFDFDFFFFFFFFFFFFF7F7F7FFFFFFFEFEFEFBFBFBFFFFFF
FDFDFDFFFFFFFFFFFFFCFCFCFDFDFDFFFFFFFCFCFCFFFFFFFDFDFDFFFFFFFAFAFAFFFFFF
FCFCFCFFFFFFFFFFFFFDFDFDFEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFCFCFCFFFFFFFEFEFE
FEFEFEFFFFFFFCFCFCFFFFFFFFFFFFFCFCFCFFFFFFFEFEFEFFFFFFFFFFFFFAFAFAFFFFFF
FFFFFFFEFEFEFDFDFDFFFFFFFFFFFFF6F6F6FFFFFFF9F9F9FBFBFBFFFFFFFFFFFFFFFFFF
FFFFFFFEFEFEFEFEFEFFFFFFFEFEFEFFFFFFFAFAFAFEFEFEFFFFFFFEFEFEFFFFFFFDFDFD
FAFAFAFFFFFFFBFBFBFFFFFFFCFCFCFDFDFDFFFFFFFFFFFFFFFFFFF7F7F7FFFFFFFDFDFD
FDFDFDFFFFFFFFFFFFFCFCFCFFFFFFFAFAFAFFFFFFFDFDFDFFFFFFFDFDFDFCFCFCFFFFFF
FFFFFFFBFBFBFFFFFFF9F9F9FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF010101FFFFFFFFFFFF
FEFEFEFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFBFBFBFDFDFD010101000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000060606000000040404020202030303000000000000
000000000000000000000000050505040404000000010101000000020202000000020202
000000000000020202000000010101000000020202000000000000020202000000010101
010101000000020202000000000000020202000000010101000000000000010101010101
000000000000000000000000020202000000000000040404020202020202000000030303
000000000000000000000000020202020202000000020202030303000000000000020202
020202010101000000010101010101030303000000030303000000010101010101000000
000000020202000000000000020202000000020202000000000000060606000000000000
000000000000000000040404000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000010101FDFDFDFBFBFB
FFFFFFFFFFFFFEFEFEFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFFF
FFFFFFFFFFFFFFFFFF
pop
P
% End of image
% End of Graphics
MathPictureEnd
\
\>"], "Text",
 ImageSize->{531, 469},
 ImageMargins->{{1, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 
  1}},ImageCache->GraphicsData["CompressedBitmap", "\<\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\
\>"],ImageRangeCache->{{{51.6875, 581.688}, {606.625, 138.625}} -> {-67.7361, \
134.141, 1.05226, 1.05226}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Strontium", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["The model", "SubsubsectionIcon"],

Cell["The compartments has been numbered as follow : ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompartNumbers", "[", "strontium", "]"}]], "Input",
 CellLabel->"In[106]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "\<\"Blood\"\>"},
    {"2", "\<\"ST0\"\>"},
    {"3", "\<\"ST1\"\>"},
    {"4", "\<\"ST2\"\>"},
    {"5", "\<\"Trabecular Marrow\"\>"},
    {"6", "\<\"Trabecular Volume Exchange\"\>"},
    {"7", "\<\"Trabecular Volume NonExchange\"\>"},
    {"8", "\<\"Cortical Surface\"\>"},
    {"9", "\<\"Cortical Volume Exchange\"\>"},
    {"10", "\<\"Cortical Volume NonExchange\"\>"},
    {"11", "\<\"Urinary Bladder\"\>"},
    {"12", "\<\"URINE\"\>"},
    {"13", "\<\"ULI\"\>"},
    {"14", "\<\"LLI\"\>"},
    {"15", "\<\"FECES\"\>"},
    {"16", "\<\"SI\"\>"},
    {"17", "\<\"ST\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.3992823504704447`*^9, 3.417835851063205*^9, 
  3.4798276880691853`*^9, 3.479828348057314*^9, 3.4798295530677576`*^9, 
  3.5185350694215546`*^9, 3.6434437554446135`*^9},
 CellLabel->"Out[106]//TableForm="]
}, Open  ]],

Cell["\<\
We build the compartmental matrix for americium. Transfer rates are taken \
from Table A.13.1. (ICRP 78) (For GI compartments are applied the transfer \
rate included in Options[qGI]).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"TransferRates", "[", "strontium", "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<From\>\"", ",", " ", "\"\<to\>\"", ",", 
        "\"\<Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\>\""}], "}"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[107]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"From\"\>",
       HoldForm], 
      TagBox["\<\"to\"\>",
       HoldForm], 
      TagBox["\<\"Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\"\>",
       HoldForm]},
     {"1", "2", "7.5`"},
     {"1", "3", "1.5`"},
     {"1", "4", "0.003`"},
     {"2", "1", "2.5`"},
     {"3", "1", "0.11599999999999999`"},
     {"4", "1", "0.00038`"},
     {"1", "8", "1.67`"},
     {"1", "5", "2.08`"},
     {"8", "1", "0.5780000000000001`"},
     {"5", "1", "0.5780000000000001`"},
     {"10", "1", "0.00008210000000000002`"},
     {"7", "1", "0.000493`"},
     {"1", "11", "1.73`"},
     {"1", "13", "0.525`"},
     {"8", "9", "0.11599999999999999`"},
     {"9", "8", "0.0043`"},
     {"9", "10", "0.0043`"},
     {"5", "6", "0.11599999999999999`"},
     {"6", "5", "0.0043`"},
     {"6", "7", "0.0043`"},
     {"11", "12", "12"},
     {"13", "14", 
      SubscriptBox["k", "ULI"]},
     {"14", "15", 
      SubscriptBox["k", "LLI"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"From", "to", "Tranfer Rates(\!\(days\^\(-1\)\))"}}]]]], "Output",
 CellChangeTimes->{3.3992823505017242`*^9, 3.417835851063205*^9, 
  3.479827688116062*^9, 3.4798283480885615`*^9, 3.479829553192753*^9, 
  3.5185350694684305`*^9, 3.6434437555071173`*^9},
 CellLabel->"Out[107]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "element", ",", " ", "lambda", ",", " ", "fn1", ",", " ", "amad", ",", " ", 
   "class"}], "]"}]], "Input",
 CellLabel->"In[108]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"element", "=", " ", "strontium"}], ";"}]], "Input",
 CellLabel->"In[109]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsubsectionIcon"],

Cell["\<\
The bioassay report for for Strontium 85 (\[Lambda]= Log[2]/64.8 d) is\
\>", "MathCaption"],

Cell["These  values are the same that Table A.4.7 of ICRP 78 ", "Commentary"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"lambda", " ", "=", " ", 
    RowBox[{
     RowBox[{"Log", "[", "2", "]"}], "/", "64.8"}]}], ";"}], " "}]], "Input",
 CellLabel->"In[110]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[111]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.20109594194757135`", "0.01629108575415866`", 
      "0.7719732629712457`"},
     {"2", "0.065897280185095`", "0.027678360244490215`", 
      "0.6701840514154122`"},
     {"3", "0.043832738638329975`", "0.022980497736227897`", 
      "0.5962402515381868`"},
     {"4", "0.032490765195191985`", "0.016861411132198224`", 
      "0.5405442522453585`"},
     {"5", "0.025435150830013638`", "0.012331523132179592`", 
      "0.497026344560881`"},
     {"6", "0.02058039256480867`", "0.009297552798269205`", 
      "0.4618601833638017`"},
     {"7", "0.01706855655354411`", "0.007263677591836298`", 
      "0.4326138911177043`"},
     {"8", "0.01445096114270561`", "0.005858767387486122`", 
      "0.4077012765351871`"},
     {"9", "0.012453069802798951`", "0.004854217406362812`", 
      "0.3860561662514341`"},
     {"10", "0.010893654695026362`", "0.004112673631475753`", 
      "0.36694231253211124`"},
     {"20", "0.0042671791162788705`", "0.0014392716635161155`", 
      "0.24693251744984152`"},
     {"30", "0.002030984681093113`", "0.0006761520082025244`", 
      "0.18540557790868734`"},
     {"40", "0.001028369511321843`", "0.00033898714084960874`", 
      "0.1487319458807752`"},
     {"50", "0.000562317194209683`", "0.00018294306316628633`", 
      "0.12428325100668433`"},
     {"60", "0.00033815428607265755`", "0.00010835676207824082`", 
      "0.10632561163314058`"},
     {"70", "0.00022442352446805722`", "0.00007087756209573474`", 
      "0.09216345389999918`"},
     {"80", "0.00016211868092887242`", "0.00005061332674346604`", 
      "0.08047409909658453`"},
     {"90", "0.00012458561857491487`", "0.000038589301419978034`", 
      "0.07056383577861816`"},
     {"100", "0.00009964707569645564`", "0.0000307142141356952`", 
      "0.062033865656257424`"},
     {"180", "0.000024238796479644758`", "7.421361083646183`*^-6", 
      "0.023056259493159623`"},
     {"200", "0.000017379325900094076`", "5.319995352485755`*^-6", 
      "0.01813515225897324`"},
     {"300", "3.4480621554944204`*^-6", "1.0542190968152335`*^-6", 
      "0.005628602092422292`"},
     {"400", "7.512927209357781`*^-7", "2.2934862108147973`*^-7", 
      "0.0018085022398328873`"},
     {"500", "1.8256785413362487`*^-7", "5.5642344699383994`*^-8", 
      "0.000592392239402582`"},
     {"600", "4.919744425834886`*^-8", "1.4973424445426295`*^-8", 
      "0.0001960678026979642`"},
     {"700", "1.4367767158636632`*^-8", "4.3685746239977075`*^-9", 
      "0.0000652545848411707`"},
     {"800", "4.4262441076362074`*^-9", "1.3449915104201604`*^-9", 
      "0.00002178324107502792`"},
     {"900", "1.4077056775401178`*^-9", "4.2760587662256235`*^-10", 
      "7.28405302693387`*^-6"},
     {"1000", "4.5574038073191195`*^-10", "1.3840954077991826`*^-10", 
      "2.4382193799424193`*^-6"},
     {"2000", "6.953757752154854`*^-15", "2.111365161820073`*^-15", 
      "4.414945459899224`*^-11"},
     {"3000", "1.1123581688174487`*^-19", "3.377302360680801`*^-20", 
      "8.257691954982774`*^-16"},
     {"4000", "1.8352296018038688`*^-24", "5.571790054767567`*^-25", 
      "1.5873371613127753`*^-20"},
     {"5000", "3.132803046045109`*^-29", "9.51075599026665`*^-30", 
      "3.1201989651659694`*^-25"},
     {"6000", "5.5392224534857125`*^-34", "1.6815447303385665`*^-34", 
      "6.241317848219413`*^-30"},
     {"7000", "1.0131639476823759`*^-38", "3.075520017238647`*^-39", 
      "1.2649972490946776`*^-34"},
     {"8000", "1.910628675299506`*^-43", "5.799585745700094`*^-44", 
      "2.588836401996671`*^-39"},
     {"9000", "0", "0", "5.335151281187112`*^-44"},
     {"10000", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282350861442*^9, 3.417835851406955*^9, 
  3.4798276886004624`*^9, 3.479828348713526*^9, 3.479829553739607*^9, 
  3.5185350697496862`*^9, 3.6434437556321163`*^9},
 CellLabel->"Out[111]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[112]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVznk4lIseB/DJaMEww7yhhaPCLZxwE0K9Px1EizrqqlAi0i2U26IUJbIe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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwd1Hs41GkbB/AxMzmbGeanZrFli0RCEUX87oSiM0U5ZxOvHPMmOw6rKHIo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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -5.616089364470441}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-5.616089364470441, -0.09243339962030228}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, -5.4}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282353223067*^9, 3.417835853875705*^9, 
  3.4798276901161647`*^9, 3.4798283502446876`*^9, 3.4798295554114175`*^9, 
  3.518535071296591*^9, 3.6434437558821173`*^9},
 CellLabel->"Out[112]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsubsectionIcon"],

Cell["Bioassay report for SR-85 for f1 = 0.3 and f1 = 0.01", "Text",
 CellTags->"ICRP 78"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fn1", " ", "=", " ", "0.3"}], ";"}]], "Input",
 CellLabel->"In[113]:="],

Cell["These  values are the same that Table A.4.7 of ICRP 78 ", "Commentary"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[114]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.05589719553668604`", "0.21487383065836296`", 
      "0.7185892644779268`"},
     {"2", "0.021530736726591407`", "0.2700132064723502`", 
      "0.41939974037941985`"},
     {"3", "0.013901555063235416`", "0.1348726894602564`", 
      "0.2661632045264615`"},
     {"4", "0.010167805624434118`", "0.057092828193775605`", 
      "0.1960706715785409`"},
     {"5", "0.007903968727635182`", "0.023589510200797734`", 
      "0.16249105769695782`"},
     {"6", "0.006365645911948441`", "0.010223405784689724`", 
      "0.14417314837818324`"},
     {"7", "0.005259993345434095`", "0.0049445224362467685`", 
      "0.13243467220499652`"},
     {"8", "0.004439414417965867`", "0.002794264905116396`", 
      "0.1237919264648333`"},
     {"9", "0.003815424913033472`", "0.0018537871355248`", 
      "0.11680560430165679`"},
     {"10", "0.0033301383434863256`", "0.0013935425421189385`", 
      "0.11083914573851444`"},
     {"20", "0.0012939866424949138`", "0.00043663993168893635`", 
      "0.0743439931705459`"},
     {"30", "0.0006151830780237206`", "0.00020483454480939599`", 
      "0.05574737487382783`"},
     {"40", "0.0003111661189551999`", "0.00010259008473858565`", 
      "0.04468323154771124`"},
     {"50", "0.00016991079897612713`", "0.00005529117246535817`", 
      "0.0373197793879479`"},
     {"60", "0.00010201517876410799`", "0.00003269729114855839`", 
      "0.03191861407116872`"},
     {"70", "0.00006760328787761869`", "0.000021355021958713556`", 
      "0.027662927742506557`"},
     {"80", "0.00004877770619899207`", "0.000015230714461253607`", 
      "0.024152265004447712`"},
     {"90", "0.00003745491927862155`", "0.00001160248720905831`", 
      "0.02117686284483266`"},
     {"100", "0.000029942751907933952`", "9.22980011683067`*^-6", 
      "0.018616328142477472`"},
     {"180", "7.278565808535644`*^-6", "2.228533250271688`*^-6", 
      "0.006918378340276088`"},
     {"200", "5.2186438089775505`*^-6", "1.5974846952259488`*^-6", 
      "0.00544162154126086`"},
     {"300", "1.03524631281912`*^-6", "3.1651948034376175`*^-7", 
      "0.0016887940840171931`"},
     {"400", "2.2553086833700774`*^-7", "6.884843493320798`*^-8", 
      "0.0005425971829221098`"},
     {"500", "5.4795571555682884`*^-8", "1.6700429501367297`*^-8", 
      "0.0001777289745565793`"},
     {"600", "1.4763835372402693`*^-8", "4.493436505721132`*^-9", 
      "0.000058823386690255644`"},
     {"700", "4.311219666113051`*^-9", "1.3108444765726471`*^-9", 
      "0.000019577264996553874`"},
     {"800", "1.328060241066389`*^-9", "4.035545747574196`*^-10", 
      "6.535246365382412`*^-6"},
     {"900", "4.2235534906630323`*^-10", "1.2829507307562954`*^-10", 
      "2.1853030641859286`*^-6"},
     {"1000", "1.3673344391775488`*^-10", "0", "7.314940306033076`*^-7"},
     {"2000", "0", "0", "0"},
     {"3000", "0", "0", "0"},
     {"4000", "0", "0", "0"},
     {"5000", "0", "0", "0"},
     {"6000", "0", "0", "0"},
     {"7000", "0", "0", "0"},
     {"8000", "0", "0", "0"},
     {"9000", "0", "0", "0"},
     {"10000", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992823546775775`*^9, 3.417835855406955*^9, 
  3.4798276916943707`*^9, 3.479828356572448*^9, 3.479829557020731*^9, 
  3.518535072343486*^9, 3.6434437562571335`*^9},
 CellLabel->"Out[114]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[115]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV0nk41NsbAPAxQ8OMWfClqVzJUpI1QpJzKtGmRUVNJCQuGcktQqKS5Yao
6DdKmyuVNkVROseeJW1kuKlEEikpNengfn9/nOd9Ps/7vMvzvGeGb6ibP5PB
YKTR7/9RZrrX+vHuGMfs2InQa6e5eL+vd1+mSAwU/JXhYBYXZ/yqZopFQWCh
kqzQNIOLp9X8TF8oigIN8sItNxO4+K1xhru5KAUQvY38cgkXV3Z2zjcSSUHG
OV7Od8jFVraHrxqIroDGhamykfcc/MnPo0dPVAZ2B7lybaw5OMamYHxFchkI
CVZ87WHGwaoqv0Tho2WgbJ+vPMaIg02uS12rXt0HzNbLS59pc3CIvLPE73w5
uPlJzMpT4uAI5yInt5MY3AzN9pxoU8HyDrvJx3Wqgc+M+r6PB1QwdPIxmOVR
DcD84t70KBWcdC3Z8n56NXiQv6bMfo8KFsV1rOxm1ADSYTORG6SC7Qxj4qy6
a8AbW2nxhY0qeF8o+vjiUh1QL8QhOSYqeJTl/ICybASnLtdv3fFaGSu0c773
+TeCIZ5X5Xi7Mla+/mROubQRTFcNP5fTqownb9qc46/YBNa229a8a1LG1oU7
o0ramsCZsMUR+feVcciG43abYptBfsOOOQpSZbzLbVfH4/dPgcB+oXX/ZmX8
7kK5u5pVC0g5Llsuec/GhdbrHv9Y1QKIqtdpzXdsvLe2Z8mrHS2gfThBFb9m
Y5V+ruUlaQvYZlpqqiNjYwtLMXchsxVMj8xpHG9g41j0AwU+awUrTlU4rLrF
xlNfmc/GoW0g/k0k58sBNnbTvPBbUtgBJjuHbdY3YGPXIwYTeu1vgQMGxUXh
k3B3uaOxmm4P+BR94pxWlxLutbVXdLj2AdiP4/rgNUr4ulRs/Xz2AMit+PqQ
36iIA0oX8YODPoMYkV5FtYciduElrDwnHwKTGgO3nnnHwi9ymrar5g6D4deV
9s+jWbgid+ZsswXfgU20xa1sbRbuXfzVSfJ7BAjkOWqfy5iYtfRs8Y0zP8H6
aN2d97czsUdf+X6B3y8w9fRMuacqE/MYX4YMdH8D659aZofLFPCDPazSBYiA
kpzo2D93K+DzR5Nku+LHQfT6oH8LjBQwjovMf6HOgBKLiw6tHxi4keuvGvuD
AcW81ZH3/2Fg9rMOF9ZLBbioOXRPRSADg6WVpsn5TPh+blrXNCsG1uD4gtwk
Ftyfk3XOTz6BuveH/769RRFu/DbSdSB7AvXM4afmGSvBOL2pn+MWTqA4Y58V
BtxJ0NIoM2pZ1ziaIjMsyns1CfIWhfxwPTaOXF9eWHoHseG8TqY7dBxHRfzL
13NzlWG/cttA7bcxRP3QrUyWqEC3Hqtu/p0xpGa2TkFxLQeai2UGKXvGEEfz
W3+sHhdKLlocSls0hubZ6FxpGeLCa5qn9M5RY+j3JYWTpU9V4eR8M+PYfoJi
ifucsReq8FNfgHTwI0HMdYUVsE0VVhiN+HvRVh51/1zXqQoFyVf4jn0EUasK
XV72q0LZn08vsnoJMhlyHx1W5EHnTQp1Z7sI8rQr9DaZz4PNW3LsprUTVP7I
3fjseR7cE6afJKon6OC4eMzoHx4UmI1cPf6IoGXW3k+LCniQr3ZyroD287MB
e2tv8KDVkhMB7DqC+vZGVg6W82C+c3swqabnG0rFDh08KFxifVeOCdoZ35nS
rs6HXHUdnfmlBE213z6gcZgPdQ8kPW++QtBpG/UKn0Q+VPJziA2k/YcVzrqR
wof5nXf3MGnrmmgvXpnBh6Euni62lwky1Gk5dTCXDxMNi3flXSLIgunk/PUe
H/pH25QczSPIpUH/fPMgH96q0ew8nkvQX+Ju92QPAXxQnNu/+zhBr6M/ZNeK
BTArWCybTnvZmQEZa6sADgicFR9nEqT99ps4drsAXothaBnRrvFX9A4PE8CA
Ty7aXccI0gozDPD6WwDjuYvStqYRVJoYEGGJBLCBM02WkEzQgY6Rxp0aQjjL
QOtgTBxBL7c8STHTFMJ9BkdeWNI26SxYPqQlhFpjnj4fDhAke7OlLnwqnR/x
s1xPe+77isqoGULo19px2jSWoJ4vqaVJ5kL4RXIrbDCa3ldp5qW8lUJoVTqa
nR1BkLqF+8FXh4SwJSDQNiWUoNoThxfHJQih6+1twnW0o34VMQ0ShfAOilIX
0e6uFBwKThHCocawjHwJQXc21h8aPSaE0xQZe2tCCHKPdkgQ5Qrh6qzEEs5O
gqS1ekkb7gmhVN1FoSiQIH2vL6lNn4RQfyJUEuxLUHzRdvPDW9UgS1L/Msyd
IHle7oLZzWowXUkU5L+KoEGJ2pnVNuqwp6ouwtyJvpfPthMLLqnDWMa2vFUO
BH017ntbINSAUenVtVXzCGrMsD7FitSAm6fIKygLgoZ1vd4b9mlAnnuW0R1j
go7m94Y++qgBixKyz5+nPctk12jQgAZ8Y/fRMJ22p+0hwc3PGtDncfTaINq1
rpfn249oQFy+ynQG7ZyokdTVTAo6HeYpZcwmyKkl1SZCm4I/m4dn7TMiKDvx
YeKjtRSsGpWyg2cSFOkZinLcKPhOrTZqM22xpe5PyQYKhk1/8NuFts6/8Ts0
N9H1LYxZhrTzzJYu9fWmYKrdLb23hgQVtTYySQgFvw+XFW6i3aTfvt/8bwo6
unqNrjcg6Lo8uZiZSsH0AC89J9rpj+0HW9Mo+OMvmYc1bbeI054xmRS8HW41
QNFub/BeUP8/Cnblzbr9Up+g3rBeuW8BvZ/UqcaT9iPnbAubKxT0dt1f5Ur7
yrRlgSqF9PwLY82OtENqLrfduEHB2ZvreDNofxeFlJASCsZwtI179ej/OvjH
5yf3KLhrrnlmG+27lc2GF8soGBkWwq6nHbXT4uTyhxSktnhOKaTtuairSRtT
0O+IUskZ2o5amYpDFXT/+gbvdNq6A4sdqqooeG9NgVY8bQX8LTyrhoJXgbRj
N+3/ALdVUPY=
        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwd1Xk81Nv/B/CxyzqY3HFRhEK2W7JW5yQqooRLSZTc244opKRUiCjqpiii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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -3.765884774390615}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-3.765884774390615, 0.006700349131272043}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, -3.6}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282358650112*^9, 3.417835860063205*^9, 
  3.4798276945851436`*^9, 3.4798283643220015`*^9, 3.479829559801874*^9, 
  3.5185350748122835`*^9, 3.643443756835251*^9},
 CellLabel->"Out[115]="]
}, Open  ]],

Cell["Acute input", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fn1", "=", "0.01"}], ";"}]], "Input",
 CellLabel->"In[116]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[117]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.001806380067846241`", "0.2773951539496881`", 
      "0.7101587566554408`"},
     {"2", "0.0007447740902530673`", "0.3771284635050655`", 
      "0.3247296363132671`"},
     {"3", "0.0004722959847271715`", "0.18882607636952176`", 
      "0.1319762350187746`"},
     {"4", "0.00034367380928758043`", "0.07724216065327572`", 
      "0.05298621177753649`"},
     {"5", "0.0002664742953056856`", "0.02955690199340229`", 
      "0.022599077597175367`"},
     {"6", "0.00021427036498550449`", "0.011033448892044866`", 
      "0.01111091072345217`"},
     {"7", "0.00017683886806493015`", "0.0040930502257490045`", 
      "0.006722804769182184`"},
     {"8", "0.00014909957504274932`", "0.0015290669592083162`", 
      "0.004973109546324687`"},
     {"9", "0.00012803151087849459`", "0.0005855953162005604`", 
      "0.004206570279221285`"},
     {"10", "0.00011166551199444852`", "0.00023741514430358838`", 
      "0.003812732937888631`"},
     {"20", "0.00004327606945622411`", "0.000014612793106100385`", 
      "0.0024808624742362027`"},
     {"30", "0.000020566842980327276`", "6.848340618182305`*^-6", 
      "0.001859540221319884`"},
     {"40", "0.00001039958740106856`", "3.4288889932037323`*^-6", 
      "0.0014900956050641944`"},
     {"50", "5.6762259558104456`*^-6", "1.8472482328827582`*^-6", 
      "0.0012443499561343508`"},
     {"60", "3.4063677136290094`*^-6", "1.0918703352629838`*^-6", 
      "0.0010641682602809627`"},
     {"70", "2.256286560416952`*^-6", "7.127787693062277`*^-7", 
      "0.0009222396627874616`"},
     {"80", "1.6273844039387875`*^-6", "5.08170859703849`*^-7", 
      "0.000805177983011696`"},
     {"90", "1.2493104177348587`*^-6", "3.8701335441738984`*^-7", 
      "0.0007059741082493248`"},
     {"100", "9.985898028144924`*^-7", "3.078191727699682`*^-7", 
      "0.0006206071644220544`"},
     {"180", "2.4268944494976614`*^-7", "7.430609476329599`*^-8", 
      "0.0002306278974919534`"},
     {"200", "1.7400417260764226`*^-7", "5.326463245665962`*^-8", 
      "0.0001813983446723992`"},
     {"300", "3.451664371524298`*^-8", "1.0553234878051817`*^-8", 
      "0.00005629531029383978`"},
     {"400", "7.519153161939857`*^-9", "2.2953946027766068`*^-9", 
      "0.00001808704640496128`"},
     {"500", "1.8267759564428744`*^-9", "5.567597002327789`*^-10", 
      "5.924414227635429`*^-6"},
     {"600", "4.921747297674479`*^-10", "1.4979557287631247`*^-10", 
      "1.9608105614615517`*^-6"},
     {"700", "1.4371638295568425`*^-10", "0", "6.525845536963912`*^-7"},
     {"800", "0", "0", "2.178443345045455`*^-7"},
     {"900", "0", "0", "7.284432243773265`*^-8"},
     {"1000", "0", "0", "2.438342149933241`*^-8"},
     {"2000", "0", "0", "0"},
     {"3000", "0", "0", "0"},
     {"4000", "0", "0", "0"},
     {"5000", "0", "0", "0"},
     {"6000", "0", "0", "0"},
     {"7000", "0", "0", "0"},
     {"8000", "0", "0", "0"},
     {"9000", "0", "0", "0"},
     {"10000", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {
      "Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours", 
       "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282360120263*^9, 3.417835861719455*^9, 
  3.479827696194601*^9, 3.479828366071901*^9, 3.479829561379938*^9, 
  3.5185350758748035`*^9, 3.6434437572258806`*^9},
 CellLabel->"Out[117]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[118]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV03lYDOoXB3BaSM1WvVMzU7ebVFooS78s4X0lFQmFYqJui10LIZKSooUR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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwd13k0lV8XB/A7EGW6uAohQpmpkDScoxClgUqlQiJNSChUknmulGTsXjMh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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -7.622553219161745}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-7.622553219161745, 0.6576195699638371}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992823647183933`*^9, 3.41783586707883*^9, 
  3.479827699163503*^9, 3.4798283691186004`*^9, 3.4798295643954477`*^9, 
  3.518535078843611*^9, 3.64344375786652*^9},
 CellLabel->"Out[118]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsubsectionIcon"],

Cell[" AMAD 5, Sr 89 (T = 50.5 days)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"lambda", " ", "=", " ", 
   RowBox[{
    RowBox[{"Log", "[", "2", "]"}], "/", "50.5"}]}], ";", "  ", 
  RowBox[{"amad", "=", " ", 
   RowBox[{"AMADAdultW", "[", "5", "]"}]}], ";"}]], "Input",
 CellLabel->"In[119]:="],

Cell["Type F", "Text"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"fn1", " ", "=", " ", "0.3"}], ";", 
   RowBox[{"class", " ", "=", " ", "F"}], ";"}]}]], "Input",
 CellLabel->"In[120]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[121]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Lung\\nretention\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "2.3610953471749193`*^-45", "0.0672910603611541`", 
      "0.04700329657066485`", "0.4829269847155379`"},
     {"2", "0", "0.022751044629614185`", "0.06150867595469057`", 
      "0.3154541640504461`"},
     {"3", "0", "0.014989421832222464`", "0.033233779852667594`", 
      "0.23512445124550146`"},
     {"4", "0", "0.011045004207308114`", "0.01601470695206293`", 
      "0.1947696349125479`"},
     {"5", "0", "0.008607156057496072`", "0.00808383429489286`", 
      "0.17176229097280765`"},
     {"6", "0", "0.006936225798517473`", "0.004584270258725847`", 
      "0.15657180033735638`"},
     {"7", "0", "0.005730631423059817`", "0.0029717518602307793`", 
      "0.1452529611071691`"},
     {"8", "0", "0.004833830395797776`", "0.0021552641394588547`", 
      "0.13610885956428306`"},
     {"9", "0", "0.004150528219650854`", "0.0016898836304845514`", 
      "0.12834954672349802`"},
     {"10", "0", "0.0036180392081666154`", "0.0013927244674349795`", 
      "0.12156609921827197`"},
     {"20", "0", "0.0013725575752007056`", "0.000462992090605799`", 
      "0.07930390191697012`"},
     {"30", "0", "0.0006336299612573039`", "0.00021095343777835838`", 
      "0.05775142115337216`"},
     {"40", "0", "0.0003111897920885626`", "0.00010258325027181761`", 
      "0.04493780188122286`"},
     {"50", "0", "0.00016503366327108807`", "0.00005369437086910527`", 
      "0.03642667857258631`"},
     {"60", "0", "0.00009625042415393865`", "0.000030843708854903495`", 
      "0.030231824717928523`"},
     {"70", "0", "0.00006195285871432799`", "0.000019566876898692072`", 
      "0.025422381268114268`"},
     {"80", "0", "0.0000434071610168748`", "0.00001355213237222387`", 
      "0.021535297126367748`"},
     {"90", "0", "0.000032356898284941534`", "0.000010022479599764069`", 
      "0.018319663089150597`"},
     {"100", "0", "0.00002510515591093919`", "7.738259734072936`*^-6", 
      "0.01562451083530907`"},
     {"180", "0", "4.79191784020571`*^-6", "1.4671754267181689`*^-6", 
      "0.00455741439705673`"},
     {"200", "0", "3.2338492703024057`*^-6", "9.899157976769634`*^-7", 
      "0.0033739588144993376`"},
     {"300", "0", "4.739181329907266`*^-7", "1.4489697711003554`*^-7", 
      "0.0007735099821314928`"},
     {"400", "0", "7.627381099649935`*^-8", "2.328427077398855`*^-8", 
      "0.00018358368806142085`"},
     {"500", "0", "1.3690766785401243`*^-8", "4.172622671777782`*^-9", 
      "0.00004441971788635542`"},
     {"600", "0", "2.7251198142997907`*^-9", "8.294006500504878`*^-10", 
      "0.000010859881233924046`"},
     {"700", "0", "5.878627774701648`*^-10", "1.787419763347662`*^-10", 
      "2.669824377060866`*^-6"},
     {"800", "0", "1.3377328382160956`*^-10", "4.064935304575847`*^-11", 
      "6.583355310127799`*^-7"},
     {"900", "0", "3.1426488135176224`*^-11", "9.546137660489499`*^-12", 
      "1.62611466208226`*^-7"},
     {"1000", "0", "7.515416435805892`*^-12", "2.2824516558740074`*^-12", 
      "4.020723283104106`*^-8"},
     {"2000", "0", "5.546094976344119`*^-18", "1.683957386883606`*^-18", 
      "3.5212008145247374`*^-14"},
     {"3000", "0", "4.290882061182054`*^-24", "1.302782372024865`*^-24", 
      "3.1853583768196986`*^-20"},
     {"4000", "0", "3.423942493327673`*^-30", "1.0395150964419164`*^-30", 
      "2.961440764556192`*^-26"},
     {"5000", "0", "2.8268531123920907`*^-36", "8.581934397016138`*^-37", 
      "2.815467206879464`*^-32"},
     {"6000", "0", "2.4174252390114257`*^-42", "7.338590772873256`*^-43", 
      "2.72382293163183`*^-38"},
     {"7000", "0", "0", "0", "2.6700942849974133`*^-44"},
     {"8000", "0", "0", "0", "0"},
     {"9000", "0", "0", "0", "0"},
     {"10000", "0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Lung\nretention", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992823698952007`*^9, 3.417835872656955*^9, 
  3.479827704788791*^9, 3.4798283747745247`*^9, 3.4798295700358562`*^9, 
  3.5185350826405582`*^9, 3.643443759163397*^9},
 CellLabel->"Out[121]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[122]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQfUO3zORsUY3dprAt3EerZA4Ym7esVpFYZQ/jv0kO
f6IksQvO/8XstkfE8DSc/2jR3jBB4ytwfpDoot95a27B+b5tKv+Vbj6A8x/v
tdMSVHgC5z8zt2KxWfsczl83K8rkkuZrOD99pyNfdtY7ON+dt9V7wY8PcP7l
2WdSeOZ9gvMPzlPT1LP+gjDf6aNL3u+vcD6z6/yt6+d+h/PDX+yt5U/+Cefz
Mrz/oKLwG87fU8q803r/Hzh/YU/HjYLGf3D+gYaKZZeFGBxg/NPcqTx13xB8
9ou33JmvMcL59q6HdDuXMcH5wlxJ9vM6mOH8x7XFvzdHs8D5T7T5epdoscL5
DVqJXircbHC+5A3VTUvuIPi+1xa5btnPDudv4lu5bt48Djhf5JvCoc48Tjhf
UC+QkSWAC87nEv38qk6JG843NZNbdeUDgv97OePUnRd44Py9J8K05i/khfOl
rFJeC7fwwfklUY/DOsP54fz6W19P5wgLwPlCBmFNd5oRfOXY971n3iD4jZtS
9FviBOH8H0vmWWueQ/Df5gnO9TMTgvMNEhOmWC9H8D9qvXiwQkAYET8TTWYw
VyD4nxRin6q+QPCnt+9rPxEgAuefUb5Zq9+N4DMe+Fw87SiCDwDgXn+F
        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwd03lcjNsfB/CZKc1Iy0zPg0FSqSSRSJt4vtJ2JUsyMYYyuKNUli5STFq0
Korwyy1btEhS6ifKeSqVtCpSkS0lukiJPJP8zv39cV7n9X6d7XNe53v0pLvd
d3BYLNZV3P7t2+cesGjYd3hpiKHixLpfPPqI1KsvWSimQu0qg0UjPDrp5wOO
WOhLTfZuytg4xKOnVf04sUQYTC0psZ6y9QOPfm2SJDITxlGK2xdqgp7y6Iqu
LhtjYSp15XDR9G83ePRCq8jrBsIc6kdoYbLFVh59J97/dk9fDpXyaOhWnIRH
L30tKrtWcp2Se/q49XjyaJfY2U3Gm25QZO0Z86xVPDrPX3Zo0up8amKKHudP
Ox5didTSpiYXUnvzXaW1Qh79zzbPd/rCu1S4odtfTk+59GHLrLEVsXepGcz7
8W+aubTa+J/CQOYutTFBujasnkub5qW6Vb64R8li9V60VHJp/5Gu4m2Xyiit
5mFhSQGXPuhU4OCeQlPi/t3j4pO49Ein9eRTOg+ojEZXb/Y6Ls0oOZWS5nXU
xByT9ndvVWh2h+q3vh111D2T5XHPXqnQvLymOWWpddQ1l1OqDS9U6MkbNp7f
oVxPjQlHPek2Fdoi1y+4+Fk9dUbVb0PNIxXa3+OU9QZ5I7Vea7RkTaEKvcd9
T2dDTzM1/yWnUj9KhX57uUwkWPiEWnvXvz/aXIV2n3hZEZDbSZUuSLeyPD+O
dosy+K3f8ZoyjqWeG3DH0d1lS00Euu8oufCAQ22UMt1rZatsd+M9dX9bimyv
sjKdlyq2aJndT41cyk9ceVyJlpUs09jl+5lq9PCZFa2vRDurH3O9ODJACfQ5
J/jFHLr1fP12tfRBavDDpjIjEYcuTzeaPW/xN2rnkoO+ZaNsutf+q0OAYpjy
NFh4MvEim1ZyvFB0M+0HNS6qxb59FZv27Cs7orntJzWbeF5Sy7BoddaXAQNd
BXXViG16J5dFl+5XKlmMRqm45EtqDTIWfel4TPuesDHKeviV1FyPRdNHg661
arEgXa1l3bTq36huwg41+XcWzNqSoOrs/BtxH3c6K7WxQXKIvdG2ZQxRjhVz
Y69xYFpR/hvYNYYIVSmVHqMEBtZGd/vYY6j7SKCicJMy7ExX1Ey6+gu9m6OR
kGEyDkpvt0VwV/9CR022rjCYoAIfnW0LBT9G0ZR2w4KMFyoQ33Vi96ScUeTW
dtnxNuKCUZurt0wyigo0svPS03lw/P6NdmrSKCK/61bEBoyHwS/XlE52KpBg
3lq28hpVcLC9luF9UYFUJw59lOtPAD16+JF4jwItstTJeTIwAcj3xxbNdVYg
RSY7paRZDaa/2re4X1eB5KOiOb9a1UDytffGTmzO2txyeKYGp2V6Qb0zFIjH
iD7XdKnBrvRQoltHgciVuc5tH9Xg3fCQ9LW2ApkOiJhBZXVwTGpf2S9UIIl1
rpepjTpE+LCilgkUqOyhyOTCJXVYdNnkfR9HgcLHxL+Mr6qD8FvEwn3YLhZe
zQVZ6nCc87NLwVaglguyA9U31eFpReRKPnbfgaCKT2XqYG9FxS/5zSDSMFVs
16kOt6oyZNkKBvmFdcV1aGnAjas1nlXfGDTVdns/EakB95p4kUp9DPrbUqt8
a7QGZIu1nbPfM2j6QvrMzTgNmCfJXbsaW9dU2941SQNaNM/Z/d3LIEOdJ+fC
0zVAVvZ9u00Pg+ZzHJy+3tEA9Upp59G3DHJ+NPNS4ycN0M+/NHt5F4P+EneL
Yj01IfCzfUV8K4Nehrw/Wy3WhJ3ymNDl2C5p/e1KWzThuL/igKKFQdqvh8Ty
7Zow8SlN+GFX7VD2CtyrCfzAuaw1jxk0aa+hbHO8JkijskL1mxhUEi07aI40
IaRVMDjwiEGhncN1fgQfXG/e229SyaC2TU1x8ybyQUtOHvhYwSDTrqw/Bibx
QW6amJeD3f5qU03gVD68mEDUzMFe0FNeEazHh4Pr807OL2fQuy8JJTFmfOjJ
Ld3ggHDecUaZGa58iNcK9Dh1j0Fa80XhLyL48MnWhf3gNoOqT0faHz3GB0qW
3HcKO/hnAccgmg9PA/4Z3obdXaEZsSuOD4NV1uHK2LfX10YwJ/kwK5nc7FzI
IFGI3TFhOh808hYpWm8xKLVaP8bjDh/a0Vg79yaDZm7+klD/Dx8anNr9W7IZ
FLRgv9+pz3h90dyATOxGrmKFeIAPNn+xkg7/O16gwusb4oMPEbpk1v/HdcKV
FHxI606aK8/C+QpWHrAdLwCOfJrLgkwGtXBztmQZCkBp/VmvggwGhRVsN4vc
IgDxdiRTvcigFakplfbeAjgZrpz4/gKut/BqT7ZUANois4YH2FlrjY/Kdwjg
sWtNSih280B/c5CfAPRWsN2+pzNIxyxwn3+wAFozZtr1pTGo9HpYkegM3s/F
1qfrPINGMtIXz24UQHlg9HPuOQZ9ChCkrbLUAmGhqCczCdfbVu/TizO1QGKU
5FIcz6CvJn2vs/gEsKYtGhiMYtBxSZWrkxYBluvF199gGydeLu4mCGgKE+5t
xt7yVXJcZzIBb/08tPOw6//72Or0dAImFx/+6oOd5XAvMdSEANUfZqe7j+H5
WxLtRA4EeLNUsl9GMqguyeKcUhABCT2ucUPhDOJZ+Og9OESAj1f5uW5sh7a0
nMgQAjx8FQWt2PencsvGhRIw1aJA9TZ2/pWON9woAmJqu5z2Y58uks9RO02A
cWHNl59h+LyOh/fJfALWrCkemIA9qLu5x7CPALtqRy33UHy/a727H34gYHlA
5nNH7FmmexjffgJyOrLzbLAlVhGa+Z8JOPMqaq8edrVbto3tMAHbt4p9v8oZ
dD54OGEVh4QPAwZGp7AdniRYHtQmYbJabmHXEfw/N04un6JDgqiQn9uCfejV
RdfSGSTYrKBv1GDnfSz0Zs8kobThW/0t7Cnszrj42STEgTQ4CvvzXKNXFyxJ
yJSUJZpjn42+H/1wDQmPDB1jEg/jepTsRufdSVCyFssjsMXmuj8CPEgISY4N
DcLWeR7258QNJBT9MLgixc6Y5+go9SLBw6MxwAq74GkdZ9SfhPHLO4juEPx+
MzuOmMWTEH/dKtAeO28ktoiTQMKxkF2V1tgnGmw/PU0kofWBjo4ZtvvBvyWH
k3Ge6V8Gp2F3PPJaXPsfEu67X53yPZhBvXt7R6RZJKzeWSfKxX7odHa+ZQ4J
W4LCVl7BzpnmsnN8Lgljy6QrU7H9q7Kf3bxJgq5Zom8M9jehf/FoMQld2cMz
dmC3fZr+uekOCflvZH9KsP9b0Wh45S4JjcXtxeuwg/3mp/xxn4SWtgv77bEl
y97Ua9MkVPd87LbBXjopWXmgHOeZoiMxx9btt7errCRhRu3Cl8bYbHoo8EwV
CZedjXx1sf8HLrccLg==
        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwd1Hk4lcsfAPDjILKe47yKkmRJZKuEpGYSUbS5OkokpQUpsoTshGxFShGy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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -7.667161674869663}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-7.667161674869663, -1.0999291136880132`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, -7.4}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Lungs\"", 11, StripOnInput -> False], 
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.39928238242276*^9, 3.41783588526633*^9, 
  3.4798277137423744`*^9, 3.479828383117794*^9, 3.479829578160544*^9, 
  3.518535089281311*^9, 3.6434437609446635`*^9},
 CellLabel->"Out[122]="]
}, Open  ]],

Cell["Type S", "Text"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"fn1", " ", "=", " ", "0.01"}], ";", 
   RowBox[{"class", " ", "=", " ", "M"}], ";"}]}]], "Input",
 CellLabel->"In[123]:="],

Cell["These  values are the same that Table A.4.12 of ICRP 78 ", "Commentary"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Barium", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["The model", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompartNumbers", "[", "barium", "]"}]], "Input",
 CellLabel->"In[124]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "\<\"Plasma\"\>"},
    {"2", "\<\"ST0\"\>"},
    {"3", "\<\"ST1\"\>"},
    {"4", "\<\"ST2\"\>"},
    {"5", "\<\"Cortical Surface\"\>"},
    {"6", "\<\"Cortical Volume Exch\"\>"},
    {"7", "\<\"Cortical Volume Nonexch\"\>"},
    {"8", "\<\"Trabecular Surface\"\>"},
    {"9", "\<\"Trabecular Volume Exch\"\>"},
    {"10", "\<\"Trabecular Volume Nonexch\"\>"},
    {"11", "\<\"Bladder\"\>"},
    {"12", "\<\"Urine\"\>"},
    {"13", "\<\"ULI\"\>"},
    {"14", "\<\"LLI\"\>"},
    {"15", "\<\"FEC\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.39928238253224*^9, 3.41783588536008*^9, 
  3.479827713883007*^9, 3.479828383289659*^9, 3.4798295783167877`*^9, 
  3.5185350893125615`*^9, 3.643443760991541*^9},
 CellLabel->"Out[124]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"TransferRates", "[", "barium", "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<From\>\"", ",", " ", "\"\<to\>\"", ",", 
        "\"\<Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\>\""}], "}"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[125]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"From\"\>",
       HoldForm], 
      TagBox["\<\"to\"\>",
       HoldForm], 
      TagBox["\<\"Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\"\>",
       HoldForm]},
     {"1", "2", "23.`"},
     {"1", "3", "7.`"},
     {"1", "4", "0.14`"},
     {"2", "1", "7.67`"},
     {"3", "1", "0.693`"},
     {"4", "1", "0.00038`"},
     {"1", "5", "7.78`"},
     {"5", "1", "0.578`"},
     {"5", "6", "0.116`"},
     {"6", "5", "0.0097`"},
     {"6", "7", "0.0042`"},
     {"7", "1", "0.0000821`"},
     {"1", "8", "9.72`"},
     {"8", "1", "0.578`"},
     {"8", "9", "0.116`"},
     {"9", "8", "0.0097`"},
     {"9", "10", "0.0042`"},
     {"10", "1", "0.000493`"},
     {"1", "11", "2.24`"},
     {"1", "13", "20.16`"},
     {"13", "14", 
      SubscriptBox["k", "ULI"]},
     {"14", "15", 
      SubscriptBox["k", "LLI"]},
     {"11", "12", "12"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"From", "to", "Tranfer Rates(\!\(days\^\(-1\)\))"}}]]]], "Output",
 CellChangeTimes->{3.3992823825635195`*^9, 3.417835885375705*^9, 
  3.479827713929884*^9, 3.479828383336531*^9, 3.479829578379286*^9, 
  3.518535089359438*^9, 3.6434437610071635`*^9},
 CellLabel->"Out[125]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "element", ",", " ", "lambda", ",", " ", "fn1", ",", " ", "amad", ",", " ", 
   "class"}], "]"}]], "Input",
 CellLabel->"In[126]:="],

Cell["For f1 = 0.1,   AMAD 5, type F", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"element", "=", " ", "barium"}], ";", 
   RowBox[{"lambda", " ", "=", " ", "0"}], ";", " ", 
   RowBox[{"fn1", " ", "=", " ", "0.1"}], ";", " ", 
   RowBox[{"amad", "=", " ", 
    RowBox[{"AMADAdultW", "[", "5", "]"}]}], ";", 
   RowBox[{"class", " ", "=", " ", "F"}], ";"}], " "}]], "Input",
 CellLabel->"In[127]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[128]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.057020030189182766`", "0.15916973240180543`", 
      "0.7838102374090168`"},
     {"2", "0.009583091846547646`", "0.2104342452986817`", 
      "0.563792900263788`"},
     {"3", "0.006550545658827782`", "0.1439743231970011`", 
      "0.4132680314079596`"},
     {"4", "0.004562461769707756`", "0.0920656921349231`", 
      "0.316639877503329`"},
     {"5", "0.00318554943808122`", "0.0599123201222268`", 
      "0.2535420079430211`"},
     {"6", "0.0022313633690980786`", "0.04002722009792231`", 
      "0.21128342447600074`"},
     {"7", "0.0015700383441688073`", "0.027292668714901575`", 
      "0.18242071741693036`"},
     {"8", "0.0011116089205092782`", "0.018879023287007635`", 
      "0.16243008520941332`"},
     {"9", "0.0007937476034120435`", "0.013203437818417152`", 
      "0.14843289978758412`"},
     {"10", "0.000573274215577551`", "0.009327075137227775`", 
      "0.13853255043477866`"},
     {"20", "0.000082468677266051`", "0.0008574676869548548`", 
      "0.11112216493360828`"},
     {"30", "0.00006287167419593426`", "0.0005777811223486307`", 
      "0.10394001151720597`"},
     {"40", "0.00005603413194953284`", "0.0005126515005564741`", 
      "0.09794983836402733`"},
     {"50", "0.000050197762662594625`", "0.00045917499840766873`", 
      "0.0925950740230699`"},
     {"60", "0.000044990866077046845`", "0.00041152263968684266`", 
      "0.08779699894833928`"},
     {"70", "0.000040339486476434136`", "0.0003689557810500621`", 
      "0.08349595671016599`"},
     {"80", "0.00003618413806297932`", "0.0003309284554018632`", 
      "0.07963893204662138`"},
     {"90", "0.000032471854218851966`", "0.0002969558915378867`", 
      "0.07617857717539271`"},
     {"100", "0.000029155328238982328`", "0.0002666051547971504`", 
      "0.07307259989506257`"},
     {"180", "0.000012636032922993222`", "0.00011543362805903346`", 
      "0.057196759164857926`"},
     {"200", "0.000010355879457171237`", "0.00009456821322655767`", 
      "0.05488703478153237`"},
     {"300", "4.240237385791552`*^-6", "0.000038608441382835534`", 
      "0.04809638807493891`"},
     {"400", "2.2268558940259295`*^-6", "0.000020190686216538245`", 
      "0.04502672181312767`"},
     {"500", "1.5413137033765123`*^-6", "0.000013924476062486535`", 
      "0.043195463540915385`"},
     {"600", "1.2865895592491586`*^-6", "0.000011600616680054743`", 
      "0.041798442357049666`"},
     {"700", "1.172613812711401`*^-6", "0.00001056451214004328`", 
      "0.04057417263578711`"},
     {"800", "1.1055425665458876`*^-6", "9.957352101630512`*^-6", 
      "0.03943668285466165`"},
     {"900", "1.0549731806345011`*^-6", "9.500916727189779`*^-6", 
      "0.038356808990931655`"},
     {"1000", "1.0110159777859153`*^-6", "9.104712669932846`*^-6", 
      "0.03732381464801949`"},
     {"2000", "6.815243981908754`*^-7", "6.137171021682736`*^-6", 
      "0.02898526261457028`"},
     {"3000", "4.711845304756872`*^-7", "4.242880523516734`*^-6", 
      "0.023297128047453996`"},
     {"4000", "3.353151518392661`*^-7", "3.0192781385746104`*^-6", 
      "0.019312238375401455`"},
     {"5000", "2.4655670480158536`*^-7", "2.2199590046269313`*^-6", 
      "0.01643303497876532`"},
     {"6000", "1.8771739100013722`*^-7", "1.6900912454750894`*^-6", 
      "0.014280844941363353`"},
     {"7000", "1.4797381877587265`*^-7", "1.3321980923131083`*^-6", 
      "0.012614653418781105`"},
     {"8000", "1.2049667304876374`*^-7", "1.0847741312696585`*^-6", 
      "0.01128019730688485`"},
     {"9000", "1.0096531273041422`*^-7", "9.089074550130277`*^-7", 
      "0.010178016958016435`"},
     {"10000", "8.663739174425561`*^-8", "7.799004890524791`*^-7", 
      "0.009243374569572835`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282382923237*^9, 3.41783588570383*^9, 
  3.479827714351781*^9, 3.47982838378963*^9, 3.4798295788167686`*^9, 
  3.5185350896406927`*^9, 3.6434437611165404`*^9},
 CellLabel->"Out[128]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[129]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV1Hk81NsbB/CZOWNmrFkGUymyVChxuaLknFRaKJpbFEqESGS5liIpKkKL
UFFUhMbShizJI9PCkMoWTZeypJS0WVL8vr8/zuu83v+c57ye83nOPPf9fE8G
jUa7Q63/768Wh5o0BUVadiYadyZzJOGQu+tgMs8Jr+0qHeYzJeHshJDhxNuL
uT/q3bg0SZj9aOz0Ct5B3LSs4HjWGAd69M46LOGdxL6yLNXPAxx4+OaN+UJe
Ot43xXF7/pgDjcdv2QgqMvCm/N0pIw850LEkZsci58v4jDpz3swaDoySFMKz
u4KdRzr8Y+5xQOqcuYdacjaO8TBF1fkcMF4aW6DNE+D9tyGtKpED5Ql+Jf2D
AhxjbGviGs8Byx6H6tyKAqyZMhYtdZwD6+J1mxc6F+EPvB1NYYc5UOy354CK
3S2c29UiEARxoK5G5vKs5Lt4SGxI3+HEgU+7Hfs0eZVYapZavqMBByJN86c2
xFfiTpp26Cl9DshITvCCf1XipKufNEULObCoOH1jnbgKRzYU12zV4oDf+Juy
3VersY56jqCIx4Ew6zur+amA1QeqEh2YHBjvMlM9N1eIt3imKM3oZgNZ7aa9
wFGIU92pY8RsiCuKN6o6LcTTjfM0i7vYwIvusumlPcJlbdfKndvZYKYTGW3c
+wgrYNv+niY2HNhf86El7wl+otVXF1fNhl/I+j7XSIQttVl0ZhYb6J1SPwY9
RbhQ8UmU/WU2cIqb9avTRTi3I0s+K4MNqtu2Z3gyG7EN64qD1QU2mBTuO1jW
0YhNx2Wqrpxlg9+Wc2bbop7h2ESf3HuxbAjgB3Q19T/Hb823qy7cx4Z316od
FIxb8Sm9By4zMRsKTTY3jdq24jfnL0g3rGBD6OO+VWKvVtxdr1YQYcEGyY/S
Rnnprdg3LOr2W3M2GBo5Sa9gtOGEK/3J5SZsiKoZrfF+0Ya1m+UjTuuxYZZ4
iS7s78CHiyT6X6iwga98bdK/sAvnudSCxVcWbDyuPa3Z2YPpBi3Lw6+zoLfa
Uk9Bow/P4fxoueXOgoGly5gWRe/xPZXPZwLUWFCc7mTyUncI1xYLtf57JQF7
KlbK+e4dxvrRv8J5GRKwVvaYzZXxEdxVcOmpeLsEtGQ0eshkfsPfQUasqi4B
tZnzdQ2W/8BpO4dujb1nwoDV19X+kz9xQVBF/cGbTEBrskpvXh7DsuZpc52j
mOA4WH1oxu4JPDFlWRC2kQmytC8j2hqT+PwRNU9LTSbcD0EVy2t+44DCD17e
UwiuJsa9Cjgyhd9mTZUcEyP418DpDj1uCgfdu05ToLzuuX5i8qkp7D0ulXLp
NYJhpWZckjGFwyu+ny3pQmCRoZw3VjqFXQMDP7x/heDVjWshUR+nsFq1Dc2l
DYH8k/uKif9MY2U1ozMHniGA6PDcFkUayXio33uiFsGnv+Tt3VVoxHGyK0mN
Mq8/b2JkJo0Yyp2Ivw0IAtd32MrNoxFeUFywuAaBpqLp93VLaITmKSlv+gBB
TPZ3/MCGRtYvxtvHKxFYP/bvzI+lEeuth1PLSxCIpD1lokZppJuzLFjzBoKe
d/x5vydoxMczy6oxH8GPCmJ68A+NxOQtcQqlPNdbbVcok04SC3e5ifIQBAlb
7vor0smf5KHG8FwEsw5ZObsa0EmVgs90TzYCn2F1AfGiEznzefSBTATsF11r
UTudfE5yP1aVSvXDP8h1TSedzLjAl4ugnC8jFXZCTCfmEzObl1HesM48V7qX
Tppw5VhlCoJTNeeZ3BE6eTwt8676HALl4i212lIM4lA+m/7sLAKthGfLrC0Z
pL9jKlXlFHX/hV78uJUM0nFguluchED4+I9Pw2oGMbSbsTObshdj8cVNNgyS
+e2/n4aUBQcSxhy2MQhRE53ZlIjAyHtdyZ4gBlkVLb3t3EkEeM3DxfG5DNLL
EG6wOoGAL+QcVRAwyMrtr49JUfZaZdd+sYhBVCvcJ14eR5C4UhwlKGGQAB9e
vAflrhWjzaKHDPLmaYT1yWNUnkz1guS6GeR68gulnhgENxYkl51TRcR+cq3o
bjSC+7mvpNRmI8IYcqg9Svm5jrprzlxEAl0CP26mPKpVyC7VQaRAYWbbyGEE
qzUeb2s3RkTvy262EeX/eL9+8ewRERbYVlQeQqAk5Y4z4xDZPD5b7dtBBO/s
+GkfExBp7Mkarad8J9Xqs+lpRPiRz8evUrafp5XRnIrIjB25wXzKSWZ9o7Rs
RJrj9HDpAeo993gV765GxEP4QPZoOILJur1zdL8hkix0O7k0FEGDpPO/IT+p
eojO5VJOt7MR1Y4jImtbCyMhCMxe6x9wmkak+4tSjIByyLdPrQkyTPLhiVSe
OuUvGvsTh+czSQQrzVb+XwS9h4In7zozSe+fLgWpIASXBiuqv+xkkrW7vjkM
BSLY8g8tWt+dSZr1IyoaKQsXJjGzvZnk/U+n9tOUc1pyZZNDmGRTvcBXlbKH
bpd6wGkmUV7g9l4/AEFfK1m9qI5JLo1eW+7jT1lfLilHT4IMXFJcYeBL9TMM
Jc43kCAvj0+JlCh31o2fzDeSID0hcv9O7EXwzLk3rtBMgqx98EfuEeXyhPLY
EmsJsqa7zXcH5YQh90ihuwSJ2HU2K9kHwV8F93z70iWIn39/n6w3gmg9tw3a
0iyi+dXiHfZEYLqCZrtXjkXqm8TT+pQ/22VtvKXAIn5HI/R5lJ1C3thb8Fgk
RHlD4YgHAmPY7rhFh0Xkf5DN1ygPbOV7xGIW2awXq8ChbHtkVVRfMIscq151
T+yOYOYrnTs5YhaRKTPG13ch2Nh+bU1JDZt4tS68beZC5UHuRnFmJoeoFzZc
mL0NAXdU42G8vyQRVR3vs9qCQMFgM51pL0VkOYGSw3YIpJS/f4zSlCauA7uu
5tkg+Nt0rqB1RJq0LR2+b7KWykcePbXiuQxJupl0X8EKQfVTB72sq7Lkbzl3
q0kL6v9Y5jGkFCtHlqq9t5+/lJoPp16HeMcZpL057IyvEYLDXT9F+5TkyWRo
kc8pfQSKhg5HxTHyRLfww/zv2tT87/iS1PhJnggHngymzUVw5I7HktidCmTj
y+068aoIxnMyl+s+o0wTzj4qT/XTX+HyJlNFUpISFfJJEoGh266U5XmK5Ha7
gbiFgeCr3mBPvrwSMf37nNvm3wwQnTW5gMKVSGlZe86cUQZ809jRrzOoRBIG
GoWCLww4f+LBiaf2XLKiytF/8gMDwl3212TwuaSifVb3O8pORhpj/lu4pCw9
0rGB8tzXR7yUt3GJW62B60XKOQZr1ri7comNUnPDUsp32kSM335cssf2t0ro
IAMatToPLUngkgvKg1fHBxhQPB5fykjiEq3bi2a8pXy6adnntlNcsrM8I7ae
Mj/skktkMpf8pSUZl065s8F1ef1FLml8f+arBeWBwIFx93wukeqv5sf0M+Cp
9XlDUwGXDJdFr95HWTB7nbdkIZd0vSiw3ErZ79GNjps3uWTrmfW2Cyj/4PmV
/S7jEoaA0yTqY0D75znDzeVcMuIZzCilfO/hM53sSi4RLd5NMikf3GeYuv4B
l/S+6G4LoOyy8m2jGlD104IXO1G2VElmjtRyyXqz9KRVlDWGrCzq6rjEZI7j
6CLKdPgenPaISySzi/aoUP4fy2ITkA==
        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwVznk81Ikfx/G5yZVjqllRVEqSqJaofD8J2VJJoijHUEllJZXaaCstRdp0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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -3.4256703786247225`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-3.4256703786247225`, 0.13213807075169182`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282385097183*^9, 3.417835888063205*^9, 
  3.4798277156955996`*^9, 3.4798283854457846`*^9, 3.479829580222965*^9, 
  3.5185350914532275`*^9, 3.643443761335292*^9},
 CellLabel->"Out[129]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[130]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.005408853259538032`", "0.27241925900425634`", 
      "0.7221718877362063`"},
     {"2", "0.0010921947004813915`", "0.3700065729490992`", 
      "0.3510731200866256`"},
     {"3", "0.0007037997609010589`", "0.19033364963412347`", 
      "0.1600356706916012`"},
     {"4", "0.0004897231317351389`", "0.08200738782185392`", 
      "0.07753855973801219`"},
     {"5", "0.00034175098310286695`", "0.034251772836965164`", 
      "0.04294503591794414`"},
     {"6", "0.00023921162987921934`", "0.014742971666129912`", 
      "0.02796285262193502`"},
     {"7", "0.00016814586757271893`", "0.006806073454928802`", 
      "0.02098863329943349`"},
     {"8", "0.00011888512985226717`", "0.0034561846409441356`", 
      "0.017413563528637082`"},
     {"9", "0.00008473110802572053`", "0.0019417000969774167`", 
      "0.015387132323633942`"},
     {"10", "0.00006104324857032816`", "0.001191584401031771`", 
      "0.014134504674031835`"},
     {"20", "8.355922890896338`*^-6", "0.00008752273149113463`", 
      "0.011129649505590629`"},
     {"30", "6.302815040957381`*^-6", "0.000057940902118610096`", 
      "0.010406220942647962`"},
     {"40", "5.615308569436326`*^-6", "0.000051374509399454774`", 
      "0.009805842448749377`"},
     {"50", "5.0303496653461`*^-6", "0.0000460142746786258`", 
      "0.009269233881151927`"},
     {"60", "4.508530881298521`*^-6", "0.00004123869308475005`", 
      "0.008788417138739082`"},
     {"70", "4.042385672566691`*^-6", "0.000036972788942166504`", 
      "0.00835741137548144`"},
     {"80", "3.6259511623644132`*^-6", "0.000033161822936968004`", 
      "0.00797090351325035`"},
     {"90", "3.253919169106216`*^-6", "0.000029757212224065625`", 
      "0.007624148507017974`"},
     {"100", "2.9215487643959254`*^-6", "0.00002671556945328668`", 
      "0.007312907967425505`"},
     {"180", "1.266047564462444`*^-6", "0.000011565730238870947`", 
      "0.005722122148583429`"},
     {"200", "1.0375402884196458`*^-6", "9.474686812149455`*^-6", 
      "0.005490707784841354`"},
     {"300", "4.2466202173989907`*^-7", "3.866683908439368`*^-6", 
      "0.00481045787111864`"},
     {"400", "2.2289873157464724`*^-7", "2.0210177265585563`*^-6", 
      "0.0045031011155863`"},
     {"500", "1.542067660816179`*^-7", "1.3931361726167261`*^-6", 
      "0.00431984252188438`"},
     {"600", "1.2868953129985174`*^-7", "1.1603401181160128`*^-6", 
      "0.004180091135335205`"},
     {"700", "1.1727719161254424`*^-7", "1.05659460041636`*^-6", 
      "0.00405764217095094`"},
     {"800", "1.1056503110198207`*^-7", "9.958325676512683`*^-7", 
      "0.003943880287438402`"},
     {"900", "1.055062138885423`*^-7", "9.501718928588837`*^-7", 
      "0.003835883189943274`"},
     {"1000", "1.0110964707534583`*^-7", "9.105437926305165`*^-7", 
      "0.0037325753221352483`"},
     {"2000", "6.815743019842127`*^-8", "6.137620450542315`*^-7", 
      "0.002898656936097833`"},
     {"3000", "4.7121662575746884`*^-8", "4.2431695669543565`*^-7", 
      "0.0023298031467128403`"},
     {"4000", "3.3533599861322594`*^-8", "3.019465877169246`*^-7", 
      "0.0019312881268030136`"},
     {"5000", "2.4657042182920762`*^-8", "2.2200825325964686`*^-7", 
      "0.0016433507680849615`"},
     {"6000", "1.8772656890900415`*^-8", "1.690173894353282`*^-7", 
      "0.0014281204823412906`"},
     {"7000", "1.4798009040307893`*^-8", "1.3322545676136728`*^-7", 
      "0.0012614937097041958`"},
     {"8000", "1.205010700732834`*^-8", "1.0848137243536782`*^-7", 
      "0.0011280428302164`"},
     {"9000", "1.0096848891761917`*^-8", "9.08936053716728`*^-8", 
      "0.0010178210506171616`"},
     {"10000", "8.663976287529777`*^-9", "7.799218378849032`*^-8", 
      "0.0009243540647955537`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992823865673337`*^9, 3.41783588979758*^9, 
  3.4798277172581797`*^9, 3.479828387055067*^9, 3.479829581754156*^9, 
  3.518535092562624*^9, 3.6434437616946707`*^9},
 CellLabel->"Out[130]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[131]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV03k01VsbB/AzIUNufsNxoitjGTJUOhWxt8IVSclFGpQpDSiFhpNUSkJd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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwVlmc8Ffwfhs9yCg10lMpqKCRUoqR+P0IaZh56jJSErLIqq1JKZRzUOcfe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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -6.274198193297884}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-6.274198193297884, 0.5537197417271191}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992823903365498`*^9, 3.41783589454758*^9, 
  3.479827719930191*^9, 3.4798283899767737`*^9, 3.479829584316558*^9, 
  3.518535095218925*^9, 3.6434437622571745`*^9},
 CellLabel->"Out[131]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[132]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Lung\\nretention\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "2.393726432015305`*^-45", "0.01707939710511045`", 
      "0.09831631602921126`", "0.4900794164386708`"},
     {"2", "0", "0.002919589997206663`", "0.13335359669063118`", 
      "0.2750436164759696`"},
     {"3", "0", "0.001985854524321068`", "0.0787672424122357`", 
      "0.1653153733826537`"},
     {"4", "0", "0.0013830299326252132`", "0.04240737164641409`", 
      "0.11086561122760505`"},
     {"5", "0", "0.0009655910440964435`", "0.023756099926106763`", 
      "0.08222256064545458`"},
     {"6", "0", "0.000676311193421866`", "0.014234535335157152`", 
      "0.06586912653420016`"},
     {"7", "0", "0.00047581837680539963`", "0.009052826445149119`", 
      "0.05580978339849012`"},
     {"8", "0", "0.00033683765289121287`", "0.006010161358240285`", 
      "0.049267551388263595`"},
     {"9", "0", "0.00024047311649768102`", "0.004107558677623212`", 
      "0.04484769738753739`"},
     {"10", "0", "0.0001736337791836554`", "0.0028652774321512517`", 
      "0.0417823642629728`"},
     {"20", "0", "0.00002485308818877532`", "0.000258597816814532`", 
      "0.0334500887470968`"},
     {"30", "0", "0.00001892741424590295`", "0.00017394564134108267`", 
      "0.03128690585575893`"},
     {"40", "0", "0.000016868380365524845`", "0.00015432753114415568`", 
      "0.029483612196702126`"},
     {"50", "0", "0.000015111389228118863`", "0.0001382287297895697`", 
      "0.027871628178170252`"},
     {"60", "0", "0.000013543910468284074`", "0.00012388350943993293`", 
      "0.026427229961057924`"},
     {"70", "0", "0.000012143664382513464`", "0.00011106923002412658`", 
      "0.02513245796910181`"},
     {"80", "0", "0.000010892743016886492`", "0.00009962152705416186`", 
      "0.023971352526337947`"},
     {"90", "0", "9.775201345554874`*^-6", "0.00008939446533099901`", 
      "0.022929660105512135`"},
     {"100", "0", "8.776798207108753`*^-6", "0.00008025771465134182`", 
      "0.021994649106590273`"},
     {"180", "0", "3.8038497786802884`*^-6", "0.00003474922296730146`", 
      "0.017215474505054784`"},
     {"200", "0", "3.1174354913174503`*^-6", "0.000028467926857329504`", 
      "0.01652017509692178`"},
     {"300", "0", "1.2763925504697023`*^-6", "0.000011621887656552282`", 
      "0.014476011785300332`"},
     {"400", "0", "6.702896965422867`*^-7", "6.077456565179926`*^-6", 
      "0.013552005055090847`"},
     {"500", "0", "4.6391804914822955`*^-7", "4.191112543631276`*^-6", 
      "0.013000804039233801`"},
     {"600", "0", "3.8723927240280273`*^-7", "3.4915683829947475`*^-6", 
      "0.012580322116622742`"},
     {"700", "0", "3.529311083450611`*^-7", "3.1796873530502007`*^-6", 
      "0.01221184206866631`"},
     {"800", "0", "3.327428943242054`*^-7", "2.996934141144547`*^-6", 
      "0.011869483252913988`"},
     {"900", "0", "3.1752225725730117`*^-7", "2.8595537915031277`*^-6", 
      "0.011544466291243043`"},
     {"1000", "0", "3.0429202475313645`*^-7", "2.7403043328533966`*^-6", 
      "0.01123355923303787`"},
     {"2000", "0", "2.051226803458919`*^-7", "1.8471429253409666`*^-6", 
      "0.008723852197983085`"},
     {"3000", "0", "1.4181529669555007`*^-7", "1.2770057628347029`*^-6", 
      "0.007011858991566813`"},
     {"4000", "0", "1.0092179719841613`*^-7", "9.087301143309578`*^-7", 
      "0.005812502644437452`"},
     {"5000", "0", "7.420759082503621`*^-8", "6.681538421678471`*^-7", 
      "0.004945931923560208`"},
     {"6000", "0", "5.64983459406458`*^-8", "5.08676151116192`*^-7", 
      "0.004298175105247978`"},
     {"7000", "0", "4.453647340393711`*^-8", "4.0095880103835704`*^-7", 
      "0.0037966923444324183`"},
     {"8000", "0", "3.626650831945258`*^-8", "3.2649009381420166`*^-7", 
      "0.0033950540515120162`"},
     {"9000", "0", "3.038803834856229`*^-8", "2.735584516081607`*^-7", 
      "0.003063325201400341`"},
     {"10000", "0", "2.6075681248895373`*^-8", "2.3473048022014734`*^-7", 
      "0.0027820212353714528`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Lung\nretention", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992823953569574`*^9, 3.417835900563205*^9, 
  3.479827725602357*^9, 3.479828395288968*^9, 3.4798295895194826`*^9, 
  3.5185350992033763`*^9, 3.643443763475936*^9},
 CellLabel->"Out[132]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[133]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQfUO3zORsUY2dxVOZpoVVMgeMzVtWq0issofx3ySH
P1GS2AXn/2J22yNieBrOf7Rob5ig8RU4P0h00e+8NbfgfN82lf9KNx/A+Y/3
2mkJKjyB85+ZW7HYrH0O56+bFWVySfM1nJ++05EvO+sdnO/O2+q94McHOP/y
7DMpPPM+wfkH56lp6ll/QZjv9NEl7/dXOJ/Zdf7W9XO/w/nhL/bW8if/hPN5
Gd5/UFH4DefvKWXeab3/D5y/sKfjRkHjPzj/QEPFsstCDA4w/mnuVJ66bwg+
+8Vb7szXGOF8e9dDup3LmOB8Ya4k+3kdzHD+49ri35ujWeD8J9p8vUu0WOH8
Bq1ELxVuNjhf8obqpiV3EHzfa4tct+xnh/M38a1cN28eB5wv8k3hUGceJ5wv
qBfIyBLABedziX5+VafEDeebmsmtuvIBwf+9nHHqzgs8cP7eE2Fa8xfywvlS
VimvhVv44PySqMdhneH8cH79ra+nc4QF4Hwhg7CmO80IvnLs+94zbxD8xk0p
+i1xgnD+jyXzrDXPIfhv8wTn+pkJwfkGiQlTrJcj+B+1XjxYISCMiJ+JJjOY
KxD8TwqxT1VfIPjT2/e1nwgQgfPPKN+s1e9G8BkPfC6edhTBBwD83nXF
        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV1nk0ldsbB/AzF973eI9z6CSZlaMypFwJe8uQQlyJUMmQpNBApYt0NZlL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        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV1nk0lesXB/AzK5XESUdJpDJkargy5XkoSkWSkJQMV3JzkiENEl3FNVUk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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -7.748551403515918}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-7.748551403515918, -0.20301532243674025`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, -7.4}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Lungs\"", 11, StripOnInput -> False], 
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282404959856*^9, 3.417835910938205*^9, 
  3.4798277334152565`*^9, 3.4798284019292107`*^9, 3.4798295965984297`*^9, 
  3.518535105437871*^9, 3.643443765194701*^9},
 CellLabel->"Out[133]="]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Uranium", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["The model", "SubsubsectionIcon"],

Cell["The compartments has been numbered as follow: ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompartNumbers", "[", "uranium", "]"}]], "Input",
 CellLabel->"In[134]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "\<\"Plasma\"\>"},
    {"2", "\<\"RBC\"\>"},
    {"3", "\<\"ST0\"\>"},
    {"4", "\<\"ST1\"\>"},
    {"5", "\<\"ST2\"\>"},
    {"6", "\<\"Liver1\"\>"},
    {"7", "\<\"Liver2\"\>"},
    {"8", "\<\"UrinaryPath\"\>"},
    {"9", "\<\"OtherKidney\"\>"},
    {"10", "\<\"TrabecularSurface\"\>"},
    {"11", "\<\"ExchTrabVol\"\>"},
    {"12", "\<\"NonExchTrabVol\"\>"},
    {"13", "\<\"CorticalSurf\"\>"},
    {"14", "\<\"CorticalVolExch\"\>"},
    {"15", "\<\"CorticalVolNonExch\"\>"},
    {"16", "\<\"Bladder\"\>"},
    {"17", "\<\"Urine\"\>"},
    {"18", "\<\"ULI\"\>"},
    {"19", "\<\"LLI\"\>"},
    {"20", "\<\"FEC\"\>"},
    {"21", "\<\"SI\"\>"},
    {"22", "\<\"ST\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.3992824050536957`*^9, 3.417835911031955*^9, 
  3.479827733524637*^9, 3.4798284021323233`*^9, 3.4798292710121527`*^9, 
  3.479829596707819*^9, 3.518535105469122*^9, 3.643443765225952*^9},
 CellLabel->"Out[134]//TableForm="]
}, Open  ]],

Cell["\<\
 Transfer rates are taken from Table A.13.1. (ICRP 78) (For GI compartments \
are applied the transfer rate included in Options[qGI]).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"TransferRatesE", "[", "uranium", "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<From\>\"", ",", " ", "\"\<to\>\"", ",", 
        "\"\<Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\>\""}], "}"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[135]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"From\"\>",
       HoldForm], 
      TagBox["\<\"to\"\>",
       HoldForm], 
      TagBox["\<\"Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\"\>",
       HoldForm]},
     {"1", "3", "10.5`"},
     {"1", "2", "0.245`"},
     {"1", "16", "15.43`"},
     {"1", "8", "2.94`"},
     {"1", "9", "0.0122`"},
     {"1", "18", "0.122`"},
     {"1", "6", "0.367`"},
     {"1", "4", "1.63`"},
     {"1", "5", "0.0735`"},
     {"1", "10", "2.04`"},
     {"1", "13", "1.63`"},
     {"3", "1", "8.32`"},
     {"2", "1", "0.347`"},
     {"8", "16", "0.099`"},
     {"9", "1", "0.00038`"},
     {"6", "1", "0.092`"},
     {"6", "7", "0.00693`"},
     {"4", "1", "0.0347`"},
     {"5", "1", "0.000019`"},
     {"13", "1", "0.0693`"},
     {"13", "14", "0.0693`"},
     {"7", "1", "0.00019`"},
     {"11", "12", "0.00578`"},
     {"12", "1", "0.000493`"},
     {"15", "1", "0.0000821`"},
     {"14", "13", "0.0173`"},
     {"14", "15", "0.00578`"},
     {"10", "1", "0.0693`"},
     {"11", "10", "0.0173`"},
     {"10", "11", "0.0693`"},
     {"16", "17", "12"},
     {"18", "19", 
      SubscriptBox["k", "ULI"]},
     {"19", "20", 
      SubscriptBox["k", "LLI"]},
     {"21", "1", 
      RowBox[{
       SubscriptBox["f", "B"], " ", 
       SubscriptBox["k", "SI"]}]},
     {"21", "18", 
      SubscriptBox["k", "SI"]},
     {"22", "21", 
      SubscriptBox["k", "ST"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"From", "to", "Tranfer Rates(\!\(days\^\(-1\)\))"}}]]]], "Output",
 CellChangeTimes->{3.3992824050849752`*^9, 3.417835911031955*^9, 
  3.479827733571515*^9, 3.47982840219482*^9, 3.4798292710746512`*^9, 
  3.47982959686409*^9, 3.518535105515998*^9, 3.643443765257205*^9},
 CellLabel->"Out[135]//TableForm="]
}, Open  ]],

Cell["\<\
 Because the decay constant is to small for major uranium nuclides (i.e: \
U-238, U-235,U-234)  we can assume \[Lambda]=0.  \
\>", "Commentary"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "element", ",", " ", "lambda", ",", " ", "fn1", ",", " ", "amad", ",", " ", 
   "class"}], "]"}]], "Input",
 CellLabel->"In[136]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"element", "=", " ", "uranium"}], ";", 
   RowBox[{"lambda", " ", "=", " ", "0"}], ";"}], " "}]], "Input",
 CellLabel->"In[137]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[138]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.6449932072755642`", "0.0016844948036295023`", 
      "0.3533222979208092`"},
     {"2", "0.022107830794588057`", "0.00187219346975929`", 
      "0.3293422736564618`"},
     {"3", "0.017996533842386198`", "0.0009470271556020265`", 
      "0.3103987126584738`"},
     {"4", "0.016268086997306808`", "0.0004240733478193589`", 
      "0.29370655231334764`"},
     {"5", "0.014761998386549402`", "0.00019775277818297058`", 
      "0.2787468011486152`"},
     {"6", "0.013433725547812414`", "0.00010579415738307943`", 
      "0.26520728144341993`"},
     {"7", "0.012255871179689515`", "0.00006791400322389671`", 
      "0.2528834962605065`"},
     {"8", "0.011206628512378108`", "0.000051081369939175994`", 
      "0.24162578637818924`"},
     {"9", "0.010268370221809847`", "0.00004249542890461975`", 
      "0.23131492072747475`"},
     {"10", "0.00942665324402081`", "0.00003728411486565741`", 
      "0.22185098336858836`"},
     {"20", "0.004388986642765297`", "0.000017644834662502345`", 
      "0.15904401685113112`"},
     {"30", "0.002388221946108021`", "0.000011118757120538855`", 
      "0.12743165997110784`"},
     {"40", "0.001500297786784635`", "8.035795094881197`*^-6", 
      "0.10888315154485954`"},
     {"50", "0.0010530171118236925`", "6.201380050512061`*^-6", 
      "0.09649539433790931`"},
     {"60", "0.0007950382368926701`", "4.9426930279325345`*^-6", 
      "0.08743174853378538`"},
     {"70", "0.0006275219146554822`", "4.013623380382447`*^-6", 
      "0.08041109310326533`"},
     {"80", "0.0005089288369379552`", "3.302217786765459`*^-6", 
      "0.0747825110997074`"},
     {"90", "0.00042013167051882516`", "2.745965204076293`*^-6", 
      "0.0701713940143045`"},
     {"100", "0.0003512740431893535`", "2.304697252529541`*^-6", 
      "0.06633752447612744`"},
     {"180", "0.0001093871108986677`", "7.226341860278409`*^-7", 
      "0.05027519159329367`"},
     {"200", "0.00008577229634464806`", "5.669484165672536`*^-7", 
      "0.04833456716078442`"},
     {"300", "0.00003109183059882281`", "2.0587108988433592`*^-7", 
      "0.04308228435545363`"},
     {"400", "0.000016077889604108886`", "1.0660483937361548`*^-7", 
      "0.04086756446229947`"},
     {"500", "0.000011549421935243276`", "7.665103043084931`*^-8", 
      "0.03952179587959552`"},
     {"600", "9.981574563069917`*^-6", "6.627280699575281`*^-8", 
      "0.03845103774778576`"},
     {"700", "9.266453644712902`*^-6", "6.153335249317734`*^-8", 
      "0.03748616158796441`"},
     {"800", "8.805804765893432`*^-6", "5.847698092854153`*^-8", 
      "0.03657789048834591`"},
     {"900", "8.42913414714902`*^-6", "5.5976356124934996`*^-8", 
      "0.035711021623375985`"},
     {"1000", "8.08746026409457`*^-6", "5.370758741495181`*^-8", 
      "0.03488008770023095`"},
     {"2000", "5.469636236831582`*^-6", "3.632322639318523`*^-8", 
      "0.0281596729670003`"},
     {"3000", "3.8125327588151015`*^-6", "2.5318718036677294`*^-8", 
      "0.02355114209899977`"},
     {"4000", "2.7516900475248185`*^-6", "1.8273851085917527`*^-8", 
      "0.020286760456011417`"},
     {"5000", "2.063133851936544`*^-6", "1.3701261268388946`*^-8", 
      "0.01788810080285315`"},
     {"6000", "1.6079478908533062`*^-6", "1.0678435632252895`*^-8", 
      "0.016055932167293032`"},
     {"7000", "1.299864314694213`*^-6", "8.632487935822343`*^-9", 
      "0.014602227389040988`"},
     {"8000", "1.0852194445611085`*^-6", "7.207049117192261`*^-9", 
      "0.013408068481095804`"},
     {"9000", "9.305537812705211`*^-7", "6.179921676379894`*^-9", 
      "0.012397570831213107`"},
     {"10000", "8.149385301390449`*^-7", "5.412121808302589`*^-9", 
      "0.011521718557093085`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992824056949315`*^9, 3.417835911625705*^9, 
  3.4798277343371787`*^9, 3.4798284029447765`*^9, 3.479829271762138*^9, 
  3.479829597614191*^9, 3.5185351059847565`*^9, 3.643443765444704*^9},
 CellLabel->"Out[138]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[139]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVxXk81HkfAPBxJHeOn0wqWbS7I4UIhb5fFUtSsfsgx9NSIhE9KWmR1NZO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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV1Hk0lWsXAHBCiWR6ntNRuIbqhkIDirJfhVBKElIoqVumBimVDA00oEsi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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -8.073859195551618}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-8.073859195551618, 0.6704303518743467}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282408807272*^9, 3.41783591492258*^9, 
  3.4798277361341457`*^9, 3.4798284047415485`*^9, 3.479829273683976*^9, 
  3.4798295995519514`*^9, 3.5185351080629215`*^9, 3.643443765772832*^9},
 CellLabel->"Out[139]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsubsectionIcon"],

Cell[TextData[{
 "We are going to evaluate the daily urine and faecal excretion for a single \
intake ",
 Cell[BoxData[
  SubscriptBox["I", "0"]]],
 "= 1 by ingestion in t = 0 for f1= 0.05 and f = 0.002"
}], "Text",
 CellTags->"ICRP 78"],

Cell["Here is calculated the  for f1 = 0.05", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fn1", " ", "=", " ", "0.05"}], ";"}]], "Input",
 CellLabel->"In[140]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[141]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.03147712596649704`", "0.2717926767643416`", 
      "0.6967301972691609`"},
     {"2", "0.001681949405693623`", "0.3687879276172747`", 
      "0.32626032024619256`"},
     {"3", "0.0009219725242209306`", "0.18581016304749504`", 
      "0.13952818467447664`"},
     {"4", "0.0008298434175361066`", "0.0766560856540281`", 
      "0.06204225560291245`"},
     {"5", "0.0007525249182906753`", "0.029573751451708284`", 
      "0.03171597923291348`"},
     {"6", "0.000684433659867598`", "0.011107958446265144`", 
      "0.01992358712678074`"},
     {"7", "0.0006241161834207171`", "0.004125342387845419`", 
      "0.015174128555514605`"},
     {"8", "0.0005704317887213813`", "0.0015251538819045325`", 
      "0.013078542884888694`"},
     {"9", "0.0005224610762059097`", "0.0005633043792234455`", 
      "0.011992777429459341`"},
     {"10", "0.000479452796873045`", "0.00020849942492153`", 
      "0.011304825207664765`"},
     {"20", "0.00022250641382122113`", "9.017961814737269`*^-7", 
      "0.007995274347155613`"},
     {"30", "0.00012070092551193928`", "5.601853031065397`*^-7", 
      "0.006395154098742112`"},
     {"40", "0.00007562622230599097`", "4.0409020696833094`*^-7", 
      "0.005459040015539049`"},
     {"50", "0.00005298213369407667`", "3.1156419645366645`*^-7", 
      "0.00483525258221389`"},
     {"60", "0.00003995616703893895`", "2.482086017755914`*^-7", 
      "0.004379519584163873`"},
     {"70", "0.000031515543829859806`", "2.0149185568245814`*^-7", 
      "0.004026823700298383`"},
     {"80", "0.000025548461942857467`", "1.6573922549285316`*^-7", 
      "0.003744213927367419`"},
     {"90", "0.00002108454430688883`", "1.3779346574042378`*^-7", 
      "0.003512772515613286`"},
     {"100", "0.00001762494205903662`", "1.1563013738336855`*^-7", 
      "0.0033203916046282995`"},
     {"180", "5.483102213056732`*^-6", "3.622229022738423`*^-8", 
      "0.0025148560873286562`"},
     {"200", "4.2987611612050475`*^-6", "2.841434623720201`*^-8", 
      "0.002417588361997205`"},
     {"300", "1.5572255689030867`*^-6", "1.0310965651308618`*^-8", 
      "0.0021544263146664943`"},
     {"400", "8.046619387530249`*^-7", "5.335317423857695`*^-9", 
      "0.0020435398115751452`"},
     {"500", "5.777176171240135`*^-7", "3.834182700496649`*^-9", 
      "0.0019762059722935672`"},
     {"600", "4.991763572007035`*^-7", "3.31428700761089`*^-9", 
      "0.0019226523332002694`"},
     {"700", "4.633767717050069`*^-7", "3.0770263455237015`*^-9", 
      "0.0018744013411557841`"},
     {"800", "4.4033076196381415`*^-7", "2.9241180205515983`*^-9", 
      "0.0018289831536569719`"},
     {"900", "4.2149223623117425`*^-7", "2.79905370783161`*^-9", 
      "0.0017856359203666143`"},
     {"1000", "4.044060354924106`*^-7", "2.6855986541538565`*^-9", 
      "0.0017440857856219202`"},
     {"2000", "2.7350242057331414`*^-7", "1.816298178224378`*^-9", 
      "0.0014080387010362264`"},
     {"3000", "1.9063976256623004`*^-7", "1.2660230600465729`*^-9", 
      "0.0011775954790644839`"},
     {"4000", "1.37592961030851`*^-7", "9.137487267760433`*^-10", 
      "0.0010143657196029867`"},
     {"5000", "1.0316223235981147`*^-7", "6.850998521440476`*^-10", 
      "0.0008944258066353988`"},
     {"6000", "8.04010996702546`*^-8", "5.339463868902786`*^-10", 
      "0.0008028127933843118`"},
     {"7000", "6.499576011306882`*^-8", "4.3164129375603704`*^-10", 
      "0.0007301244535653947`"},
     {"8000", "5.426277552744892`*^-8", "3.6036443145384217`*^-10", 
      "0.00067041434771331`"},
     {"9000", "4.6529013355547585`*^-8", "3.090048784052155`*^-10", 
      "0.0006198879084516937`"},
     {"10000", "4.074793606679249`*^-8", "2.7061279491197754`*^-10", 
      "0.0005760941310205506`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992824114660544`*^9, 3.417835917531955*^9, 
  3.4798277389155383`*^9, 3.4798284076007586`*^9, 3.479829276449548*^9, 
  3.479829602286694*^9, 3.5185351100629597`*^9, 3.643443766429096*^9},
 CellLabel->"Out[141]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[142]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV0nk8lfkXB3Bc1b33ee5FnmREUZpQthIm5TyJZjAkI3uaolLZyprQMqUk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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV1Xc8V98fB/DPJmT1UUQiUlZUQqhzKrTI/FGEkoRKMkoqIlFW35SEEpFx
fYysZB0rZKSQrJBRsvfI+p3+uo/n4zzuue/365xzj7j1NcOLFBKJdINMIv17
tsrfUKp3vnMwyPYZ+2Veaslda6vBUEEzEOh6mfcLg1ryZLGCYiboAB6IsZ1R
XqGUCH+cf3xA0APo3O9hMYYoJT0yT0wUBAOAidLK+dxySknZjx/7dwpGghje
o9KGNykle1V8UyQFCTCpFyXg2U0uGblg2r9NMB8cBC11vVmkkr9U7ULm7lpQ
/duDsuCzjHrfFJnw7W0GQOD+QVuwgAwF3iw5stqBwrFi7bqrM0jXT3JtW1sP
SD5xJo29cAL1FR2U4RPrB3XVuufSHYfRLxU1mkbqb3AL5GXtrB9A1z/8Pbur
4DeYDCtn784bQMtqBTlin36DE/blsnHxA4j/oMYl+sBvwFo8Wmd8ZwABzYM1
n0UGweu/RpwWcgPohf7h/84HDQKmVuSm1ZB+dML+hIj/5T8geGAg2NayD6VF
mik1Sg+DBgc3iyHJn0hapSy8WXkYWJwRrtkk8BPFN0kvtRwZBkLxpUb69J8o
kmuxtMNiGBQQjem9Az3ogWe43sCTYUD9LLQjKLEHnbVudlhYHAZf94yNjcn1
IA6ZU7GiNSOAo+Dc5hyvLnTpwyHuyw5jYPcRnrfzHB1opN3Gxs99DPQnRKs4
jbUjp2X//Fi/MfBO538lpMZ25AE+27a+GQMtzJPB9hHtKOijGdLqGAPe+Ya0
M9LtKOOri5OYzjjQG81sSdBtQyszhn+GNk6AFz6j3B8Sv6Oj6x+cjFmYADqT
V3Qevm5GPrJDS/vWJsCbYi0lpYBmVHhcj1VLnwQvusS/TLk2I0U/ofXz/JNg
+IoVJelEMxJcS/2sKz8JIg7MXJyca0JDEy0GS+cnQY/d2boFwyYU3LzztEnt
JOAR4GyLFmxE1VPB7CNfJ4GW0odf/9EbEYVvOs+7dRK4d+6PeDb1Fd3QLRJK
HZgEwo0Xar7UfUWWlQYdVNIUYBzuvCLs8xUp5nlYvlOaAqqN7tJT419QU1Sd
DVf0FMissWj9mtGAuqhdw/fip0Bz93xx4uMGNHR53HmWmAIp7157vHJsQBQN
fu+u91Og1X2DwqBcA1LsNH2V8XUKDGm1Fy0Qn1GISN83Y/o0SG6Unp1n1aMT
rxa1X12ZBpqL7RZ/q2qRCZ3zM5/LNGC+NywiiFpkfVXkf363poH5It8P9+Ba
dOsAuHDNbxpsv7dvs6NRLUr64et1KGYauIvD7PyeGsQQ5c0baJoGD/p2EPWk
GlQaLSW9S30GcGtE6dqYVCPDT2HSCodnwD6SW/hdtWrUO02TUTw+A66mv7B7
L1qNaMf7ZPaYzoBphaLjQb+rkPb0azlllxkg9ICakOdRhWqOCikeTJkBStNX
stkTK1HzBKfKKeFZcGwo78Doxo/IRvi2it62WbBjbIPM6GoFmtUaUtGXngWw
/3Ivx+8KtDGqWtVQZRYcFzawev2+Ap3WeqBmYjQLvC+4S8iYVaAfEasHLANn
gewGrddZ8eXo1+FJTcelWRDyfS1m+VQZGvubdWKePAf0OMgtg+plaD7zhv49
9jmw7WVGxMjOMsQusWweKjAHGIblD9SoZUiGyuaSqzAHUrWvr4zmlaKr5SKx
qxfmgFr7QmPczlI0c+TYSkjdHJh7uMX/s2AJWl7ioAo2zYG3gSn8AewliJ5d
zx7bNgf8lRt+50wgtFHSiJn1aw4cLdP+6Z6BkCrNUvY7aR7UjWtVL+xG6E6F
y5mt++aBSgD//VKNYkTVep2T/moeaJKpd+45FaL/EFL6GD8P3pD9+AsNC5Go
Wk9We8o8MJ+pei25rxCpKohn0vPngbq54+jtvwXIUSguzbxlHiTx+nkd9C9A
raMJiWw8C2D16uT4SFI+Sn2eFmF1bwHsfdKQWMj5AanxNQi6+S8ApPaC/fB0
HqoOHA8PCFkAkc8Gh8ba81DvPcXnOS8XQM9C8MNiIg8JXs4M5fywAO4xftxS
1MlDPiA38P3kAqhRLZnc//w9Mh0sustzYRFI7CDtLNTKRbmsgCaqwyKIMCo9
rbEnFzGvm0ovOC2CSvUHwT9Ec1Hj4kRzj+ciGFxk2vks5KBTnJJymZGLIMxw
OtEgNQdp7gpoN25cBNYPzFC/SA7a42qiEnnoL7BmPTVu5s9GT1QlgkOO/QW9
EY/2y1Kz0cTyeK+P3l8QY6N8JXo6C6U9eBRy2eIvoNl272xrzkLS4YUDGrf+
gtfdnGwvX2Qhsfxtz7oz/oKsXpfvKtuz0HrS+ISk2BKwnY2Q/WKQifoNeHRi
pZbAYTauQqidifLjFBK3yC+BxgI2oUq1TGR31Mlio9oSeJEmXsstmYnKQiY/
sRkvgQV/O4Gw+XfIfcvMmyH/JVCXYZ1s8eYd0rvGXLUNWcL3mZgR94t3SKpU
6UzfsyXgrRgn3Bj8DjXZuPF0xi4B/lF6TOitd2gXa+52fcESuHOgOGrG4B3q
V1s0zhhfAp7CudXbGe9QQZBQhtzcEuC9bb9/eTkDhXbt50xexuPDyfL90xkI
+HiUxq5bBlGDsRqDPzNQ5Kcl+acSy0A80Eq9uDgD6Z9eZdwwXQYRt0b3Bt3O
QIVu1A/qaBkkNvv0spEzkGCAd7Bm5TLQ4jqbHTCVjlyi187r1i8Dp0vrGnb0
pSOZqiUOq45l4Bt6LaaqIh29EJw56zO/DLyf8twIf5SO3Ar6SZ8UVkDnxPMi
baF09KXB+ttX5RVQ/Npz4BNnOpLr70luP7AC2jlq8i+vpqF+rh+GIydXQNPi
WBhHfxoytPwWz2O3AsR5G/elZ6ShXeTKYyYxK+BT0QMBW700FCCgucUqcQU4
plsfLTiShgakyyYvpa2AR1pevbKqaeilYXHkrcIV0MWwCbQUT0Oc8bkjL1tX
QI3dpn202VQ0qJ34Xx/vKrDf4s4nFZuKYoMetjp5rwL1uFT5W5ypyHWXWSb5
4Sqw8lN64ERNRce+yAaFhqwC//a5RI8lFhrb0ACyo1aBBY96eeUwC2lECSTO
56yCb+MsP7V6FmpNfuPmObQKJD3dvZyfshDrpKsezyQeb/X09AtiIa9RLemY
+VVw/WeqXMoDFpLa/aezlLYGbNwvC0i5s5BrnoImfesaGFReH9llwUK8VYX8
QUZroPfk0XVAjoX67UJGRMzWQKCu2h49KRZ6z3GuMvXcGmjxAEKOYixkeYrq
0XB1DRyeo6R8Z+Lvfzv+k//hGjDU255sspqCjvW3pEcUroHS9V2zQ00pqOSe
e0ITPwkKk0McWA9T0MgeXn3rjST4KU3IkuKbggQHEhcnhEjQkudU7EWvFHT9
+HcdbnESLM/4GmF0IwVt41eePqZAgm/5Omc+2aSg+3HToPgkCYZcdF7P0ExB
Gf8L/KOjR4IGtINV22AK6mSTeNphSIIFYlKzJzRSkNIVw18LZ0jwvarPgSKl
FNSv9C5orx0J9p9euyMllYK0Kx3bknxJMKX8MJzhSEHO7oz7Kg9JsK5bL6CA
LQVFy0TLVQaS4JfRlddBtBQ0F1Lv1RdKguv6v9acXCVQoqmclGgsCWr81+mk
PkUg9j9/nJ8WkaChwWb52g4CKUV5i2wrJcEDN26NSLQR6JyuUGVGBe5HQmDN
t4VAH94dE/pcS4JpSgqVVl8J5OCRiNjbSbBY/JenWxWBajkvcnnOkWCJ0OIh
nhwC9fQaii8vkqDmiXbj0UwCzXyAyh4rJBjV0bOrMYNAonYi527QyJDH0nE8
nUUg54qmLEd+Mrx4wYz1IZ5Am+8eNrfaRYaL1he758IIpGCs6PRjNxk+Znsv
tf8ZgTRlRR+Y7yPDS+xXt3mHEsixbTHNVIMMp74bzIs/JlDZvncU/RNkqOWG
zr19SCD7sa0EtCXD6cazk2/vEMjz43pUbE+GXt8C9TRuEyj05VKTxlUyLC7p
cf5+i0CFJ76vqLqSoWt7/lfhmwTiTQwx2O1Dho/+2Lh2XCdQntXKgng0GWrE
b26RsSNQvfLw+phYMuTbpnKK7RKBete3bRN9S4Z0jqjC3xcJxFWYrbOZRYZV
Dm90si/gfAWvxPDnk+GpoZ9THlYEYvvafpTaQob5PB6e2aYEanV0ttJqI8N9
k5dD200IlMTFcdO/kwxbnmzzomKfOLY/gbOPDPnHa0otjAkUgsJpzAmch1Md
+14DAgmkGZdKclBgukRO2ZmTBPp1cqTVdj0F3iAlE8knCJT75/5EEi8FJlUX
jy8dJ9Dp7Vlb5TdR4DevEdfEYwR6+ZLPc58kBVKfOSYJaRNIIvCzmvZBCszR
0vtmcwiv505bw4eHKHC/v5PVd0igisoV+xpN/L5uX+dJbFuKfMSpkxTYdvVh
hBogEHErcN7kNAXS66tcdh0g0G67Y9mXnCkwxqom1WE/gSiMntpkNwoUUH2Q
u6hKoMa4m33D7hRoXhN1OgDbtTuB38mLArm8zY0zVHD+JvTr7kEU2FoQ94pb
mUBAq0z+UQIFvrHWAbx7CWRYwe7DR1BgSV4VM30PrueIXktEKgV2Jhdd18MO
OtTpSWRT4PNvO1jPdhOo/cBcQ20ZBdrFLAcpKhJotFBD0riSAoUTOtk6FAhE
0rjv3vmJApeurnX7Ye9Q4xUf/UKBaUXiz3p34fqUZZy5uynw8YGq+8nyBPLP
cap83kuBZYc1zlliRyq937z1FwXWUZNdmNilezTLFUYpcKO8pbyvHIG4FSyZ
BksUWD1PvX5dlkDJO0Jzn26iQsJiNMhLGu/HhFYOEWEqFNqk16qF/WX7Vqt4
USpUYb0TXI89J8Fiy9lOheEvy+yjd+LzIVZ5umUvFe6c+jBYu4NApq+5Ui1V
qHDowfWbEdgOokbk32pUeNx8uusS9hORnuT5Q1RY5bRJlg27S/DvX0F9KlS6
FGWhJ0WgyXCoF2tEhU493KclsGmb/OOkTamQz2mUb2E7gWQFmDpqllTousjI
i8N259v1yvwKFb4+Gn+Hir2BwxpEP6TC0VNPvXol8PnQM3w+FEiF6ncDDMux
M8MOjyo/psIk34GEeGx9cYmohjAqnDKi1NlhB6v2z5HiqPC9YE/j3DYCnfVs
1tVNoMJusy+3O7DlKiriI5JxPaKHwkuwa/TeGu7JoMKnl5NEg7DZLtmmXSii
QuGOebATu4VlQs8oocIVqqwuL3bClPbZ5XIqNDP2QgviOD/PHRxhNVT4JOZo
fQ22d9jgxcrvVHjKJ8XaBXup3GGL9BQVbnznp/hNDH9vnbmr2ywVon1lXWXY
kXona0sXqLBd0r4jA1u1Q/aW2RoVatnP5Qdju02NNAdy0WDW0OzECWxN1R+y
rTw02JZoNKGGzfSs95HcQIPNIEBJFjtzXZpikRANyqpz+HNhj4tdCxqTosEW
kel9jVsJVGxr1acmQ4OJo+EHKrBDWHpq/vI0+OZhiHcutpyq4uBWJRo0uncz
PwrbXm/yiMEhGtxfvfebHXbfXZelLHMavEpr/smF/XLwQ9G4JQ1+zKp0oWAb
G5HuyVrT4K/Pc7sXRPF53xlMi7OjQedsEcV+7PimhPWhbjQocujW1mLsswdH
G+rdaTB0VWMtG5uZvDd03R0aFDeOobOwfT1LNnr70GDvluT7kdg20u1bnR7T
oM9xtr23sEWeifWmhNLg4YDFfdexm1dt43+H0aC0aaiZPbZm8/ROq5c0qH/R
jmGGLem1fs+pZBrsWl1s1cDub4aacuU0KJN4aZoN+yXwZ9hV0uCVM2sNZGxj
or467hOez2Lx49IW3I+Xma7wFxqM5ji+PI4dL+NqwvGDBhmP5P3asM+G5Qtq
99DgXXqseDM2k0Tu8O6jwYVX3E2fsX2/BVst/qHBSULzRgW2zb1Eu8E5nKef
Y1YGtsjwqIzkXxqUtF+cTsFu/p/SqNUKDXL/uHc0ccu/+6z0+ncqHc59kZCK
xpZsafeo5KXD8i1WeUHY/bLcwfEydNjecmboCnbXTWqQ1C463HZest8Ou618
ISBpNx2yC3uM2WB/Nu97yFKlwxK3a3stsPMC83yztenQYcjF7RR24LD1nQpr
OiyIPv18L7afyunb2rZ0ONib7qKIfe++rke1PR1WtXSdlcd2FVZ1r3OiwzL5
SoMd2JYn17s2e9JhwgtuJIy9J+X95f5IOgzt7nFjYMvNsxxso+mQGmAxS8Xe
ceSN/WAs7o/t4F3yvzw6gi6NJNHh7OXrb5dFCMTgtL4wk0uH6RofDaex2xy4
zGlNdFgdwrXyE7s5l2zm10KH2YF9Y93Ynynzp9nb6fB9yMtfP7DLIn+acP2k
w4y9Cr/bsFk1uYbMcTr8eNtEuhH7nsz5E5KcDLjRrCy8HFv5AEnHgZsBw9W3
zJdij+q91s3gY8CHo2xmJdhmbj/0NQQZMPggkCnC3ltyxtR4OwPK6MtN5WL/
+p+hjS9gQL7vfbwp2DreRzz7XRgwxKVKPAyb8qzXS+YmA3KbrjY9xf6Q4O3t
5MGAifrz/qHYUnXId/kenj+FbfYx9tpGjUBmCAMmP3zeG4CdyVJ6oZnEgIej
cqne2EKt2zPjOxlQzMBZ2hGbv85lQrGHATnMHg9fweYoKd1V1MeAnV+ItMvY
y4kWKd+GGFBTukLFHrvnZlg8Y5EBN9W1G9tgJ2yih9sJsEH/0e4cs3/9mfbf
ljvFBn1iRqaPYuu2vNHKRmxQ5sOzTIl/9XAnp0VHs0PSoHlXlzDe/3NiZY8c
10GdZZJADDbfLgMyTZ8DusdeELfA5hCYHvLcxgm75LtebsXepyxKNE9wwhsa
ajL9m/H/M5Ec9uELF3R//uq/eOyiahOZ17Hr4Um9Qh4H7M1qNsMbfLmh60JW
pCy2q1mfySNTHqh3v1l/SohAXu2ztVc28EK133/0CrD5FU18Ou/zwmOVfAe9
sSUsxoPrRnjhWm1Rpw62d6aNgq8lHyxkLd7YiL0QH60u/ZkPxkXrNfcJ4vV3
5Ht1Spkfcnd4Wb7HVjx/7pl6Ij8c3LHsHIA9KTPYk8S7AfrENX+8gF37ROkF
1X0DrC84TjmEPSVmMbB9cAM0UY/vEMUO9y/2r9Znwgnn8/oUbPez11CUIRNO
+Yq2krHNdovNOxozYS9j87l/Fu3wthU4zYQtFXVOJOz4XVpa1lZMuNVla9jq
Jpz/t1rK8lUm7BJy/vMXu06i7a5CIBNaxAaWTGOnLTzKoQQzYdMEu/4/P65X
G/0WwoTmqLx7Ctvw5suzd0KZsHTv5NokdluNlfqnCCbMW5E5MoH96/qvBesk
JlSZ4Pk2gl2tHa6oTDAh7aKl3T8Twsfs1rGY8Ejwn6Vh7Ksfk7+npzNhUHKO
xD/PCF7NXc7F9QDJG3+wW0a3jDXkMeH8gAnnP78v+7w9Lp8Jc6c/xgxie1xR
DDtezITTX0/X/cY+e+hnnUgJE2a9uGP9zwc3htImSpkw26lz4Re22PBhjfJy
JrQ2cn/8z+SSaZfnH5lw9pq+1D//H27cleg=
        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -4.296822220135705}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-4.296822220135705, 0.3350235635737236}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282417190258*^9, 3.417835923250705*^9, 
  3.4798277430407495`*^9, 3.4798284116474004`*^9, 3.479829280465096*^9, 
  3.4798296062872314`*^9, 3.518535113547402*^9, 3.6434437673666058`*^9},
 CellLabel->"Out[142]="]
}, Open  ]],

Cell["Here is calculated the  for f1 = 0.002", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fn1", " ", "=", " ", "0.002"}], ";"}]], "Input",
 CellLabel->"In[143]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[144]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.0012556418195924153`", "0.2819493959191487`", 
      "0.7167949622142163`"},
     {"2", "0.00007037261284843028`", "0.388276600829948`", 
      "0.32844798877127035`"},
     {"3", "0.000036943425899794166`", "0.19654394616105422`", 
      "0.13186709918432052`"},
     {"4", "0.00003322095439477332`", "0.08119842403428326`", 
      "0.05063545419564696`"},
     {"5", "0.000030124677882795116`", "0.03134149074949394`", 
      "0.0192638387682747`"},
     {"6", "0.000027398248152641106`", "0.011772976030758121`", 
      "0.007463464489368417`"},
     {"7", "0.00002498319476635356`", "0.004371265771471584`", 
      "0.003067215523134954`"},
     {"8", "0.00002283380322917522`", "0.001614792261276271`", 
      "0.0014295894586339823`"},
     {"9", "0.000020913233189219786`", "0.0005951948332686927`", 
      "0.0008134813921805427`"},
     {"10", "0.00001919138556700573`", "0.0002191854919457081`", 
      "0.000575104514672301`"},
     {"20", "8.905238671029633`*^-6", "4.566729247820323`*^-8", 
      "0.0003198863593499917`"},
     {"30", "4.830134561365298`*^-6", "2.2414743508104784`*^-8", 
      "0.0002558442327258278`"},
     {"40", "3.0260405097130643`*^-6", "1.6167326747510394`*^-8", 
      "0.00021838555685512164`"},
     {"50", "2.1198212297550683`*^-6", "1.246497798375126`*^-8", 
      "0.00019342693313636135`"},
     {"60", "1.5985763038132452`*^-6", "9.930072763837087`*^-9", 
      "0.00017519349245485522`"},
     {"70", "1.2608464054607727`*^-6", "8.06097823636569`*^-9", 
      "0.00016108297582509114`"},
     {"80", "1.022102651767042`*^-6", "6.630579303129093`*^-9", 
      "0.0001497766840730112`"},
     {"90", "8.435071430133126`*^-7", "5.512534629931555`*^-9", 
      "0.00014051760313966484`"},
     {"100", "7.050961198342743`*^-7", "4.625840717550045`*^-9", 
      "0.00013282126154380228`"},
     {"180", "2.1934615208463583`*^-7", "1.4490369908112845`*^-9", 
      "0.00010059595588414183`"},
     {"200", "1.7196672846195294`*^-7", "1.136681244916453`*^-9", 
      "0.00009670486740177468`"},
     {"300", "6.22932479263762`*^-8", "4.124665546376374`*^-10", 
      "0.00008617750688005156`"},
     {"400", "3.2187708414786287`*^-8", "2.134208370600788`*^-10", 
      "0.00008174180575852834`"},
     {"500", "2.3109099949977004`*^-8", "1.5336992341028194`*^-10", 
      "0.00007904837976720715`"},
     {"600", "1.996721073492568`*^-8", "1.325725165469504`*^-10", 
      "0.00007690620937733165`"},
     {"700", "1.8535157483552753`*^-8", "1.230816282519436`*^-10", 
      "0.00007497615857164577`"},
     {"800", "1.7613295340656427`*^-8", "1.1696515134099705`*^-10", 
      "0.00007315942403114492`"},
     {"900", "1.685974630588063`*^-8", "1.1196252582501968`*^-10", 
      "0.00007142552900127405`"},
     {"1000", "1.6176294261721885`*^-8", "1.0742429706169911`*^-10", 
      "0.00006976351846820415`"},
     {"2000", "1.0940129799904413`*^-8", "0", "0.00005632159612012107`"},
     {"3000", "7.625611503914707`*^-9", "0", "0.0000471038431642879`"},
     {"4000", "5.503731976247265`*^-9", "0", "0.00004057463787693743`"},
     {"5000", "4.126498158738077`*^-9", "0", "0.000035777032117170204`"},
     {"6000", "3.216049915479469`*^-9", "0", "0.00003211250585340656`"},
     {"7000", "2.5998344758087046`*^-9", "0", "0.00002920496870057239`"},
     {"8000", "2.1705139065639385`*^-9", "0", "0.000026816562256547465`"},
     {"9000", "1.8611626532100752`*^-9", "0", "0.00002479550331759166`"},
     {"10000", "1.6299190580487753`*^-9", "0", "0.00002304375137887958`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282419786481*^9, 3.417835925781955*^9, 
  3.4798277457908907`*^9, 3.4798284144284906`*^9, 3.479829283261917*^9, 
  3.4798296091001096`*^9, 3.5185351154536886`*^9, 3.643443768007228*^9},
 CellLabel->"Out[144]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[145]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV03k8V9kbB/CvJZUtyw333m8ypSZkKUSS5xKTIVqmJDFFixZCihJiMpUU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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV13k0lU8YB/C7X6FCN6n8pEiRXSFhppKsWSMS9yKJ7Iooa1K2UpasZQlJ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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -7.855607967438007}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-7.855607967438007, 0.7119758734444415}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992824258078427`*^9, 3.41783593179758*^9, 
  3.479827751244294*^9, 3.479828418756366*^9, 3.479829287308715*^9, 
  3.479829613225664*^9, 3.5185351190318823`*^9, 3.6434437689134855`*^9},
 CellLabel->"Out[145]="]
}, Open  ]],

Cell["These  values are the same that Table A.12.? of ICRP 78 ", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsubsectionIcon"],

Cell[TextData[{
 "Now it evaluates  lung retention and the daily urine and faecal excretion \
for a single intake ",
 Cell[BoxData[
  SubscriptBox["I", "0"]]],
 "= 1 by inhalation in t = 0 for AMAD 5, and type S "
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fn1", " ", "=", " ", "0.002"}], ";", " ", 
  RowBox[{"amad", "=", " ", 
   RowBox[{"AMADAdultW", "[", "5", "]"}]}], ";", " ", 
  RowBox[{"class", " ", "=", " ", "S"}], ";"}]], "Input",
 CellLabel->"In[146]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[147]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Lung\\nretention\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.06427552500237536`", "0.0007039962593648613`", 
      "0.11387953855106758`", "0.49089159234482294`"},
     {"2", "0.06269378801433073`", "0.0000440788558102043`", 
      "0.16275643453253827`", "0.24932846379528442`"},
     {"3", "0.06193513789049532`", "0.0000259854301102886`", 
      "0.08384098905595876`", "0.1364863414303088`"},
     {"4", "0.06130047409779483`", "0.000023659237179731243`", 
      "0.03523951490155966`", "0.0905638051029238`"},
     {"5", "0.060694931817597914`", "0.00002195098091628371`", 
      "0.01402575226274369`", "0.0725947407271285`"},
     {"6", "0.060105359291272434`", "0.000020477534800593215`", 
      "0.005651548640172935`", "0.06548012553136733`"},
     {"7", "0.05952967062958558`", "0.00001917267824656267`", 
      "0.0024677448238166547`", "0.062462508351318835`"},
     {"8", "0.058967285487397984`", "0.000018007524523841467`", 
      "0.0012720970495169528`", "0.060977169480946634`"},
     {"9", "0.058417835123414426`", "0.00001696205902189645`", 
      "0.0008212249995198442`", "0.06006715897965459`"},
     {"10", "0.057880987087771014`", "0.00001602041377346021`", 
      "0.0006467528392190697`", "0.05937796263326933`"},
     {"20", "0.05313929788613847`", "0.000010229702182821057`", 
      "0.00043851167628679993`", "0.05430888922588359`"},
     {"30", "0.04935432825601153`", "7.716778906501423`*^-6", 
      "0.0003500019182618927`", "0.050342139431231094`"},
     {"40", "0.04631240670334732`", "6.441465805823859`*^-6", 
      "0.000281220272799608`", "0.04716509403961897`"},
     {"50", "0.0438491883809243`", "5.6867677568385455`*^-6", 
      "0.00022761750597801583`", "0.044598669337097135`"},
     {"60", "0.041837963228833416`", "5.178782980343535`*^-6", 
      "0.00018572500061584535`", "0.042507429162442344`"},
     {"70", "0.04018079749916242`", "4.8050322252156386`*^-6", 
      "0.00015288926665689428`", "0.04078767677779576`"},
     {"80", "0.03880180963056222`", "4.514583156411782`*^-6", 
      "0.0001270756642077417`", "0.039359446225648326`"},
     {"90", "0.037642056328222546`", "4.2813216338854`*^-6", 
      "0.00010672041037465552`", "0.038160777895602176`"},
     {"100", "0.036655635365972564`", "4.089982064961993`*^-6", 
      "0.0000906187396555215`", "0.03714349016157874`"},
     {"180", "0.031972952567723444`", "3.2904082791756356`*^-6", 
      "0.00003723145670777098`", "0.032358036501244185`"},
     {"200", "0.0312186664649487`", "3.184021125821404`*^-6", 
      "0.000032999895338465396`", "0.03159585591127798`"},
     {"300", "0.028174460369493545`", "2.8152135470001574`*^-6", 
      "0.000024311962080129923`", "0.02853799662492384`"},
     {"400", "0.0256500197832833`", "2.5518190782149175`*^-6", 
      "0.000021169153766768117`", "0.026011822176716354`"},
     {"500", "0.023406716857724684`", "2.3289948321483095`*^-6", 
      "0.00001891993433972977`", "0.023768302459183863`"},
     {"600", "0.02139231874660401`", "2.131871035731224`*^-6", 
      "0.000016977426230607717`", "0.021753613279278324`"},
     {"700", "0.019580131605462667`", "1.955265638997443`*^-6", 
      "0.0000152460932811814`", "0.01994080216835734`"},
     {"800", "0.0179488559839372`", "1.7964062138725242`*^-6", 
      "0.000013695558802309313`", "0.018308553223359756`"},
     {"900", "0.01647975458899397`", "1.6532862719626298`*^-6", 
      "0.00001230588843389828`", "0.01683816077478255`"},
     {"1000", "0.01515608482609662`", "1.5242365896269393`*^-6", 
      "0.000011060193639896021`", "0.015512921538213226`"},
     {"2000", "0.007276566540623153`", "7.520061746130353`*^-7", 
      "3.883249867557732`*^-6", "0.007609033877549548`"},
     {"3000", "0.004270569822741313`", "4.527148655558179`*^-7", 
      "1.4544678179902008`*^-6", "0.004574395760461345`"},
     {"4000", "0.002957011962681757`", "3.1907656498214587`*^-7", 
      "6.140691880575366`*^-7", "0.0032342275227363053`"},
     {"5000", "0.002263663623664677`", "2.470237486847538`*^-7", 
      "3.087018783909899`*^-7", "0.002517401244704393`"},
     {"6000", "0.0018228563480254336`", "2.005640751953034`*^-7", 
      "1.8648950292246384`*^-7", "0.0020559791101748635`"},
     {"7000", "0.0015035285167753596`", "1.666792891659441`*^-7", 
      "1.2930317004914912`*^-7", "0.001718397075589507`"},
     {"8000", "0.0012550507091918428`", "1.402308614881654`*^-7", 
      "9.701941327216025`*^-8", "0.0014535842017511067`"},
     {"9000", "0.0010549132337941709`", "1.1887771544081584`*^-7", 
      "7.563901353640958`*^-8", "0.0012386958607285353`"},
     {"10000", "0.0008910504723014032`", "1.0134279082541983`*^-7", 
      "5.998588482951069`*^-8", "0.001061421161437224`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Lung\nretention", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282439680434*^9, 3.417835945344455*^9, 
  3.47982776532314*^9, 3.4798284333492756`*^9, 3.4798293017928114`*^9, 
  3.479829627305681*^9, 3.518535128188308*^9, 3.643443772179144*^9},
 CellLabel->"Out[147]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[148]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVzWs0lHkcwPG5djHjMuaxO7FKE1umE9M2Ucb6/XUM3dDazmhFbS5bS3Ql
KXdt2VYhRdGUyaZks7GKwvO4nchIG9lBOiPMEgm5zkzzbPviez4vv8sDD/mE
0CgUiufn/le5JkrUevS0i98G53wsiUnEBu4dyuT5gcvvu5eTcUwiY76B5scL
Bf4ytmz4FJOwaJy9+C0vBiLvLUmriWQSKkGG1J73KxhsrnQ98DOTqOvt3biK
dw38q6/Sn+xgEuscU+5Z84qAnQBvApYxidEg3wE+7zE8U3Sn51QxCA3dvQpb
2wL+RsXOTmo68VZeLeWs64D67xUNTy3phI+ZXBtR3A0BckHM/C4a4fmLNcnv
UkGVZGW4dTKV6K92EXCsBkBom/vG5QmFUDs6MZz/+BfeWjb1xDeQ+P1rfqKX
tiMg+oaDKpbo8f2VrkZhoWMg42udDM/rcA/DM9tuzo3DvpJpjWO3Bm/PVQSz
ZZOgo0V9SUjm8VrZ17Z24inwyN5or6uYxdWbJtwitNMQ1sAr8zOYwemSG+Ul
12fhaIry2IXoKdx3qDrWOGge3HvNXjo0TuKGlA/j1lZa6MneIlxvPoFXRdIr
xbgOqi2Ut6Z4H/D8384pDyfqwd1fwCt8MoITCdG3200piNVuN3rk6hDewgph
x81Q0PUH3tuPOwziC//u9qB3UpGjhnlzYrAPB0ndmtTbNMRojV+2Vd6Lcw0C
QXaOjhQ2Oc1Vmk68P/aYtmw3A3VGpvCOtrzAB1YbpRUImEg6HJtw6UwjniDY
t9WatQA191LDgqgP8CVKm9KC1wvQobGwp5CVB56dcslf+ELU8DbDLSCTgFKj
u/dlskUozjugfdq5FbAZq7rUiMUoZpBxbcGpDuDYfUdl7DBA3ld897c1dYOB
2cd3cXwW0phdEuq8VLDeYWlRxzgL/aAtOxtk3Q/aQurlyhdsVH4rKsFYqIbq
JqngRr4hUuYl9eyhDIO5U/AIN8UI0XqSVoYwR+G4X7801dcYXZ5juo22jUF8
93TLQa4JmhLSd6vqxsFUKE16nWyC5Dza2izHSVgR8CFNMWqCIEl5GNI/QmJp
sH3KHg5a/SLRO4s2DXMFMrHtcw4afx3zbnvYDLyP4Fz3cjBFm1l5J7MrZ0G4
78cscaEpOhcqHzXlz8OEYEh1x4SLasy2FS4/ooGWDFEOPZqL0p2yw85XaGHS
KmDQZoiLGkUqj2HzT5B9tuZs0w4MSRJWhVND9BDtfwjP9cGQ2jV/V12oHvzW
Ws1G7MQQN1glTj6sh6U9iT+Z7cKQaZBimHFaDwV2EkngXgxxLNgDCy/pofRV
C00XjiHpgRW+7Fo9KFZ0xdqfx5CzKFlqbEnC/bnUcloahoY6I93a+CRcbHV6
/+oChrz3/ym4uIoEnxN5/qczMSTuoqqMRCR0Pdsrbr76+Ve/esxwGwnqI+q5
wDsY4heV5RicJKHJPVvoUIQhLN6L9SyOhCKLzQcWF2NoWG4XlZpCQnjj3X9K
SjBk1vdItCidhCle+EPdQwzFepbtZBaS0PnecqytAkMbplxSG4pJeFT33ObW
YwydcP1UnlxKQsxB4eUtNRjqozHnqDUk+Lv2Kb4iMOSV62FYW0+CyxeZjPFa
DMn4JeYJzSRYjWxyrq/HkH+5oxW0kUAlPh670oihQdRrqe8g4T/2yURt
        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV1Xk8lfkXB3BbDdeS5ZH73Ps8TwZNqCylVOT7ZUJRKiOEGNIw1oxJJYyK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        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV1ms4lOvXAPBhKOfjsIkkZDNy2CUkuR82UiGpKAlJEhIpG/+dQkU5JIoS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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -8.631639765076889}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-8.631639765076889, 2.955058331766388}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Lungs\"", 11, StripOnInput -> False], 
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992825178330145`*^9, 3.417836022813205*^9, 
  3.479827781902114*^9, 3.4798284505981474`*^9, 3.479829327323571*^9, 
  3.4798296493555193`*^9, 3.518535139594777*^9, 3.6434437760385594`*^9},
 CellLabel->"Out[148]="]
}, Open  ]],

Cell["These  values are the same that Table A.12.? of ICRP 78 ", "Text"],

Cell["\<\
Sometime it can be useful to obtain an approximated expressions for \
estimating the lung retention and the urine and faecal excretion. \
\>", "MathCaption"],

Cell["\<\
The first step is to obtain the full expression (It is not shown because is \
too long)\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"uraniumLungRet", "[", "t_", "]"}], ",", " ", 
     RowBox[{"uraniumUriExcretion", "[", "t_", "]"}], ",", " ", 
     RowBox[{"uraniumFecExcretion", "[", "t_", "]"}], ",", " ", 
     RowBox[{"uraniumWholebody", "[", "t_", "]"}]}], "}"}], "=", 
   RowBox[{"Map", "[", 
    RowBox[{"Last", ",", 
     RowBox[{"BiokdataReport", "[", 
      RowBox[{
      "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
       "\"\<Automatic\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
       " ", "fn1", ",", "t", ",", "lambda"}], "]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[149]:="],

Cell["\<\
Here is build a new expression eliminating the negligible terms\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"uraniumLungRetShort", "[", "t_", "]"}], "=", 
  RowBox[{"Drop", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"uraniumLungRet", "[", "t", "]"}], "//", "Chop"}], ",", "7"}], 
   "]"}]}]], "Input",
 CellLabel->"In[150]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"0.010053333963025171`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "10.0001`"}], " ", "t"}]]}], "+", 
  RowBox[{"0.007981512842198623`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2.0001`"}], " ", "t"}]]}], "+", 
  RowBox[{"0.010307893988629533`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.0301`"}], " ", "t"}]]}], "+", 
  RowBox[{"0.016134061219013337`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.0201`"}], " ", "t"}]]}], "+", 
  RowBox[{"0.03190068914967446`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.0011`"}], " ", "t"}]]}], "+", 
  RowBox[{"0.004428311936829278`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.00022`"}], " ", "t"}]]}], "+", 
  RowBox[{"0.0010868960941352924`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.0001`"}], " ", "t"}]]}]}]], "Output",
 CellChangeTimes->{3.3992825320966034`*^9, 3.417836036688205*^9, 
  3.479827797215398*^9, 3.479828467690694*^9, 3.479829343182642*^9, 
  3.479829665310788*^9, 3.5185351476886826`*^9, 3.643443779522966*^9},
 CellLabel->"Out[150]="]
}, Open  ]],

Cell["\<\
Both expression are compared. It can be observer that the short expression \
give the same solution that the full expression\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Table", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"uraniumLungRet", "[", "t", "]"}], "-", 
      RowBox[{"uraniumLungRetShort", "[", "t", "]"}]}], ")"}], "/", 
    RowBox[{"uraniumLungRet", "[", "t", "]"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", " ", "1", ",", "100"}], "}"}]}], "]"}]], "Input",
 CellLabel->"In[151]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2.1591092110568665`*^-16", ",", "0.`", ",", "0.`", ",", 
   RowBox[{"-", "1.131947836624781`*^-16"}], ",", "0.`", ",", "0.`", ",", 
   "0.`", ",", "0.`", ",", "0.`", ",", "1.1988209346507957`*^-16", ",", 
   RowBox[{"-", "1.20978501583828`*^-16"}], ",", "0.`", ",", 
   "1.2315471703300002`*^-16", ",", "0.`", ",", "1.2530761231939263`*^-16", 
   ",", "1.2637489419678622`*^-16", ",", "1.2743585410079919`*^-16", ",", 
   "0.`", ",", 
   RowBox[{"-", "1.2953821260240525`*^-16"}], ",", "0.`", ",", "0.`", ",", 
   "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", ",", 
   "0.`", ",", "0.`", ",", "1.4059342207868155`*^-16", ",", 
   "1.41553015039318`*^-16", ",", "1.425047019217988`*^-16", ",", 
   RowBox[{"-", "1.4344842627858123`*^-16"}], ",", "1.4438413734701461`*^-16",
    ",", 
   RowBox[{"-", "1.4531178994231922`*^-16"}], ",", "0.`", ",", "0.`", ",", 
   RowBox[{"-", "1.4804602634573218`*^-16"}], ",", "1.4894110078379682`*^-16",
    ",", 
   RowBox[{"-", "1.4982797046921137`*^-16"}], ",", "0.`", ",", "0.`", ",", 
   RowBox[{"-", "1.52439232746826`*^-16"}], ",", "1.532931882823647`*^-16", 
   ",", 
   RowBox[{"-", "1.541389141556144`*^-16"}], ",", "0.`", ",", 
   "1.5580571356798207`*^-16", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`",
    ",", "0.`", ",", "1.6061025008478605`*^-16", ",", 
   RowBox[{"-", "1.613827347692095`*^-16"}], ",", "0.`", ",", 
   "1.6290380215960753`*^-16", ",", "1.6365247304040293`*^-16", ",", "0.`", 
   ",", "0.`", ",", "0.`", ",", "0.`", ",", "1.6727919290502996`*^-16", ",", 
   "1.679815952557065`*^-16", ",", "0.`", ",", "1.6936393557732483`*^-16", 
   ",", "1.700440010635518`*^-16", ",", 
   RowBox[{"-", "1.7071675111787626`*^-16"}], ",", 
   RowBox[{"-", "1.713822533523781`*^-16"}], ",", "0.`", ",", "0.`", ",", 
   "1.733359690251571`*^-16", ",", "0.`", ",", "0.`", ",", "0.`", ",", "0.`", 
   ",", 
   RowBox[{"-", "1.7645386673451845`*^-16"}], ",", "0.`", ",", "0.`", ",", 
   "1.7824492822888858`*^-16", ",", "0.`", ",", "0.`", ",", 
   "1.7997878014838695`*^-16", ",", "1.8054438368640494`*^-16", ",", 
   "1.81103945229926`*^-16", ",", "0.`", ",", 
   RowBox[{"-", "1.822052588838106`*^-16"}], ",", "1.8274716933536803`*^-16", 
   ",", 
   RowBox[{"-", "1.8328335436945979`*^-16"}], ",", 
   RowBox[{"-", "1.8381389298971456`*^-16"}], ",", "0.`", ",", "0.`", ",", 
   "0.`", ",", "0.`", ",", 
   RowBox[{"-", "1.8638464181351848`*^-16"}], ",", "0.`", ",", "0.`", ",", 
   RowBox[{"-", "1.8786434110536597`*^-16"}], ",", "1.8834757802139033`*^-16",
    ",", "1.8882594341184875`*^-16", ",", "0.`"}], "}"}]], "Output",
 CellChangeTimes->{3.3992825322060823`*^9, 3.41783603676633*^9, 
  3.4798277973404045`*^9, 3.479828468050044*^9, 3.479829343292015*^9, 
  3.479829665467059*^9, 3.5185351477668085`*^9, 3.643443779554207*^9},
 CellLabel->"Out[151]="]
}, Open  ]],

Cell["\<\
We procedure in the same way for urine and faecal excretion.  We build a new \
expression eliminating the negligible terms\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"uraniumUriExcretionShort", "[", "t_", "]"}], "=", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"Drop", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"uraniumUriExcretion", "[", "t", "]"}], "/.", "  ", 
       RowBox[{
        RowBox[{"x_", "?", "NumberQ"}], " ", ":>", " ", 
        RowBox[{"SetPrecision", "[", 
         RowBox[{"x", ",", " ", "3"}], "]"}]}]}], ",", " ", "8"}], "]"}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "7"}]}]}], "]"}]}]], "Input",
 CellLabel->"In[152]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "1.5226989551476599604740158611093647778`3."}], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "10.0001`3."}], " ", "t"}]]}], "-", 
  RowBox[{"1.69960557902560771559308250289177522063`3.", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "6.01202404809619238476953907815631262525`3."}], " ", 
     "t"}]]}], "+", 
  RowBox[{"1.107932615140316996715785791138841887`2.9740985808133718", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "5.37800351023898315361293498426675796509`3."}], " ", 
     "t"}]]}], "+", 
  RowBox[{"0.00016322831885213056062229608489388966`3.", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2.0001`3."}], " ", "t"}]]}], "+", 
  RowBox[{"2.70161299575155635421642123924699`2.7689500729604766*^-6", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.3436368331818790977649769047275185585`3."}], " ", 
     "t"}]]}], "+", 
  RowBox[{"3.47464273492264255747166397728098`2.9742687169627113*^-6", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.13884393166609187986182405438739806414`3."}], " ", 
     "t"}]]}], "+", 
  RowBox[{"6.397824055223090144808059491488`2.9295939492678724*^-7", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.09900000000000375166564481332898139954`3."}], " ", 
     "t"}]]}], "+", 
  RowBox[{"0.00001629512802677443785586992169855947`2.928063646236547", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.09727564424805734688561642542481422424`3."}], " ", 
     "t"}]]}], "+", 
  RowBox[{"3.16580133640662834525886237813097`3.*^-6", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.0301`3."}], " ", "t"}]]}], "+", 
  RowBox[{"2.10864664955638517803565568087265`3.*^-6", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.0201`3."}], " ", "t"}]]}], "+", 
  RowBox[{"1.03971557281315133823996338380269`2.77498152388484*^-6", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.01258381655073037563852267339825630188`3."}], " ", 
     "t"}]]}], "+", 
  RowBox[{"3.0644983144635824789947520230271`3.*^-6", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.0011`3."}], " ", "t"}]]}], "+", 
  RowBox[{"4.3188681782442561729595809083548`3.*^-7", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.00022`3."}], " ", "t"}]]}], "+", 
  RowBox[{"1.1660226234121856547787388080906`3.*^-7", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.0001`3."}], " ", "t"}]]}]}]], "Output",
 CellChangeTimes->{3.3992825322373624`*^9, 3.417836036781955*^9, 
  3.479827797387282*^9, 3.4798284681125393`*^9, 3.4798293433545136`*^9, 
  3.4798296655295677`*^9, 3.5185351477980595`*^9, 3.643443779585458*^9},
 CellLabel->"Out[152]="]
}, Open  ]],

Cell["\<\
Both expression are compared. It can be observed that the short expression \
gives the same solution that the full expression for t>1\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"uraniumUriExcretion", "[", "t", "]"}], "-", 
        RowBox[{"uraniumUriExcretionShort", "[", "t", "]"}]}], ")"}], "/", 
      RowBox[{"uraniumUriExcretion", "[", "t", "]"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "1", ",", "100"}], "}"}]}], "]"}], ",", "0.05"}],
   "]"}]], "Input",
 CellLabel->"In[153]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"-", "0.3293458517541049`"}], ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.399282532440681*^9, 3.417836036969455*^9, 
  3.479827797590417*^9, 3.4798284686906238`*^9, 3.4798293435576344`*^9, 
  3.479829665763974*^9, 3.5185351479386873`*^9, 3.643443779632333*^9},
 CellLabel->"Out[153]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"uraniumFecExcretionShort", "[", "t_", "]"}], "=", 
  RowBox[{"Chop", "[", 
   RowBox[{
    RowBox[{"Drop", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"uraniumFecExcretion", "[", "t", "]"}], "/.", "  ", 
       RowBox[{
        RowBox[{"x_", "?", "NumberQ"}], " ", ":>", " ", 
        RowBox[{"SetPrecision", "[", 
         RowBox[{"x", ",", " ", "3"}], "]"}]}]}], ",", "8"}], "]"}], ",", 
    RowBox[{"10", "^", 
     RowBox[{"-", "7"}]}]}], "]"}]}]], "Input",
 CellLabel->"In[154]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"20.64512962765085345802264921166724320756`2.9999758686474802", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "6.01202404809619395109621109440922737122`3."}], " ", 
     "t"}]]}], "+", 
  RowBox[{"0.00055747597824496710371339810302648843`2.974098635381038", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "5.37800351023898315361293498426675796509`3."}], " ", 
     "t"}]]}], "+", 
  RowBox[{"0.7636616532730770012804555335605982691`3.", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "2.0001`3."}], " ", "t"}]]}], "-", 
  RowBox[{"4.85202736047259903595998964398461339442`3.", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "1.80000000000001136868377216160297393799`3."}], " ", 
     "t"}]]}], "+", 
  RowBox[{"2.0730448683891431471693067578598856926`3.", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "1.`3."}], " ", "t"}]]}], "+", 
  RowBox[{"0.00033071455218468097381201431517183664`3.", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.0301`3."}], " ", "t"}]]}], "+", 
  RowBox[{"0.00033720536601857323266706600861652987`3.", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.0201`3."}], " ", "t"}]]}], "+", 
  RowBox[{"0.00003193709921090956416200867806765018`3.", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.0011`3."}], " ", "t"}]]}], "+", 
  RowBox[{"5.3353438004373129888158189260139`3.*^-7", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "0.00022`3."}], " ", "t"}]]}]}]], "Output",
 CellChangeTimes->{3.399282532471961*^9, 3.41783603698508*^9, 
  3.479827797621669*^9, 3.479828468784367*^9, 3.479829343604509*^9, 
  3.4798296658264823`*^9, 3.5185351479855633`*^9, 3.643443779663583*^9},
 CellLabel->"Out[154]="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Chop", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{"uraniumFecExcretion", "[", "t", "]"}], "-", 
        RowBox[{"uraniumFecExcretionShort", "[", "t", "]"}]}], ")"}], "/", 
      RowBox[{"uraniumFecExcretion", "[", "t", "]"}]}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"t", ",", " ", "1", ",", "100"}], "}"}]}], "]"}], ",", "0.05"}],
   "]"}]], "Input",
 CellLabel->"In[155]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
   "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", 
   ",", "0", ",", "0"}], "}"}]], "Output",
 CellChangeTimes->{3.3992825326596394`*^9, 3.417836037156955*^9, 
  3.4798277978091784`*^9, 3.4798284690655975`*^9, 3.4798293437763805`*^9, 
  3.4798296660296345`*^9, 3.518535148141816*^9, 3.643443779710486*^9},
 CellLabel->"Out[155]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "uraniumLungRet", ",", "uraniumLungRetShort", ",", "uraniumUriExcretion", 
   ",", "uraniumFecExcretion", ",", "uraniumUriExcretionShort", ",", 
   "uraniumFecExcretionShort"}], "]"}]], "Input",
 CellLabel->"In[156]:="]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Radium", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["The model", "SubsubsectionIcon"],

Cell["The compartments has been numbered as follow : ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompartNumbers", "[", "radium", "]"}]], "Input",
 CellLabel->"In[157]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "\<\"Blood\"\>"},
    {"2", "\<\"ST1\"\>"},
    {"3", "\<\"ST0\"\>"},
    {"4", "\<\"ST2\"\>"},
    {"5", "\<\"CorticalSurf\"\>"},
    {"6", "\<\"CorticalVolExch\"\>"},
    {"7", "\<\"CorticalVolNonExch\"\>"},
    {"8", "\<\"TrabecularSurface\"\>"},
    {"9", "\<\"ExchTrabVol\"\>"},
    {"10", "\<\"NonExchTrabVol\"\>"},
    {"11", "\<\"Liver1\"\>"},
    {"12", "\<\"Bladder\"\>"},
    {"13", "\<\"Urine\"\>"},
    {"14", "\<\"ULI\"\>"},
    {"15", "\<\"LLI\"\>"},
    {"16", "\<\"FEC\"\>"},
    {"17", "\<\"SI\"\>"},
    {"18", "\<\"ST\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.3992825326909194`*^9, 3.41783603717258*^9, 
  3.479827797856056*^9, 3.479828469143717*^9, 3.479829343838879*^9, 
  3.479829666076516*^9, 3.518535148188692*^9, 3.6434437797417173`*^9},
 CellLabel->"Out[157]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"TransferRatesE", "[", "radium", "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<From\>\"", ",", " ", "\"\<to\>\"", ",", 
        "\"\<Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\>\""}], "}"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[158]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"From\"\>",
       HoldForm], 
      TagBox["\<\"to\"\>",
       HoldForm], 
      TagBox["\<\"Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\"\>",
       HoldForm]},
     {"1", "2", "7"},
     {"1", "3", "22.68`"},
     {"1", "4", "0.07`"},
     {"1", "12", "0.606`"},
     {"1", "14", "21.79`"},
     {"1", "8", "9.72`"},
     {"1", "5", "7.78`"},
     {"5", "1", "0.578`"},
     {"5", "6", "0.116`"},
     {"6", "5", "0.0185`"},
     {"6", "7", "0.0046`"},
     {"1", "11", "0.35`"},
     {"8", "1", "0.578`"},
     {"8", "9", "0.116`"},
     {"9", "8", "0.0185`"},
     {"9", "10", "0.00046`"},
     {"10", "1", "0.000493`"},
     {"7", "1", "0.0000821`"},
     {"11", "1", "0.0139`"},
     {"2", "1", "0.693`"},
     {"3", "1", "7.56`"},
     {"4", "1", "0.00038`"},
     {"12", "13", "12"},
     {"14", "15", 
      SubscriptBox["k", "ULI"]},
     {"15", "16", "1"},
     {"17", "14", 
      SubscriptBox["k", "SI"]},
     {"18", "17", 
      SubscriptBox["k", "ST"]},
     {"17", "1", 
      RowBox[{
       SubscriptBox["f", "B"], " ", 
       SubscriptBox["k", "SI"]}]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"From", "to", "Tranfer Rates(\!\(days\^\(-1\)\))"}}]]]], "Output",
 CellChangeTimes->{3.3992825327221994`*^9, 3.417836037188205*^9, 
  3.4798277978873076`*^9, 3.4798284709404655`*^9, 3.479829343885753*^9, 
  3.4798296661233974`*^9, 3.518535148235568*^9, 3.643443779772959*^9},
 CellLabel->"Out[158]//TableForm="]
}, Open  ]],

Cell["It assumed f1=0.2.", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"element", "=", "radium"}], ";", " ", 
  RowBox[{"fn1", " ", "=", " ", "0.2"}], ";"}]], "Input",
 CellLabel->"In[159]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsubsectionIcon"],

Cell["\<\
Here is calculated the daily urine and faecal excretion for radium 228 (T =  \
5.75 y). \
\>", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"lambda", " ", "=", " ", 
   RowBox[{
    RowBox[{"Log", "[", "2", "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"5.75", "*", "365.24"}], ")"}]}]}], ";"}]], "Input",
 CellLabel->"In[160]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[161]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.015318009569277403`", "0.17104359955715123`", 
      "0.8133083956796302`"},
     {"2", "0.002559570235298329`", "0.22560538767011276`", 
      "0.5848750499124538`"},
     {"3", "0.0017489195599616344`", "0.15407098957245413`", 
      "0.42886213482451163`"},
     {"4", "0.0012202342169867577`", "0.09838651699120686`", 
      "0.3291138611729632`"},
     {"5", "0.0008554991778800231`", "0.06401462316015086`", 
      "0.26413513284248624`"},
     {"6", "0.0006036739608914323`", "0.04284356144653278`", 
      "0.22060073411067346`"},
     {"7", "0.0004297422947476127`", "0.029343099596553776`", 
      "0.19075509503733595`"},
     {"8", "0.00030954932919393454`", "0.020460110511797854`", 
      "0.16992248693176237`"},
     {"9", "0.00022643168559258517`", "0.014490530143738864`", 
      "0.15514945149840118`"},
     {"10", "0.00016889397034619585`", "0.010426845454727492`", 
      "0.14450251349999071`"},
     {"20", "0.00003939378669643925`", "0.0015505199328520753`", 
      "0.10992365022981714`"},
     {"30", "0.00003119146029672156`", "0.001149381470438793`", 
      "0.09649815139312426`"},
     {"40", "0.000026684394459212555`", "0.0009811550113595427`", 
      "0.08537587154405041`"},
     {"50", "0.000022892712859384475`", "0.0008416232437784783`", 
      "0.07583740126279856`"},
     {"60", "0.000019651277041938563`", "0.0007223986166366557`", 
      "0.067643827734551`"},
     {"70", "0.000016877581648126105`", "0.0006203870525934834`", 
      "0.06060062410288313`"},
     {"80", "0.000014502917360336994`", "0.0005330576109715763`", 
      "0.05454209272983337`"},
     {"90", "0.000012468887332037086`", "0.0004582605488244887`", 
      "0.04932682836404875`"},
     {"100", "0.000010725800611588964`", "0.0003941668039725657`", 
      "0.0448340855087847`"},
     {"180", "3.283151333768712`*^-6", "0.00012056511807988126`", 
      "0.025175384446095576`"},
     {"200", "2.458809465202485`*^-6", "0.00009027159119275192`", 
      "0.022882061076483187`"},
     {"300", "6.203085665906425`*^-7", "0.00002272619656667014`", 
      "0.01729544952709261`"},
     {"400", "1.9660646331899808`*^-7", "7.167944690426014`*^-6", 
      "0.01541852316166035`"},
     {"500", "9.45594752289042`*^-8", "3.424069108960147`*^-6", 
      "0.014427853268643695`"},
     {"600", "6.746981506538676`*^-8", "2.432443392030541`*^-6", 
      "0.013674158903867424`"},
     {"700", "5.826922924099844`*^-8", "2.097391213967327`*^-6", 
      "0.013003893880026205`"},
     {"800", "5.3517199393227326`*^-8", "1.9254617804077645`*^-6", 
      "0.012379086948985837`"},
     {"900", "5.000050819758084`*^-8", "1.7987130249892397`*^-6", 
      "0.011789194001350672`"},
     {"1000", "4.693584441421082`*^-8", "1.6884046565355774`*^-6", 
      "0.011230316544441801`"},
     {"2000", "2.574941305352716`*^-8", "9.262206692114487`*^-7", 
      "0.00698350566225262`"},
     {"3000", "1.4579498675429931`*^-8", "5.244090949828851`*^-7", 
      "0.004413192705097496`"},
     {"4000", "8.501800419380145`*^-9", "3.0578804933265345`*^-7", 
      "0.002823842683625037`"},
     {"5000", "5.090944899564496`*^-9", "1.8310161743070668`*^-7", 
      "0.0018239796618316636`"},
     {"6000", "3.118693097524763`*^-9", "1.1216391154805624`*^-7", 
      "0.0011864439718818748`"},
     {"7000", "1.9466626545409515`*^-9", "7.00100632813463`*^-8", 
      "0.0007757463414491161`"},
     {"8000", "1.2333744329808253`*^-9", "4.435640000454104`*^-8", 
      "0.0005091364326072674`"},
     {"9000", "7.905520775382741`*^-10", "2.8430557393239727`*^-8", 
      "0.00033507634220432484`"},
     {"10000", "5.112008339964744`*^-10", "1.8384066119911188`*^-8", 
      "0.00022096371476369318`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992825331757565`*^9, 3.417836037594455*^9, 
  3.4798277984498367`*^9, 3.479828474455843*^9, 3.479829344416993*^9, 
  3.4798296666390915`*^9, 3.5185351485949497`*^9, 3.6434437799135847`*^9},
 CellLabel->"Out[161]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[162]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVz3k4lesaBvA1KOP3WR9fWRpkDCsZykHY3pcylC1ap1AqJRrsrNK8hZCS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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwVjHk01Iv/h2elqGEY3WmRvRuVJaWy9HkrouiSSkIUolVRyk2UImQ7uZXK
TVl+JZlJQim8JzOGMZayhVRu1rJNdtm+fn+8zus85znnUfM443CUQiKR7s/v
/79p3YUNVf6Xt2YHrHS71kHnBXu49ySwnQlbjSDHrs903q1JAcWZfYJYtFQy
tquOzlteOh5vxr5ExOlNGi4pofPadG456rFvEtXYX5X7iM4r+fJly2r2A+KX
OKaK5ULnGW4Ke67JziTOhpvFBdbSeH2eBzrU2W+JDUcbdVIFVN5v6o5CloGY
GBfKhty+ReZ9Ty1yZBrWE/erttDsds+hg1LqlG9WCyHdr/30Z/0U7r6hOafe
3EY4tapK+fpMYHvRVh2magfxQ+HGYGbYKHZtMqaZcrqJgG/hmWveDCH3gfOG
Wu1eotbztcLanRL0KTBnnDwxQNz0Phu5LK4PrRaH2zyekBDdzz/tkn7bg3VJ
lV6LkocItXFldYWkTnyfvEpb12SE6H0cEnJz4Dt2bftl4Ts1SrDDs36fPNmG
VMtHeS8ejhN+BtpFCtWteKCnKFjOc5Io2+I2lirfjItJgxJN1Sli4T/HRaOj
DdixR842ZdUU8Y7LCHPpbcC3aXpPlddNETu1o9XK2xrwmNXZQ0uMpwhSpNtE
nrgBS+J+iaT3TRGTh+lF7SkNGKg8kvozYoqgP5ltD7Ob7xlP7ssenCKYDBlq
+Yt6LAygFpjgNNEb83gu43odsm+GxloIpwkfpefW/X/X4bnkuSO7q6aJR1bP
RZvP1qFO2ZSM++dpok2kcbTTtQ7vsUdcr41PE9T9Xg9vG9VhwLsOkkhvhjjO
Z45Y9daiLllo7fh4huj2l73z42AtpsRENp0NnSWM3PY6Otl8xPO6zjnkyFlC
vfBPRtP2j2j9YU1MQtwsQf9su+eQ6UccUKwhcpNmCR3+sG/guo9omqT0dDxv
lpCayC+SyH3EpmepASE/Z4nWrnGX7oYPKF9WqBCzd47YQqxybjn6AXlXA5/U
KZDgYOJCVrxODfatl7f3WEKCrJ/vUF25BtmdTyclS0kQ3BU28F6uBv12frJl
qJEgyHHsnfpoNaorGA1b65GA82HU6zSvGq+nDRPFNiTQ6EUftYPVuEPo25wR
RgJJlcKqpoQqFMseXRQyRoJMSOarr6rEtu8OatOTJFAYJJcmLq/EkQIwujRD
goqUBW5LmJW48tiKwxdoZHClPyD0p8XoL6h75atAhmgVQ+XGWjEuC97m4q5L
BkHTwlWdoWI8PqCSCd5kOBdqc7e7qwKlP7ZYURvJ4Lh8dfwmsQibfP3dLZvJ
cIlZaHGOL8KMRTIXI1rJcPuZilz+OxHust7yRLadDD7tZ2vss0QYh4k0loQM
ha+//d0SK0Il7r73mjIUIAzU9ho7iFAjutp4x1YKCPzSKbJt5Tiy2tsh0pwC
FvI6OqrN5SgQzhyvsKDAnhmbGpPacvSmrLv/lw0FpOZCr9wQlGPm39Hjjk4U
WCuKGj72rBwNjlnn+vhTwExqboHb+XIkLEvWRT2hgOe+Kz3djHJ0ECy4xsyk
QFjDhivEgvnedrvG+xwKvM3wpieTyzHGvDUkM5cCNwatys+MlGGL2ViNuIQC
QRKXq0dbyvC8kY4/4xsFJlTGg28/LcNnfybk//MHFQYPGP9o3FGGhU+aZFYs
p8IhycNWknkZftBScU9fSYVi2TySgUkZjmlkSedpUeHlLWt+ml4ZWqgKnRoN
qfDPZpeYWnYZfmX//s22p8L9865U+z4hKsp4EMmR877hsmtKohC/2znc/RlN
hQRJ483WBCHm3NnWbxRPhb6164NWxAnRXk0jqeYOFW5pUOMzw4QYu7ljjJRG
hZDgRXOzfkKU9vHmehZRIccxpD1stxCn+CeUtYeoIGuWJtMhLcT24HNTr1xo
UNwWyR6ILMV/ewqKBt1oEPnKYcgqvBT37SVdXeNBg7pwiuX/hZaiYHUsLe0Y
DVxuBFmcuFSK6XVPFicE0MCwm7FZ+VQpemm3qJyNp4Gbfo2Thn0pdtSDxVo+
Deg2xvK3l83zGkZsug4diOiNL7TfCPDrRWrMKl06SK70G1LzBNjMn7iZYUCH
5P02T769FGC1S3tk1mY6fA3SNU95LsA30W/CcnfQobdJVLnjkQCjez0uCzzo
cH3Tf7p/RAhw/fPXJzse0EGr0/Uwx0mAV3WO7NKUlQI5/spdhRQBGpmRbE8w
pCBh6anvB0kC7Ld7tDubKQUpazewJ2f46Bzwxd6ULQX/KmfamU7y0ZB38MA+
LSlQMh+/2zDIx679Dl5hhBQERaU12n/ho23o9pCOc1Iwnfhg9f4CPi5t0spJ
b5WCC9mGwrHzfNzdmGqZi9JwPKreQbqvBHMYz7jJyQuA9lsz996pEmSNqZZE
+S6ECrOD//0efY9M3T1kmr0MKHwWPU7xe48ySsM/Q9RloUJT3Jou4eFGo5WZ
9RJZqH8ZVLr/FA+nnpLvFHxYBKo1gxQiC7Go3FHnUcpiWH8kqXRLZDEuM/bq
VQxjALP08dgpKMLzzu2OUQfkIF//l2cBvRCvtIyKTynKg0GxZb6z+C0q6Dte
a70uDyvDe77y/QtQ49BgbGWfPNR13Wr6of8GQ3O89MLcmHC57rUKfsrHifRk
E+1qJgSGZFfkxeRhvy/z4V9GCrDouHkkzyMX9Y8cvm3yVAHOHDDRT9d7hb90
etoy5BWBL46xu66Rg+JbG+5RAxXhga3qMNPgJQ6pHurU6lGEgP1pg0nbszEx
ojii3J4FUvTPHM4cFwNdz2CSAwsirtxY/NckF50NVMd997Hgz52bLgwNcXHl
51BvJScW6J4o8bTq4mK6rqWlhzsLFO378tWquJjTIKZMn2bBt2G/M/eSuFip
0RysF80CyC/QjDfhInciKo8Sy4I4mcMz2Ru5GF9l3N8Qx4JQz4/fG/W46HDx
X9fLCSx4dqapTleTi80V7iai+yzo0eyzkVvMxS6/rgmPDBY0kTZdTPjGwfId
ifpGmSyoYLYwRps5mLnc+tjCLBZ0lkiyXeo5eLr02acXL1gQph6luFHEwRH2
6fzpfBYMV0zvYr/iYGO/8kDNm/n+lRndJA4HX5dUa6W9nee4zcvVMzh46ZT+
nZ3FLFjIWCJr+pCDrub/Va7gsYAbR2fUJHJw65IEmuQ9C6JHP/zhncBB1d5t
pnw+C7pNlq4mx3KQzBs+d7eUBQE+IVsfR3Dwf7w0u3Y=
        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -4.880824841261099}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-4.880824841261099, 0.38079276494170056`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992825359752984`*^9, 3.41783604048508*^9, 
  3.479827800387436*^9, 3.479828476174472*^9, 3.4798293460575867`*^9, 
  3.4798296683268185`*^9, 3.5185351497824726`*^9, 3.6434437802104626`*^9},
 CellLabel->"Out[162]="]
}, Open  ]],

Cell["These  values are the same that Table A.8.15 of ICRP 78 ", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsubsectionIcon"],

Cell["For f1 = 0.2 , and Radium-226, T = 1600 y ", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"lambda", " ", "=", " ", 
   RowBox[{
    RowBox[{"Log", "[", "2", "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"1600", "*", "365.24"}], ")"}]}]}], ";"}]], "Input",
 CellLabel->"In[163]:="],

Cell["\<\
Values for daily excretion are the same that Table A.8.7 of ICRP 78 \
\>", "Text"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[164]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.0029275980733061277`", "0.26360792606216193`", 
      "0.73346328974929`"},
     {"2", "0.000572085478181204`", "0.3542747273598251`", 
      "0.37861560693929625`"},
     {"3", "0.0003736693209795124`", "0.1862851296305703`", 
      "0.19195635890600424`"},
     {"4", "0.00026050609768359014`", "0.08418859966639615`", 
      "0.10750702545956149`"},
     {"5", "0.00018252458070997792`", "0.03802979056555331`", 
      "0.06929458279757675`"},
     {"6", "0.00012867019757688562`", "0.01829399937075381`", 
      "0.05087183103788526`"},
     {"7", "0.00009146518868856673`", "0.00965729419716876`", 
      "0.04112301131217379`"},
     {"8", "0.0000657502702621027`", "0.005616231646754783`", 
      "0.03544098061852642`"},
     {"9", "0.000047965114731681836`", "0.003546965425483854`", 
      "0.031846008041223624`"},
     {"10", "0.00003565279018561885`", "0.0023851262127074987`", 
      "0.02942519126529499`"},
     {"20", "7.992752326439548`*^-6", "0.00031584489477438796`", 
      "0.022184580232298513`"},
     {"30", "6.317795828878543`*^-6", "0.0002328393081787055`", 
      "0.019532463510526395`"},
     {"40", "5.421812059285841`*^-6", "0.00019935498192532542`", 
      "0.01733682386349135`"},
     {"50", "4.666666172491147`*^-6", "0.00017156466038598125`", 
      "0.015449539211787775`"},
     {"60", "4.0190599849695875`*^-6", "0.00014774446012738582`", 
      "0.013824712202061289`"},
     {"70", "3.46312536718466`*^-6", "0.00012729792108442974`", 
      "0.012425074562581198`"},
     {"80", "2.985641360372964`*^-6", "0.00010973799167238933`", 
      "0.0112187892524513`"},
     {"90", "2.5753378023563216`*^-6", "0.00009464977201878821`", 
      "0.010178603291165033`"},
     {"100", "2.2225953609829464`*^-6", "0.00008167917427622736`", 
      "0.009281173757470894`"},
     {"180", "6.984088665790763`*^-7", "0.00002564728338731144`", 
      "0.005346704581550181`"},
     {"200", "5.264871859833587`*^-7", "0.000019329250395864146`", 
      "0.004890983624034109`"},
     {"300", "1.372288154680518`*^-7", "5.027669700215801`*^-6", 
      "0.003818660536257453`"},
     {"400", "4.492269724317135`*^-8", "1.6378254888152552`*^-6", 
      "0.0035175347780306548`"},
     {"500", "2.231031974879129`*^-8", "8.078820017961458`*^-7", 
      "0.00340143382132337`"},
     {"600", "1.644253171485214`*^-8", "5.927942170346803`*^-7", 
      "0.003331491239480215`"},
     {"700", "1.4672344137302227`*^-8", "5.281293410186315`*^-7", 
      "0.0032741045383609052`"},
     {"800", "1.3925560542306788`*^-8", "5.010192115446005`*^-7", 
      "0.0032209920514936754`"},
     {"900", "1.3445276854456975`*^-8", "4.836790280626209`*^-7", 
      "0.0031700585585097392`"},
     {"1000", "1.3043090339408615`*^-8", "4.6919397077165547`*^-7", 
      "0.0031207383361006326`"},
     {"2000", "9.94177396164935`*^-9", "3.576111263866916`*^-7", 
      "0.002696255751671355`"},
     {"3000", "7.820966812321406`*^-9", "2.81311878446471`*^-7", 
      "0.0023673530410927976`"},
     {"4000", "6.336511629749092`*^-9", "2.279081428092851`*^-7", 
      "0.0021046187366312455`"},
     {"5000", "5.271806575832711`*^-9", "1.8960651421876325`*^-7", 
      "0.0018887563101082745`"},
     {"6000", "4.486996722423083`*^-9", "1.6137500234268834`*^-7", 
      "0.0017069717521469457`"},
     {"7000", "3.8913129112492175`*^-9", "1.3994775292696758`*^-7", 
      "0.0015506797702526938`"},
     {"8000", "3.4254924797785036`*^-9", "1.23192528590397`*^-7", 
      "0.0014140342738556935`"},
     {"9000", "3.0505729406203433`*^-9", "1.0970749648347926`*^-7", 
      "0.001292983459937678`"},
     {"10000", "2.740725397635828`*^-9", "9.856337012992248`*^-8", 
      "0.0011846598157421889`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Urine\n24 hours", "Faecal\n24 hours", 
       "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282536538335*^9, 3.417836041031955*^9, 
  3.4798278028094344`*^9, 3.4798284768619237`*^9, 3.4798293467138243`*^9, 
  3.4798296690456653`*^9, 3.518535150001227*^9, 3.643443780397964*^9},
 CellLabel->"Out[164]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[165]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV03k8lekXAPC7mOwmvK/3vaWyVcNki6SU56Hso+XWILSgxchVIm0YGSUh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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwVlmk8FGwfhWcMkqXQ0LSQJZWdFB7FfVe2EEIUSSEtorJUeipb9qUilKIZ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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -6.9283922679213905`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-6.9283922679213905`, 0.6181921981527801}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992825400103927`*^9, 3.41783604461008*^9, 
  3.4798278048407884`*^9, 3.479828478861783*^9, 3.4798293486669116`*^9, 
  3.4798296709834256`*^9, 3.5185351511731243`*^9, 3.6434437807260923`*^9},
 CellLabel->"Out[165]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsubsectionIcon"],

Cell["Class M, AMAD 5, Radium 228 (T = 5.75 y)", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"lambda", " ", "=", " ", 
    RowBox[{
     RowBox[{"Log", "[", "2", "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"5.75", "*", "365.24"}], ")"}]}]}], ";", 
   RowBox[{"amad", "=", " ", 
    RowBox[{"AMADAdultW", "[", "5", "]"}]}], ";", 
   RowBox[{"class", " ", "=", " ", "M"}], ";"}], " "}]], "Input",
 CellLabel->"In[166]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[167]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Lung\\nretention\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.05760658352347845`", "0.0015798608839010981`", 
      "0.10590242779515849`", "0.4977930332453003`"},
     {"2", "0.055895856591397584`", "0.0003109063061113542`", 
      "0.14715687916806108`", "0.2714503355431889`"},
     {"3", "0.05493142078196172`", "0.00020590113605798867`", 
      "0.07958527649364773`", "0.16262310644042674`"},
     {"4", "0.05408491790958464`", "0.00014592870791879452`", 
      "0.03731905659656303`", "0.11445915547118106`"},
     {"5", "0.053271311348348706`", "0.00010480423079488801`", 
      "0.01781026378732285`", "0.09259141939192603`"},
     {"6", "0.05247866465431829`", "0.00007640066541246694`", 
      "0.009263635501042412`", "0.08178109155436221`"},
     {"7", "0.05170489684909112`", "0.0000567448279149182`", 
      "0.005400733077455348`", "0.07576714942084264`"},
     {"8", "0.05094926820423875`", "0.00004312122516769545`", 
      "0.00351863395460029`", "0.07198567008879635`"},
     {"9", "0.05021123363204422`", "0.000033659895594683474`", 
      "0.002511075200288395`", "0.06934556777439305`"},
     {"10", "0.049490287887800154`", "0.00002707125080569675`", 
      "0.0019206109331596536`", "0.067348663975156`"},
     {"20", "0.04312072420434276`", "0.000011368230477850213`", 
      "0.000717504399179355`", "0.05715489098796204`"},
     {"30", "0.03800858155465973`", "9.525370608437623`*^-6", 
      "0.0005682614135355186`", "0.050606157752624996`"},
     {"40", "0.033848540756050045`", "8.28678396340951`*^-6", 
      "0.00047031709319394284`", "0.04523679779231105`"},
     {"50", "0.030415176592872156`", "7.270699227110408`*^-6", 
      "0.0003941680606101677`", "0.040748073676463034`"},
     {"60", "0.02754136747579874`", "6.423777023186495`*^-6", 
      "0.000334064861565519`", "0.0369518233601867`"},
     {"70", "0.025102657536278595`", "5.711168877660378`*^-6", 
      "0.0002861443235936006`", "0.03370626078937989`"},
     {"80", "0.023005904493266803`", "5.106276629093365`*^-6", 
      "0.0002475440581713628`", "0.03090315661043892`"},
     {"90", "0.02118101926007158`", "4.58854308703667`*^-6", 
      "0.0002161261664811646`", "0.028459285222625957`"},
     {"100", "0.01957494044935525`", "4.141956441810119`*^-6", 
      "0.00019028559907031985`", "0.026310160433238916`"},
     {"180", "0.011236521958393801`", "2.047482263408035`*^-6", 
      "0.00008504654456407759`", "0.015406468674916286`"},
     {"200", "0.009881795797308702`", "1.7540880212319874`*^-6", 
      "0.00007221171294426157`", "0.013711065912459934`"},
     {"300", "0.005286143682676789`", "8.651795174559083`*^-7", 
      "0.0000350964948275177`", "0.008160856269753028`"},
     {"400", "0.0028525475382500188`", "4.535874789563657`*^-7", 
      "0.00001835990069558334`", "0.005313964444936788`"},
     {"500", "0.00154293459786079`", "2.4526132137046875`*^-7", 
      "9.903334572938261`*^-6", "0.00376949065435496`"},
     {"600", "0.0008358468427295302`", "1.3563229492713777`*^-7", 
      "5.45369952278523`*^-6", "0.00289980589130381`"},
     {"700", "0.0004534676198132631`", "7.685134209785723`*^-8", 
      "3.0705784034898823`*^-6", "0.0023900401838967307`"},
     {"800", "0.0002463935173495431`", "4.4984919276897525`*^-8", 
      "1.7813174057262578`*^-6", "0.002075350060385751`"},
     {"900", "0.00013409268097374746`", "2.7550296012891822`*^-8", 
      "1.0780127357346332`*^-6", "0.0018678312988419585`"},
     {"1000", "0.00007309761221440993`", "1.7908487819708393`*^-8", 
      "6.905971778710613`*^-7", "0.001720168161446426`"},
     {"2000", "1.8787152623557294`*^-7", "3.806947831350557`*^-9", 
      "1.370273760302774`*^-7", "0.0010199979738794761`"},
     {"3000", "5.902535126965417`*^-10", "2.1369547942926474`*^-9", 
      "7.686431928425588`*^-8", "0.0006440879267610419`"},
     {"4000", "2.1878831822469196`*^-12", "1.2446494243212783`*^-9", 
      "4.476693313929023`*^-8", "0.00041194933536360206`"},
     {"5000", "8.966051631965888`*^-15", "7.445546817478796`*^-10", 
      "2.6778791693495144`*^-8", "0.00026600018949957067`"},
     {"6000", "3.8650942051589675`*^-17", "4.5572549373311853`*^-10", 
      "1.6390202520148995`*^-8", "0.0001729834636711362`"},
     {"7000", "1.7066230350786618`*^-19", "2.8426555404301153`*^-10", 
      "1.0223377522338328`*^-8", "0.0001130837960455111`"},
     {"8000", "7.626152789874594`*^-22", "1.800094592770183`*^-10", 
      "6.473765709016792`*^-9", "0.00007420939422436113`"},
     {"9000", "3.4314625560470915`*^-24", "1.1533260276731651`*^-10", 
      "4.147698804252758`*^-9", "0.00004883462322851619`"},
     {"10000", "1.5516119776749065`*^-26", "7.455527981157511`*^-11", 
      "2.68119619915586`*^-9", "0.000032201460563181836`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Lung\nretention", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282551689988*^9, 3.41783605601633*^9, 
  3.479827816700771*^9, 3.4798284909546814`*^9, 3.4798293605416837`*^9, 
  3.479829682906903*^9, 3.5185351596732874`*^9, 3.643443783569912*^9},
 CellLabel->"Out[167]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[168]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVxX081HccAPBzp2uRi/Nt3fV4hOX5WmI53efLuqQyskYviRGmPNQqm5cX
lTwlybQUWS4yT/PQFGHx+0VeE9KDyFkeQp4fjuN+53nbH+/XW8vrjJMPnUaj
2f/n/9uNfzJ7eS5M6HRMmbPHlUmGe3kM3eS4wu5UOaHnwiST5p7TXTmnYYkz
642OMslNdVTiXk4ofOHCzp60Z5I9BknOppxrkCgoUs62ZpI1nZ17dnDuwmhu
4JdsfSa5yyLqDx1OPjwZZh4YolaRYydd+rU5lZDb/evG+ORV5Dxj/1O0sxEE
v1jbbSCVyd7MKmeNXe8g56z3g+sKBum0PnMhqKADNpj5sh+aMUj7GJ0VbUkP
nIs8ZDfjQSf7qoQGGrx+0PefX9ZPVSIHLCyVrQoH4YlKmXHIMxpZdNfV7K3+
KGzIUvKRdawQP1RYs/xPT0DIrfvBPIdlwlYt+tB9hRQKnVF0QcYi0ZLW5L02
fRqqZq38C9QXiGfpevomghnQco0mM2PniAGbqX1BC7Pgt+ITH9xJEQyRuLT4
HgXaLdvkQkc54TJUFb7u5BzEThfLvTNnCDXapFSHtwBSPS3xiaVp4mkwo0JA
LMLM7+OGjcFTRMb1q+1nI5bBZjqKzro3SZCXQ7Jb2DSs2MFa4V4bIxpVfdZe
lNNw/4G2U6f3DBOr33TYMtqUcNR4DK9r8RMBohrjuGw6xkuGVO5iL6Gp4gXp
Vxl4Gcq8DSK7ib7w8wuPjivjCw42k0MxEqLfkJWQZbAK21YnitxKW4jLBp4H
dVSZGCVrJQ0NNxDcdt2SrA9MXPS62iinqpqwb8sUPSZWY4v9b9mgnkKUsPKK
0tM/ww4SYXzcxJ+A5LyauKA1uLRlxBHN14KGyRElZUcV/ChB5F/+1ytQWS8b
uaitilvNPIz6bVpht/nW/HdSVRyz93oWN7gDFnKUkiter8WhE+bfRSx2Q1W9
s4E4Qw2n1LsblUb1wkZL71HNKBYuERep5+78BBdc+5zjXNbhN9QlcWnGIFzq
mG0M0FTH3x4+0u0jHwY23/nKh0h1vOAelsYNGIPtJyYTmsbUsUYg46v32RMQ
UeJtGuWugcdGort0L0lBkZUu0G/WwHxJ/NyVtCkYD9K49405G6es+EqL0qaB
7/n9LUEOG1s/rgu1ypHBlMFQT666JlZlZZRvuTMDjUlmKYwQTXzUZMQ4O2QW
pnknPukOaeK8cIdIrpcc7sRWx9Y7IlzjYtvTx6cgxO0MkeaEsHNxqqmvGQWu
O3lU0FGE86aweNCCgq3/RPiuP4bwslpd16CQgiwTkcjLA+EXwm2SzsMUlLQ2
0hcDES49WHFD7EdB03ZJuGk8wiLNh7dDxBQUKeJK6QkIb+M3J3RlUpD40nK8
9QbCdUvv0r/OpsDp59/cwm4i3FzToKZaSIGkwUPwIhXhv4/f5iZWUjDw44DC
KxfhU36hlf6tFNTvv8M3z0e4Mi3AoradgvxNB/zWFCC8N3SugfuBgsC6vPfF
xQjzxtR2P++lYIYTWLZYhvAmmd06lpSCtvEtE6/KEa7QsxS4yyh4UtOs+6AS
YVUhN6xQTkFoAD/ZrhphT8+XArslCtysPzZtJhHepzCvTKYpQPj5TWXpM4Tn
r5Yf/shQAG/Uxqq2FuEJ2CwzXK0AJVJ2/nYdwv1gVBisooB/AW2dVwA=
        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwVz3s4lHkbB/BxyMZgDU/P88wz1kqUGZtz8qb6/WpTqtVBwoosEavQqnXo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        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVlXk01P0Xx2cMlVEYhqYSsjxlsqVQKp+Pimh/JJXImsdTEUk7UdZE8VRC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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -7.711283945520008}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-7.711283945520008, 2.3401752291536266`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Lungs\"", 11, StripOnInput -> False], 
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282595141893*^9, 3.41783610070383*^9, 
  3.479827832529706*^9, 3.479828506641077*^9, 3.479829378619461*^9, 
  3.47982969806519*^9, 3.5185351690640926`*^9, 3.643443787241776*^9},
 CellLabel->"Out[168]="]
}, Open  ]],

Cell["These  values are the same that Table A.8.14 of ICRP 78 ", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Lead", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Model", "SubsubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompartNumbers", "[", "lead", "]"}]], "Input",
 CellLabel->"In[169]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "\<\"Plasma\"\>"},
    {"2", "\<\"RBC\"\>"},
    {"3", "\<\"ST0\"\>"},
    {"4", "\<\"ST1\"\>"},
    {"5", "\<\"ST2\"\>"},
    {"6", "\<\"Cortical Surface\"\>"},
    {"7", "\<\"Cortical Volume Exch\"\>"},
    {"8", "\<\"Cortical Volume Nonexch\"\>"},
    {"9", "\<\"Trabecular Marrow Surface\"\>"},
    {"10", "\<\"Trabecular Volume Exch\"\>"},
    {"11", "\<\"Trabecular Volume Nonexch\"\>"},
    {"12", "\<\"Liver1\"\>"},
    {"13", "\<\"Liver2\"\>"},
    {"14", "\<\"Kidneys (Urinary Path)\"\>"},
    {"15", "\<\"Other Kidney Tissue\"\>"},
    {"16", "\<\"Sweat\"\>"},
    {"17", "\<\"Bladder\"\>"},
    {"18", "\<\"Urine\"\>"},
    {"19", "\<\"ULI\"\>"},
    {"20", "\<\"LLI\"\>"},
    {"21", "\<\"FEC\"\>"},
    {"22", "\<\"SI\"\>"},
    {"23", "\<\"ST\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.399282595232229*^9, 3.41783610079758*^9, 
  3.4798278326547127`*^9, 3.4798285068285637`*^9, 3.4798293802288055`*^9, 
  3.479829698221461*^9, 3.5185351690953436`*^9, 3.643443787273027*^9},
 CellLabel->"Out[169]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"TransferRatesE", "[", "lead", "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<From\>\"", ",", " ", "\"\<to\>\"", ",", 
        "\"\<Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\>\""}], "}"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[170]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"From\"\>",
       HoldForm], 
      TagBox["\<\"to\"\>",
       HoldForm], 
      TagBox["\<\"Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\"\>",
       HoldForm]},
     {"1", "2", "28.`"},
     {"1", "17", "1.75`"},
     {"1", "19", "0.7`"},
     {"1", "9", "4.86`"},
     {"1", "6", "3.89`"},
     {"1", "12", "4.9`"},
     {"1", "14", "2.45`"},
     {"1", "15", "0.0245`"},
     {"1", "3", "22.16`"},
     {"1", "4", "0.7`"},
     {"1", "5", "0.14`"},
     {"1", "16", "0.42`"},
     {"2", "1", "0.139`"},
     {"6", "1", "0.5`"},
     {"9", "1", "0.5`"},
     {"6", "7", "0.5`"},
     {"9", "10", "0.5`"},
     {"7", "6", "0.0185`"},
     {"10", "9", "0.0185`"},
     {"7", "8", "0.0046`"},
     {"10", "11", "0.0046`"},
     {"11", "1", "0.000493`"},
     {"8", "1", "0.0000821`"},
     {"12", "1", "0.0312`"},
     {"12", "22", "0.0321`"},
     {"12", "13", "0.00693`"},
     {"13", "1", "0.0019`"},
     {"14", "17", "0.139`"},
     {"15", "1", "0.0019`"},
     {"3", "1", "7.39`"},
     {"4", "1", "0.00416`"},
     {"4", "21", "0.00277`"},
     {"5", "1", "0.00038`"},
     {"17", "18", "12"},
     {"19", "20", 
      SubscriptBox["k", "ULI"]},
     {"20", "21", 
      SubscriptBox["k", "LLI"]},
     {"22", "1", 
      RowBox[{
       SubscriptBox["f", "B"], " ", 
       SubscriptBox["k", "SI"]}]},
     {"22", "19", 
      SubscriptBox["k", "SI"]},
     {"23", "22", 
      SubscriptBox["k", "ST"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"From", "to", "Tranfer Rates(\!\(days\^\(-1\)\))"}}]]]], "Output",
 CellChangeTimes->{3.3992825952623415`*^9, 3.41783610079758*^9, 
  3.479827832685964*^9, 3.4798285068754354`*^9, 3.4798293802913046`*^9, 
  3.479829698268342*^9, 3.5185351691422195`*^9, 3.643443787288652*^9},
 CellLabel->"Out[170]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "element", ",", " ", "lambda", ",", " ", "fn1", ",", " ", "amad", ",", " ", 
   "class"}], "]"}]], "Input",
 CellLabel->"In[171]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"element", "=", " ", "lead"}], ";", 
   RowBox[{"lambda", " ", "=", " ", "0"}], ";", " ", 
   RowBox[{"fn1", " ", "=", " ", "0.2"}], ";", " ", 
   RowBox[{"amad", "=", " ", 
    RowBox[{"AMADAdultW", "[", "5", "]"}]}], ";", 
   RowBox[{"class", " ", "=", " ", "F"}], ";"}], " "}]], "Input",
 CellLabel->"In[172]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[173]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.04651935769264104`", "0.005538628583531824`", 
      "0.9479420137238217`"},
     {"2", "0.011661037240782601`", "0.0077881145100081595`", 
      "0.9284928619730312`"},
     {"3", "0.010684926139925444`", "0.006281123191784643`", 
      "0.9115268126413212`"},
     {"4", "0.010107171689933636`", "0.00523472897711208`", 
      "0.8961849119742754`"},
     {"5", "0.009645503518712184`", "0.0047331130415518285`", 
      "0.8818062954140116`"},
     {"6", "0.009240939945305227`", "0.004505762296485194`", 
      "0.8680595931722213`"},
     {"7", "0.008869754656513629`", "0.004393894396333087`", 
      "0.8547959441193745`"},
     {"8", "0.00852191562490845`", "0.004325918846166732`", 
      "0.8419481096482994`"},
     {"9", "0.00819287672461061`", "0.00427222690423984`", 
      "0.8294830060194491`"},
     {"10", "0.007880309878981029`", "0.004221178393878866`", 
      "0.8173815177465893`"},
     {"20", "0.005451626185685454`", "0.0035821895597362152`", 
      "0.7139960470127731`"},
     {"30", "0.0039027957739350416`", "0.002877413244603999`", 
      "0.6366444284194861`"},
     {"40", "0.0028849998542822552`", "0.002266907762546594`", 
      "0.5782406879207908`"},
     {"50", "0.0021984441109847985`", "0.0017849996204097607`", 
      "0.5334682370981916`"},
     {"60", "0.0017242158637863492`", "0.0014201338743276004`", 
      "0.4984759524876661`"},
     {"70", "0.001389185321715558`", "0.0011486636579256249`", 
      "0.4705278519448537`"},
     {"80", "0.0011471355344409573`", "0.0009473660427885555`", 
      "0.4476995728823164`"},
     {"90", "0.0009682135547730009`", "0.0007972124212284049`", 
      "0.4286428324531424`"},
     {"100", "0.0008328026078408268`", "0.0006837869755653703`", 
      "0.41241234204162475`"},
     {"180", "0.00036565362948937086`", "0.0003058808970756999`", 
      "0.3332449255393373`"},
     {"200", "0.0003129218595969152`", "0.0002643084624951719`", 
      "0.32083859906385065`"},
     {"300", "0.00016057390280485584`", "0.00014008868958710619`", 
      "0.27908186801997`"},
     {"400", "0.00009590802738428106`", "0.00008295314933207121`", 
      "0.2559393562235428`"},
     {"500", "0.00006585256198063383`", "0.000054593961142337943`", 
      "0.2413384737131949`"},
     {"600", "0.00005049337166128376`", "0.00003961542503551352`", 
      "0.2309788625152001`"},
     {"700", "0.00004172798490005569`", "0.000031134390112000365`", 
      "0.22291257201027156`"},
     {"800", "0.000036127615843761784`", "0.000025949481361683957`", 
      "0.21620866274251618`"},
     {"900", "0.00003217494414568811`", "0.000022517916854009057`", 
      "0.21039448901472535`"},
     {"1000", "0.00002916193305793624`", "0.000020070020685401813`", 
      "0.20521315243070806`"},
     {"2000", "0.00001535117895630489`", "0.000010245154688934277`", 
      "0.17038751526195411`"},
     {"3000", "0.000010192697948177565`", "6.779638298474999`*^-6", 
      "0.14962265806911323`"},
     {"4000", "7.357314950197369`*^-6", "4.8871745582657056`*^-6", 
      "0.13521044637358304`"},
     {"5000", "5.545753879857007`*^-6", "3.680773272507487`*^-6", 
      "0.12457961707869511`"},
     {"6000", "4.32322936140539`*^-6", "2.867340981305838`*^-6", 
      "0.11643596744334314`"},
     {"7000", "3.4752035347820898`*^-6", "2.3033952362798427`*^-6", 
      "0.10999366239888514`"},
     {"8000", "2.8732015444135617`*^-6", "1.9032672654295535`*^-6", 
      "0.10474418622188603`"},
     {"9000", "2.4351454576826415`*^-6", "1.612275218363518`*^-6", 
      "0.10035107799521856`"},
     {"10000", "2.1075499131856246`*^-6", "1.3947963223640003`*^-6", 
      "0.09658898944584343`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282595939866*^9, 3.417836101469455*^9, 
  3.4798278335141315`*^9, 3.4798285077035017`*^9, 3.479829381135038*^9, 
  3.4798296990965786`*^9, 3.51853516970473*^9, 3.6434437875074034`*^9},
 CellLabel->"Out[173]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[174]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVz2s8lGkDgPEx4/Q8zjy109aULEKTQ8lxc98VtZsVr23HqRQatW0MW5vD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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAA2C12NM1yfD6GK/NqAK4YwH1iX+iS
GFo/p9Kz4q6pGMCR+cQCWhhqP6y5Z6hdpRjAG8X3jz0Yej9hGV0gvJwYwOAq
kVYvGIo/6aQ/3nyLGMDC3d05KBiaP2hvbMsOaRjAMzeEqyQYqj9cBKragCQY
wOxjV+QiGLo/eF7G4AWdF8D6A0a8FDHLP+RSs9bigRbA4qK9VhEz1D/4IiHK
OYoVwFIVovturNo/lAGHUxapFMBNhiT/ItngPxLjpDkqyRPA470+KhEg5D+1
am91ywoTwOY3OgQ8rec/ySC5VqBPEsCumlo00inrPzemPPitqRHAZ7lBDmtq
7j/rg/5XLR0RwEcNhUug+PA/QRq1f32SEMDTm8xkDJ7yP58voyH+GxDAwZ4m
KS479D9uARwsrWAPwOZC8URu+/U/1SkwdTeGDsADRZ+1r533PyVS54odxQ3A
V+i9fQ9j+T9gNUMg9/sMwA0A7/AkIPs/49fS77M7DMC8dQO5O7/8P5WSXR3h
igvAoYyI2HCB/j+MeV/iFswKwMCAeKbTEgBAGTCZiewZCsDLC2UMfvYAQGUq
AsItWAnAB9HaRwPWAUDpP8D+HJkIwD9Fwi2JpgJACUtSbETmB8ATCmI/nogD
QPRfZUUZJAfA431z+7NbBEAA0gW4Dm8GwOQrDo2kKgVA1d1LMFi+BcCAKmFK
JAsGQOFtKKwrAAXAGdglsqTcBkCRj+40z1AEwE3WokW0vwdA34/CwtaVA8Cy
Dqmunp4IQMiYWZc74gLAFPYgwoluCUA+WM/x/D4CwBEuUQEEUApA6IInQHCT
AcAKFfPqfiILQDty7Mkt+QDANTYeqtTwC0CCXAa/HWgAwPunAZW50AxA5W3F
NIek/7+9yFYqn6ENQMJ+oUwjnP6/Gjpk6xOEDkBfi0vlEI/9v3Ra41aJVw9A
BHlWONik/L9/2vXLbBMQQIn3691hz/u/EjBWgtyDEEDQ9eGIxPn6vyNd743M
7BBA8hZpv7JC+r+BsmQvhF4RQAZLYPoSjfm/+KSeOynOEUBrzOgfWur4v+1u
EZ1ONhJATeDa0Qpf+L8wYWCUO6cSQDW/isvp0/e/8Sro4KgQE0Bbv+2mr1v3
v8uRNJgDeBNA3cpHfJTt9r/yIF3lJegTQB5wsnmdffa/l4e+h8hQFED6oF7d
Whv2v3hcb7+bUhRARQh04bAZ9r9aMSD3blQUQMzP3lIHGPa/HtuBZhVYFEDS
i0F9tRT2v6QuRUViXxRAE5cq7RYO9r+y1csC/G0UQKPTWSLuAPa/zCPZfS+L
FEDc4UU97eb1v674ibUCjRRAYWOwu1Dl9b+PzTrt1Y4UQOG7laS04/W/Unec
XHySFEBjwo61feD1v9nKXzvJmRRAqst+0hTa9b/mceb4YqgUQNF+outWzfW/
yEaXMDaqFEBwKbMKwcv1v6obSGgJrBRAiHxekyvK9b9txanXr68UQMlFWOEB
x/W/9Bhttvy2FEDfdrVus8D1v9btHe7PuBRAJ1902SC/9b+3ws4lo7oUQFSK
fa2OvfW/emwwlUm+FED23UyRa7r1v1xB4cwcwBRAiKcCodq49b8+FpIE8MEU
QPU74hlKt/W/IOtCPMPDFECUJOT7ubX1vwHA83OWxRRAGnQBRyq09b+5bly5

        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -6.697476434744847}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-6.697476434744847, -0.3668408419360073}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, -6.4}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282598785469*^9, 3.417836104531955*^9, 
  3.479827835436105*^9, 3.4798285096721134`*^9, 3.4798293831662493`*^9, 
  3.4798297009874573`*^9, 3.518535171564141*^9, 3.6434437878824067`*^9},
 CellLabel->"Out[174]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[175]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.008795766635952135`", "0.23865760047089168`", 
      "0.7525466328931658`"},
     {"2", "0.0024490568238888233`", "0.30931830063975085`", 
      "0.4407792754295262`"},
     {"3", "0.0021623791328822944`", "0.15426752041627556`", 
      "0.28434937588036824`"},
     {"4", "0.002039719082568614`", "0.06391816496178768`", 
      "0.2183914918360119`"},
     {"5", "0.0019443560530374854`", "0.025164577381097314`", 
      "0.19128255840187705`"},
     {"6", "0.0018618522048318153`", "0.009991203394925666`", 
      "0.17942950280211953`"},
     {"7", "0.0017866166156580987`", "0.004253444459355396`", 
      "0.17338944172710596`"},
     {"8", "0.0017163063313331561`", "0.0021125145846704885`", 
      "0.1695606208111023`"},
     {"9", "0.001649876902440811`", "0.001315159098378954`", 
      "0.1665955848102825`"},
     {"10", "0.0015868077179261586`", "0.0010149856264348722`", 
      "0.16399379146592138`"},
     {"20", "0.0010970639257443793`", "0.0007189461131548933`", 
      "0.14311212485352903`"},
     {"30", "0.0007849277013680239`", "0.0005778331970846193`", 
      "0.12756381402301423`"},
     {"40", "0.000579911453971016`", "0.00045530069193466804`", 
      "0.11582674426758129`"},
     {"50", "0.0004416775853300914`", "0.0003584751779927564`", 
      "0.10683184163041881`"},
     {"60", "0.0003462330604440608`", "0.00028513062917509546`", 
      "0.09980435977560195`"},
     {"70", "0.00027883029534333387`", "0.0002305511031449048`", 
      "0.0941937534970749`"},
     {"80", "0.00023015305699253946`", "0.00019008109804465045`", 
      "0.08961274956366312`"},
     {"90", "0.00019418575643606606`", "0.00015989842231211443`", 
      "0.08579000231508767`"},
     {"100", "0.00016697652834277155`", "0.000137104640684841`", 
      "0.08253527838052156`"},
     {"180", "0.00007323397222137179`", "0.0000612573642106394`", 
      "0.06667242319871114`"},
     {"200", "0.000062667129822995`", "0.00005292718911978703`", 
      "0.06418787011003851`"},
     {"300", "0.000032147956115377574`", "0.00002804605340545399`", 
      "0.055826874898787016`"},
     {"400", "0.000019196470522078735`", "0.000016604313834288342`", 
      "0.051194121218334505`"},
     {"500", "0.000013177774067178044`", "0.000010925815084798438`", 
      "0.04827190528266633`"},
     {"600", "0.000010102610491381087`", "7.926933200999228`*^-6", 
      "0.04619892353748526`"},
     {"700", "8.347987042061494`*^-6", "6.229147382713629`*^-6", 
      "0.04458506292473775`"},
     {"800", "7.227138479840717`*^-6", "5.191344093652753`*^-6", 
      "0.04324390415509406`"},
     {"900", "6.436180582578693`*^-6", "4.504581730305213`*^-6", 
      "0.04208081127230748`"},
     {"1000", "5.833324205263557`*^-6", "4.01474226161512`*^-6", 
      "0.04104435300705072`"},
     {"2000", "3.070495644182797`*^-6", "2.0492063997328697`*^-6", 
      "0.03407839876880859`"},
     {"3000", "2.0386666567361045`*^-6", "1.356012633063966`*^-6", 
      "0.02992512556996227`"},
     {"4000", "1.4715406203343745`*^-6", "9.774866436039822`*^-7", 
      "0.027042517785711106`"},
     {"5000", "1.1092022466838158`*^-6", "7.361889120703277`*^-7", 
      "0.0249162463136161`"},
     {"6000", "8.646811772029112`*^-7", "5.734916800233247`*^-7", 
      "0.02328744513766755`"},
     {"7000", "6.950654969830466`*^-7", "4.606955284246553`*^-7", 
      "0.021998934716020095`"},
     {"8000", "5.74658130230582`*^-7", "3.806652947978967`*^-7", 
      "0.02094900441021278`"},
     {"9000", "4.870422417530343`*^-7", "3.2246377629436065`*^-7", 
      "0.020070357250970224`"},
     {"10000", "4.2151996627621396`*^-7", "2.7896589000191846`*^-7", 
      "0.019317920465371223`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Urine\n24 hours", "Faecal\n24 hours", 
       "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992825996135545`*^9, 3.41783610532883*^9, 
  3.4798278364361563`*^9, 3.479828510672043*^9, 3.4798293841974792`*^9, 
  3.479829701956338*^9, 3.518535171970399*^9, 3.643443788101159*^9},
 CellLabel->"Out[175]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[176]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVzXk8Vfkfx3HLcXFt995z4oaM5crYmWS76vslVJYxPBqMRJRqKpcyUxik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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV1Wk41Iv7BvBhkGxZRoesof6RrU2l9HxbiErZwkFEjnZZW6SyRYhKRZYU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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -5.723921172995176}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-5.723921172995176, 0.3449892911078897}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992826026398306`*^9, 3.417836108563205*^9, 
  3.479827840483212*^9, 3.4798285127968936`*^9, 3.4798293863693123`*^9, 
  3.4798297040972505`*^9, 3.5185351743766947`*^9, 3.643443788523038*^9},
 CellLabel->"Out[176]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[177]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Lung\\nretention\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "2.393726432015305`*^-45", "0.014803230216292096`", 
      "0.048868978591754986`", "0.5418029207649442`"},
     {"2", "0", "0.0037701141626904633`", "0.06417080602442532`", 
      "0.39509938730296473`"},
     {"3", "0", "0.003435914083655567`", "0.032732140765418055`", 
      "0.32995618629713175`"},
     {"4", "0", "0.0032487022984016567`", "0.014307991730928643`", 
      "0.3017401316917919`"},
     {"5", "0", "0.0030997595988179194`", "0.006384450132222455`", 
      "0.28833456234880417`"},
     {"6", "0", "0.0029695064285123474`", "0.0032725499597731494`", 
      "0.2806499183778432`"},
     {"7", "0", "0.002850115384859242`", "0.0020883891855106584`", 
      "0.27518071549371775`"},
     {"8", "0", "0.002738282087514421`", "0.0016391588667426932`", 
      "0.27060804154036555`"},
     {"9", "0", "0.0026325134507694803`", "0.0014638843528623768`", 
      "0.26643982153012835`"},
     {"10", "0", "0.002532048435095885`", "0.001389246983975162`", 
      "0.2624921041978276`"},
     {"20", "0", "0.0017515016628031344`", "0.0011503952294764086`", 
      "0.2292467569101272`"},
     {"30", "0", "0.0012537755460510919`", "0.0009241476110038865`", 
      "0.2043997044537939`"},
     {"40", "0", "0.0009267263782017365`", "0.0007280868904859794`", 
      "0.18563978911496098`"},
     {"50", "0", "0.0007061303118436196`", "0.0005732980541862803`", 
      "0.17125910231071045`"},
     {"60", "0", "0.0005537667114573624`", "0.00045609416953403675`", 
      "0.16002041362351674`"},
     {"70", "0", "0.0004461323781161791`", "0.0003688888933575246`", 
      "0.15104471332226266`"},
     {"80", "0", "0.0003683746679938593`", "0.0003042257082991606`", 
      "0.14371373523321318`"},
     {"90", "0", "0.0003109003286746598`", "0.0002559928978798781`", 
      "0.13759429636817772`"},
     {"100", "0", "0.000267405776132143`", "0.00021955959130771918`", 
      "0.13238269193273572`"},
     {"180", "0", "0.00011738784376828792`", "0.00009819733397736785`", 
      "0.10696532734852102`"},
     {"200", "0", "0.0001004576277623126`", "0.00008485008629516289`", 
      "0.10298250983062904`"},
     {"300", "0", "0.00005154681717202403`", "0.000044970571496553285`", 
      "0.08957766177796425`"},
     {"400", "0", "0.00003078675348873461`", "0.000026628412948894592`", 
      "0.08214867786896832`"},
     {"500", "0", "0.000021138105091730863`", "0.000017524449087116117`", 
      "0.07746180995028869`"},
     {"600", "0", "0.000016207517691400886`", "0.000012716076390313635`", 
      "0.07413648530768745`"},
     {"700", "0", "0.00001339375502485557`", "9.993571725857436`*^-6", 
      "0.07154734933834521`"},
     {"800", "0", "0.000011596044378770626`", "8.329196443609271`*^-6", 
      "0.06939554539050649`"},
     {"900", "0", "0.000010327273977588092`", "7.227675522282484`*^-6", 
      "0.06752934420131475`"},
     {"1000", "0", "9.360143453488595`*^-6", "6.441924431686841`*^-6", 
      "0.0658662776167436`"},
     {"2000", "0", "4.9272277010369014`*^-6", "3.288360990541875`*^-6", 
      "0.05468832303919205`"},
     {"3000", "0", "3.2715118690948564`*^-6", "2.176035085853928`*^-6", 
      "0.04802349400520156`"},
     {"4000", "0", "2.3614460439719265`*^-6", "1.5686156454603611`*^-6", 
      "0.04339766436021716`"},
     {"5000", "0", "1.779995190843292`*^-6", "1.1814009424921529`*^-6", 
      "0.03998553404590626`"},
     {"6000", "0", "1.3876058628670834`*^-6", "9.203164809531636`*^-7", 
      "0.03737170528250985`"},
     {"7000", "0", "1.1154182220814157`*^-6", "7.393089464530905`*^-7", 
      "0.035303950845371364`"},
     {"8000", "0", "9.221960486013869`*^-7", "6.108814684414876`*^-7", 
      "0.03361905406117425`"},
     {"9000", "0", "7.815950395610727`*^-7", "5.174829805004375`*^-7", 
      "0.032209022184538125`"},
     {"10000", "0", "6.764481675011758`*^-7", "4.4767975377474345`*^-7", 
      "0.03100152594956781`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Lung\nretention", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282611733715*^9, 3.417836117375705*^9, 
  3.4798278495611043`*^9, 3.4798285215462775`*^9, 3.479829397384726*^9, 
  3.4798297128796806`*^9, 3.5185351807205667`*^9, 3.643443790648058*^9},
 CellLabel->"Out[177]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[178]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJxTTMoPSmViYGAwAWIQfUO3zORsUY2dxVOZpoVVMgeMzVtWq0issofx3ySH
P1GS2AXn/2J22yNieBrOf7Rob5ig8RU4P0h00e+8NbfgfN82lf9KNx/A+Y/3
2mkJKjyB85+ZW7HYrH0O56+bFWVySfM1nJ++05EvO+sdnO/O2+q94McHOP/y
7DMpPPM+wfkH56lp6ll/QZjv9NEl7/dXOJ/Zdf7W9XO/w/nhL/bW8if/hPN5
Gd5/UFH4DefvKWXeab3/D5y/sKfjRkHjPzj/QEPFsstCDA4w/mnuVJ66bwg+
+8Vb7szXGOF8e9dDup3LmOB8Ya4k+3kdzHD+49ri35ujWeD8J9p8vUu0WOH8
Bq1ELxVuNjhf8obqpiV3EHzfa4tct+xnh/M38a1cN28eB5wv8k3hUGceJ5wv
qBfIyBLABedziX5+VafEDeebmsmtuvIBwf+9nHHqzgs8cP7eE2Fa8xfywvlS
VimvhVv44PySqMdhneH8cH79ra+nc4QF4Hwhg7CmO80IvnLs+94zbxD8xk0p
+i1xgnD+jyXzrDXPIfhv8wTn+pkJwfkGiQlTrJcj+B+1XjxYISCMiJ+JJjOY
KxD8TwqxT1VfIPjT2/e1nwgQgfPPKN+s1e9G8BkPfC6edhTBBwD83nXF
        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwVz3k41HkcB/DfHHIN5jvzU9OxPRK1rKulclTfbxYVSU0tmhS5ah3japes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        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV1Gk8lAsbBvBZLEUyGCVJJAlZWhVO96OIhJDoKHVoT4kjbadVRQrntEgU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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -7.690088944230677}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-7.690088944230677, -0.8461023745743992}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, -7.4}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Lungs\"", 11, StripOnInput -> False], 
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282624215222*^9, 3.41783613014133*^9, 
  3.479827860342078*^9, 3.4798285320299144`*^9, 3.479829723568617*^9, 
  3.518535189111353*^9, 3.643443793069954*^9},
 CellLabel->"Out[178]="]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
Model for thorium, neptunium, plutonium, americium and curium \
\>", "Section"],

Cell[CellGroupData[{

Cell["\<\
Biokinetic model for thorium, neptunium, plutonium, americium and curium \
(ICRP 78). \
\>", "SubsubsectionIcon"],

Cell["GI include ST,SI,ULI,LLI (not represented).", "Text"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@004TV<0@0006@000000000000005P1003l0000
00000000003c=@00NbL00215CDH00040S4TB00d000010000000000000000000080<005P200100@00
l000000000000000000004H0001L90T0CR@904M4BD<1002000<001TYN0h00000=R@900402@000a^B
1000006B100000@000030@P01@0000`2P_h:0PD0000;0P000001TP@0@@/P0<`0OP4:0P000022oPX2
000002P0000:0P00OP40004060000000`2<900000000000000000000003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo00000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool000000000
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooo`0000000000
0000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo0000
00000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`0000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooo0000000000000000000000000000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003oooooool0003oooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooool000000000003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooooooool000000000003oooooooooooooooooooooool00000003oooooool0
003oooooooooool0003oooooool000000000003oool0003oooooool0000000000000003oooooool0
000000000000003oooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000000000000000000000000000000
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooo`0000000?ooooooo`0000000?ooooooo`0000000?oooooo
o`000?ooo`000?ooooooooooo`000?ooooooo`000?ooooooo`0000000?ooo`0000000?ooo`000000
0?ooooooo`000?ooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000000000000000
00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooo0000oooooooooooooooooooo0000oooooooo0000
oooooooooooo0000oooo0000oooooooooooo0000oooooooo0000oooooooooooo0000oooo0000oooo
oooooooo0000oooooooooooooooooooo0000oooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000
0000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooool0003oooooooooool000000000003o
ooooool0003oooooooooool0003oool0003oooooooooool0003oooooool00000000000000000003o
ool0003oooooooooool0003oooooool0000000000000003oooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`0000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooo
ooooooooooooooooo`000?ooooooooooo`000?ooo`000?ooooooooooo`000?ooooooo`000?oooooo
ooooo`000?ooo`000?ooooooooooo`000?ooooooo`000?oooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo00000000000000000000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooo0000oooooooo0000oooo00000000oooooooo0000oooooooo
0000oooooooooooo0000oooooooo0000oooo00000000oooooooo0000oooooooo0000oooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0000000000000003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003oooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ool00000003oooooooooooooool0003oooooooooooooool00000003oooooool0003oool00000003o
ooooooooooooool000000000003oooooooooool0000000000000003oooooool0000000000000003o
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00000000000?ooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooo`000?ooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000000000000000000000000000oooooooo0000
oooooooooooooooooooooooooooooooo000000000000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0000000000000000000000000
00000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?ooooooooooooooooooo`000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?oooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooo`0000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
00000000000000000000oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003oooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00000000000000000003oooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?ooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003oooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?ooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
ooooooooooooo`000?ooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooo`000?oooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo000000000000
oooooooo0000oooooooooooo000000000000oooooooo0000oooooooooooo0000oooooooo0000oooo
oooooooo000000000000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooo000000000000oooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooo0000000000000000oooooooooooo00000000oooo0000oooo0000oooooooo
oooooooo0000oooooooo0000000000000000oooooooooooo00000000oooooooooooooooo00000000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo0000
000000000000oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooo0000oooooooo0000oooooooooooo0000000000000000oooo0000oooo
oooooooo0000oooooooooooooooooooo00000000oooooooooooo0000oooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo000000000000oooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooool000000000003oooooooooool00000
003oool00000003oool0003oooooool0003oooooool0003oooooool0003oooooooooool0003ooooo
ool0003oooooool00000003oool00000003oooooooooooooooooooooooooooooooooooooooooool0
003oooooool0000000000000000000000000003oooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooooooool0003oooooooooool00000003oool0003oooooool00000003oool0
003oooooooooooooool0003oool0003oooooooooool0003oooooool0003oooooool0003oooooool0
003oooooool00000003oooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooool0000000000000000000000000003oooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooool0003oooooool00000003oooooool0003oooooool0003oooooool00000003o
ool0003oooooooooool0003oooooooooool00000003oooooool00000003oool00000003oooooool0
0000003oooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000000000000000
00000000003oooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooo`000?ooo`000?oooooo
ooooo`000?ooooooooooo`000?ooo`000?ooooooo`000?ooooooo`000?ooooooo`000?oooooooooo
o`000?ooooooo`000?ooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`00000000000000000000000000000000000?oooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooo`000?oooooooooo
o`000?ooo`000?ooooooooooooooo`000?ooo`000?ooooooooooo`000?ooooooo`000?oooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooo`0000000000000000000000000000000?ooo`000?oooooooooooooooooo
ooooooooooooooooooooooooooooo`000?ooooooo`0000000?ooooooo`000?ooooooo`000?oooooo
ooooo`000?ooo`000?ooooooooooo`000?ooooooooooo`000?ooooooooooooooo`000?ooo`000000
0?ooooooo`0000000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
000000000000000000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo0000oooo
oooo0000oooooooo0000oooooooooooo0000oooo0000oooooooo0000oooooooo0000oooooooo0000
oooooooooooo0000oooooooo0000oooooooo00000000000000000000oooooooooooooooooooooooo
oooooooooooooooooooo000000000000000000000000000000000000000000000000000000000000
00000000oooo0000oooooooooooooooooooooooooooooooooooooooooooo000000000000oooo0000
oooooooooooo0000oooo0000oooooooooooooooo0000oooooooo0000000000000000oooooooo0000
oooooooooooooooooooo00000000000000000000oooooooooooooooooooooooooooooooooooooooo
oooooooo0000000000000000000000000000000000000000000000000000000000000000oooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooo0000000000000000oooo0000oooooooo
oooo0000000000000000oooo0000oooooooooooo0000oooooooooooo0000oooooooooooooooo0000
oooo000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooo
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ool0003oooooool0003oooooool0003oooooooooool0003oool0003oooooool0003oooooool0003o
ooooool0003oooooooooool0003oooooool0003oooooool0003oooooooooool0003ooooooooooooo
ooooooooooooooooooooooooooooool0003oooooool000000000000000000000003ooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooool00000003ooooooooo
ooooool0003oooooooooool0003oool0003oooooooooooooool0003oool0003oooooooooool0003o
ooooool0003oooooooooooooooooool0003oooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooool000000000000000000000003oooooooooool0
003oooooooooooooooooooooooooooooooooooooooooooooool0003oool0003oooooool0003oool0
003oooooool0003oooooooooool0003oool0003oooooooooool0003oooooooooool0003ooooooooo
ooooool0003oool0003oool00000003oool0003ooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool000000000000000000000003oooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?ooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooo`000?ooooooooooo`000?ooooooooooo`000?ooo`000?ooooooo`000?ooooooo`000?oo
ooooo`000?ooooooo`0000000?ooooooo`000?ooooooo`000?ooooooooooo`000?ooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooo`000000000000000000
0?ooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooo`000?ooooooooooo`000?ooo`0000000?ooooooooooo`000?ooooooo`000?oo
ooooo`000?ooooooo`000?ooooooo`000?ooooooo`000?ooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?ooooooooooo`0000000000000000000?oooooooooo
ooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?ooo`000?oooooo
ooooo`0000000?ooooooooooo`000?ooooooo`000?ooo`0000000?ooooooo`0000000?oooooooooo
o`000?ooooooo`000?ooo`000?ooooooo`000?ooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`0000000000000000000?ooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooo0000oooooooooooo0000oooooooooooo000000000000oooooooo0000oooo
oooo0000oooooooo0000oooooooo0000oooo00000000oooo00000000oooooooooooooooo00000000
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
000000000000oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
0000oooooooooooooooo0000oooo0000oooooooooooo0000oooo0000oooo0000oooo000000000000
oooooooo000000000000oooooooooooo00000000oooooooooooooooo00000000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo0000000000000000oooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo00000000
0000oooooooooooo00000000oooooooooooo000000000000oooooooo0000oooo0000oooo0000oooo
0000oooooooooooo00000000oooooooo0000oooooooo0000oooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo000000000000oooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003oooooooooooooooooool0003ooooo
ooooooooooooooooooooooooool0003oooooooooooooooooool0003ooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooool0003oooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ool00000003oooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
o`000?ooooooooooooooooooooooooooooooo`000?ooooooooooooooooooo`000?oooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooo`000000000000000?oooooooooooooooooooooooooooooooooooooo
ooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
ooooooooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooooooo0000oooooooooooo
oooo0000oooooooooooo00000000000000000000oooo00000000000000000000oooooooo00000000
00000000oooooooooooo000000000000oooooooo00000000000000000000oooo0000oooo00000000
000000000000oooooooo0000oooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooo0000oooooooooooooooo0000oooooooooooo
000000000000000000000000oooo0000000000000000oooooooooooo000000000000oooooooooooo
0000000000000000oooo00000000000000000000oooo0000oooooooo00000000000000000000oooo
0000oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooo0000oooooooooooooooo0000oooooooooooo0000000000000000
0000oooooooo0000000000000000oooooooo0000000000000000oooooooooooo000000000000oooo
oooo00000000000000000000oooooooo0000oooo00000000000000000000oooooooo0000oooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003oooooooooooooooooool0003oooooooooooooool0003o
ooooooooooooool0003oooooooooool0003oooooooooool0003oool0003oooooooooooooool0003o
ool0003oooooooooool0003oool0003oooooooooooooooooool0003oooooooooool0003oool0003o
ool0003oooooooooool0003oooooool0003oooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003oooooooooool0003oooooooooooooool0003o
ooooooooool0003oooooooooooooool0003oool0003oooooooooool0003oool0003oooooooooool0
003oool0003oooooooooooooooooool0003oooooooooool0003oool0003oooooool0003ooooooooo
ool0003oool0003oooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003oooooooooooooooooool0003oooooooooooooool0003oooooooooool0003o
ooooooooool0003oooooool0003oooooooooool0003oool0003oooooooooool0003oool0003ooooo
ooooooooooooool0003oooooooooool0003oooooool0003oool0003oooooooooool0003oooooool0
003oooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?ooooooooooooooooooo`000?oooooooooo
ooooo`000?ooooooooooooooo`000?ooooooooooo`00000000000?ooo`000?ooo`000?oooooooooo
ooooo`000?ooo`0000000000000000000?ooo`000?ooooooooooooooooooo`000?ooooooooooo`00
0?ooo`000?ooo`00000000000?ooo`000?ooooooo`000?ooooooooooo`000?oooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooo`000?oooooooooo
ooooo`000?ooooooooooo`000000000000000?ooo`000?ooo`000?ooooooooooo`000?ooo`000000
0000000000000?ooo`000?ooooooooooooooooooo`000?ooooooooooo`000?ooo`000?ooooooo`00
000000000?ooo`000?ooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?ooooooooooooooooooo`000?ooooooooooooooo`000?oooooo
ooooo`00000000000?ooo`000?ooooooo`000?ooooooooooo`000?ooo`0000000000000000000?oo
o`000?ooooooooooooooooooo`000?ooooooooooo`000?ooooooo`000?ooo`00000000000?ooo`00
0?ooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooo0000
oooooooooooooooo0000oooooooooooooooo0000oooooooooooooooooooooooo00000000oooo0000
oooooooooooooooo0000oooo0000oooooooooooo0000oooo0000oooooooooooooooooooo0000oooo
oooooooo0000oooo0000oooooooooooooooo00000000oooooooo0000oooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo0000
oooooooooooooooo0000oooooooooooooooooooooooo000000000000oooo0000oooooooooooo0000
oooo0000oooooooooooo0000oooo0000oooooooooooooooooooo0000oooooooooooo0000oooo0000
oooooooooooooooo000000000000oooo0000oooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooooooo
0000oooooooooooooooooooo000000000000oooooooo0000oooooooooooo0000oooo0000oooooooo
oooo0000oooo0000oooooooooooooooooooo0000oooooooooooo0000oooooooo0000oooooooooooo
oooo00000000oooooooo0000oooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
ooooool0003oooooooooooooool0003oooooooooooooool0003oooooooooool0003oooooooooool0
003oool0003oooooooooooooool0003oool0003oooooooooool0003oool0003ooooooooooooooooo
ool0003oooooooooool0003oool0003oool0003oooooooooool0003oooooool0003oooooooooool0
003oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooool0003oooooooooooooool0003oooooooooool0003oooooooooooooool0003oool0003ooooo
ooooool0003oool0003oooooooooool0003oool0003oooooooooooooooooool0003oooooooooool0
003oool0003oooooool0003oooooooooool0003oool0003oooooooooooooooooooooool0003ooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooool0003ooooo
ooooooooool0003oooooooooool0003oooooooooool0003oooooool0003oooooooooool0003oool0
003oooooooooool0003oool0003oooooooooooooooooool0003oooooooooool0003oooooool0003o
ool0003oooooooooool0003oooooool0003oooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
ooooooooooooooooo`000?ooooooooooooooo`000?ooooooooooooooo`00000000000?ooooooo`00
0000000000000?ooo`0000000000000000000?ooooooo`000000000000000?ooooooooooo`000000
00000?ooooooo`000?ooooooooooo`000?ooo`000?ooooooo`000000000000000?ooooooo`000000
00000?ooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooo`000?ooooooooooooooo`00000000000?ooooooo`0000000000000000000?oo
o`000000000000000?ooooooooooo`00000000000?ooooooooooo`000000000000000?ooo`000?oo
ooooooooo`000?ooo`000?ooooooo`0000000000000000000?ooo`000000000000000?oooooooooo
o`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
o`000?ooooooooooooooo`00000000000?ooo`0000000000000000000?ooooooo`00000000000000
0?ooooooo`000000000000000?ooooooooooo`00000000000?ooooooo`000?ooooooooooo`000?oo
ooooo`000?ooooooo`000000000000000?ooooooo`00000000000?ooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooo0000oooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003oooooooooooooooooool0003oool0000000000000000000000000003ooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oool000000000000000000000003ooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooool0
003oooooool000000000000000000000003ooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?ooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003oooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003oooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?ooooooooooooooooooo`00000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000?oooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo000000000000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo00000000oooooooooooooooooooo000000000000000000000000oooo0000000000000000oooo
oooo0000000000000000oooooooooooo0000000000000000oooo000000000000000000000000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool000000000003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool00000003oooooooooooooooooool00000003oool00000003oool000000000003o
ool0003oool000000000003oool0003oooooool000000000003oool0003oool00000003oooooool0
0000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000000000000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`0000000?ooooooooooooooooooo`0000000000000000000?ooo`00
00000000000000000?ooo`0000000?ooooooooooooooooooo`0000000000000000000?ooooooo`00
00000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000000000000000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo00000000000000000000oooooooooooooooo00000000
0000oooo00000000000000000000oooo00000000oooooooooooooooooooo00000000000000000000
oooo0000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000
00000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool00000000000000000003oooooool00000
003oool00000003oool00000003oooooool0003oool000000000003oool0003oooooool00000003o
ooooool0003oool00000003oooooool00000003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`0000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooo
ooooo`0000000000000000000?ooooooo`000000000000000?ooooooo`000000000000000?oooooo
ooooo`000000000000000?ooo`00000000000000000000000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0000000000000000000000000003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
00000000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000000000000000?ooo`00000000000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooo00000000oooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooo00000000oooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000000000000000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00000000000000000000000000000003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000
00000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000000000000000000000000000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`0000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo000000000000000000000000
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000
00000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool000000000000000000000003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`0000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000000000000000000000000000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000000000000000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooo00000000oooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool000000000003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`00000000000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003oooooooooooooooooooooooooooooooooooooooooooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool00000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
0000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooo`000000000000000?ooooooooooo`0000000?ooo`000?ooooooo`000?oooooo
ooooo`000?ooooooo`00000000000?ooo`000?ooooooooooo`0000000?ooooooooooo`0000000000
0?ooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooo`000?ooooooo`000?ooooooooooo`000?ooooooo`00000000000?ooo`000?ooo`000?oooooo
o`000?ooooooooooooooooooo`0000000?ooooooooooo`000?ooooooooooo`000?oooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooo0000oooooooooooooooooooo000000000000
0000oooo0000oooooooo00000000000000000000oooo0000oooooooooooo0000oooooooo0000oooo
oooooooo000000000000oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooo00000000oooooooooooo0000oooo0000oooooooo00000000oooooooo
0000oooooooooooo0000oooooooo0000oooooooo00000000oooo00000000oooooooo0000oooo0000
0000oooo00000000oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooo0000oooooooo00000000oooooooo0000oooo0000oooooooooooo00000000oooo
0000oooooooo0000oooooooooooo00000000oooooooo0000oooo000000000000oooooooo00000000
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooool0003oooooooooooooooooooooooooooooool00000003oooooooooool0003o
ooooooooool0003oool0003oooooool0003oooooooooool0003oool0003oooooooooool0003ooooo
ool0003oooooool0003oooooooooool0003oooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooool0003oool0003oooooooooool0
003oooooool0003oooooooooool0003oooooool0003oooooooooool0003oool0003ooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooool0003oooooool00000003oooooool0003oool0003ooooooooooooo
ool0003oool0003oooooool0003oooooooooool0003oooooooooool0003oool0003oool0003ooooo
ool00000003oooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
ooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooo`000000000000000?oo
ooooo`000?ooooooooooo`000?ooo`000?ooooooo`000?ooooooooooo`000?ooo`000?oooooooooo
o`000?ooooooo`000?ooooooo`0000000000000000000?ooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooo`00000000000?ooo`000?oo
ooooooooo`000?ooooooo`000?ooooooooooo`000?ooooooo`0000000000000000000?ooo`000?oo
ooooooooooooooooo`0000000000000000000?ooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooo`000?ooo`000000000000000?ooo`000?ooooooo`00
00000000000000000?ooo`000?ooooooo`000?ooooooooooo`000?ooooooooooo`000?ooo`000?oo
o`0000000000000000000?ooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000oooo
oooo0000oooooooo0000oooooooooooo0000oooo0000oooooooo0000oooooooooooo0000oooo0000
oooooooooooo0000oooooooo0000oooooooo0000oooooooooooo0000oooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo000000000000oooooooo
oooo0000oooooooooooo0000oooooooo0000oooooooooooo0000oooooooo0000oooooooooooo0000
oooo0000oooooooooooooooooooo0000oooooooooooo0000oooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooo0000oooo0000oooooooo0000oooo0000
oooo0000oooooooooooooooo0000oooo0000oooooooo0000oooooooooooo0000oooooooooooo0000
oooo0000oooooooo00000000oooo0000oooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003oooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool0
0000003oooooool0003oooooool00000003oooooool0003oool0003oooooool0003oooooooooool0
003oool00000003oooooool0003oooooool0003oooooool00000003oool00000003ooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool00000003ooooo
ooooooooooooool0003oooooooooool0003oooooool000000000000000000000003oool000000000
00000000003oooooool0000000000000003oooooool000000000003ooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooool00000003oooooooooool0
003oool0003oooooool00000000000000000003oool000000000000000000000003oooooool00000
00000000003oool0003oooooool0003oooooooooool0003oooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
ooooooooo`000?ooooooooooo`000?ooooooooooooooo`0000000?ooooooo`000?ooooooo`000?oo
ooooooooo`000?ooo`000?ooo`0000000?ooo`00000000000?ooooooooooo`00000000000?oooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`00
0?ooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooo`000?oooooo
ooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooo0000oooooooooooo00000000oooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooo00000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooo
00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
0000oooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ool0003oooooooooooooooooooooool0003oooooooooooooool0003ooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
o`00000000000?ooooooooooooooo`00000000000?ooooooo`000?ooooooooooo`00000000000000
0?ooooooooooo`0000000?ooooooooooo`000000000000000?ooo`000?oooooooooooooooooooooo
ooooooooo`000?ooooooooooooooooooooooo`000000000000000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooo`00000000000000
00000?ooooooooooo`000000000000000?ooo`000?ooooooooooo`000000000000000?oooooooooo
o`00000000000?ooo`00000000000000000000000?ooo`000?oooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000?oo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooo`0000000000000000000?oo
ooooooooo`000000000000000?ooo`000?ooooooooooo`000000000000000?ooooooooooo`000000
00000?ooo`00000000000000000000000?ooo`000?ooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000
00000?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00000000000?ooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooo0000oooooooooooo0000oooooooooooo0000oooo0000oooooooo0000oooooooooooo0000
oooooooo0000oooooooo0000oooooooo0000oooo0000oooooooooooo0000oooo0000oooooooooooo
oooooooooooooooooooo0000oooooooooooooooo00000000000000000000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000
oooooooooooooooo0000oooo0000oooooooooooo0000oooo0000oooooooooooo0000oooooooo0000
oooooooo0000oooooooooooooooo0000oooooooooooooooo0000oooo0000oooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
0000000000000000oooooooooooooooo0000oooooooooooooooooooooooooooo0000oooooooooooo
oooooooo0000oooo0000oooooooooooo0000oooo0000oooooooooooo0000oooooooo0000oooooooo
0000oooooooooooooooo0000oooooooooooooooo0000oooo0000oooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo000000000000000000000000oooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo000000000000000000000000oooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
ooooooooooooool0003oooooooooooooooooool0003oool0003oooooooooool0003oool0003ooooo
ooooool0003oooooool0003oooooool0003oooooooooooooool0003oooooooooool0003oool0003o
ooooooooooooooooooooooooooooool0003oool00000000000000000000000000000003ooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ool0003oooooooooooooooooooooooooool0003oooooooooool0003oool0003oooooooooool0003o
ooooool0003oooooool0003oooooooooooooool0000000000000003oool0003oool0003ooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool000000000000000000000000000000000003oooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooool0003oooooooooool0003oool0003oooooooooool0003oooooool0
003oooooool0003oooooooooooooool0000000000000003oool0003oool0003ooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool000000000000000000000000000000000003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0000000000000000000000000
00000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`00
0?ooooooooooooooooooooooo`000?ooooooooooooooooooooooooooo`000?ooooooooooo`000?oo
o`000?ooooooooooo`000?ooooooo`000?ooooooo`000?ooooooooooooooooooo`0000000?ooo`00
0?ooo`000?ooooooooooooooooooooooooooooooo`00000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000?oooooooooo
ooooooooooooo`000?ooooooooooooooooooooooooooo`000?ooooooooooo`000?ooo`000?oooooo
ooooo`000?ooooooo`000?ooooooo`000?ooooooooooooooooooooooooooo`00000000000?ooo`00
0?ooooooooooooooooooooooooooooooo`0000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000?oooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooo`000?ooooooooooo`000?ooo`000?ooooooooooo`00
0?ooooooo`000?ooooooo`000?ooooooooooooooooooooooooooo`00000000000?ooo`000?oooooo
ooooooooooooooooooooo`0000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000oooooooo
oooo0000oooo0000oooooooooooo0000oooooooo0000oooooooo0000oooooooooooooooo0000oooo
oooo00000000oooo0000oooooooooooooooooooooooooooooooo0000oooo00000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooo00000000oooooooo0000oooo
00000000oooooooo0000oooooooo0000oooooooo00000000oooo0000oooo00000000oooooooooooo
0000oooo0000oooooooooooooooooooooooooooooooo000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000oooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooo00000000oooooooo0000oooo00000000
oooooooo0000oooooooo0000oooooooo00000000oooo0000oooo00000000oooooooooooo0000oooo
0000oooooooooooooooooooooooooooo000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooool0003oooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
ool0003oool0003oooooool00000003oooooool0003oooooool0003oooooool0003oooooool0003o
ooooool0003oooooool0003oool0003oooooooooooooooooooooooooooooool0003ooooooooooooo
ooooool0000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooool0003oooooooooooooooooooooooooooooool000000000
003oooooool0003oool0003oool0000000000000003oooooooooool000000000003oooooooooool0
00000000003oooooool0003oooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool00000000000000000003oooooooooooooool0003o
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooool000000000003ooooo
ool0003oool0003oool0000000000000003oooooooooool000000000003oooooooooool000000000
003oooooool0003oooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool00000000000000000003ooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00000000000000000003oooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
ooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooo
o`000?ooooooo`00000000000?ooooooo`0000000000000000000000000000000?ooooooooooo`00
00000?ooooooooooooooo`00000000000?ooo`000?ooooooooooooooooooooooooooooooo`000?oo
ooooooooooooooooooooo`000000000000000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooo`000?ooooooooooo`0000000?oooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000?oooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooo`0000000?ooooooooooo`0000000?oooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000?oooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00000000000?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000oooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo0000000000000000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooo0000000000000000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
ooooool000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003oooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooo`00000000000?ooooooo`000000000000000?ooooooo`000?oo
ooooooooo`000?ooooooo`0000000?ooo`000000000000000?ooo`000?ooooooooooo`000?oooooo
o`0000000000000000000000000000000?ooooooooooo`000?oooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooo0000oooooooooooooooo0000oooooooooooooooo0000
oooo0000oooooooooooo0000oooooooo0000oooo0000oooooooooooo0000oooo0000oooooooooooo
0000oooooooo0000oooooooooooooooooooooooo0000oooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooool0003oooooooooooooool0003ooooooooo
ooooool0003oool0003oooooooooool0003oooooool0003oool00000000000000000003oool0003o
ooooooooool0003oooooool0003oooooooooool0000000000000003oooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooo`000?ooooooooooooooo`00
0?ooooooooooooooo`000?ooo`000?ooooooooooo`000?ooooooo`000?ooo`000?ooooooooooo`00
0?ooo`000?ooooooooooo`000?ooooooo`000?ooooooo`000?ooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo00000000oooo
0000oooo00000000oooooooo00000000oooo00000000oooooooo0000oooooooo0000oooo00000000
oooooooo0000oooo00000000oooooooo0000oooooooo0000oooooooo0000oooooooooooo0000oooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ool000000000003oooooooooool00000003oooooooooool0003oool00000003oooooool000000000
003oooooool00000003oooooool0003oool00000003oooooooooool000000000003oool000000000
003oooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooo000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
00000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooooooool000000000
003oooooooooooooool0003oooooooooooooooooooooooooool0003oooooooooooooool0003ooooo
ooooooooool0000000000000003oooooooooool00000003oooooool00000003ooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000000000000000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`00
0?ooooooooooo`000?ooooooooooo`000?ooooooooooooooooooooooooooo`000?oooooooooooooo
o`000?ooooooooooo`000?ooooooooooo`000?ooooooo`000?ooooooo`000?ooo`000?oooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo00000000000000000000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooo00000000oooooooooooo00000000oooooooo0000oooooooooooooooooooooooooooo0000oooo
oooooooooooo0000oooooooooooo0000oooooooooooo0000oooo0000oooooooooooooooooooo0000
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool000000000000000000000003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooool0003oooooooooooooooooool0003oooooool0003ooooooooooooooooooooooooo
ool0003oooooooooooooool0003oooooooooooooool00000003oool0003oool0003ooooooooooooo
ooooool0003oooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000000000000000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooo`000?ooooooo`000000000000000?ooooooo`000?oooooooooooooo
ooooooooooooo`000?ooooooooooooooo`000?ooooooooooo`000?ooooooo`0000000?ooo`000?oo
ooooooooooooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooo0000oooo
000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooo0000oooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooo0000oooooooooooooooo00000000oooooooooooo0000oooooooo0000
oooooooo0000oooooooo0000oooo0000oooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ool0003oooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooool0003ooooooooooooooooooooooooooooo
ool0003oooooooooooooooooooooooooool0003oooooooooooooool000000000003oooooool00000
00000000003oooooooooool00000003oool0003oool0003oooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooo`00000000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?ooooooooooo`00
0?ooooooooooo`000?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooo000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000
00000000oooooooooooooooo0000oooooooooooooooo0000000000000000000000000000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
ool00000000000000000003oooooool00000003oool00000003oooooool0000000000000003oool0
0000003oooooooooool000000000003oooooool000000000003oool00000000000000000003oool0
0000003oooooooooool0003oooooooooooooooooool0000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
ooooooooo`00000000000?ooo`00000000000?ooo`0000000?ooo`000?ooooooo`00000000000?oo
o`000?ooo`0000000?ooooooo`0000000?ooo`0000000?ooo`0000000?ooo`00000000000?ooo`00
00000?ooo`0000000?ooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`0000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooo00000000oooooooo000000000000oooo0000000000000000oooooooo0000
0000000000000000oooo00000000oooooooo00000000000000000000oooo00000000oooo00000000
oooooooooooo0000oooo00000000oooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooo0000000000000000000000000000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003oooooooooooooooooool0000000000000003oooooool0000000000000003o
ooooool00000000000000000003oool00000003oooooool00000000000000000003oool00000003o
ool00000003oooooooooool0003oool00000003oooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool000000000
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?ooooooooooo`0000000000000000000?ooooooooooo`000000
000000000?ooooooo`0000000000000000000?ooo`0000000?ooooooo`0000000000000000000000
0000000000000000000000000000000000000?ooo`00000000000000000000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooo00000000oooooooooooo00000000
oooo00000000oooo00000000oooooooooooo00000000oooooooo00000000oooooooooooo00000000
0000oooo0000000000000000oooooooo000000000000oooooooo000000000000000000000000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003oooooooooool00000000000000000
00000000003oool00000003oooooooooooooooooooooooooooooooooooooool00000003ooooooooo
ooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
o`00000000000?ooooooooooo`0000000?ooooooooooooooooooooooooooooooooooooooo`000000
0?ooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`00000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
0000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000000000000000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool00000000000000000003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`0000000000000000000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo000000000000000000000000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000000000000000003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000000000000000
0?ooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool00000000000000000003ooooo
ooooool0003oooooool000000000003oooooooooooooool00000003oooooooooooooool000000000
0000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooo`000?ooooooo`000?ooooooo`000?ooo`000?ooooooooooo`000?ooooooo`000?oooooooooo
o`000?ooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooo0000oooo0000oooo0000oooooooooooo0000oooooooo0000oooooooooooo
0000oooo0000oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooool0003oool0003oool0003oooooooooool0003oooooool0003o
ooooooooool0003oool0003oooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooo`000?ooooooo`000?ooo`000?ooooooooooo`000?oo
ooooo`000?ooooooooooo`000?ooo`000?ooooooooooo`000?oooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo000000000000000000000000oooooooo0000oooo00000000oooo
00000000oooooooo0000oooooooo00000000oooo00000000oooo00000000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooool0003oool0003ooooo
ool000000000003oooooooooooooool00000003oooooooooooooool0000000000000003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
0000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooo`0000000?oo
o`000?ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000000000000000
0000oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000oooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo000000000000oooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooooooo`0000000000000000000?ooooooooooo`000?oooooooooo
o`000?ooo`000?ooooooo`000?ooooooo`0000000000000000000?ooooooo`000?ooooooooooo`00
00000?ooooooooooooooooooooooo`000000000000000?ooooooo`0000000000000000000?oooooo
o`00000000000?ooooooooooo`000?ooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooo0000oooooooooooooooooooo0000oooooooo0000
oooooooooooo0000oooo0000oooooooo0000oooooooo0000oooooooooooo0000oooooooo0000oooo
oooooooo00000000oooooooooooooooooooooooo0000oooooooooooo0000oooo0000oooooooooooo
0000oooooooo0000oooo0000oooooooooooo0000oooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003oooooooooooooooooooooooooooooool0003oooooooooooooooooool0003o
ooooool0003oooooooooool0003oool0003oooooool0003oooooool0003oooooooooool0003ooooo
ool0003oooooooooool00000003oooooooooooooooooooooool0003oooooooooool0003oool0003o
ooooooooool0003oooooool0003oool0003oooooooooool0003ooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
ooooo`000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooo`000?oooooooooooooo
ooooo`000?ooooooo`000?ooooooooooo`000?ooo`000?ooooooo`000?ooooooooooo`0000000000
00000?ooooooo`000?ooooooo`000?ooooooo`000?ooooooooooooooooooo`000?ooooooooooo`00
0?ooooooo`000000000000000?ooooooo`000?ooo`000?ooooooooooo`000?oooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooo`000000000000000?ooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000?oooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooo`0000000000000000000?ooo`000?oo
ooooooooo`000?ooooooooooooooo`000000000000000?ooooooo`000?oooooooooooooooooooooo
ooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooo000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooo0000oooooooo0000oooooooooooo0000oooo0000oooooooo0000oooooooo0000
oooooooooooo0000oooooooo0000oooooooo0000oooooooo0000oooooooooooooooooooo0000oooo
oooooooo0000oooo0000oooooooooooo0000oooooooo0000oooo0000oooooooooooo0000oooooooo
oooooooooooooooooooooooooooo0000oooooooooooo000000000000000000000000oooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000
0000000000000000oooooooooooo0000oooooooooooooooooooooooooooo0000oooooooooooooooo
oooo0000oooooooooooo00000000oooooooo0000oooooooooooooooo0000oooo0000oooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool000000000000000000000000000000000003ooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
ool0003oooooooooooooooooool0003oooooool000000000003oool0003oool0000000000000003o
ooooooooool0000000000000003oooooool0000000000000003oooooooooool0003ooooooooooooo
ool0000000000000003oooooooooool0000000000000003oool00000000000000000000000000000
003oooooooooooooooooooooooooooooooooool000000000000000000000000000000000003ooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool000000000000000000000000000000000003oooooooooooooooooooooooooool0003ooooo
ooooooooooooool0003oooooooooool00000003oooooool000000000000000000000003oool0003o
ooooooooooooooooooooooooooooool0003oooooooooooooool00000003ooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000?oooooooooooooooooo
ooooooooooooo`000?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooo`000?oo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000?oooooooooooooooooooooooooo
o`000?ooooooooooooooooooo`000?ooooooo`000?ooooooo`000?ooo`000?ooooooooooooooo`00
0?ooo`000?ooooooooooooooooooooooooooooooo`000?ooooooooooooooo`0000000?oooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo00000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000oooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo00000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000oooooooooooooooo
oooooooooooo0000oooooooooooooooooooo0000oooo00000000oooooooo0000oooo00000000oooo
oooo00000000oooo0000oooooooooooooooooooooooooooooooo0000oooooooooooooooo00000000
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003oooooooooooooool00000000000000000003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooool00000000000000000003oooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00000000000000000003oooooooooooooool0003ooooo
ooooooooooooooooooooool0003oooooooooooooooooool0003oool0003oooooooooool0003ooooo
ooooool00000003oooooooooool000000000003oooooooooooooool0003oool0003ooooooooooooo
ool00000003oooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooo`0000000000
00000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooo`000000000000000?ooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00000000000?oooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oo
ooooooooooooo`0000000?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooo0000oooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooo00000000oooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003oooooooooooooool000000000003oooooooooool00000003ooooooooo
ool0003oooooooooool0003oooooool00000003oooooool00000003oooooooooool0003oooooool0
003oooooool000000000003oool000000000003oooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00000003oooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?ooooooooooo`0000000?ooo`000?ooo`0000000?oooooo
o`0000000?ooo`000?ooooooooooo`000?ooooooo`000?ooo`0000000?ooooooo`000?ooooooo`00
0?ooooooo`000?ooooooo`000?ooooooo`000?ooooooooooo`000?ooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooo0000oooooooooooooooo0000
oooooooooooooooo0000oooo0000oooooooooooo0000oooooooo0000oooo0000oooooooooooooooo
oooooooo0000oooooooo0000oooooooo0000oooooooooooooooooooooooo0000oooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooool0003ooooooooo
ooooool0003oooooooooooooool0003oool0003oooooooooool0003oooooool0003oool000000000
00000000003oooooool0003oooooool0003oooooool0003oooooool0000000000000003ooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooo`00
0?ooooooooooooooo`000?ooooooooooooooo`000?ooo`000?ooooooooooo`000?ooooooo`000?oo
o`000?ooooooooooo`000?ooooooo`000?ooooooo`000?ooooooo`000?ooooooo`000?oooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
00000?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooo000000000000oooooooo0000000000000000oooooooo00000000000000000000oooo
000000000000oooo0000000000000000oooooooo0000000000000000oooooooo0000000000000000
0000000000000000oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo00000000oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool00000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00000003oooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`00000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?ooooooooooooooooooooooooooo`000000000000000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooo`0000000?ooooooo`00
0?ooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooo00000000000000000000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000000000000000
oooo00000000oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
ooooooooooooool0000000000000003oooooooooool0003oool00000000000000000003oooooool0
000000000000003oooooool00000000000000000003oooooool000000000003oooooool0003ooooo
ooooooooooooooooooooooooooooooooool0003oool00000000000000000000000000000003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000
00000000000000000000003oooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?ooooooooooooooooooooooo`000?ooooooooooo`000?ooooooo`000?ooo`000?ooooooooooo`00
0?ooo`000?ooooooooooo`000?ooooooo`000?ooooooooooo`000?ooo`000?ooooooooooo`000?oo
o`000?ooooooooooooooooooooooooooooooooooooooo`0000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000000000000000000000000000?ooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooo0000oooooooooooo0000oooooooo0000oooo00000000
0000oooo0000oooo0000oooooooooooo0000oooooooo0000oooooooooooo0000oooo000000000000
00000000oooo0000oooooooooooooooooooooooooooooooooooooooo0000oooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo00000000000000000000oooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003oooooooooooooooooooooool0003oooooooooool0003oooooool0003o
ooooooooool000000000003oool0003oooooooooool0003oooooool0003oooooooooool0003oool0
003oooooooooool0003oool0003oooooooooooooooooooooooooooooooooooooool0003ooooooooo
ooooooooool00000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool00000000000000000003oooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?ooooooo`0000000?oo
ooooo`000?ooo`000?ooooooooooo`000?ooo`0000000?ooo`0000000?ooooooo`000?ooooooo`00
00000?ooo`0000000?ooo`0000000?ooo`0000000?ooooooooooooooooooooooooooooooooooo`00
0?ooooooooooooooooooooooooooo`000000000000000?oooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000000000000000?oooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo000000000000
oooooooooooooooo0000oooooooo000000000000oooooooooooo0000000000000000oooooooooooo
0000000000000000oooooooo000000000000oooooooo0000oooo0000oooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo000000000000oooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
ooooooooooooool000000000000000000000003oool00000003oooooooooool0003oooooool00000
003oooooool00000003oooooool000000000003oooooooooooooooooooooooooooooooooool00000
000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool0
003oooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooool000000000000000000000003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ool00000000000000000003oool0003oooooooooooooool0003oooooooooooooool000000000003o
ooooool0003oooooooooooooooooooooool00000000000000000003oooooooooool000000000003o
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
ooooooooooooooooooooo`0000000?ooooooooooo`0000000?ooo`0000000?ooooooooooo`000?oo
ooooo`0000000?ooooooo`0000000?ooo`0000000?ooo`0000000?oooooooooooooooooooooooooo
o`0000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
ooooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000?oooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooo`00000000000000000000000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooo`000?ooooooooooooooooooo`000?ooooooooooooooo`000?ooooooooooo`000?oo
ooooo`000?ooooooo`000?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooo00000000oooooooooooooooo0000oooo00000000oooooooo
oooo0000oooooooo00000000oooooooo00000000oooo00000000oooooooooooooooooooooooooooo
oooo0000000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo000000000000000000000000000000000000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooo00000000oooooooo
oooo0000oooooooooooo0000oooo0000oooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooooooooooooooooooooooooooooooool00000003oooooooooooooool0003oool00000
003oooooooooool0003oooooool00000003oooooool00000003oool00000000000000000003ooooo
ooooool0000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000
003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003oooooooooooooooooooooool0003oooooooooooooooooool0003oooooooooool00000
003oooooooooool00000000000000000003oool0003oooooooooooooooooooooooooooooool00000
003oooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooooooooooooooooooooooooooooooo`0000000?ooooooooooooooo`00
0?ooo`00000000000?ooooooo`000?ooooooo`0000000?ooooooo`0000000?ooo`0000000?ooo`00
00000?ooooooooooooooooooooooooooo`0000000000000000000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`0000000?ooooooo`000?ooooooo`00000000000?oo
ooooo`000000000000000?ooooooo`0000000?ooo`000?ooooooooooo`0000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooo`00000000000000
000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooo`000?ooooooooooooooooooo`000?oooooo
o`000?ooooooo`000?ooooooo`000?ooooooooooo`000?ooo`000?oooooooooooooooooooooooooo
ooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooo
oooooooo0000oooo0000000000000000oooo0000oooooooo000000000000000000000000oooooooo
000000000000oooooooooooooooooooooooooooooooooooooooo0000000000000000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000000000000000oooooooo
oooo0000oooooooooooo0000oooooooo0000oooooooo0000oooooooooooo0000000000000000oooo
0000oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo0000oooo0000oooo
oooooooo0000oooo0000oooooooo0000oooo0000oooooooo00000000oooooooo0000oooooooo0000
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooo00000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooo0000oooooooooooooooooooo
0000oooooooo0000oooooooo00000000oooo0000oooooooo00000000oooo00000000oooooooooooo
oooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooooooooooooooooooooooooooooooool00000
003oooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool0003ooooooooooooo
ool0003oooooool0003oooooooooool0003oooooool0003oooooool0003oooooool0003ooooooooo
ool0003oool0003oooooooooooooool0003oool0003ooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooool0003o
ooooooooooooooooool0003oooooooooooooool0003oool0003oooooooooool0003oooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool0003ooooooooo
ooooooooool0003oooooool0003oooooooooool0003oooooool000000000003oooooool000000000
003oooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
ooooo`0000000?ooooooooooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?oo
ooooooooooooo`000?ooooooo`000?ooooooooooo`000?ooooooo`000?ooooooo`000?ooooooo`00
0?ooooooooooo`000?ooo`000?ooooooooooooooo`000?ooo`000?oooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooo`000?ooo`000000000000000?ooooooo`000000000000000?ooo`000?ooooooooooo`000?oo
ooooo`0000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000?ooo`0000000?oooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooo0000oooooooooooooooo0000oooooooo0000oooooooooooo0000oooooooo0000oooooooo0000
oooooooooooo00000000oooo0000oooo0000oooooooooooo0000oooooooo0000oooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooo0000oooo0000oooooooooooooooooooo0000oooooooooooooooo0000oooooooo
oooo0000oooooooo0000oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooo0000oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo000000000000oooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
ooooooooooooool0003oooooooooooooool0003oooooool0003oooooooooool0003oooooool0003o
ooooool0003oooooool0003oooooool00000003oool0003oooooooooool0003oooooool0003ooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool000000000003oooooool0003oool00000000000000000003oool0000000000000003oool0
003oooooooooool0003oooooool0000000000000003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?ooooooooooooooooooooooo`000?ooooooooooooooo`000?ooooooo`0000000?ooooooo`000?oo
ooooo`0000000?ooo`000?ooooooooooo`000?ooooooo`000?ooo`0000000?ooooooo`000?oooooo
ooooo`000?ooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooo0000oooooooooooooooo0000oooooooo000000000000
oooo0000oooooooo0000000000000000oooooooooooo0000000000000000oooo0000oooo0000oooo
0000oooooooooooo0000oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003oooooooooooooooooooooool0003oooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooool0003oooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?ooooooooooooooo`00
0?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooo`000000000000000?oooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
00000000oooooooooooooooooooooooooooooooooooo0000oooooooo000000000000000000000000
0000oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003oooooooooooooooooooooooooooooooooool0000000000000000000000000
00000000003oooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooo`0000000000000000000?ooooooooooo`0000000?ooo`000?oo
ooooo`000?ooooooooooo`00000000000?ooooooooooo`000?ooooooooooooooooooooooo`000?oo
ooooo`00000000000?ooooooooooo`000000000000000?ooo`000?ooooooooooo`000?ooooooo`00
0000000000000?ooooooo`00000000000?ooooooooooooooooooooooooooooooo`00000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooo0000oooooooooooo0000oooooooooooo0000oooo
oooo0000oooooooo0000oooooooo0000oooooooooooo0000oooooooo0000oooooooooooooooooooo
oooo0000oooo0000oooooooo0000oooooooo0000oooooooooooo0000oooo0000oooooooooooo0000
oooo0000oooooooooooo0000oooooooo0000oooo0000oooooooooooooooooooooooooooooooo0000
oooooooo000000000000000000000000oooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003oooooooooooooooooooooooooool0003oooooooooooooooooool0003ooooo
ool0003oooooool0003oooooool0003oooooool00000000000000000003oooooool0003ooooooooo
ooooooooooooool000000000003oooooool0003oooooool0003oooooooooool0003oool0003ooooo
ooooool0003oool00000000000000000003oooooool0003oool0003ooooooooooooooooooooooooo
ooooool0003oooooooooooooool00000000000000000003oooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooo`000?oooooooooooooooooo
o`000?ooooooo`000?ooooooo`000?ooooooo`000?ooooooo`000?ooooooooooo`000?ooooooo`00
0?ooooooooooooooooooooooo`000?ooo`000?ooooooo`000?ooooooo`000?ooooooooooo`000?oo
o`000?ooooooooooo`000?ooo`000?ooooooooooo`000?ooooooo`000?ooo`000?oooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooo`000?ooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000oooooooo
oooooooooooo0000oooooooo0000oooooooo0000oooooooo0000oooooooo00000000oooo00000000
oooooooo0000oooooooooooooooooooooooo0000oooo00000000oooo0000oooooooo00000000oooo
00000000oooo00000000oooooooo0000oooo00000000oooooooo0000oooo0000oooooooo00000000
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooooooool0
003oooooooooooooooooool0003oool0003oool0003oool000000000003oooooooooooooool00000
0000003oooooooooool000000000003oooooooooooooool0003oooooooooool00000003ooooooooo
ool0000000000000003oool0003oool00000003oooooooooooooool00000003oooooool0003ooooo
ooooool0003oooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
ooooooooooooo`000?ooooooooooo`000?ooooooooooo`000?ooooooo`000?oooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooo00000000000000000000oooooooooooo0000oooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooo0000oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`00000000000?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo000000000000000000000000oooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000003oooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool000000000000000000000000000000000003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000000000000000
003oooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`00000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00000000000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000
00000?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000
oooooooooooo00000000oooo00000000oooooooo00000000000000000000oooo0000oooooooooooo
00000000oooooooo00000000oooooooooooooooooooo00000000oooooooooooo0000000000000000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool000000000003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00000003oooooooooool00000003oool00000003oooooool00000000000000000003oool0003o
ooooooooool00000003oool0000000000000003oooooooooooooool00000003oooooool000000000
00000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000000000000000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`0000000?ooooooo`0000000?ooooooo`0000000?ooo`0000000?ooo`0000000000
0?ooo`000?ooooooooooo`0000000?ooo`0000000?ooo`0000000?ooooooo`000000000000000?oo
o`0000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo00000000000000000000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo00000000oooooooo00000000oooooooo00000000oooo00000000oooo
oooo00000000oooo0000oooooooooooo00000000oooo00000000000000000000oooooooo00000000
00000000oooooooo0000000000000000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0000000000000000000000000003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00000000000000000003oooooooooool00000003oool0
0000003oool000000000003oool00000003oooooool00000003oool00000000000000000003ooooo
ool0003oooooool00000000000000000003oool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000000000000000000
00000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`0000000?ooo`000?ooooooooooooooo`00
00000?ooooooo`0000000000000000000?ooo`00000000000000000000000?ooo`00000000000000
0?ooooooo`0000000?ooooooooooo`00000000000000000000000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo000000000000
0000oooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooo000000000000
oooooooo00000000oooooooo00000000000000000000oooo0000oooo000000000000oooooooooooo
00000000oooooooooooo00000000oooooooooooo0000oooo0000000000000000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooo000000000000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooo
ooooool0003oooooool00000003oooooooooooooooooool00000003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooool000000000000000000000003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
00000?ooooooooooo`0000000?ooo`0000000?ooooooooooooooooooo`0000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`00000000000000000000000000000000000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool00000003oooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`0000000000000000000?ooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
o`000000000000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo000000000000000000000000oooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooo000000000000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003oooooool00000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?ooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000000000000000000000000000oooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool000000000003oooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
00000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`0000000?ooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000003ooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00000003oooooooooooooooooooooooooooooool00000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooo
ooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooo
oooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooo
ooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
00000?ooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo00000000oooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00000003oooooooooooooooooooooooooooooool00000003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000?ooooooooooooooooooooooooooooooo`0000000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooo
00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooo000000000000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooo
ooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool00000003oooooooooooooooooooooooooooooooooooooooooool0
00000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooo
ooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooo
ooooooooo`00000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000
oooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooo
oooooooooooooooooooo000000000000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00000003oooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooo
ooooooooooooooooooooooooool00000000000000000003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`0000000?ooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oo
ooooooooooooooooooooooooooooooooooooo`0000000000000000000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooo00000000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
00000000oooooooooooooooooooooooooooooooooooo0000000000000000000000000000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00000003oooooooooooooooooooooooooooooool00000
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool00000003oooooooooooooooooooooooooooooooooool0000000000000000000000000
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`0000000?ooooooooooooooooooooooooooooooooooo`00000000000000
0?ooo`00000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooo
oooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooo
oooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooo
ooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooo
ooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
00000?ooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooo
ooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo00000000oooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooo
oooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000003ooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000?ooooooooooooooooooo`000?ooooooo`0000000?oo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`0000000?ooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooo000000000000
00000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooo00000000oooooooo0000oooooooooooooooooooooooooooooooo00000000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo0000oooooooooooo0000
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooo
ool0000000000000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0000000000000003oool00000003oooooooooooooooooooooooooooooool0
0000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003oool0003oool0
00000000003oooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooo
ooooooooooooo`000000000000000000000000000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000000000000000000000000000?oooooooooooooooooooooo
ooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000
00000000000000000?ooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000
oooooooooooooooooooooooooooo00000000000000000000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000000000000000000000000000oooooooooooo
oooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo000000000000000000000000oooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00000003oooooooooooooooooooooooooool00000000000000000003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool00000000000000000003ooooo
ooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool00000000000000000003oooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`0000000?ooooooooooooooooooooooooooo`000000000000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000000
00000?ooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`0000000000000000000?oooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooo00000000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
000000000000oooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000000000000000oooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00000003oooooooooooooooooooooooooooooool00000
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool000000000003oooooooooooooooooooooooooooooooooooooool00000003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`00000000000?ooooooooooooooooooooooooooooooooooooooo`000000
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo000000000000oooooooooooooooooooooooooooooooooooo
oooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
0000oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool00000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
003oooooooooooooooooooooooooool0000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000003ooooooooooooooooooooooooooooooooo
ooooooooooooool00000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003ooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
ooooooooo`000?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooo0000oooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
ooooooooooooool0003oooooooooooooooooool0003oooooooooooooooooool00000003oool0003o
ool0003oooooooooool0003oooooooooool0003oooooooooool00000003oooooooooooooool0003o
ooooooooooooooooool00000003oooooooooool0003oooooooooooooooooooooooooool0003ooooo
ooooool0000000000000003oooooooooooooool0003oooooooooooooooooool000000000003ooooo
ooooool0003oooooooooooooooooool0003oooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?ooooooooooooooooooooooo`000?ooooooooooooooooooo`000?ooooooooooooooo`000?oooooo
o`0000000?ooo`000?ooooooooooo`000?ooooooooooo`000?ooooooo`000?ooooooo`000?oooooo
ooooo`000?ooooooooooooooo`000?ooooooo`000?ooooooo`000?ooooooooooooooooooooooo`00
0?ooooooooooo`000?ooooooooooo`000?ooooooooooooooo`000?ooooooooooooooooooo`000?oo
ooooo`000?ooooooooooo`000?ooooooooooooooo`000?ooooooooooooooooooooooooooo`000?oo
ooooooooooooooooo`000?ooooooooooooooooooo`00000000000?ooooooo`000?ooooooooooo`00
0?ooooooooooo`000?ooooooooooo`0000000?ooooooooooooooo`000?ooooooooooooooooooo`00
00000?ooooooooooo`000?ooooooooooooooooooooooooooo`000?ooooooooooo`00000000000000
0?ooooooooooooooo`000?ooooooooooooooooooooooooooo`000?ooooooooooo`000?oooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?ooooooooooooooo`00000000000?ooooooooooooooo`00
0?ooooooooooooooooooo`0000000000000000000?ooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooooooo
0000oooooooooooo0000oooo0000oooooooooooo0000oooooooooooo0000oooooooo0000oooooooo
oooo0000oooooooo00000000oooooooo0000oooooooooooooooo0000oooo0000oooooooooooooooo
oooooooo0000oooooooooooo0000oooooooooooooooo0000oooooooooooo0000oooooooooooooooo
0000oooooooooooo0000oooooooooooo0000oooooooooooooooo0000oooooooooooooooooooooooo
oooo0000oooooooooooooooooooo0000oooooooooooooooo0000oooooooo0000oooooooo0000oooo
oooooooo0000oooooooooooo0000oooo00000000oooooooo00000000oooo000000000000oooooooo
00000000oooooooo0000oooooooo0000oooooooooooooooooooooooo0000oooooooo00000000oooo
oooooooo00000000oooooooooooo0000oooooooooooooooooooooooooooo0000oooooooooooo0000
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooo00000000oooooooooooo00000000
oooooooo0000oooooooooooooooooooo00000000oooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003oooooooooooooooooooooool0003oooooooooooooooooool0003ooooo
ooooooooool0003oooooooooool0003oool0003oooooooooool0003oooooooooool0003oooooool0
003oooooooooool0003oooooool00000003oooooool000000000000000000000003oool0003ooooo
ooooooooooooooooool0003oooooooooooooooooooooooooooooool0003oooooooooool0003ooooo
ooooooooool0003oooooooooool0003oooooooooool0003oooooooooooooool0003ooooooooooooo
ooooooooooooool0003oooooooooooooooooool0003oooooooooooooool0003oooooool0003ooooo
ool0003oooooooooool0003oooooooooool0003oool0003oooooooooooooool0003oool0003oool0
003oooooool0003oooooooooooooooooooooool0003oooooooooooooooooooooool0003ooooooooo
ooooooooooooooooooooool0003oooooooooool0003oooooooooooooooooooooooooool0003ooooo
ooooool0003oooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooool0003oooooool0003oooooooooooooooooooooooooool0003oooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooo
o`000?ooooooooooooooo`000?ooooooooooo`000?ooo`000?ooooooooooo`000?ooooooooooo`00
0?ooooooo`000?ooooooooooo`000?ooo`000?ooooooo`000?ooo`000?ooooooooooooooo`000?oo
o`000?ooooooooooooooooooooooo`000?ooooooooooooooooooooooo`0000000?oooooooooooooo
o`000?ooooooooooooooo`000?ooooooooooo`000?ooooooooooo`000?ooooooooooooooo`000?oo
ooooooooooooooooooooooooo`000?ooooooooooooooooooo`000?ooooooooooooooo`000?oooooo
o`000?ooooooo`000?ooooooooooo`000?ooooooooooo`000?ooo`000?ooooooooooooooo`000?oo
o`000?ooo`000?ooooooo`0000000000000000000?ooooooo`000?ooooooooooooooooooooooo`00
0?ooooooooooooooooooooooooooooooo`000?ooooooooooo`000?oooooooooooooooooooooooooo
o`000?ooooooooooo`000?ooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
ooooooooooooooooo`000?ooooooo`000?ooooooooooooooooooooooooooooooo`000?oooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo0000oooooooo
oooooooooooo0000oooooooooooooooo0000oooooooooooo0000oooo00000000oooooooo00000000
oooooooo0000oooooooo0000oooooooo0000000000000000oooooooo0000oooo00000000oooooooo
00000000oooo00000000oooooooooooooooooooo0000oooooooooooo000000000000oooooooooooo
oooooooooooo0000oooooooooooooooo0000oooooooooooo0000oooooooooooo0000oooooooooooo
oooo0000oooooooooooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooooooo
0000oooooooo0000oooooooo0000oooooooooooo0000oooooooooooo0000oooo0000oooooooooooo
oooo0000oooo0000oooo0000oooooooo0000oooooooooooo0000oooooooo0000oooooooooooooooo
oooooooo0000oooooooooooooooo0000000000000000oooooooooooooooo0000oooooooooooooooo
oooooooooooo0000oooooooooooo0000oooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooo0000000000000000oooooooooooo0000oooooooooooooooooooooooooooooooo0000
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool0
003oooooooooooooooooool0003oooooooooooooool0003oooooooooool0003oool0003oool0003o
ool0003oool00000003oooooooooooooool00000003oooooool0003oooooooooool0003ooooooooo
ool00000003oooooooooool0003oool0003oooooooooooooooooool0003oooooool0003ooooooooo
ooooooooooooooooooooool0003oooooooooooooool0003oooooooooool0003oooooool0003ooooo
ooooooooooooool0003oooooooooooooooooooooooooool0003oooooooooooooooooool0003ooooo
ooooooooool0003oooooool0003oooooool00000003oooooool00000003oooooool0003oooooool0
003oooooool0003oool0003oooooooooool0003oooooool0003oooooool0003oooooool00000003o
ooooooooooooooooool0003oooooooooool0003oooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooool0003oooooooooool0003oooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003oooooooooooooool0003oooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
ooooooooool0003oooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
ooooooooo`000?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooo`00
0?ooooooooooo`0000000?ooooooooooo`000?ooooooooooooooo`0000000?ooooooo`000?oooooo
o`000?ooooooooooooooooooo`000?ooooooooooooooooooooooooooo`000?oooooooooooooooooo
o`000?ooooooooooooooo`000?ooooooo`000?ooooooo`00000000000?ooo`000?ooo`0000000?oo
ooooooooooooo`0000000?ooooooo`000?ooooooooooo`000?ooooooooooo`0000000?oooooooooo
o`00000000000?ooooooooooooooooooo`000?ooo`000?ooooooooooooooooooo`000?oooooooooo
o`000?ooooooooooooooooooo`000?ooo`000?ooooooooooo`000?ooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?ooooooo`000?ooooooooooooooooooo`000?ooooooo`000?oooooooooooooo
ooooo`000?ooooooooooo`000?ooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooo0000oooooooo0000000000000000000000000000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooo0000000000000000oooooooo000000000000000000000000oooooooo000000000000
oooooooo0000oooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000oooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooo0000oooooooooooo0000oooo
oooooooooooo0000oooooooooooooooooooooooo00000000oooooooooooo0000oooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooo0000oooooooooooo0000oooooooooooo0000oooo
oooooooooooooooo0000oooooooo0000oooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003oooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooooooool0
003oooooool0000000000000000000000000003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooool000000000
0000003oool0000000000000000000000000003oooooooooooooool0003oooooool0003ooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003oooooooooool000000000003oooooool00000
0000000000000000003oooooooooool000000000003oooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool0003ooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ool0003oooooool000000000003oool0003oooooool000000000003oooooooooool0003oooooool0
000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003oooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooo`000?ooooooooooo`000?ooooooo`0000000?ooooooo`000?ooooooo`0000000?ooo`00
0?ooo`0000000?ooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
o`000?ooooooooooo`000?ooooooo`000?ooooooo`0000000?ooo`000000000000000?ooooooo`00
0?ooooooooooo`000?ooooooo`000?ooooooooooo`000?ooooooo`000000000000000?ooooooo`00
00000000000000000?ooo`000?ooooooo`0000000000000000000?ooo`0000000?ooo`0000000000
00000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooo`0000000000000000000?oo
ooooo`000?ooooooo`00000000000?ooooooooooooooo`000?ooooooooooo`000?oooooooooooooo
ooooooooooooo`000?ooooooooooooooo`000000000000000?ooooooo`000?ooooooooooo`000?oo
ooooooooo`000?ooooooo`000000000000000?ooooooooooo`000?ooooooooooooooo`0000000000
00000?ooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooo0000oooooooooooo0000oooooooooooo0000oooooooo0000oooooooooooo
0000oooo0000oooo0000oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooo0000oooooooooooo0000oooooooo0000oooooooo0000oooooooo0000oooooooooooo
0000oooo0000oooooooooooo0000oooooooo0000oooooooooooo0000oooooooo0000oooooooooooo
0000oooo0000oooooooooooo0000oooo0000oooooooo0000oooooooooooo0000oooo0000oooooooo
0000oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo0000oooooooooooo
oooooooo0000oooo0000oooo0000oooooooooooo0000oooooooo00000000oooooooo00000000oooo
oooooooooooooooooooooooo0000oooooooooooooooo0000oooooooo0000oooooooo0000oooooooo
oooo0000oooooooooooo0000oooo0000oooooooooooooooo0000oooo0000oooo0000oooooooo0000
oooooooooooo0000oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooool0003oooooooooooooool000000000003oool0003oooooool0003o
ooooooooool0003oool0003oool0003oooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003oooooooooooooooooooooooooool0003ooooooooooooo
ooooooooooooooooooooool0003oooooooooool0003oooooool0003oooooool0003oooooool0003o
ooooooooooooooooool0003oooooooooool0003oooooool0003oooooooooool0003oooooool0003o
ooooooooooooooooool0003oooooooooool0003oool0003oooooool0003oooooooooool0003oool0
003oooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooool0003oool0003oool0003oooooooooool0003oooooool00000003oooooool0
0000003oooooooooooooooooooooooooool0003oooooooooooooool0003oooooool0003oooooool0
003oooooooooool0003oooooooooool0003oool0003oooooooooooooool0003oool0003oool0003o
ooooool0003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`00000000000000000000000?ooooooooooo`000?ooo`00000000000?oo
ooooo`000?ooooooooooo`000?ooo`000?ooo`000?ooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooooooo`000?ooooooooooo`000?ooooooo`000?ooooooo`000?oo
ooooo`0000000000000000000?ooo`000?ooooooooooo`000?ooooooo`000?ooooooooooo`000?oo
ooooo`0000000000000000000?ooo`000?ooooooooooo`000?ooo`000?ooooooo`00000000000000
00000?ooo`000?ooooooo`0000000000000000000?oooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
ooooooooooooooooooooo`00000000000?ooo`000?ooo`000?ooooooooooo`000?ooooooo`000000
00000000000000000?ooooooooooooooooooooooooooo`000?ooooooooooooooo`000?ooooooo`00
0?ooooooo`000?ooooooooooo`000?ooooooooooo`000?ooo`000?ooooooooooooooo`000?ooo`00
0?ooo`000?ooooooo`0000000000000000000?ooo`000?oooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooo0000oooooooo0000oooooooo
oooo0000oooooooo0000oooooooo0000oooooooo0000oooooooo0000oooo00000000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooo0000oooooooooooo0000oooooooo0000oooo
oooo0000oooooooo0000oooooooooooo0000oooo0000oooooooooooo0000oooooooo0000oooooooo
oooo0000oooooooo0000oooooooooooo0000oooo0000oooooooooooo0000oooo0000oooooooo0000
oooooooooooo0000oooo0000oooooooo0000oooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooo00000000oooooooooooooooo0000oooo0000oooooooooooo0000oooo
oooo0000oooo00000000oooo0000oooooooooooooooooooooooooooo0000oooooooooooooooo0000
oooooooo0000oooooooo0000oooooooooooo0000oooooooooooo0000oooo0000oooooooooooooooo
0000oooo0000oooo0000oooooooo0000oooooooooooo0000oooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003oooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooool0003ooooooooo
ool000000000003oooooooooool000000000003oooooooooool0003oooooool0000000000000003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
ooooooooooooool0003oooooooooooooooooooooooooooooooooool0003oooooooooool000000000
0000003oool000000000003oool0000000000000003oooooool000000000003oool0000000000000
0000000000000000003oooooool0000000000000003oooooool00000000000000000003oool0003o
ooooool00000000000000000000000000000003oool0000000000000003ooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003oooooooooooooooooooooool00000003oooooooooooooooooooooool0003oooooool000000000
003oooooool0003oooooooooool0003oooooool0003oooooooooooooooooooooool0003ooooooooo
ooooool0003oooooool0003oooooool000000000003oool00000000000000000003oooooool00000
00000000003oool0003oooooooooool0003oooooool0000000000000003oool000000000003ooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
ooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?ooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?ooooooooooooooooooooooo`000?ooooooooooooooooooo`000?ooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000000000000000
00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooo0000oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooo00000000000000000000oooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003oooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
ooooooooo`0000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000?ooooooooooooooooooooooooooo`0000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`00000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo00000000oooo00000000oooo00000000oooooooo0000000000000000
0000oooo00000000000000000000oooo00000000000000000000oooo00000000oooooooooooo0000
0000oooooooooooooooo000000000000oooooooooooooooooooooooo00000000000000000000oooo
oooo00000000000000000000oooo00000000oooooooo0000000000000000oooooooooooooooooooo
00000000oooooooooooo00000000oooo00000000000000000000oooo00000000000000000000oooo
oooo000000000000000000000000oooooooo000000000000oooooooo00000000000000000000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00000003oool00000003oool00000003oooooool0003o
ooooool00000003oool0003oooooool00000003oool00000003oool00000003oool00000003ooooo
ooooool00000003oooooooooool00000003oool00000003oooooooooooooool00000003oooooool0
0000003oool000000000003oool00000003oool00000003oooooool00000003ooooooooooooooooo
ooooooooool00000003oooooooooool00000003oool00000003oool00000003oool00000003ooooo
ool0003oooooool00000003oooooool00000003oool00000003oool00000003oool00000003ooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`0000000000000000000000000000000?oo
ooooo`0000000000000000000?ooo`0000000000000000000?ooooooo`000000000000000?ooo`00
00000?ooooooo`000000000000000?ooooooo`0000000000000000000?ooooooooooooooo`000000
0?ooooooo`0000000?ooo`0000000?ooooooooooo`000?ooo`0000000?ooooooo`0000000?oooooo
ooooooooooooooooooooo`0000000?ooooooooooo`0000000?ooooooo`000000000000000?oooooo
o`000000000000000?ooooooo`0000000?ooooooo`0000000?ooo`0000000000000000000?oooooo
o`000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo000000000000000000000000
00000000oooooooooooooooo000000000000oooo000000000000oooooooooooo000000000000oooo
oooooooo00000000oooooooo0000000000000000oooooooo00000000000000000000oooooooooooo
oooooooooooo0000000000000000oooo00000000oooooooooooo0000oooo00000000oooooooo0000
0000oooooooooooooooooooooooooooo00000000oooooooooooo00000000oooo000000000000oooo
oooooooo000000000000oooooooooooooooo00000000oooooooo00000000oooo0000000000000000
0000oooo000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0000000000000
0000000000000000003oooooool0003oooooool00000003oool0003oooooool00000003oool00000
003oool00000003oool00000003oooooool0003oooooool00000003oool00000003oool00000003o
ooooooooooooooooool0000000000000003oooooool000000000003oool00000003oool00000003o
ooooool00000003oooooooooooooooooooooooooool00000003oooooooooool00000003oool00000
003oool00000003oool00000003oooooool0003oooooool00000003oooooool00000003oool00000
003oool00000003oool00000003oooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
000000000?ooooooo`00000000000?ooooooo`0000000000000000000?ooo`000000000000000000
0?ooo`0000000000000000000?ooo`0000000?ooooooo`000?ooooooo`0000000?ooooooo`000000
00000?ooooooooooooooooooo`00000000000?ooooooo`000?ooooooo`0000000000000000000?oo
o`00000000000?ooo`000000000000000?ooooooooooooooooooo`0000000?ooooooooooo`000000
0?ooo`0000000000000000000?ooo`0000000000000000000?ooooooo`0000000?ooooooo`000000
0?ooooooo`00000000000?ooooooo`0000000000000000000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo000000000000oooooooo000000000000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo00000000oooooooo00000000oooooooooooooooooooo
oooooooooooo00000000oooooooo00000000oooooooooooooooooooooooooooo00000000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00000003oooooooooool000000000003ooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00000000000000000003ooooooooo
ooooooooooooooooooooool000000000000000000000003oooooooooooooooooool0000000000000
00000000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo00000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool000<0000000004@0000`000080000
2`000100001I0@00o@0000T0000@0000F@400?d000090000400000X20022o_oo2P00010000000000
00000540000h90T000000000001H0@00o00000000000000000000000000:0P00OP400500000X0000
N0000<0S2@000000803<00X20022o_oo:00000X2001n0@000@0H000000308`T00000000000000000
00000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool00000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooo`00000000000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooo000000000000000000000000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooool000000000000000000000003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`0000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003oooooool0000000000000000000000000
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooo`00
0?ooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
o`00000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooo`00000000000?oooooooooooooo
ooooooooo`0000000?ooooooo`000?ooooooooooo`000?ooooooo`00000000000?ooo`000?oooooo
o`000000000000000?ooooooo`000000000000000?ooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
0000000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo00000000oooooooo0000
0000oooooooo00000000oooooooo0000oooo0000oooooooooooo0000oooooooo0000oooooooo0000
0000oooo00000000oooo00000000oooooooo0000oooooooo0000oooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool000000000000000000000003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool0003ooooooooo
ooooooooool0003oooooool0003oooooooooool0003oool0003oooooooooool0003oooooool0003o
ooooooooool0003oool0003oooooooooool0003oooooooooooooooooool0003ooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`00000000000000000000000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`00
0?ooooooooooo`00000000000?ooooooo`000?ooooooooooo`000?ooo`000?ooooooooooo`000?oo
ooooo`0000000000000000000?ooo`000?ooooooooooo`000?ooooooo`000000000000000?oooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo00000000000000000000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooo0000oooooooooooo0000oooo0000oooooooo
oooo0000oooooooo0000oooooooooooo0000oooo0000oooooooooooo0000oooooooo0000oooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool00000000000000000003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooool0003oooooooooooooooooooooooooooooooooool0003oooooool0003oool0
0000003oooooool0003oooooool0003oooooooooool0003oooooool0003oool00000003oooooool0
003oooooool0003oooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000000000000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooo`0000000?ooooooooooooooo`000?ooooooooooooooo`000000
0?ooooooo`000?ooo`0000000?ooooooooooooooo`00000000000?ooooooooooo`00000000000000
0?ooooooo`000000000000000?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo000000000000oooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooo0000oooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0000000000000
000000000000003oooooool0003oooooooooooooooooooooooooooooool000000000003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`00000000000000000000000000000000000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooo0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000oooooooooooooooo
oooooooooooooooooooooooooooooooooooo00000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool000000000000000000000003oooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000000000000000?ooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?ooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003oooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooo0000oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003oooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooool000000000003oooooool0003oooooooooool000000000003oooooool0003ooooo
ooooool0003oooooool0003oooooooooool000000000003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003oooooooooooooooooooooool000000000003ooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooool0000000000000003oooooooooool00000
003oool0003oool0003oooooooooooooool0003oooooool0000000000000003oooooooooool00000
003oooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooool0000000000000003oooooooooooooooooooooool0003ooooooooooooo
ooooooooooooooooooooooooooooooooool0003oooooooooool0003oooooool0003oooooooooool0
000000000000003oool0003oooooooooool0003oooooooooooooooooool00000003oooooooooool0
003oooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
00000000003oooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?ooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooo`00
000000000?ooooooooooo`0000000?ooo`0000000?ooo`000?ooooooo`000?ooooooo`000?oooooo
o`000?ooooooooooo`000?ooooooo`000?ooooooo`0000000?ooo`0000000?oooooooooooooooooo
ooooooooooooooooooooooooo`000?ooooooo`000000000000000000000000000?oooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooo`000?ooooooooooo`0000000?oo
o`000?ooooooo`0000000?ooo`000?ooooooooooooooo`000?ooo`000?ooooooooooo`000?oooooo
o`000?ooooooo`000?ooooooo`000?ooooooo`0000000?oooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooo`000000000000000000000000000?ooooooooooo`000?oo
ooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooo`0000000?ooooooo`000?oo
ooooo`000?ooooooo`0000000?ooo`000?ooooooooooo`000?ooooooooooo`0000000?ooooooo`00
00000?ooo`0000000?ooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000000000000000000000000000?ooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooo0000oooo0000oooooooooooo0000oooooooooooo0000oooo0000oooooooo0000oooooooo
0000oooooooo0000oooooooooooo0000oooooooo0000oooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo000000000000000000000000000000000000oooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooo0000oooooooooooo0000oooo0000oooooooooooooooo0000oooo0000oooooooooooo
0000oooooooo0000oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooo00000000000000000000000000000000
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo00000000oooo
oooo0000oooooooo0000oooooooooooo0000oooo0000oooooooooooo0000oooooooooooo0000oooo
oooooooooooo0000oooo00000000oooooooo00000000oooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo000000000000000000000000000000000000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003oooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooool0003oooooool0003oooooool0003oooooooooool0003oool0003oooooool0
003oooooool0003oooooool0003oooooooooool0003oooooool0003oooooool00000000000000000
003oooooooooooooooooooooooooooooooooooooooooool000000000000000000000000000000000
00000000000000000000000000000000003oool0003ooooooooooooooooooooooooooooooooooooo
ooooool000000000003oool0003oooooooooool0003oool0003oooooooooooooool0003oooooool0
000000000000003oooooool0003oooooooooooooooooool00000000000000000003ooooooooooooo
ooooooooooooooooooooooooooooooooool000000000000000000000000000000000000000000000
0000000000000000003oooooooooooooooooooooooooooooooooooooooooooooool0003oool00000
00000000003oool0003oooooooooool0000000000000003oool0003oooooooooool0003ooooooooo
ool0003oooooooooooooool0003oool000000000000000000000003ooooooooooooooooooooooooo
ooooooooooooooooooooooooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000000003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?ooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooo`000?ooooooo`000?ooooooo`000?ooooooooooo`000?ooo`00
0?ooooooo`000?ooooooo`000?ooooooo`000?ooooooooooo`000?ooooooo`000?ooooooo`000?oo
ooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooo`000?ooooooo`0000000000
0000000000000?ooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooo`0000000?ooooooooooooooo`000?ooooooooooo`000?ooo`000?ooooooooooooooo`00
0?ooo`000?ooooooooooo`000?ooooooo`000?ooooooooooooooooooo`000?ooooooooooo`000?oo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooo`0000000000
0000000000000?ooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`00
0?ooo`000?ooooooo`000?ooo`000?ooooooo`000?ooooooooooo`000?ooo`000?ooooooooooo`00
0?ooooooooooo`000?ooooooooooooooo`000?ooo`000?ooo`0000000?ooo`000?oooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00000000000000000000000?ooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooo0000oooooooooooo0000oooooooooooo0000oooo0000
oooooooo0000oooooooo0000oooooooo0000oooooooo00000000oooooooo0000oooooooo0000oooo
oooooooo0000oooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooo00000000000000000000oooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooo0000oooooooooooo0000oooo00000000oooo
oooooooo0000oooooooo0000oooooooo0000oooooooo0000oooooooo0000oooooooo0000oooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo0000
0000000000000000oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooo0000oooooooooooo00000000oooooooooooo0000oooooooo0000oooo00000000
oooooooo00000000oooooooooooo0000oooooooo0000oooo0000oooooooo0000oooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo00000000000000000000oooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooool0003oooooooooool0003oooooooooool0
00000000003oooooool0003oooooool0003oooooool0003oooooool0003oool00000003oool00000
003oooooooooooooool000000000003oooooooooooooooooooooooooooooooooooooooooooooool0
003oooooooooooooooooooooool000000000003oooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooooooool0003oooooooooooooool0003oool0003oooooooooool0003oool0
003oool0003oool000000000003oooooool000000000003oooooooooool00000003ooooooooooooo
ool00000003oooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooool0000000000000003oooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooool000000000003oooooooooool00000003oooooooooool000000000003ooooo
ool0003oool0003oool0003oool0003oooooooooool00000003oooooool0003oooooool0003ooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000003ooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooo`000?ooooooooooooooooooo`00
0?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooooooo`000?ooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000?ooooooooooooooo`0000000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooo0000oooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooo0000oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooo0000000000000000oooooooooooo
oooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?ooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003oooooooooooooooooool0003ooooo
ooooooooool0003oooooooooooooool0003oooooooooool00000000000000000003oool000000000
00000000003oooooool0000000000000003oooooooooool000000000003oooooool0000000000000
0000003oool0003oool00000000000000000003oooooool0003oooooooooool0003ooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooool0003ooooo
ooooooooool0003oooooooooool000000000000000000000003oool0000000000000003ooooooooo
ool000000000003oooooooooool0000000000000003oool00000000000000000003oool0003ooooo
ool00000000000000000003oool0003oooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003oooooooooooooooooool0003oooooooooooooool0003o
ooooooooool00000000000000000003oooooool0000000000000003oooooool0000000000000003o
ooooooooool000000000003oooooool00000000000000000003oooooool0003oool0000000000000
0000003oooooool0003oooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
o`000?ooooooooooooooo`000?ooooooooooooooo`000?ooooooooooo`000?ooooooooooo`000?oo
o`000?ooooooooooooooo`000?ooo`000?ooooooooooo`000?ooo`000?ooooooooooooooooooo`00
0?ooooooooooo`000?ooo`000?ooo`000?ooooooooooo`000?ooooooo`000?ooooooooooo`000?oo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
o`000?ooooooooooooooo`000?ooooooooooo`000?ooooooooooooooo`000?ooo`000?oooooooooo
o`000?ooo`000?ooooooooooo`000?ooo`000?ooooooooooooooooooo`000?ooooooooooo`000?oo
o`000?ooooooo`000?ooooooooooo`000?ooo`000?ooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooo`000?oooooooooo
ooooo`000?ooooooooooo`000?ooooooooooo`000?ooooooo`000?ooooooooooo`000?ooo`000?oo
ooooooooo`000?ooo`000?ooooooooooooooooooo`000?ooooooooooo`000?ooooooo`000?ooo`00
0?ooooooooooo`000?ooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooo0000oooooooooooooooo0000oooooooooooooooo0000oooooooooooo000000000000
oooo0000oooo0000oooooooooooooooo0000oooo00000000000000000000oooo0000oooooooooooo
oooooooo0000oooooooooooo0000oooo0000oooo000000000000oooo0000oooooooo0000oooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooo0000oooooooooooooooo0000oooooooooooo0000000000000000oooo0000oooo0000
oooooooooooo0000oooo00000000000000000000oooo0000oooooooooooooooooooo0000oooooooo
oooo0000oooo0000oooooooo000000000000oooo0000oooo0000oooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo0000
oooooooooooooooo0000oooooooooooo000000000000oooo0000oooooooo0000oooooooooooo0000
oooo00000000000000000000oooo0000oooooooooooooooooooo0000oooooooooooo0000oooooooo
0000oooo000000000000oooo0000oooooooo0000oooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003oooooooooooooooooool0003oooooooooooooool0003oooooooooooooool0003ooooooooooooo
ooooooooool00000003oool0003oooooooooooooool0003oool0003oooooooooool0003oool0003o
ooooooooooooooooool0003oooooooooool0003oool0003oooooooooooooool00000003oooooool0
003oooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooool0003oooooooooooooool0003oooooooooooooooooooooool000000000
003oool0003oooooooooool0003oool0003oooooooooool0003oool0003oooooooooooooooooool0
003oooooooooool0003oool0003oooooooooooooool000000000003oool0003ooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
ooooool0003oooooooooooooool0003oooooooooooooooooool000000000003oooooool0003ooooo
ooooool0003oool0003oooooooooool0003oool0003oooooooooooooooooool0003oooooooooool0
003oooooool0003oooooooooooooool00000003oooooool0003oooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?ooooooooooooooooooo`000?ooooooooooooooo`000?ooooooooooooooo`000?oo
ooooooooo`000?ooooooooooo`000?ooo`000?ooooooooooooooo`000?ooo`000?ooooooooooo`00
0?ooo`000?ooooooooooooooooooo`000?ooooooooooo`000?ooo`000?ooo`000?ooooooooooo`00
0?ooooooo`000?ooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooo`000?ooooooooooooooo`000?ooooooooooo`000?oooooo
ooooooooo`000?ooo`000?ooooooooooo`000?ooo`000?ooooooooooo`000?ooo`000?oooooooooo
ooooooooo`000?ooooooooooo`000?ooo`000?ooooooo`000?ooooooooooo`000?ooo`000?oooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
ooooooooooooooooo`000?ooooooooooooooo`000?ooooooooooo`000?ooooooooooo`000?oooooo
o`000?ooooooooooo`000?ooo`000?ooooooooooo`000?ooo`000?ooooooooooooooooooo`000?oo
ooooooooo`000?ooooooo`000?ooo`000?ooooooooooo`000?ooooooo`000?oooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooooooo0000oooooooooooo
oooo000000000000oooooooo0000000000000000oooo00000000000000000000oooooooo00000000
00000000oooooooooooo000000000000oooooooo0000oooooooooooo0000oooo0000oooooooo0000
000000000000oooooooo000000000000oooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooo0000oooooooooooooooo000000000000oooo
oooo00000000000000000000oooo0000000000000000oooooooooooo000000000000oooooooooooo
0000000000000000oooo0000oooooooooooo0000oooo0000oooooooo00000000000000000000oooo
0000000000000000oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooo0000oooooooooooooooo000000000000oooo0000000000000000
0000oooooooo0000000000000000oooooooo0000000000000000oooooooooooo000000000000oooo
oooo0000oooooooooooo0000oooooooo0000oooooooo0000000000000000oooooooo000000000000
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003oooooooooooooooooool0003oooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003oooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?ooooooooooooooooooo`000?ooo`000000
000000000000000000000?ooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooo`0000000000000000000000
0?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?ooooooo`00000000000000000000000?oooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?ooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003oooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooo00000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool00000003oooooooooooooooooool000000000000000000000
003oool0000000000000003oooooool0000000000000003oooooooooool0000000000000003oool0
00000000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000000
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`0000000?ooooooooooooooooooo`0000000?oo
o`0000000?ooo`00000000000?ooo`000?ooo`00000000000?ooo`000?ooooooo`00000000000?oo
o`000?ooo`0000000?ooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooo
00000000000000000000oooo00000000000000000000oooo00000000oooooooooooooooooooo0000
0000000000000000oooooooo00000000000000000000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000000000000000
003oooooooooooooool000000000003oool00000000000000000003oool00000003ooooooooooooo
ooooool00000000000000000003oool0000000000000003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000000000000000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000
0000000000000?ooooooo`0000000?ooo`0000000?ooo`0000000?ooooooo`000?ooo`0000000000
0?ooo`000?ooooooo`0000000?ooooooo`000?ooo`0000000?ooooooo`0000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo00000000000000000000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo00000000oooooooooooooooooooo00000000000000000000oooooooo0000000000000000oooo
oooo0000000000000000oooooooooooo0000000000000000oooo000000000000000000000000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0000000000000000000000000003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000000000000000000000000000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`00000000000000000000000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000000000000000oooo0000
00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003oool00000
003oooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool00000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003oool00000003oooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000000000000000
0000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000000000000000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000
00000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo00000000000000000000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0000000000000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool000000000000000000000003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`0000000000000000000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000000000000000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo00000000000000000000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo000000000000000000000000
00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0000000000000003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003oooooool0
0000003oooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo000000000000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`00
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000?oooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooo0000000000000000oooooooooooo00000000
oooo0000oooooooo0000oooooooooooo0000oooooooo000000000000oooo0000oooooooooooo0000
0000oooooooooooo000000000000oooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooo0000oooooooo0000oooooooooooo0000oooooooo00000000
0000oooo0000oooo0000oooooooo0000oooooooooooooooooooo00000000oooooooooooo0000oooo
oooooooo0000oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
ooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooool0003ooooo
ooooooooooooool0000000000000003oool0003oooooool00000000000000000003oool0003ooooo
ooooool0003oooooool0003oooooooooool000000000003oooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooool00000003oooooooooool0003oool0
003oooooool00000003oooooool0003oooooooooool0003oooooool0003oooooool00000003oool0
0000003oooooool0003oool00000003oool00000003oooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooool0003oooooool00000003oooooool0003oool0
003oooooooooool00000003oool0003oooooool0003oooooooooool00000003oooooool0003oool0
00000000003oooooool00000003oooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
0000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
o`0000000?ooooooooooo`000?ooooooooooo`000?ooo`000?ooooooo`000?ooooooooooo`000?oo
o`000?ooooooooooo`000?ooooooo`000?ooooooo`000?ooooooooooo`000?oooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
o`000?ooo`000?ooooooooooo`000?ooooooo`000?ooooooooooo`000?ooooooo`000?oooooooooo
o`000?ooo`000?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooo`000?ooooooo`0000000?oooooo
o`000?ooo`000?ooooooooooooooo`000?ooo`000?ooooooo`000?ooooooooooo`000?oooooooooo
o`000?ooo`000?ooo`000?ooooooo`0000000?ooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooo0000000000000000oooooooo0000oooooooooooo0000oooo0000oooooooo0000oooooooo
oooo0000oooo0000oooooooooooo0000oooooooo0000oooooooo00000000000000000000oooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooo000000000000oooo0000oooooooooooo0000oooooooo0000oooooooooooo0000oooooooo0000
0000000000000000oooo0000oooooooooooooooooooo00000000000000000000oooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000oooo00000000
00000000oooo0000oooooooo00000000000000000000oooo0000oooooooo0000oooooooooooo0000
oooooooooooo0000oooo0000oooo00000000000000000000oooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
ooooooooooooooooool0003oooooool0003oooooool0003oooooooooool0003oool0003oooooool0
003oooooooooool0003oool0003oooooooooool0003oooooool0003oooooool0003oooooooooool0
003oooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooool000000000003oooooooooool0003oooooooooool0003oooooool0003oooooooooool0003o
ooooool0003oooooooooool0003oool0003oooooooooooooooooool0003oooooooooool0003ooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooooooool0003o
ool0003oooooool0003oool0003oool0003oooooooooooooool0003oool0003oooooool0003ooooo
ooooool0003oooooooooool0003oool0003oooooool00000003oool0003ooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`00
0?ooooooooooooooooooooooo`0000000?ooooooo`000?ooooooo`0000000?ooooooo`000?ooo`00
0?ooooooo`000?ooooooooooo`000?ooo`0000000?ooooooo`000?ooooooo`000?ooooooo`000000
0?ooo`0000000?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooo`0000000?ooooooooooooooooooo`000?ooooooooooo`000?ooooooo`0000000000
0000000000000?ooo`0000000000000000000?ooooooo`000000000000000?ooooooo`0000000000
0?ooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooo`0000000?ooooooooooo`000?ooo`000?ooooooo`0000000000000000000?ooo`0000000000
0000000000000?ooooooo`000000000000000?ooo`000?ooooooo`000?ooooooooooo`000?oooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooo0000oooooooooooo0000oooooooooooooooo00000000
oooooooo0000oooooooo0000oooooooooooo0000oooo0000oooo00000000oooo000000000000oooo
oooooooo000000000000oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooo0000oooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooo0000oooooooooooooooooooo00000000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooool0003oooooooooooooooooooooool0003oooooooooool00000003ooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooool00000000000000000003ooooooooooooooooooooo
ooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooool0003oooooooooooooooooool00000003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
ooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?ooooooooooooooo`00
0?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooo000000000000oooooooooooooooo000000000000oooooooo0000
oooooooooooo0000000000000000oooooooooooo00000000oooooooooooo0000000000000000oooo
0000oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo0000000000000000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooo00000000000000000000oooooooooooo0000000000000000oooo0000oooooooooooo
0000000000000000oooooooooooo000000000000oooo000000000000000000000000oooo0000oooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo000000000000oooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooo00000000000000000000oooooooooooo0000000000000000oooo0000oooooooooooo00000000
00000000oooooooooooo000000000000oooo000000000000000000000000oooo0000oooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo000000000000oooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo000000000000oooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ool0003oooooooooooooooooooooooooool0003oooooooooool0003oooooooooool0003oool0003o
ooooool0003oooooooooool0003oooooool0003oooooool0003oooooool0003oool0003ooooooooo
ool0003oool0003oooooooooooooooooooooooooooooool0003oooooooooooooool0000000000000
0000003oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooool0003oooooooooooooool0003oool0003oooooooooool0003oool0003o
ooooooooool0003oooooool0003oooooool0003oooooooooooooool0003oooooooooooooool0003o
ool0003oooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool00000000000000000003oooooooooooooool0003ooooooooooooooooo
ooooooooool0003oooooooooooooooooool0003oool0003oooooooooool0003oool0003ooooooooo
ool0003oooooool0003oooooool0003oooooooooooooool0003oooooooooooooool0003oool0003o
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool000000000000000000000003oooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0000000000000
00000000003oooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
ooooooooooooo`000?ooooooooooooooooooooooo`000?ooooooooooooooooooo`000?ooo`000?oo
ooooooooo`000?ooo`000?ooooooooooo`000?ooooooo`000?ooooooo`000?ooooooooooooooo`00
0?ooooooooooo`000?ooo`000?ooooooooooooooooooooooooooooooo`000?ooo`00000000000000
00000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooo`000?ooooooooooooooooooooooooooo`000?ooooooooooo`00
0?ooo`000?ooooooooooo`000?ooooooo`000?ooooooo`000?ooooooooooooooo`00000000000000
0?ooo`000?ooo`000?ooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`00000000000000000000000000000000000?oooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooo`000?ooooooooooo`000?ooo`00
0?ooooooooooo`000?ooooooo`000?ooooooo`000?ooooooooooooooo`000000000000000?ooo`00
0?ooo`000?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`0000000000000000000000000000000000
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`00000000000000000000000000000000000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooo0000oooooooooooo0000oooo0000oooooooooooo0000oooooooo0000oooooooo0000oooooooo
oooooooooooo00000000oooo0000oooo0000oooooooooooooooooooooooooooooooo000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000oooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000oooo
oooooooo0000oooo0000oooooooooooo0000oooooooo0000oooooooo0000oooooooooooooooooooo
oooooooo000000000000oooo0000oooooooooooooooooooooooooooooooo00000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000oooooooooooo
0000oooo0000oooooooooooo0000oooooooo0000oooooooo0000oooooooooooooooooooooooooooo
000000000000oooo0000oooooooooooooooooooooooooooo00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
ooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool0003ooooooooooooo
ooooooooooooool0003oooooooooool0003oool0003oooooooooool0003oooooool0003oooooool0
003oooooooooooooool0003oooooool00000003oool0003oooooooooooooooooooooooooooooool0
003oool0000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000003oooooooooooooooooooooool0003ooooooooooooooooooooooooo
ool00000003oooooool0003oool00000003oooooool0003oooooool0003oooooool00000003oool0
003oool00000003oooooooooool0003oool0003oooooooooooooooooooooooooooooool000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000003oooooooooooooooooooooooooool0003oooooooooooooooooooooooooool00000
003oooooool0003oool00000003oooooool0003oooooool0003oooooool00000003oool0003oool0
0000003oooooooooool0003oool0003oooooooooooooooooooooooooool000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooo`000?ooo`000?ooooooo`0000000?ooooooo`000?ooooooo`00
0?ooooooo`000?ooooooo`000?ooooooo`000?ooooooo`000?ooo`000?oooooooooooooooooooooo
ooooooooo`000?ooooooooooooooooooo`000000000000000?oooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooo
ooooooooooooooooo`00000000000?ooooooo`000?ooo`000?ooo`000000000000000?oooooooooo
o`00000000000?ooooooooooo`00000000000?ooooooo`000?oooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000000
00000?ooooooooooooooo`000?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooo`00000000000?ooooooo`000?ooo`000?ooo`000000000000000?ooooooooooo`000000
00000?ooooooooooo`00000000000?ooooooo`000?ooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000
0000000000000?ooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000000000000000?ooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooo0000oooooooooooooooooooo0000oooooooo000000000000oooooooo00000000000000000000
000000000000oooooooooooo00000000oooooooooooooooo000000000000oooo0000oooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooo0000000000000000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000
oooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
00000000oooooooooooooooooooooooo0000oooooooooooooooooooooooooooo00000000oooooooo
oooo00000000oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo000000000000oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo000000000000oooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
ooooooooooooooooool0003oooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooool0000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ool0000000000000003oooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003oooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`00
0?ooooooooooooooooooooooooooooooo`00000000000?oooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooo000000000000oooooooo0000
000000000000oooooooo0000oooooooooooo0000oooooooo00000000oooo0000000000000000oooo
0000oooooooooooo0000oooooooo00000000000000000000000000000000oooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooool0003ooooooooooooo
ool0003oooooooooooooool0003oool0003oooooooooool0003oooooool0003oool0003ooooooooo
ool0003oool0003oooooooooool0003oooooool0003oooooooooooooooooooooool0003ooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooo`000?oo
ooooooooooooo`000?ooooooooooooooo`000?ooo`000?ooooooooooo`000?ooooooo`000?ooo`00
00000000000000000?ooo`000?ooooooooooo`000?ooooooo`000?ooooooooooo`00000000000000
0?ooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooo0000oooooooooooooooo0000oooooooooooooooo0000oooo0000oooooooooooo0000oooooooo
0000oooo0000oooooooooooo0000oooo0000oooooooooooo0000oooooooo0000oooooooo0000oooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooool00000003oool0003oool00000003oooooool00000003oool00000003oooooool0
003oooooool0003oool00000003oooooool0003oool00000003oooooool0003oooooool0003ooooo
ool0003oooooooooool0003oooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooo`00000000000?ooooooooooo`0000000?ooooooooooo`000?oo
o`0000000?ooooooo`00000000000?ooooooo`0000000?ooooooo`000?ooo`0000000?oooooooooo
o`00000000000?ooo`00000000000?ooooooooooooooo`000?oooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ool00000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000003ooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000000000000000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooo`00000000000?ooooooooooooooo`000?ooooooooooooooooooooooooooo`00
0?ooooooooooooooo`000?ooooooooooooooo`000000000000000?ooooooooooo`0000000?oooooo
o`0000000?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000000000000000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooo0000oooooooooooo0000oooooooooooo0000oooooooooooooooooooo
oooooooo0000oooooooooooooooo0000oooooooooooo0000oooooooooooo0000oooooooo0000oooo
oooo0000oooo0000oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000000000000000003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooool00000003oooooooooool00000003oooooool0003ooooooooo
ooooooooooooooooool0003oooooooooooooool0003oooooooooool0003oooooooooool0003oool0
003oooooooooooooooooool0003oooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000000
0000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooo`000?ooooooooooooooooooo`000?ooooooo`00
0?ooooooooooooooooooooooooooo`000?ooooooooooooooo`000?ooooooooooooooo`0000000?oo
o`000?ooo`000?ooooooooooooooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooo0000oooooooo0000000000000000
oooooooo0000oooooooooooooooooooooooooooo0000oooooooooooooooo0000oooooooooooo0000
oooooooo00000000oooo0000oooooooooooooooooooo0000oooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool00000003oool0003oool000000000003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooool0003ooooooooooooo
ooooooooooooooooool0003oooooooooooooooooooooooooool0003oooooooooooooool00000003o
ooooooooool0003oooooool0003oooooool0003oooooool0003oool0003ooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooo`000?ooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooo`000?oooooooooooooo
o`00000000000?ooooooo`000000000000000?ooooooooooo`0000000?ooo`000?ooo`000?oooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooo000000000000000000000000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooo0000oooooooooooo0000oooooooooooo0000oooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooool000000000000000000000003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooool000000000003oooooooooooooool0003oooooooooooooool000000000
0000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooo`000?ooooooooooooooo`0000000000000000000?ooooooo`0000000?ooo`0000000?oo
ooooo`000000000000000?ooo`0000000?ooooooooooo`00000000000?ooooooo`00000000000?oo
o`0000000000000000000?ooo`0000000?ooooooooooo`000?ooooooooooooooooooo`0000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooo0000oooooooooooo000000000000oooo000000000000oooo00000000oooo
0000oooooooo000000000000oooo0000oooo00000000oooooooo00000000oooo00000000oooo0000
0000oooo000000000000oooo00000000oooo00000000oooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo00000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooool0003oooooooooool00000003oooooool000000000003oool0
000000000000003oooooool00000000000000000003oool00000003oooooool00000000000000000
003oool00000003oool00000003oooooooooool0003oool00000003oooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003oooooool000000000
0000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooo`000?ooooooooooooooooooo`00000000000000
0?ooooooo`000000000000000?ooooooo`0000000000000000000?ooo`0000000?ooooooo`000000
0000000000000?ooo`0000000?ooo`0000000?ooooooooooo`000?ooo`0000000?ooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooo`00000000000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooo0000oooooooooooo000000000000
00000000oooooooooooo0000000000000000oooooooo00000000000000000000oooo00000000oooo
oooo000000000000000000000000000000000000000000000000000000000000oooo000000000000
000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003oooooooooooooooooool0003oooooooooool0
0000003oooooooooool00000003oool00000003oool00000003oooooooooool00000003oooooool0
0000003oooooooooool000000000003oool0000000000000003oooooool000000000003oooooool0
00000000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oo
ooooooooo`000000000000000000000000000?ooo`0000000?oooooooooooooooooooooooooooooo
ooooooooo`0000000?ooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooo0000oooooooooooooooooooo000000000000oooooooooooo00000000oooooooooooooooooooo
oooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003oooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?ooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooo000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003ooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000000000000000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0000000000000003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000000000000000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000000000000000
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000
000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`00000000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo00000000000000000000oooo00000000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`0000000000000000000?ooooooooooo`000?ooooooo`00000000000?ooooooooooooooo`000000
0?ooooooooooooooo`000000000000000?oooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooo0000oooooooo0000oooooooo0000oooo0000oooooooooooo
0000oooooooo0000oooooooooooo0000oooo00000000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooool0003oool0003oool0003oooooooooool0
003oooooool0003oooooooooool0003oool0003oooooooooool0003ooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooo`000?ooo`000?ooo`000?oo
ooooooooo`000?ooooooo`000?ooooooooooo`000?ooo`000?ooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo0000oooooooo0000
oooo0000oooooooooooo0000oooooooo0000oooooooooooo0000oooo0000oooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000000000000000003o
ooooool0003oool00000003oool00000003oooooool0003oooooool00000003oool00000003oool0
0000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooo`000?ooo`000?ooooooo`00000000000?ooooooooooooooo`0000000?oooooooooooooo
o`000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooo00000000oooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool000000000000000000000003oooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
0000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool00000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`00000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000000000000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
00000000003oooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo00000000000000000000
oooooooooooo0000oooooooooooo0000oooo0000oooooooo0000oooooooo00000000000000000000
oooooooo0000oooooooooooo00000000oooooooooooooooooooooooo0000000000000000oooooooo
00000000000000000000oooooooo000000000000oooooooooooo0000oooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooool0003ooooooooo
ooooooooool0003oooooool0003oooooooooool0003oool0003oooooool0003oooooool0003ooooo
ooooool0003oooooool0003oooooooooool00000003oooooooooooooooooooooool0003ooooooooo
ool0003oool0003oooooooooool0003oooooool0003oool0003oooooooooool0003ooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooo`00
0?ooooooooooooooooooo`000?ooooooo`000?ooooooooooo`000?ooo`000?ooooooo`000?oooooo
o`000?ooooooooooo`000?ooooooo`000?ooooooooooo`0000000?ooooooooooooooooooooooo`00
0?ooooooooooo`000?ooo`000?ooooooooooo`000?ooooooo`000?ooo`000?ooooooooooo`000?oo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooo0000000000000000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooo0000oooooooo0000oooooooooooo0000oooo0000oooooooo
0000oooooooooooo0000000000000000oooooooo0000oooooooo0000oooooooo0000oooooooooooo
oooooooo0000oooooooooooo0000oooooooo0000000000000000oooooooo0000oooo0000oooooooo
oooo0000oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo000000000000
0000oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo000000000000oooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000
0000000000000000oooo0000oooooooooooo0000oooooooooooooooo0000000000000000oooooooo
0000oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003oooooooooool000000000000000000000003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
ooooooooooooooooool0003oooooooooooooooooool0003oooooool0003oooooooooool0003oool0
003oooooool0003oooooool0003oooooooooool0003oooooool0003oooooool0003oooooool0003o
ooooooooooooooooool0003oooooooooool0003oool0003oooooooooool0003oooooool0003oool0
003oooooooooool0003oooooooooooooooooooooooooooooooooool0003oooooooooool000000000
000000000000003oooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool000000000000000000000003oooooooooool0003ooooooooooooooooooooo
ooooool0003oooooooooooooooooool0003oooooooooool00000003oooooool0003ooooooooooooo
ool0003oool0003oooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00000000000000000000000000000000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooo`000?ooooooooooooooooooo`000?ooooooo`00000000000?oo
o`000?ooo`000000000000000?ooooooooooo`000000000000000?ooooooo`000000000000000?oo
ooooooooo`000?ooooooooooooooo`000000000000000?ooooooooooo`000000000000000?ooo`00
00000000000000000000000000000?ooooooooooooooooooooooooooooooooooo`00000000000000
000000000000000000000?ooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`00000000000000000000000000000000000?oooooooooo
ooooooooooooooooo`000?ooooooooooooooooooo`000?ooooooooooo`0000000?ooooooo`000000
00000000000000000?ooo`000?ooooooooooooooooooooooooooooooo`000?ooooooooooooooo`00
00000?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000oooooooooooooooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
oooooooooooooooooooooooooooo0000oooooooooooooooooooo0000oooooooo0000oooooooo0000
oooo0000oooooooooooooooo0000oooo0000oooooooooooooooooooooooooooooooo0000oooooooo
oooooooo00000000oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000003oooooooooooooooooooooooooooooool0003oooooooooooooooooool0003o
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oool0003ooooooooooooooooooooooooooooooooooooooooooooo
ooooool0000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000003oooooooooooooooooooooooooool0003oooooooooooooooooool0003oool00000003o
ooooool0003oool00000003oooooool00000003oool0003oooooooooooooooooooooooooooooool0
003oooooooooooooool00000003oooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
o`0000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooo`0000000000000000000?ooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000000000000000
0?ooooooooooooooo`000?ooooooooooooooooooooooooooo`000?ooooooooooooooooooo`000?oo
o`000?ooooooooooo`000?ooooooooooo`0000000?ooooooooooo`00000000000?oooooooooooooo
o`000?ooo`000?ooooooooooooooo`0000000?ooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooo0000000000000000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooo0000000000000000oooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000
0000oooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo00000000oooooooooooooooo00000000oooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooooooool0003ooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003oooooooooooooool00000003ooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooo`00000000000?oo
ooooooooo`0000000?ooooooooooo`000?ooooooooooo`000?ooooooo`0000000?ooooooo`000000
0?ooooooooooo`000?ooooooo`000?ooooooo`00000000000?ooo`00000000000?oooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo00000000
oooo0000oooo00000000oooooooo00000000oooo0000oooooooooooo0000oooooooo0000oooo0000
0000oooooooo0000oooooooo0000oooooooo0000oooooooo0000oooooooo0000oooooooooooo0000
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
ool0003oooooooooooooool0003oooooooooooooool0003oool0003oooooooooool0003oooooool0
003oool0003oooooooooooooooooooooool0003oooooool0003oooooool0003ooooooooooooooooo
ooooool0003oooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00000003oooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?ooooooooooo`000?ooooooooooooooo`000?ooooooooooooooo`000?ooo`000?ooooooooooo`00
0?ooooooo`000?ooo`0000000000000000000?ooooooo`000?ooooooo`000?ooooooo`000?oooooo
o`000000000000000?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`0000000?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooo0000oooooooooooooooo0000oooooooooooooooo0000oooo0000oooo
oooooooo0000oooooooo0000oooo0000oooooooooooo0000oooooooo0000oooooooo0000oooooooo
0000oooooooo0000oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo00000000oooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003oooooooooooooool000000000003oooooool0000000000000003ooooo
ool00000000000000000003oool000000000003oool0000000000000003oooooool0000000000000
003oooooool00000000000000000000000000000003oooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00000003oooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`00000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000?oooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
00000?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo00000000
00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooo00000000oooooooo0000oooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooool00000
000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool00000000000000000003oool00000003oooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?ooooooooooooooooooooooo`000000000000000?ooooooooooo`000?ooo`00
00000000000000000?ooooooo`000000000000000?ooooooo`0000000000000000000?ooooooo`00
000000000?ooooooo`000?ooooooooooooooooooooooooooooooooooooooo`000?ooo`0000000000
000000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000000000000000000000000000?ooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooo0000oooooooooooo0000oooooooo
0000oooo0000oooooooooooo0000oooo0000oooooooooooo0000oooooooo0000oooooooooooo0000
oooo0000oooooooooooo0000oooo0000oooooooooooooooooooooooooooooooooooooooo00000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000000000000000000000000000oooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool0003oooooooooool0
003oooooool0003oool000000000003oool0003oool0003oooooooooool0003oooooool0003ooooo
ooooool0003oool00000000000000000003oool0003ooooooooooooooooooooooooooooooooooooo
ool0003oool000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool00000000000000000003ooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?oo
ooooooooo`000?ooooooo`000?ooooooooooo`00000000000?ooo`000?ooooooooooo`000?oooooo
o`000?ooooooooooo`000?ooo`000?ooooooooooo`000?ooo`000?oooooooooooooooooooooooooo
ooooooooooooo`000?ooooooooooooooooooo`0000000000000000000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000000000000000?oo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooo0000oooooooo00000000oooooooo0000oooo0000oooooooooooo0000oooo00000000oooo0000
0000oooooooo0000oooooooo00000000oooo00000000oooo00000000oooo00000000oooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000000000000000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo000000000000
0000oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
ooooooooooooool000000000003oooooooooooooool0003oooooool000000000003oooooooooool0
000000000000003oooooooooool0000000000000003oooooool000000000003oooooool0003oool0
003oooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool000000000003oooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
ooooooooooooooooooooooooooooooooooooooooo`00000000000000000000000?ooo`0000000?oo
ooooooooo`000?ooooooo`0000000?ooooooo`0000000?ooooooo`00000000000?oooooooooooooo
ooooooooooooooooooooo`0000000000000000000?oooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?ooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?ooooooooooo`00000000000000000000000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooo`0000000000000000000?ooo`000?ooooooooooooooo`000?oo
ooooooooooooo`00000000000?ooooooo`000?ooooooooooooooooooooooo`000000000000000000
0?ooooooooooo`00000000000?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooo00000000oooo
00000000oooooooooooo0000oooooooo00000000oooooooo00000000oooo00000000oooo00000000
oooooooooooooooooooooooooooo00000000000000000000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooo0000oooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo00000000000000000000
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooo
oooo0000oooooooooooo0000oooooooo0000oooooooo0000oooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003oooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooo
ool0003oool00000003oooooooooool0003oooooool00000003oooooool00000003oool00000003o
ooooooooooooooooooooooooooooool0000000000000000000000000003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000000000000000
000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooool0003oooooooooooooooooool0003o
ooooooooool00000003oooooooooool0003oooooooooool0003oool0003ooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooool0003oooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?ooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oo
ooooooooooooo`000?ooo`0000000?ooooooooooo`000?ooooooo`0000000?ooooooo`0000000?oo
o`0000000000000000000?ooooooooooo`0000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`0000000?ooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000?ooooooooooooooooooooooo`000?oooooooooooooo
ooooo`000?ooooooooooo`0000000?ooooooooooo`0000000000000000000?ooo`000?oooooooooo
ooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
00000000oooooooooooooooo0000oooo000000000000oooooooo0000oooooooo00000000oooooooo
00000000oooo00000000oooo00000000oooooooooooooooooooooooooooo00000000000000000000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooo
0000oooooooo000000000000oooooooo0000000000000000oooooooo00000000oooo0000oooooooo
oooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooo000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo0000oooo
oooooooooooooooo0000oooooooo0000oooooooo0000oooooooo0000oooooooooooo0000oooo0000
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
ooooooooool00000003oooooooooooooool0003oool0000000000000003oool0003oooooool00000
0000000000000000003oooooool000000000003oooooooooooooooooooooooooooooooooooooool0
000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
ool0000000000000003oooooooooool0003oooooooooool0003oooooool0003oooooool0003ooooo
ooooool0000000000000003oool0003oooooooooooooooooool0003ooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooool0003oool0003oooooooooool0003oool0003oooooool0003oool0003oooooool00000
003oooooool0003oooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooool00000000000000000003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ool0003oooooooooooooooooool0003oooooool0003oooooool00000003oool0003oooooool00000
003oool00000003oooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
ooooooooooooooooooooo`0000000?ooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
ooooooooo`000?ooooooooooooooo`000?ooooooo`000?ooooooooooo`000?ooooooo`000?oooooo
o`000?ooooooo`000?ooooooooooo`000?ooo`000?ooooooooooooooo`000?ooo`000?oooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooo`000?ooooooooooooooooooo`000?ooooooooooooooo`000?ooo`000?oo
ooooooooo`000?ooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooo`000?ooooooooooooooooooo`000?ooooooo`000?ooooooooooo`000?ooooooo`00
000000000?ooooooo`00000000000?ooooooooooooooooooooooooooooooo`000?oooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooo00000000oooooooooooooooo0000oooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooo0000oooooooooooooooo0000oooooooo0000oooooooooooo0000oooooooo
0000oooooooo0000oooooooo0000oooooooooooo0000oooo0000oooooooooooooooo0000oooo0000
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooo0000oooo0000000000000000oooooooo0000000000000000
oooo0000oooooooooooo0000oooooooo00000000000000000000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooo00000000oooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003oooooooooooooooooooooool0003oooooooooooooool0003oooooool0003oooooooooool0
003oooooool0003oooooool0003oooooooooool00000003oool0003oool0003oooooooooool0003o
ooooool0003oooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooool0003oool0003oooooooooooooooooool0003o
ooooooooooooool0003oooooooooool0003oooooool0003oooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooool0003oooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000
003oooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?ooooooooooooooooooooooo`000?ooooooooooooooo`000?ooooooo`000?oo
ooooooooo`000?ooooooo`000?ooooooo`000?ooooooo`000?ooooooo`0000000?ooo`000?oooooo
ooooo`000?ooooooo`000?ooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`00000000000?ooooooo`000?ooo`000000000000000000
0?ooo`000000000000000?ooo`000?ooooooooooo`000?ooooooo`000000000000000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooo0000oooooooooooooooo0000oooo
oooo00000000oooooooo0000oooooooo00000000oooo0000oooooooooooo0000oooooooo0000oooo
00000000oooooooo0000oooooooooooo0000oooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool0003ooooooooooooo
ool0003oooooool000000000003oool0003oooooool0000000000000003oooooooooool000000000
0000003oool0003oool0003oool0003oooooooooool0003ooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?oo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooo`000?ooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooo0000oooooooooooooooo0000oooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooo0000000000000000oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool00000003oooooooooooooooooooooooooooooooooool0003ooooo
ool0000000000000000000000000003oooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
o`00000000000000000000000000000000000?ooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooo00000000000000000000oooo
oooooooo00000000oooo0000oooooooo0000oooooooooooo000000000000oooooooooooo0000oooo
oooooooooooooooooooo0000oooooooo000000000000oooooooooooo0000000000000000oooo0000
oooooooooooo0000oooooooo0000000000000000oooooooo000000000000oooooooooooooooooooo
oooooooooooo00000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo00000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooool0003ooooooooo
ool0003oooooooooool0003oooooool0003oooooool0003oooooool0003oooooooooool0003ooooo
ool0003oooooooooooooooooooooool0003oool0003oooooool0003oooooool0003oooooooooool0
003oool0003oooooooooool0003oool0003oooooooooool0003oooooool0003oool0003ooooooooo
ooooooooooooooooooooool0003oooooool000000000000000000000003oooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooo`000?oo
ooooooooooooooooo`000?ooooooo`000?ooooooo`000?ooooooo`000?ooooooo`00000000000000
00000?ooooooo`000?ooooooooooooooooooooooo`00000000000?ooooooo`000?ooooooo`000?oo
ooooooooo`000?ooo`000?ooooooooooo`000?ooo`0000000000000000000?ooooooo`000?ooo`00
0?ooooooooooooooooooooooooooooooo`000?ooooooooooooooo`0000000000000000000?oooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooo0000oooooooooooooooooooo0000oooooooo0000oooooooo0000oooooooo0000oooooooo0000
oooooooooooo0000oooooooo0000oooooooooooooooooooooooo0000oooo0000oooooooo0000oooo
oooo0000oooooooooooo0000oooo0000oooooooooooo0000oooo0000oooooooooooo0000oooooooo
0000oooo0000oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
0000oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
ooooooooooooool0003oooooooooooooooooool0003oooooool0003oooooool0003oooooool0003o
ooooool00000003oool00000003oooooool0003oooooooooooooooooooooool0003oool00000003o
ool0003oooooool00000003oool00000003oool00000003oooooool0003oool00000003oooooool0
003oool0003oooooool00000003oooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
ooooooooooooooooooooooooo`000?ooooooooooooooooooo`000?ooo`000?ooo`000?ooo`000000
00000?ooooooooooooooo`00000000000?ooooooooooo`00000000000?ooooooooooooooo`000?oo
ooooooooo`0000000?ooooooooooo`000000000000000?ooo`000?ooo`0000000?oooooooooooooo
o`0000000?ooooooo`000?ooooooooooo`000?ooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooo0000oooooooooooo0000oooooooooooo0000oooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003oooooooooooooooooooooooooooooool00000000000000000003ooooooooo
ool0003oooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003oooooooooooooool0003oooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo000000000000oooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool000000000000000000000003ooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`0000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000?oooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000000000000000
00000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`00000000000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`0000000000000000000?ooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo000000000000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo000000000000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo000000000000oooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool000000000003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00000003oooooooooool00000003oool00000003oooooool0000000000000
0000003oool0003oooooooooool00000003oooooool00000003oooooooooooooooooool00000003o
ooooooooool0000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000?ooooooooooo`0000000?ooo`0000000?ooooooo`00
00000000000000000?ooo`000?ooooooooooo`0000000?ooo`000000000000000?oooooooooooooo
o`0000000?ooooooo`0000000000000000000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000000000000000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo00000000oooooooo00000000oooooooo00000000
oooo00000000oooo000000000000oooo0000oooooooooooo00000000oooo00000000oooo00000000
oooooooo0000000000000000oooo00000000000000000000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0000000000000
0000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00000003oooooool00000003ooooo
ool00000003oool00000003oooooool00000003oool0003oooooooooool00000003oool000000000
00000000003oooooool0000000000000003oooooool0000000000000003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000
000000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000000000000000000
0?ooooooooooo`0000000?ooo`0000000?ooo`00000000000?ooo`0000000?ooooooo`0000000?oo
o`0000000000000000000?ooooooo`000?ooooooo`0000000000000000000?ooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000
oooo0000oooooooooooooooo00000000oooooooo00000000000000000000oooo0000000000000000
00000000oooo0000000000000000oooooooo00000000oooooooooooo000000000000000000000000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0000000000000003oool00000003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00000003oool000000000003oooooool00000003oooooool00000000000000000003oool0003o
ool000000000003oooooooooool00000003oooooooooool00000003oooooooooool0003oool00000
00000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool000000000
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`0000000?ooooooooooo`000?ooooooo`0000000?ooooooooooooooooooo`000000
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooo`0000000000
0000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo00000000oooooooooooo00000000oooo00000000oooooooooooooooo
oooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000000000000000
00000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`00000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000000000000000
0000oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooo0000000000000000000000000000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
00000000000000000000003oooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooooooooooool000000000003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000000000000000000000000?ooooooo`00000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000oooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0000000000000000000000000003oooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`00000000000?ooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
00000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`00000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooo
ooooooooool000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooo
ooooooooooooooooooooo`0000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000
oooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00000003oooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`0000000?ooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooo00000000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00000003oooooooooooooooooooooooooooooool00000
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooo
ooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooo
oooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000000000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooo
ooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooo
ooooooooooooool000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
00000?ooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooo
ooooooooooooooooooooooooo`00000000000?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo00000000oooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooo
oooooooooooooooooooooooooooooooooooo000000000000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00000003oooooooooooooooooooooooooooooool00000003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000
003oooooooooooooooooooooooooooooooooooooooooool000000000003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000?ooooooooooooooooooooooooooooooo`0000000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`0000000?ooooooooooooooooooooooooooooooooooooooo`0000000000000000000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooo
00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooo0000000000000000
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooo
ooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool00000003oooooooooooooooooooooooooooooooooool000000000
0000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooo
ooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooo
o`000000000000000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooo
oooooooooooo0000000000000000oooo000000000000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00000003oooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooo
ooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`0000000?ooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oo
ooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooo00000000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
00000000oooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00000003oooooooooooooooooooooooooooooool00000
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool00000003oooooooooooooooooooooooooooooooooooooooooool00000003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
000000000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooo
oooo0000oooooooo00000000oooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooo
oooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooo
ooooooooooooool00000000000000000000000000000003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003oool00000003oooooool0003ooooooooooooooooo
ooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooool0003oooooooooool0003oooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
00000?ooooooooooooooooooooooo`000000000000000000000000000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000000000000000?ooo`0000000?oooooo
ooooooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`0000000?ooo`000?ooo`00000000000?ooooooooooooooooooooooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo00000000oooooooooooooooooooooooo0000000000000000000000000000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo000000000000000000000000
0000oooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo000000000000000000000000oooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool00000003oooooooooooooooooooooooooool00000000000000000003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0000000000000
000000000000003oooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool000000000000000000000003ooooooooooooooooooooooooo
ooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`0000000?ooooooooooooooooooooooooooo`00000000000000
00000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`0000000000000000000?ooooooooooooooooooooooooooooooooooo`0000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`0000000000000000000?oooooooooooooooooo
ooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo00000000oooooooooooooooooooooooooooo0000
000000000000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo00000000000000000000oooooooooooooooooooooooooooooooooooo00000000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooo00000000000000000000oooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00000003ooooooooooooooooooooo
ooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool000000000003oooooooooooooooooooooooooooooooooooooool0
0000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0000000000000
003oooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?oooooooooo
ooooooooooooooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`00000000000?oooooooooooooooooooooooooooooo
ooooooooo`0000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`0000000?ooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo000000000000oooooooooooooooooooo
oooooooooooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo00000000oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00000003oooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool000000000003ooooooooo
ooooooooooooooooooooooooooooool00000003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool00000003oooooooooooooooooooooooooooooooooooooooooool0003o
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
ooooooooo`0000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000?ooooooooooooooooooooooooooo`0000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
0000000000000000000000000000000000000000000000000000000000000000000000000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`00000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003oooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooool0003oooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?ooooooooooooooooooooooo`000?ooooooooooooooooooo`000?oooooooooo
ooooooooo`0000000?ooo`000?ooo`000?ooooooooooo`000?ooooooooooo`000?ooooooooooo`00
00000?ooooooooooooooo`000?ooooooooooooooooooo`0000000?ooooooooooo`000?oooooooooo
ooooooooooooooooo`000?ooooooooooo`000000000000000?ooooooooooooooo`000?oooooooooo
ooooooooo`00000000000?ooooooooooo`000?ooooooooooooooooooo`000?oooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooo0000oooooooooooooooooooo0000
oooooooooooooooo0000oooooooo00000000oooo0000oooooooooooo0000oooooooooooo0000oooo
oooo0000oooooooo0000oooooooooooo0000oooooooooooooooo0000oooooooo0000oooooooo0000
oooooooooooooooooooooooo0000oooooooooooo0000oooooooooooo0000oooooooooooooooo0000
oooooooooooooooooooo0000oooooooo0000oooooooooooo0000oooooooooooooooo0000oooooooo
oooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooooooooooo000000000000
oooooooo0000oooooooooooo0000oooooooooooo0000oooooooooooo00000000oooooooooooooooo
0000oooooooooooooooooooo00000000oooooooooooo0000oooooooooooooooooooooooooooo0000
oooooooooooo0000000000000000oooooooooooooooo0000oooooooooooooooooooooooooooo0000
oooooooooooo0000oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo0000
00000000oooooooooooooooo0000oooooooooooooooooooo00000000000000000000oooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool0003ooooooooooooo
ooooool0003oooooooooooooool0003oooooooooool0003oool0003oooooooooool0003ooooooooo
ool0003oooooool0003oooooooooool0003oooooool00000003oooooool0003oooooooooooooool0
003oool0003oooooooooooooooooooooool0003oooooooooool0003oooooooooooooool0003ooooo
ooooool0003oooooooooooooool0003oooooooooool0003oooooooooool0003oooooooooooooool0
003oooooooooooooooooooooooooool0003oooooooooooooooooool0003oooooooooooooool0003o
ooooool0003oooooool0003oooooooooool0003oooooooooool0003oool00000003oooooool00000
003oool000000000003oooooool00000003oooooool0003oooooool0003ooooooooooooooooooooo
ool0003oooooool00000003oooooooooool00000003oooooooooool0003ooooooooooooooooooooo
ooooool0003oooooooooool0003oooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooool0
0000003oooooooooool00000003oooooool0003oooooooooooooooooool00000003ooooooooooooo
ooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?oo
ooooooooooooooooo`000?ooooooooooooooo`000?ooooooooooo`000?ooo`000?ooooooooooo`00
0?ooooooooooo`000?ooooooo`000?ooooooooooo`000?ooooooo`0000000?ooooooo`0000000000
0000000000000?ooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
o`000?ooooooooooo`000?ooooooooooooooo`000?ooooooooooo`000?ooooooooooo`000?oooooo
ooooooooo`000?ooooooooooooooooooooooooooo`000?ooooooooooooooooooo`000?oooooooooo
ooooo`000?ooooooo`000?ooooooo`000?ooooooooooo`000?ooooooooooo`000?ooo`000?oooooo
ooooooooo`000?ooo`000?ooo`000?ooooooo`000?ooooooooooooooooooooooo`000?oooooooooo
ooooooooooooo`000?ooooooooooooooooooooooooooooooo`000?ooooooooooo`000?oooooooooo
ooooooooooooooooo`000?ooooooooooo`000?ooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooooooo`000?ooooooo`000?ooooooooooooooooooooooooooo`00
0?ooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooo0000oooooooooooooooooooo0000oooooooooooooooo0000oooooooooooo0000oooo0000oooo
oooooooo0000oooooooooooo0000oooooooo0000oooooooooooo0000oooo0000oooooooo0000oooo
0000oooooooooooooooo0000oooo0000oooooooooooooooooooooooo0000oooooooooooooooooooo
oooo00000000oooooooooooooooo0000oooooooooooooooo0000oooooooooooo0000oooooooooooo
0000oooooooooooooooo0000oooooooooooooooooooooooooooo0000oooooooooooooooooooo0000
oooooooooooooooo0000oooooooo0000oooooooo0000oooooooooooo0000oooooooooooo0000oooo
0000oooooooooooooooo0000oooo0000oooo0000oooooooo00000000000000000000oooooooo0000
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo0000oooooooooooo0000
oooooooooooooooooooooooooooo0000oooooooooooo0000oooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooo0000oooooooo0000oooooooooooooooooooo
oooooooooooo0000oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
ooooooooooooool0003oooooooooooooooooool0003oooooooooooooool0003oooooooooool0003o
ool00000003oooooool00000003oooooool0003oooooool0003oooooool0000000000000003ooooo
ool0003oool00000003oooooool00000003oool00000003oooooooooooooooooool0003ooooooooo
ool000000000003oooooooooooooooooooooool0003oooooooooooooool0003oooooooooool0003o
ooooooooool0003oooooooooooooool0003oooooooooooooooooooooooooool0003ooooooooooooo
ooooool0003oooooooooooooool0003oooooool0003oooooool0003oooooooooool0003ooooooooo
ool0003oool0003oooooooooooooool0003oool0003oool0003oooooool0003oooooooooool0003o
ooooool0003oooooooooooooooooooooool0003oooooooooooooool0000000000000003ooooooooo
ooooool0003oooooooooooooooooooooooooool0003oooooooooool0003oooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003oooooooooooooooooool0000000000000003oooooooooool0003ooooooooo
ooooooooooooooooooooool0003oooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?ooooooooooooooooooooooo`000?ooooooooooooooooooo`000?ooooooooooooooo`000?oooooo
ooooo`000?ooo`000?ooo`000?ooo`000?ooo`0000000?ooooooooooooooo`0000000?ooooooo`00
0?ooooooooooo`000?ooooooooooo`0000000?ooooooooooo`000?ooo`000?oooooooooooooooooo
o`000?ooooooo`000?ooooooooooooooooooooooooooooooo`000?ooooooooooooooo`000?oooooo
ooooo`000?ooooooo`000?ooooooooooooooooooo`000?ooooooooooooooooooooooooooo`000?oo
ooooooooooooooooo`000?ooooooooooooooo`000?ooooooo`000?ooooooo`0000000?ooooooo`00
00000?ooooooo`000?ooooooo`000?ooooooo`000?ooo`000?ooooooooooo`000?ooooooo`000?oo
ooooo`000?ooooooo`0000000?ooooooooooooooooooo`000?ooooooooooo`000?oooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooo`000?ooooooooooo`000?oooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?ooooooooooooooo`000?ooooooooooooooooooooooooooo`00
0?ooooooooooooooooooooooooooooooooooo`000?ooooooo`000?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooo0000oooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooo0000oooooooooooo00000000oooooooooooo0000oooooooooooooooo
00000000oooooooo0000oooooooo0000oooooooooooooooooooo0000oooooooooooooooooooooooo
oooo0000oooooooooooooooooooo0000oooooooooooooooo0000oooooooo0000oooooooo00000000
0000oooo0000oooo00000000oooooooooooooooo00000000oooooooo0000oooooooooooo0000oooo
oooooooo00000000oooooooooooo000000000000oooooooooooooooooooo0000oooo0000oooooooo
oooooooooooo0000oooooooooooo0000oooooooooooooooooooo0000oooo0000oooooooooooo0000
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooo0000oooooooooooooooooooo0000
oooooooo0000oooooooooooooooooooo0000oooooooooooo0000oooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003oooooooooooooooooooooool0003oooooool000000000000000000000
0000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooool0000000000000003oooooool00000000000000000
0000003oooooool000000000003oooooool0003oooooooooooooooooooooool0003ooooooooooooo
ooooooooooooool0003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ool0003oooooooooool0003oooooooooooooool0003oooooooooooooooooooooool00000003ooooo
ooooool0003oooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooool0003ooooooooo
ool0003oooooooooool0003oooooooooooooooooool0003oooooool0003oooooooooool0003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
ooooooooooooooooooooooooo`000?ooooooo`000000000000000000000000000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooo`000000000000000?ooo`000000000000000000000000000?oooooooooooooo
o`000?ooooooo`000?ooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
o`00000000000?ooooooo`00000000000000000000000?ooooooooooo`00000000000?ooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool0
003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooool0003oooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
ooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooo`000?ooooooo`00000000000?ooo`000?ooooooo`0000000000
0?ooooooooooo`000?ooooooo`000000000000000?oooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
o`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooo0000oooooooooooo0000oooooooo00000000oooooooo
0000oooooooo00000000oooo0000oooo00000000oooo00000000oooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooo0000oooooooooooo0000oooooooo0000oooooooo00000000oooo
0000000000000000oooooooo0000oooooooooooo0000oooooooo0000oooooooooooo0000oooooooo
0000000000000000oooooooo00000000000000000000oooo0000oooooooo00000000000000000000
oooo00000000oooo0000000000000000oooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooo00000000000000000000oooooooo0000oooooooo000000000000oooooooooooooooo0000oooo
oooooooo0000oooooooooooooooooooooooooooo0000oooooooooooooooo0000000000000000oooo
oooo0000oooooooooooo0000oooooooooooo0000oooooooo0000000000000000oooooooooooo0000
oooooooooooooooo0000000000000000oooo0000oooooooooooooooooooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003oooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003oooooooooooooool0003oooooooooool0003oooooooooool0
003oooooool0003oooooooooool0003oool0003oool0003oooooooooool0003ooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooooooool0
003oooooooooooooooooooooooooooooooooool0003oooooooooool0003oooooool0003oooooool0
003oooooool0003oooooooooool0003oool0003oooooooooool0003oooooool0003oooooooooool0
003oooooool0003oooooooooool0003oool0003oooooooooool0003oool0003oooooool0003ooooo
ooooool0003oool0003oooooool0003oooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooo
ooooooooool0003oooooooooooooooooool0003oool0003oool0003oooooooooool0003oooooool0
0000003oooooool00000003oooooooooooooooooooooooooool0003oooooooooooooool0003ooooo
ool0003oooooool0003oooooooooool0003oooooooooool0003oool0003oooooooooooooool0003o
ool0003oool0003oooooool0003oooooooooool0003oool0003ooooooooooooooooooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?ooooooooooo`000?ooooooooooooooo`000000
00000?ooo`000?ooooooo`000?ooooooooooo`000?ooo`000?ooo`000?ooooooooooo`000?oooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
ooooooooo`000?ooooooooooooooooooooooooooooooooooo`000?ooooooooooo`000?ooooooo`00
0?ooooooo`000?ooooooo`000?ooooooooooooooooooo`000?ooooooooooo`000?ooooooo`000?oo
ooooooooo`000?ooooooo`000?ooooooooooooooooooo`000?ooooooooooo`000?ooo`000?oooooo
o`000?ooooooooooo`000?ooo`000?ooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooooooooooooooooooo`000?ooo`000?ooo`000?ooooooooooo`00
0?ooooooo`0000000?ooooooo`0000000?ooooooooooooooooooooooooooo`000?oooooooooooooo
o`000?ooooooo`000?ooooooo`000?ooooooooooo`000?ooooooooooo`000?ooo`000?oooooooooo
ooooo`000?ooo`000?ooo`000?ooooooo`000?ooooooooooooooooooo`000?oooooooooooooooooo
ooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo000000000000000000000000oooooooo
oooo0000oooo000000000000oooooooo0000oooooooooooo0000oooo0000oooo0000oooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo0000oooooooooooo0000
oooooooo0000oooooooo0000oooooooo00000000000000000000oooo0000oooooooooooo0000oooo
oooo0000oooooooooooo0000oooooooo00000000000000000000oooo0000oooooooooooo0000oooo
0000oooooooo00000000000000000000oooo0000oooooooo00000000000000000000oooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooo000000000000oooo0000oooo0000oooo
oooooooo0000oooooooo000000000000000000000000oooooooooooooooooooooooooooo0000oooo
oooooooooooo0000oooooooo0000oooooooo0000oooooooooooo0000oooooooooooo0000oooo0000
oooooooooooooooo0000oooo0000oooo0000oooooooo00000000000000000000oooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooool0003ooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ool0003oooooool0003oooooooooool0003oooooool0003oooooool0003oooooool0003oooooool0
003oool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0
003oooooooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooool0003ooooo
ooooool0003oooooool0003oooooool0003oooooool0003oooooooooool0003oool0003ooooooooo
ool0003oooooool0003oooooooooool0003oooooool0003oooooooooool0003oool0003ooooooooo
ool0003oool0003oooooool0003oooooooooool0003oool0003oooooool0003oooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooool0003oooooooooooooooooooooooooooooool00000003oooooooooooooool0003o
ool0003oooooooooool0003oooooool0003oool00000003oool0003ooooooooooooooooooooooooo
ool0003oooooooooooooool0003oooooool0003oooooool0003oooooooooool0003oooooooooool0
003oool0003oooooooooooooool0003oool0003oool0003oooooool0003oooooooooool0003oool0
003oooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`000?oo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooo`000?ooooooooooo`00000000000?ooooooooooo`00000000000?ooooooooooo`00
0?ooooooo`000000000000000?oooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooo`000?ooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooo
o`000?ooooooooooo`000000000000000?ooo`00000000000?ooo`000000000000000?ooooooo`00
000000000?ooo`0000000000000000000000000000000?ooooooo`000000000000000?ooooooo`00
00000000000000000?ooo`000?ooooooo`0000000000000000000000000000000?ooo`0000000000
00000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooo`000?ooooooooooooooooooooooo`0000000?oooooooooooooooooo
ooooo`000?ooooooo`00000000000?ooooooo`000?ooooooooooo`000?ooooooo`000?oooooooooo
ooooooooooooo`000?ooooooooooooooo`000?ooooooo`000?ooooooo`00000000000?ooo`000000
0000000000000?ooooooo`000000000000000?ooo`000?ooooooooooo`000?ooooooo`0000000000
00000?ooo`00000000000?ooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooo0000oooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooo0000oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooo0000oooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooo0000oooooooooooo
oooooooo0000oooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
ooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool000000000000000000000003ooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003oooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooool0003oooooooooooooooooooooooooool0003ooooooooooooo
ooooooooooooooooooooool0003oooooooooooooooooooooooooooooooooool0003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003oool0003oooooooooooooooooooooooooooooool0
003oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooool0003oooooooooooooooooooooooooool0
0000000000000000003oooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooool0000000000000000000000000003ooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooool0003oooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?ooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooo`000?ooooooooooooooooooooooooooo`000?oo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooo00000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000oooooooooooooooooooooooo
oooo0000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooo000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000oooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00000003oool00000003oool00000
003oooooool00000000000000000003oool00000000000000000003oool00000000000000000003o
ool00000003oooooooooool00000003oooooooooooooool000000000003ooooooooooooooooooooo
ool00000000000000000003oooooool00000000000000000003oool00000003oooooool000000000
0000003oooooooooooooooooool00000003oooooooooool00000003oool00000000000000000003o
ool00000000000000000003oooooool000000000000000000000003oooooool000000000003ooooo
ool00000000000000000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003o
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`0000000?ooo`000000
0?ooo`0000000?ooooooo`000?ooooooo`0000000?ooo`000?ooooooo`0000000?ooo`0000000?oo
o`0000000?ooo`0000000?ooooooooooo`0000000?ooooooooooo`0000000?ooo`0000000?oooooo
ooooooooo`0000000?ooooooo`0000000?ooo`00000000000?ooo`0000000?ooo`0000000?oooooo
o`0000000?ooooooooooooooooooooooooooo`0000000?ooooooooooo`0000000?ooo`0000000?oo
o`0000000?ooo`0000000?ooooooo`000?ooooooo`0000000?ooooooo`0000000?ooo`0000000?oo
o`0000000?ooo`0000000?ooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo00000000
000000000000000000000000oooooooo00000000000000000000oooo00000000000000000000oooo
oooo0000000000000000oooo00000000oooooooo0000000000000000oooooooo0000000000000000
0000oooooooooooooooo00000000oooooooo00000000oooo00000000oooooooooooo0000oooo0000
0000oooooooo00000000oooooooooooooooooooooooooooo00000000oooooooooooo00000000oooo
oooo0000000000000000oooooooo0000000000000000oooooooo00000000oooooooo00000000oooo
00000000000000000000oooooooo0000000000000000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00000000000000000000000000000003oooooooooooooool000000000003oool000000000003o
ooooooooool000000000003oooooooooool00000003oooooool0000000000000003oooooool00000
000000000000003oooooooooooooooooooooool0000000000000003oool00000003oooooooooool0
003oool00000003oooooool00000003oooooooooooooooooooooooooool00000003oooooooooool0
0000003oool000000000003oooooooooool000000000003oooooooooooooool00000003oooooool0
0000003oool00000000000000000003oool000000000003ooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`0000000000000000000000000000000?ooooooo`000?ooooooo`0000000?ooo`00
0?ooooooo`0000000?ooo`0000000?ooo`0000000?ooo`0000000?ooooooo`000?ooooooo`000000
0?ooo`0000000?ooo`0000000?ooooooooooooooooooo`000000000000000?ooooooo`0000000000
0?ooo`0000000?ooo`0000000?ooooooo`0000000?ooooooooooooooooooooooooooo`0000000?oo
ooooooooo`0000000?ooo`0000000?ooo`0000000?ooo`0000000?ooooooo`000?ooooooo`000000
0?ooooooo`0000000?ooo`0000000?ooo`0000000?ooo`0000000?ooooooo`000?oooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo000000000000oooooooo000000000000oooooooo0000000000000000
0000oooo00000000000000000000oooo00000000000000000000oooo00000000oooooooo0000oooo
oooo00000000oooooooo000000000000oooooooooooooooooooo000000000000oooooooo0000oooo
oooo00000000000000000000oooo000000000000oooo0000000000000000oooooooooooooooooooo
00000000oooooooooooo00000000oooo00000000000000000000oooo00000000000000000000oooo
oooo00000000oooooooo00000000oooooooo000000000000oooooooo00000000000000000000oooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool000000000003oooooool000000000003ooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00000003oooooool0
0000003oooooooooooooooooooooooooooooool00000003oooooool00000003ooooooooooooooooo
ooooooooool00000003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooool0003ooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
0?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`0000000?ooooooooooo`00000000000?oo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
00000?ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
00000000000000000?ooooooooooooooooooooooooooooooo`00000000000000000000000?oooooo
ooooooooooooo`00000000000000000000000000000000000?oooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`000?oooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooo0000oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
0000oooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooool0003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooool0003oooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`000?oooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooo`000?ooooooooooooooooooooooooooooooooooooooooooooooooooo`00
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooo0000oooooooooooooooooooooooooooooooooooooooooooo
oooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000003ooooooooooooooooooooooooooooooooo
ooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ool00?oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooo`00oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooo003ooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooool00?oooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooo`00oooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooo003ooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooool00?oooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
oooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo
ooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooooo`00
9@0000`0000700209@0000`000000020<00000`0000?0020B`000100000000001@0000h0000D0000
00000100000D0000
\>"], "Text",
 ImageSize->{344, 252},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}]
}, Closed]],

Cell[CellGroupData[{

Cell["Plutonium", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["The model", "SubsubsectionIcon"],

Cell["The compartments has been numbered as follow: ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompartNumbers", "[", "plutonium", "]"}]], "Input",
 CellLabel->"In[179]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "\<\"Blood\"\>"},
    {"2", "\<\"ST0\"\>"},
    {"3", "\<\"ST1\"\>"},
    {"4", "\<\"ST2\"\>"},
    {"5", "\<\"Liver1\"\>"},
    {"6", "\<\"Liver2\"\>"},
    {"7", "\<\"Kidneys(Urinary)\"\>"},
    {"8", "\<\"Other kidneys\"\>"},
    {"9", "\<\"Cort. bone\"\>"},
    {"10", "\<\"Cort. Surface\"\>"},
    {"11", "\<\"Cort. Vol.\"\>"},
    {"12", "\<\"Trab. Volum\"\>"},
    {"13", "\<\"Trab. Surf.\"\>"},
    {"14", "\<\"Trab. bone\"\>"},
    {"15", "\<\"Gonads\"\>"},
    {"16", "\<\"Bladder\"\>"},
    {"17", "\<\"URI\"\>"},
    {"18", "\<\"ULI\"\>"},
    {"19", "\<\"LLI\"\>"},
    {"20", "\<\"FEC\"\>"},
    {"21", "\<\"SI\"\>"},
    {"22", "\<\"ST\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.399282624305558*^9, 3.417836130219455*^9, 
  3.479827860451451*^9, 3.4798285322330256`*^9, 3.479829723693634*^9, 
  3.518535189142603*^9, 3.6434437931012044`*^9},
 CellLabel->"Out[179]//TableForm="]
}, Open  ]],

Cell["\<\
We build the compartmental matrix for plutonium. Transfer rates are taken \
from Table A.12.1. (ICRP 78) (For GI compartments are applied the transfer \
rate included in Options[qGI]).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"TransferRatesE", "[", "plutonium", "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<From\>\"", ",", " ", "\"\<to\>\"", ",", 
        "\"\<Tranfer Rates(\!\(\*SuperscriptBox[\(days\), \(-1\)]\))\>\""}], 
       "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[180]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"From\"\>",
       HoldForm], 
      TagBox["\<\"to\"\>",
       HoldForm], 
      TagBox["\<\"Tranfer Rates(\\!\\(\\*SuperscriptBox[\\(days\\), \\(-1\\)]\
\\))\"\>",
       HoldForm]},
     {"1", "2", "0.2773`"},
     {"1", "3", "0.0806`"},
     {"1", "4", "0.0129`"},
     {"1", "13", "0.1941`"},
     {"1", "10", "0.1294`"},
     {"1", "8", "0.00323`"},
     {"1", "5", "0.1941`"},
     {"1", "15", "0.00023`"},
     {"1", "18", "0.0129`"},
     {"1", "7", "0.00647`"},
     {"1", "16", "0.0129`"},
     {"2", "1", "0.693`"},
     {"3", "16", "0.000475`"},
     {"3", "1", "0.000475`"},
     {"4", "1", "0.000019`"},
     {"5", "6", "0.00177`"},
     {"5", "21", "0.000133`"},
     {"6", "1", "0.000211`"},
     {"7", "16", "0.01386`"},
     {"8", "1", "0.00139`"},
     {"9", "1", "0.0076`"},
     {"14", "1", "0.0076`"},
     {"10", "9", "0.0000821`"},
     {"10", "11", "0.0000411`"},
     {"11", "9", "0.0000821`"},
     {"12", "14", "0.000493`"},
     {"13", "14", "0.000493`"},
     {"13", "12", "0.000247`"},
     {"15", "1", "0.00019`"},
     {"16", "17", "12"},
     {"18", "19", 
      SubscriptBox["k", "ULI"]},
     {"19", "20", 
      SubscriptBox["k", "LLI"]},
     {"21", "1", 
      FractionBox[
       RowBox[{"f1", " ", 
        SubscriptBox["k", "SI"]}], 
       RowBox[{"1", "-", "f1"}]]},
     {"21", "18", 
      SubscriptBox["k", "SI"]},
     {"22", "21", 
      SubscriptBox["k", "ST"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"From", "to", 
       "Tranfer Rates(\!\(\*SuperscriptBox[\(days\), \(-1\)]\))"}}]]]], \
"Output",
 CellChangeTimes->{3.3992826243356705`*^9, 3.41783613023508*^9, 
  3.4798278604983244`*^9, 3.4798285322798967`*^9, 3.479829723740515*^9, 
  3.518535189189479*^9, 3.643443793148081*^9},
 CellLabel->"Out[180]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "element", ",", " ", "lambda", ",", " ", "fn1", ",", " ", "amad", ",", " ", 
   "class"}], "]"}]], "Input",
 CellLabel->"In[181]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"element", "=", " ", "plutonium"}], ";", 
   RowBox[{"lambda", " ", "=", " ", "0"}], ";"}], "  "}]], "Input",
 CellLabel->"In[182]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsubsectionIcon"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fn1", " ", "=", " ", 
   RowBox[{"5", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "4"}]]}]}], ";"}]], "Input",
 CellLabel->"In[183]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[184]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.00818242563343996`", "0.001605488237845898`", 
      "0.9902120861287138`"},
     {"2", "0.00448105055802106`", "0.004295996263153912`", 
      "0.981435039307539`"},
     {"3", "0.002596101951741203`", "0.004185984183279701`", 
      "0.9746529531725179`"},
     {"4", "0.001706582039797122`", "0.0031296393102910325`", 
      "0.96981673182243`"},
     {"5", "0.0012048959045721785`", "0.002163775023195036`", 
      "0.9664480608946627`"},
     {"6", "0.0008873321827528313`", "0.0014757299266879853`", 
      "0.9640849987852219`"},
     {"7", "0.0006740005798601123`", "0.0010153126230120768`", 
      "0.9623956855823496`"},
     {"8", "0.0005267087097038381`", "0.0007088780436608211`", 
      "0.9611600988289849`"},
     {"9", "0.0004237260939131682`", "0.0005025558116649731`", 
      "0.9602338169234066`"},
     {"10", "0.00035124722171830935`", "0.00036176955941474853`", 
      "0.9595208001422736`"},
     {"20", "0.00017409668207768458`", "0.00004952005377711899`", 
      "0.956247119275987`"},
     {"30", "0.00015518021215876754`", "0.00004021437781687176`", 
      "0.9542007176810867`"},
     {"40", "0.00014256041429983046`", "0.00003949085294346899`", 
      "0.952322507109322`"},
     {"50", "0.00013165648459534385`", "0.000039014435134820946`", 
      "0.9505658350189342`"},
     {"60", "0.00012213749903944304`", "0.00003854684825310706`", 
      "0.9489151160853512`"},
     {"70", "0.00011382023481310011`", "0.0000380817335050021`", 
      "0.9473575013412229`"},
     {"80", "0.00010654827747313966`", "0.00003761933010815177`", 
      "0.9458818264553354`"},
     {"90", "0.00010018562838443046`", "0.00003716002356790593`", 
      "0.9444783727219798`"},
     {"100", "0.0000946139722003414`", "0.00003670416424794709`", 
      "0.9431386784576921`"},
     {"180", "0.00006858260739606159`", "0.00003321241831505395`", 
      "0.9340039686352565`"},
     {"200", "0.00006519537221705285`", "0.00003238908845859534`", 
      "0.9320136204934837`"},
     {"300", "0.00005578274216566648`", "0.000028601755610535573`", 
      "0.9230009918478328`"},
     {"400", "0.0000514059003090539`", "0.00002536066908970236`", 
      "0.9149709859645457`"},
     {"500", "0.000048391511807355236`", "0.00002262120334517448`", 
      "0.9075946586719441`"},
     {"600", "0.0000458453429194039`", "0.000020319095440202162`", 
      "0.9007441488668239`"},
     {"700", "0.00004354780025261906`", "0.00001838877534027228`", 
      "0.8943457738444132`"},
     {"800", "0.00004143934494826862`", "0.000016770424919154703`", 
      "0.8883441487928042`"},
     {"900", "0.00003949710512152205`", "0.000015412098250067174`", 
      "0.882693140693052`"},
     {"1000", "0.000037706389454106315`", "0.000014269771093811112`", 
      "0.8773531833796675`"},
     {"2000", "0.000025798339237326218`", "9.035842844284936`*^-6", 
      "0.8353554417203001`"},
     {"3000", "0.000020057383500748927`", "7.558336794444287`*^-6", 
      "0.8045667711572428`"},
     {"4000", "0.000016980352992579384`", "6.808549150777443`*^-6", 
      "0.7790380034032246`"},
     {"5000", "0.000015122723694527274`", "6.284170620901586`*^-6", 
      "0.7565217431000358`"},
     {"6000", "0.000013865884464059341`", "5.873506265019479`*^-6", 
      "0.7359921206705039`"},
     {"7000", "0.000012932774407004022`", "5.536415631557379`*^-6", 
      "0.7169136536364488`"},
     {"8000", "0.000012191711632525415`", "5.2516706114114076`*^-6", 
      "0.6989741630977122`"},
     {"9000", "0.00001157524612427352`", "5.005851867245781`*^-6", 
      "0.6819736803427843`"},
     {"10000", "0.000011045803949949473`", "4.7898376359656325`*^-6", 
      "0.6657740127923263`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282624968027*^9, 3.41783613086008*^9, 
  3.4798278612795544`*^9, 3.479828533201707*^9, 3.4798297245374975`*^9, 
  3.518535189736365*^9, 3.643443793366843*^9},
 CellLabel->"Out[184]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[185]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVxXs0lGkcAOBhpL65fDNjvtG0tZoYu+Fgiq0T8r5pRzZJOcU2qEyy5doq
u3Iat6WoaHXfKaMkpGJXRRzyi9rU0OaSHaLFCGtKrrnbyx/PeVbII7z269No
NI///L/G+gf7+shjzqfrEm9GagSgkO/pPyuUIbNw96StrwWQMfVEXyYMRttD
V+dZNgpg6dOJM+uFMejy/PNOrVoAnZYZ3rbCk6j1RoCJb5UAqjs61q0UKlG8
fdPcvlwB2K1Nui0WFiAn94QwTpQA3u/z6TEVlqMz2d1xjQIBTNNdK6hVavTE
OftZk4yC7uxKb55dM3qV7J8+V8MHL0H2TPidNrQ8y82Ov5EPHsfF/5i2diLG
OfqRe7VGoK10tuSJepBLRdmEMNAIetc6GDjd7UMjR8/FxdKNoFAps2+00KGQ
4AsJO4t48F3ZBjIkeBBp5dFVBgd5sImd7H5tcgi9M1P6x4t50HSlLpClGkH5
ziutuwa48Fj1hYWN4xga/dgWcq2UC70uw1+Hz4wjZYZVn2MyF+jSrAdFmRPo
KJs9nCXjgk9/pYKzbwpV3q70b5BwgU37OCQWzSD1VEl6B5MLFVH0MseqWZSa
M1OubOXA9dMpmkMJ82h38f3mFZkcgPjo3CYjGnY+qSj4NZgDauZ+VuwnGh7/
zTtpZB0HFja0baK36OHzpRs9d3A4gKTV1qm5+vgy2VJ6VEcCnyFHqhQ63hUk
PqR7RoJWcXjmnq8BdtY7sEuXT0KPFZmWY7kAK4zTeeWnSIi3DNgsZhpieoOb
Q2woCUs05sU57Yb4rseXxjRPEjxasqX3qxZiCYcmHbMmoZi8VahSLcLqjpiA
t0wSqE+i6tRwApu8CPBzGWADz2a7nsE2BjZUXqo4X8MGhmB0INaUiTnWm1Uo
kw1frTEpaB5i4jrjxpzjUWyYydO7UPaKhf1iHIb13dhQWettmXWdjRf5mM56
LmXDZw6BOn4Sifv32oQr+llwRKb1TvXhYLIKm/SVsCCubVwdyufi+fbYZUFJ
LDCSeCe2/8TFAQvMPW+6s8DM/2Na3Xsuzu1zKpmiWJBQHGibtJuHXRmaOLaG
CZM5KkeLlzxMpHDyHiqZ8CGcl7l1jRF+0Loz2mMvEyQBe8875hlhF3Fmdu1y
Jgxb9nfmc/k4cMq/62Q3A9QZ9pfp0XwclLGo/upNBoyI/N+Z9/Px76tSyEQ5
Ay6deHSidhuFVzPTDr8zZUC0X0TVFS8Kz3Vs5z9bwQDZKtFE+A4KhzXcz8wX
McDkTUKQ4FsKe+02iwwxYUCOjVQq30Ph7LHpxUNLGFD8Wq0/G0Zh354tW8a5
DKgza1XYnqJwt2h+fHCegMLJ1Af6aRRuf/74Zf0cAWfqHT68Tqcwig/8+c4s
AV4/XvU7dpbC2Haw/uA0Aa0v9jg+/4XCf5smSrTjBPR+3zspz6fwOrtjyQ3v
Cah1vSRZU0Dh2EnfnkIdAQVL3Q4Qdyj8xphndXqAgLCnt/4sKqLwYlQW4dpP
wJgwrGS2hMLKHdLmMi0BLR8+H/zjIYVtpj5FXOwmoLT6pfmNcgpHxeuNRnYR
EBMqufDNIwpfXP+k0OovAvw2dNUtAwpb1G3qW/iWAGfjswZDjymcNdVp2NNO
gEjn4lRTQ+H9ccFseEOAHowevviUwumat9NX2gj4F8z5OvI=
        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV03k0VesbB/AzGZJ99j4c7skUosw0XITaT0pKKSS6xsIVKsmUuimVRkOl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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -8.082119013590901}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-8.082119013590901, -2.7907995304032687`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, 
     AxesOrigin -> {0, -7.800000000000001}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992826274673395`*^9, 3.417836133563205*^9, 
  3.4798278647482157`*^9, 3.479828535264062*^9, 3.479829726428376*^9, 
  3.5185351916895275`*^9, 3.6434437937887697`*^9},
 CellLabel->"Out[185]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsubsectionIcon"],

Cell["\<\
Using the package function BioassayReportE can be obtain for a single intake \
the urine and faecal excretion for different days.  \
\>", "Text"],

Cell[TextData[{
 "Here is calculated the retention in compartment URI (urine) and in FEC \
(faecal)  for  ",
 Cell[BoxData[
  SubscriptBox["I", "0"]]],
 "= 1 in t = 0 and f1 =",
 Cell[BoxData[
  RowBox[{"5", " ", 
   SuperscriptBox["10", 
    RowBox[{"-", "4"}]]}]]],
 " and for f1 =",
 Cell[BoxData[
  SuperscriptBox["10", 
   RowBox[{"-", "5"}]]]]
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fn1", " ", "=", " ", 
   RowBox[{"5", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "4"}]]}]}], ";"}]], "Input",
 CellLabel->"In[186]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[187]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "3.365732514183661`*^-6", "0.28226194271352334`", 
      "0.7177346915539692`"},
     {"2", "2.5870161369531772`*^-6", "0.3888869696235119`", 
      "0.32884513491432027`"},
     {"3", "1.4453992873607`*^-6", "0.1968832675684024`", 
      "0.13196042194663046`"},
     {"4", "9.279297921651491`*^-7", "0.08134303183421936`", 
      "0.050616462182618956`"},
     {"5", "6.466942009107656`*^-7", "0.031398308937206354`", 
      "0.01921750655121169`"},
     {"6", "4.7243620874973594`*^-7", "0.011794700394747903`", 
      "0.007422333720255038`"},
     {"7", "3.5657139856162595`*^-7", "0.004379539385351135`", 
      "0.003042437763505341`"},
     {"8", "2.769435210288936`*^-7", "0.0016179770941668885`", 
      "0.0014241837258174234`"},
     {"9", "2.2139045882988394`*^-7", "0.0005964499678492883`", 
      "0.0008275123675093054`"},
     {"10", "1.8234048525380764`*^-7", "0.0002196979345127694`", 
      "0.0006076320925112824`"},
     {"20", "8.739507290409345`*^-8", "3.509583589220958`*^-8", 
      "0.00047815243249571873`"},
     {"30", "7.773488466605253`*^-8", "2.012282056384888`*^-8", 
      "0.0004771206531861878`"},
     {"40", "7.140203044932961`*^-8", "1.9750613817522003`*^-8", 
      "0.00047618016851093886`"},
     {"50", "6.593447126056499`*^-8", "1.9512103098968123`*^-8", 
      "0.0004753006526242181`"},
     {"60", "6.116153766202916`*^-8", "1.9278280342048797`*^-8", 
      "0.0004744742576687074`"},
     {"70", "5.699121664805469`*^-8", "1.904569682707421`*^-8", 
      "0.0004736945396263715`"},
     {"80", "5.334506983118315`*^-8", "1.881446491186706`*^-8", 
      "0.0004729559001467606`"},
     {"90", "5.015490011050757`*^-8", "1.858477756863891`*^-8", 
      "0.0004722534658202918`"},
     {"100", "4.736137779160453`*^-8", "1.8356810378971364`*^-8", 
      "0.00047158299357772326`"},
     {"180", "3.431112205421957`*^-8", "1.661055174415299`*^-8", 
      "0.0004670125758974269`"},
     {"200", "3.2613399258160734`*^-8", "1.6198775946285994`*^-8", 
      "0.0004660169647673005`"},
     {"300", "2.7897442453892786`*^-8", "1.430453355489832`*^-8", 
      "0.0004615092793088194`"},
     {"400", "2.5706528355095258`*^-8", "1.268343870927083`*^-8", 
      "0.0004574934841372964`"},
     {"500", "2.4198585515597393`*^-8", "1.1313215598352097`*^-8", 
      "0.00045380472177279115`"},
     {"600", "2.292517680503375`*^-8", "1.0161740895031808`*^-8", 
      "0.0004503789622852534`"},
     {"700", "2.1776188916693747`*^-8", "9.196226042013176`*^-9", 
      "0.00044717933473335987`"},
     {"800", "2.072177879113013`*^-8", "8.38675435525728`*^-9", 
      "0.00044417813430943433`"},
     {"900", "1.9750494012341687`*^-8", "7.707344435792848`*^-9", 
      "0.0004413522867216758`"},
     {"1000", "1.8854985146224586`*^-8", "7.135976226672327`*^-9", 
      "0.0004386820027773842`"},
     {"2000", "1.2899998647032066`*^-8", "4.5181668916188106`*^-9", 
      "0.0004176813476256754`"},
     {"3000", "1.002911430812714`*^-8", "3.779267935844497`*^-9", 
      "0.00040228626090104314`"},
     {"4000", "8.490417992962612`*^-9", "3.4043376821577724`*^-9", 
      "0.00038952147862711124`"},
     {"5000", "7.561517224538052`*^-9", "3.1421330081419672`*^-9", 
      "0.0003782631004818339`"},
     {"6000", "6.93305311251502`*^-9", "2.9367915954859247`*^-9", 
      "0.000367998115655628`"},
     {"7000", "6.4664728114272735`*^-9", "2.768239908284317`*^-9", 
      "0.00035845874988915677`"},
     {"8000", "6.09592565726895`*^-9", "2.6258627407605827`*^-9", 
      "0.00034948889781411484`"},
     {"9000", "5.7876822324521085`*^-9", "2.5029498473827516`*^-9", 
      "0.000340988566655844`"},
     {"10000", "5.5229534472265446`*^-9", "2.3949400003854364`*^-9", 
      "0.0003328886552632876`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Urine\n24 hours", "Faecal\n24 hours", 
       "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992826282201443`*^9, 3.41783613432883*^9, 
  3.47982786574819*^9, 3.4798285362171197`*^9, 3.479829727350375*^9, 
  3.518535192267663*^9, 3.6434437940231094`*^9},
 CellLabel->"Out[187]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[188]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVx3s0lGkcwHHMRLmPeXRGukzyPjPzlksnFGO9T4SyiaUdISlSuml3S8mm
JF1UNmwXmxqFwsTYpiRy+dE6TbmUzX05JZJd19xb2t3ZP77nez5LQw76hGmo
qal5qvr/rRZHbOp+OO7k6U/2DE3QEBMS3JfCC2AsDXrnTo/RkPz5N40A3l7m
SHrqsPooDabVU5e/4kUzSuPolPlDNLyjkyVWvAuMYiBshUsvDVWdnfZC3g3G
Ot+jMLeZhlWr4++b82TM0cQ1fvlFNAyE+vWY8UoYhcLfQh5Nw98st1K0soY5
mFbSt/SLCN5nlEk4qxqZK4ZDY5M/i8DHOGMmIq+d8QoTcUftReB51vxfs7Z3
DDf2XJVDrxC6y5xoDr+HCW8tt43MFELvage2Y/5HxnT7n0PBYUKQ3wiw+V3U
zwi9tuAJayHsLl6rv2/vEGNyX3OPr6YQ3PXOfH17eoSx+1IXVtkpgDdptTt1
paNMIHPFW1IqgEopFlmKx5lLfMecRekC6HX+tC5iZoKpHKzXeh0nAJZremHB
rSnGhm3PtdonAL++shiD0M+MrzhP5rRZAHpqwyPm/BnG2Vdjk4AIoDSSVSyu
mGXkgam5oVYCuHPpfOt3p/5h/DsyeyyWCABio+69MVIjz3yWryvnCKBGJ0z3
xKQambyzr7SFLQCthnZ3VrM60fUo9cv6jIFxrbJIuKdBtu9NCN8wgoGrHcJI
z7NIEmdNJPqIoTvm0MzDQDYpX2/guOgthp7l+olZ9BzyNlUyntuCIZbe4WGu
o0lC7733LXuFwaSVUmR1aBJNp9vhHkoMns0Zro8qtMicefM3TldgUOjnyqXS
ueRCQ9vh3UUY0CS/KiFiHumOS4ydkmPgWH6jzvbWJtIu25UudzFoG4/9dcJM
h6Txx5vupmGwtVssaxzRIZzkzJyCZAwz2epXi1/rEv46V5bbWQxlSgmdfkeP
rG3I1uT8iGGBw85+brw+aZcfC/KNwHA4oFuS4GdALric9/uwA8PJ9oma/VxD
8jwCtTt+i8HIWhLXcdqQ6OuQJpY7hmVBw4m1A4akzrmty9sewynFTqv4bRyi
LK4O1qMxTGdJxaJ6DhEiXdtfF2AYjODc2mRnRN7qVgTq62Kw3rH9ijjbiDxd
uGviwwwFn+i+dzmGXJINL92SBiioSbZJZUVxyZyihgVenRSM8oM+UH1cUvHI
vDGuloLr58rPKb0R0VN0TV8rpSBq68GKNB9EHLSGN3qpHLCSPxWxGRHj5pw0
LZUX/3Fql/EWRO7qYFHUUwqyLF1dQ4IRcU9qZPmXUKBoqtGYPYDIaW1caPKE
gtplbTFWFxG5aYeHrz2kQD6dUKiRiMgWlJGySeXLdQ6DTT8hEr47yFpTZZ+j
N7ceT0Fk1cf4gEgFBW0vg8UvfkHk4mnTPb4PKOj9vnc6JAcRJVLfr19AgdLt
urWdDBGz8usPquUUyEzXh8/LQ6SgdMWn4yofqM5tKShA5ESUy7b+fArGeQce
zz5GpGU2e/h5HgXNg4uGXj1BRKejjH1S5aKqeiqzBJHXbAXXTuXo/dZXN5Qj
YtK6eEnWfQq2ru2qXQiIaB+7bBqostP8FPZIJSL1uS84Rirz+50dnz1D5NC2
GvUXMgrUYezQtWpEZOKk/pMq/wfG8TKT
        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV13c8V98fwPGPzxSV0SepVFpCQ0VI6rzNzKxCFCVJi6x2ZlFWEfmahUJW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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -14.828319324026277`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-14.828319324026277`, 1.3474978726872964`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282632526189*^9, 3.41783613904758*^9, 
  3.479827868013757*^9, 3.4798285385763283`*^9, 3.479829729506915*^9, 
  3.51853519443958*^9, 3.6434437944293413`*^9},
 CellLabel->"Out[188]="]
}, Open  ]],

Cell["\<\
These  values for day 1 to 10 are the same that Table A.12.14 of ICRP 78 \
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"fn1", " ", "=", " ", 
   SuperscriptBox["10", 
    RowBox[{"-", "5"}]]}], ";"}]], "Input",
 CellLabel->"In[189]:="],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[190]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "6.730830162540055`*^-8", "0.28236411345312196`", 
      "0.7176358192385751`"},
     {"2", "5.1743302542375974`*^-8", "0.3890851047240289`", 
      "0.32855066277124345`"},
     {"3", "2.8909358077822965`*^-8", "0.19699204629631897`", 
      "0.13155858756556646`"},
     {"4", "1.8559261194618996`*^-8", "0.08138842414472283`", 
      "0.05017014486158244`"},
     {"5", "1.2934265522211492`*^-8", "0.03141549520459143`", 
      "0.01875463672272549`"},
     {"6", "9.448967084664894`*^-9", "0.011800831729525273`", 
      "0.006953795544233125`"},
     {"7", "7.131590794880211`*^-9", "0.00438157339398136`", 
      "0.0025722150186609696`"},
     {"8", "5.538981913131208`*^-9", "0.001618553427403695`", 
      "0.0009536560522753615`"},
     {"9", "4.427886028291802`*^-9", "0.0005965358542832037`", 
      "0.00035711577010612955`"},
     {"10", "3.6468626369910194`*^-9", "0.00021963711557213895`", 
      "0.0001374750076713536`"},
     {"20", "1.747899990225271`*^-9", "1.0480733330857035`*^-8", 
      "9.568736850002227`*^-6"},
     {"30", "1.5546942720351045`*^-9", "4.0308331282609263`*^-10", 
      "9.542408766793795`*^-6"},
     {"40", "1.428036790603774`*^-9", "3.951918367669634`*^-10", 
      "9.523597040978551`*^-6"},
     {"50", "1.318685297925425`*^-9", "3.904183474823491`*^-10", 
      "9.50600498572384`*^-6"},
     {"60", "1.223226357369404`*^-9", "3.857387195008776`*^-10", 
      "9.48947538405421`*^-6"},
     {"70", "1.1398197025456444`*^-9", "3.810839533585763`*^-10", 
      "9.473879354445235`*^-6"},
     {"80", "1.066896561272048`*^-9", "3.7645629346998584`*^-10", 
      "9.459104928817822`*^-6"},
     {"90", "1.0030929877016828`*^-9", "3.7185959674033915`*^-10", 
      "9.445054637977233`*^-6"},
     {"100", "9.472223846197146`*^-10", "3.6729737239156137`*^-10", 
      "9.431643619595687`*^-6"},
     {"180", "6.862165454619274`*^-10", "3.323513983426101`*^-10", 
      "9.340223688462918`*^-6"},
     {"200", "6.522619984919594`*^-10", "3.241112385034369`*^-10", 
      "9.320308826596693`*^-6"},
     {"300", "5.579426335219334`*^-10", "2.8620593419397016`*^-10", 
      "9.230143227066947`*^-6"},
     {"400", "5.141242885877518`*^-10", "2.5376740454751356`*^-10", 
      "9.149817290839005`*^-6"},
     {"500", "4.839654285110017`*^-10", "2.2634932447014526`*^-10", 
      "9.076033518941062`*^-6"},
     {"600", "4.5849728109798786`*^-10", "2.0330863133785762`*^-10", 
      "9.007511038587392`*^-6"},
     {"700", "4.3551756941791165`*^-10", "1.839890959780014`*^-10", 
      "8.94351221075312`*^-6"},
     {"800", "4.144294264562742`*^-10", "1.6779202315244632`*^-10", 
      "8.883482760534823`*^-6"},
     {"900", "3.9500379977592913`*^-10", "1.541974947415576`*^-10", 
      "8.826961056216083`*^-6"},
     {"1000", "3.7709369747980146`*^-10", "1.4276487450256412`*^-10", 
      "8.77355119454799`*^-6"},
     {"2000", "2.579947043490887`*^-10", "0", "8.353512697074878`*^-6"},
     {"3000", "2.005774542395138`*^-10", "0", "8.045596215210564`*^-6"},
     {"4000", "1.6980373745849634`*^-10", "0", "7.79028876698116`*^-6"},
     {"5000", "1.5122581764260608`*^-10", "0", "7.5651109812700414`*^-6"},
     {"6000", "1.3865657737560953`*^-10", "0", "7.359802234658163`*^-6"},
     {"7000", "1.29324988083704`*^-10", "0", "7.16900682457855`*^-6"},
     {"8000", "1.2191404970292563`*^-10", "0", "6.989602492744662`*^-6"},
     {"9000", "1.1574918026350232`*^-10", "0", "6.819589270378686`*^-6"},
     {"10000", "1.1045460122168123`*^-10", "0", "6.6575850467497755`*^-6"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Urine\n24 hours", "Faecal\n24 hours", 
       "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992826333693304`*^9, 3.41783613989133*^9, 
  3.479827868998107*^9, 3.479828539607506*^9, 3.4798297304914227`*^9, 
  3.5185351949864655`*^9, 3.6434437946480937`*^9},
 CellLabel->"Out[190]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[191]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVz3tUzGkcx/GmKamp1PTLmTZ1opDJ75nfHBmrkecJU6zTomW6bHR1WTK5
N4tokkgqtWPthrElDbFFlm2cLl9TLXbSokK5ZJUM6cZkYtptZ//4nPd5/fmZ
HJ8cttbSwsIi1Lz/+5je5X93297599YnrVEnCiE1PkZfwIvCKbbnmHMJQsj/
1GAZxduIX/2g2XY2Xgjujca8QN5uPJb7XUBRrBBe8POlAt4RLIpbml0ULQTt
s2dzfXmFuLzhj8lXVwph1pyMiz68MtyZnoIcJUJ4lxDePYV3A0e0T+yQTxPC
Z3ZwNSXU4eTGJ7W1rxl4WVwjdZ7Vip0WxWbPucpAmGuxSXapA5uWcdxwJgOh
mT5jU9pfYHm1wmpTNANdNfP5zl7duLtt8goHMQM9cwKs5v36Gi+NFN0aN4mB
8sIo/wczerFyy5i8lcXAek2Q46aN/bhhfWEzp10AIQ4Hl/4yMoj3dFR1pl4W
QMvJpkR71XusjHxjcM0TwE3VtBlIbMArrFMGOrcKoGfB0CKZaRgrN9wE5SoB
sCVnrlWcNuIx2TrtcKAAwvU1qRMSPuFZohTGZroAHCwGBn28TDjQSRM/xBVA
9U62Rlw3iv/JNbIElgIoOnr48RbFv5g6lSj7PIQA0uSlLVwLsnhTS2N2NwId
Z639vo8WxFvi5Vv6CIHN/Y4Q9kMWkQ67Ht3ehABLtHRWqSVJqOcvdKtH4GIX
j1WH2cSnvvp9twZBV+p209Vvrchsa7/g/isIuv0cc0r41kSLyxR7yhCk8eO+
8uGMI8bUVUl5xQjcHk+tLHk6jtTQHmyPkwhCHxZLfquzIetUBbt0BQgqHS+U
q1TjCZa0CcVHEFAfvbRZMlsSijt0OgUCZ7SCZbXcjuAd5z14cgR2rh/e7pvC
IckhETF7ZAhmizzLWgc5ZPkx3f2DiQhMatZxzT174iwc6ZwUiaDmtpR/psiB
DKd7HtOHIvgiILHXJcOReI/OVPsFIdgR1SXNCp9A8vvUEbX+CPZ3DOuSXJxI
8duB/Im+CLiMNP3pASei6Kta9dwNgffqgZymd07EUGzynGmPQFGZKMhY40wq
rrhufDNKw0iJSjyj2Zls5WrG5/TR0CdzPv21iEskhsK3vc9pYOJilWI1l7xx
N4U2NNMwxNe/OO/kQsqOi6KS62jQ5fv/xJa7kGXSB13oMg3vvVa/mqp3IVWL
18YmnKHhxKHaQ7eXUyTI9tZceR4N8ujkupNhFHnw8cMxxuwooZdRtpIi6Z9a
X+pzafB8oljnGkGR0iblrkizS5BEEh9DEfeBe6sDcmiobNNZjm6mSP83Il/T
ERqavNtTBdkUKegJVcozaSgfybpmmUMRI6c3gDE7725AX1suRb7HjU9eH6Qh
LOVU9N4CigSn+dmHm93+Z4z4zs8UCZ8ePH12Bg09W3tG4s9T5EsWf+Gggobb
wScYURlFTrQ/z1abXea+eIPtJYpY2xY0rzF7c+OFRxUVFJE16oPuptFg4G2+
PnqdIrX1dzov7KfhYZ9H/19V5r8hY8ZYs3/XNk89e4Miz6y5djyzdycxx5fU
UmRneY175j4aooP+bpoEFFHbLXEPNHv+xAKrwZsU0bWcpQypNHj1LphXX0+R
rJ1am4tms+DD9h8bKbL7Uqkhzuz/APLuPaQ=
        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV1nc8V98bAPCPzzbKSCVZRbJCCPmqc5KZFRUilEqiZFcqKxkZRZTVsDNS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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -19.13249575688523}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-19.13249575688523, 1.7393071755354774`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282636907514*^9, 3.417836143781955*^9, 
  3.4798278709980555`*^9, 3.47982854174798*^9, 3.4798297325385723`*^9, 
  3.5185351968302507`*^9, 3.643443795054347*^9},
 CellLabel->"Out[191]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsubsectionIcon"],

Cell["Type M, AMAD 5, Pu 239 with a half-life 24100 y", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"amad", " ", "=", " ", 
   RowBox[{"AMADAdultW", "[", "5", "]"}]}], ";", 
  RowBox[{"class", "=", " ", "M"}], ";", " ", 
  RowBox[{"fn1", " ", "=", 
   RowBox[{"5", " ", 
    SuperscriptBox["10", 
     RowBox[{"-", "4"}]]}]}], ";", 
  RowBox[{"lambda", " ", "=", " ", 
   RowBox[{
    RowBox[{"Log", "[", "2", "]"}], "/", 
    RowBox[{"(", 
     RowBox[{"24100", "*", "365.24"}], ")"}]}]}], ";"}]], "Input",
 CellLabel->"In[192]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[193]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Lung\\nretention\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.05762559515662371`", "0.00023149434972861253`", 
      "0.1082924513425011`", "0.49695113305489286`"},
     {"2", "0.05593275677915807`", "0.00013064674587120453`", 
      "0.1546879319361872`", "0.26336991165917406`"},
     {"3", "0.05498582501762911`", "0.00007780548428764969`", 
      "0.07968742791870403`", "0.15462951557749022`"},
     {"4", "0.05415635083868885`", "0.000053008173141307`", 
      "0.033504197772725904`", "0.11041293765107589`"},
     {"5", "0.05335927380591857`", "0.00003907884923910711`", 
      "0.01333888620267006`", "0.0931136032873387`"},
     {"6", "0.0525826661685443`", "0.000030275829995398163`", 
      "0.0053707710512971565`", "0.08626995965873321`"},
     {"7", "0.05182446266462216`", "0.00002436066386401607`", 
      "0.002335199003812628`", "0.08337969269740422`"},
     {"8", "0.051083940087599894`", "0.00002027029936520662`", 
      "0.0011906275302822028`", "0.08197355298120211`"},
     {"9", "0.05036056948368246`", "0.000017402861957819614`", 
      "0.0007556135376068029`", "0.08112870556001152`"},
     {"10", "0.04965386116383509`", "0.000015377016488315123`", 
      "0.0005847626945251021`", "0.08050213519034155`"},
     {"20", "0.043406236967601035`", "0.000010241044371972263`", 
      "0.0003689141760743501`", "0.07611164953751237`"},
     {"30", "0.03838670178211154`", "9.507261209631359`*^-6", 
      "0.00028112567575510087`", "0.07282930956908829`"},
     {"40", "0.034298263484765626`", "8.976486833909045`*^-6", 
      "0.0002159608837407214`", "0.0703000654778936`"},
     {"50", "0.030921145160418932`", "8.514218376601467`*^-6", 
      "0.00016727844023643138`", "0.06833257547009489`"},
     {"60", "0.028092071983661555`", "8.105599914788922`*^-6", 
      "0.0001307570508215454`", "0.06678631835134165`"},
     {"70", "0.025689225995442728`", "7.741618015990688`*^-6", 
      "0.00010323763697610043`", "0.06555738156894725`"},
     {"80", "0.023621293512822793`", "7.4152381709938635`*^-6", 
      "0.0000824017805680638`", "0.06456867821250592`"},
     {"90", "0.021819473359704106`", "7.120852637255586`*^-6", 
      "0.00006654358989877612`", "0.06376283987938874`"},
     {"100", "0.02023163139919868`", "6.8539397711800065`*^-6", 
      "0.000054404588997508484`", "0.06309703092595627`"},
     {"180", "0.011924130567408726`", "5.372788431936764`*^-6", 
      "0.000017045814522822796`", "0.060213582088033415`"},
     {"200", "0.010555936865525148`", "5.121402069335612`*^-6", 
      "0.000014147412892940565`", "0.059799918340212914`"},
     {"300", "0.005836202158494793`", "4.236907517846436`*^-6", 
      "7.4162601893050275`*^-6", "0.058325634962145656`"},
     {"400", "0.003255027848737492`", "3.705086265468478`*^-6", 
      "4.663858490026157`*^-6", "0.0573427933104052`"},
     {"500", "0.0018196999778347855`", "3.3475172339039886`*^-6", 
      "3.1568381460725574`*^-6", "0.056607574959440424`"},
     {"600", "0.0010188480839594147`", "3.0854665436570793`*^-6", 
      "2.2747419602436577`*^-6", "0.05601885444992844`"},
     {"700", "0.0005712937364596929`", "2.8799085546415873`*^-6", 
      "1.7403557769905586`*^-6", "0.05552227646819005`"},
     {"800", "0.0003208284794185388`", "2.7100729005720743`*^-6", 
      "1.4048165447167196`*^-6", "0.05508682206180224`"},
     {"900", "0.00018045925661593326`", "2.564370727874358`*^-6", 
      "1.1853050947334123`*^-6", "0.054694251862622785`"},
     {"1000", "0.00010167349093379027`", "2.4360810546372207`*^-6", 
      "1.0351578091188563`*^-6", "0.054333493661098034`"},
     {"2000", "3.634712400226139`*^-7", "1.6351811028079802`*^-6", 
      "5.722382750821811`*^-7", "0.05162033342032037`"},
     {"3000", "1.5883719682254323`*^-9", "1.258173090527354`*^-6", 
      "4.7091471717816834`*^-7", "0.049678065843687766`"},
     {"4000", "8.18921565887539`*^-12", "1.0583451461747712`*^-6", 
      "4.2244386784427566`*^-7", "0.048080887563362575`"},
     {"5000", "4.667925952954965`*^-14", "9.390811582735408`*^-7", 
      "3.892676878324097`*^-7", "0.04667796999970086`"},
     {"6000", "2.798899798761254`*^-16", "8.591931776609942`*^-7", 
      "3.634684885909037`*^-7", "0.04540167896965729`"},
     {"7000", "1.7189744242550398`*^-18", "8.00328002129808`*^-7", 
      "3.4236044096860776`*^-7", "0.04421714654167519`"},
     {"8000", "1.0684196296502879`*^-20", "7.538202382549618`*^-7", 
      "3.2456873796923177`*^-7", "0.04310424986836143`"},
     {"9000", "6.686828198788151`*^-23", "7.152662980420132`*^-7", 
      "3.0923510431979624`*^-7", "0.0420502046982023`"},
     {"10000", "4.205605858777915`*^-25", "6.822334051185005`*^-7", 
      "2.9577913618346216`*^-7", "0.041046231565192576`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Lung\nretention", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992826522797923`*^9, 3.41783615929758*^9, 
  3.4798278886382294`*^9, 3.4798285588405266`*^9, 3.479829749462722*^9, 
  3.518535209502369*^9, 3.643443798851266*^9},
 CellLabel->"Out[193]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[194]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAA2C12NM1yfD50iLxQ5VkGwH1iX+iS
GFo/Pjxl1tJWBsCR+cQCWhhqP00aDFnAUwbAG8X3jz0Yej8avk9Vm00GwOAq
kVYvGIo/6XKOKVFBBsDC3d05KBiaPz5u5j+8KAbAMzeEqyQYqj8q59IbkPcF
wOxjV+QiGLo/mrE5Ti6VBcD6A0a8FDHLP+PixZqvvwTA4qK9VhEz1D/vxemj
GfgDwFIVovturNo/rkC9xjA0A8BNhiT/ItngP83XYSdmXwLA470+KhEg5D9C
ord0jJgBwOY3OgQ8rec/hu7OC8jAAMCumlo00inrP+C6Sltq2f+/Z7lBDmtq
7j9pWVInbU3+v0cNhUug+PA/GeIhQMaf/L/Tm8xkDJ7yPxeXxTyRDvu/wZ4m
KS479D+YCosqToX5v+ZC8URu+/U/3cG30tva978DRZ+1r533P0j0B6BdTfa/
V+i9fQ9j+T84ZIhqLZ/0vw0A7/AkIPs/PazW0sf58r+8dQO5O7/8Px7LPvrT
cfG/oYyI2HCB/j/ChapwNZTvv8CAeKbTEgBAYojMIE+A7L/LC2UMfvYAQK6A
U2t8Lum/B9HaRwPWAUASSv1esvDlvz9Fwi2JpgJAJMiuSzXv4r8TCmI/nogD
QLqTM1gwZd+/431z+7NbBECBc19GwmXZv+QrDo2kKgVA7mDXm8iQ07+AKmFK
JAsGQE3UQyONmMq/GdglsqTcBkAIenk1Cwq+v03WokW0vwdApZslmv3wlL+y
Dqmunp4IQF3CewtJzLI/FPYgwoluCUAyjcLxNHTEPxEuUQEEUApAx7votaIh
0D8KFfPqfiILQKi2jxOOjdU/NTYeqtTwC0BnzUGfJsfaP/unAZW50AxAVzWz
z6sr4D+9yFYqn6ENQEm0femdtuI/Gjpk6xOEDkABYVaS5WjlP3Ra41aJVw9A
60sa3WXe5z9/2vXLbBMQQID6XELnOOo/EjBWgtyDEECSVHgVfbXsPyNd743M
7BBABAS+bzv37j+BsmQvhF4RQAVj9yV6q/A/+KSeOynOEUDSTW8/RMzxP+1u
EZ1ONhJAcmVLyurQ8j8wYWCUO6cSQCueqFe74fM/8Sro4KgQE0Brkwuv7Nb0
P8uRNJgDeBNAvaxWqg6+9T/yIF3lJegTQKGzIbMIrvY/l4e+h8hQFEBrQ6us
V4P3P3hcb7+bUhRA2t2HBviG9z9aMSD3blQUQHQ+54iXivc/HtuBZhVYFEAk
1GEG1JH3P6QuRUViXxRAZ5ep3kKg9z+y1csC/G0UQHyqT9f3vPc/zCPZfS+L
FECH7J56vfX3P674ibUCjRRA18INgEL59z+PzTrt1Y4UQMeKb6fG/Pc/Unec
XHySFEAsTDRbzAP4P9nKXzvJmRRA4sPYUM0R+D/mceb4YqgUQM5h/0SlLfg/
yEaXMDaqFEBazC9QHDH4P6obSGgJrBRAi97reZI0+D9txanXr68UQO2iKih8
O/g/9Bhttvy2FEAGhbjpREn4P9btHe7PuBRAbYI847RM+D+3ws4lo7oUQDy+
kfkjUPg/emwwlUm+FECSgdF7/1b4P1xB4cwcwBRAfalM52ta+D8+FpIE8MEU
QP1Qum7XXfg/IOtCPMPDFEBIoeIRQmH4PwHA83OWxRRAS7SN0Ktk+D/LKlpu

        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwVkms01GkcgMfMVDIahr/Mf27GmBymDWOUQr1vThQdhVOjplBCZd1KocTm
Eikl2tbKNiKHKNR0pYYf1kam0laK6hyVpNx1Gbe1az885znP98c8KMo3hEqh
ULxm+d+vlsQ6PNp/ZJVjQRaLYyyCxKDAvly2ArF8bnemskSQM/EnVcEOQ8ov
0wmDBiLgNmuzV7IPI2bYHscGfRF0S3LktuwTaP+/S1+HzRVB49u3K6zY51Hs
vYHMlglzkDmmXRGzK9BgyEt+S7c5DOzy6xGxa5FKrs7bc80cJmnu9wlpGzK0
XJ610scc3her5SzZc5SgupK9m24OvibFU5FXuxA9791PNxuF4JUu/lfU2Y2W
Tyb3r0sTwgf1KglL2IPuRU06ffQWQq+jE92l8hOy39GaFG0mhKrzCoe/rfuR
q3FvTXifGeyuWc38OWwIXb6Fp98XmsHaBcfWXxwfQXpi1UD7FjN4VqAJ1leO
oRujBQOFPDNoUFpa2zh/QxvojuhSrwB6XUfXRE59R31loYyZawKguRXeqr6g
RV+R9UHdVAH49akTDXZNoOLDnm9lmwWwgDI8IhZOobKNLvs6Fwvg/kFajXP9
NCp5rC120hVAUdbxV9HJM+ju/fnrj/bwAY7Glz4zouBhlvTTuWY+tDFC9JN+
ULC1jyw2oJQP8552raV16GCWaZc2P5MPyK1xSWYpFX8zmEmiR/PBWC8IKY/T
sL7C6JDFZj58SIyZurGNjimxsWP+LnzoWcw8VSKZg0PuVBSNWvDhqGSnp5gx
F6sepBR06PKBfLVIVfJmLl4r8dbNH+KBV0ex2836eTgKTTa0tvNAxSyvUip1
sWedPOTddR4QP4SNmZHz8Zm91PyIszxg2fjo0L318IqtspmMaB7omXz9kiRi
4FrahNpyAw+WLhNUPB9h4OqE8sp6CQ+mynTO1bTr4xSZ5mIMlQfqFrmksGgB
dqfHHxO+5gLHKbjfOI2JsUrcUVnFhQOKD/JMPwO8d6PD5xOpXPil63tbuLEh
RjqfKx/5ccHITp7yJtUQp6cOVby05IKF//ApzYAhPhN0MO65lgPJqmDbtAAW
lv0jyD3bxIHxEqWz9WMWxq32pxdmc2AwknVhwzIjXETbZGrnzwG7nTt+dS4z
wsHSLCepJQdGJX3dlw2NsWbiOIjGSGjLcfidFj/bCUyrk3UkjAn9Py7qM8Za
tUEAM52EvIy6jBZvAkdyyf0/vEmI3x5VX+BL4Hvh5aW6s62QCrWRmwicMudp
O2cjCYLXyaEmWwi8c3WXFHmRUGLj5hYUSODu9ICTGR4kqF60UacjCDxaUOpt
6kqCxqIz0fYkgfOGnwzZy0ioGs+8RT1F4IgAatIaexKyHzkNvjhNYFpDLUUu
JcE37o/tR3IJLLkexzhkS0Lnw0Dn1nwCh0oTu+oWk9C7r3c86DKBm3LCrnqI
SWhxz7NbVkFgm3GzLwoLEiq46/bMv0pgK4JhHS4iIaK5/GV1NYEfBkqUp4Uk
fGNH3J6+TeAkwx2+z3gkdAzyh57cJbCl0H1vD5eEO42PF12qJbDjAasT3zkk
HA63O+dRR2CTGIObpiQJ21e/08xehR8cKmu1YpOwamEufaSBwO2h4ZoVpiQI
+11dmpoI/NdWjxeeC0nQga8xvzUTOG4z7c02ExL+AzQxJvw=
        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV1Xk41F0bB/CxZqlsQ0QiqsfuSVGS+5ci7VJREYVUSllSWiQUWshSKYqH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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -10.093496880265679`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-10.093496880265679`, 2.5807665357302136`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Lungs\"", 11, StripOnInput -> False], 
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282744106946*^9, 3.417836253438205*^9, 
  3.479827911012656*^9, 3.479828583200039*^9, 3.479829772168898*^9, 
  3.5185352275964665`*^9, 3.6434438040075626`*^9},
 CellLabel->"Out[194]="]
}, Open  ]],

Cell["These  values are the same that Table A.12.13 of ICRP 78 ", "Text"],

Cell["Type S, AMAD 5", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"amad", " ", "=", " ", 
   RowBox[{"AMADAdultW", "[", "5", "]"}]}], ";", 
  RowBox[{"class", "=", " ", "S"}], ";", " ", 
  RowBox[{"fn1", " ", "=", 
   SuperscriptBox["10", 
    RowBox[{"-", "5"}]]}], ";"}]], "Input",
 CellLabel->"In[195]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[196]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Lung\\nretention\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.06427551994091664`", "2.34475850948433`*^-6", 
      "0.11404595335802868`", "0.49142678078060764`"},
     {"2", "0.06269377814052549`", "1.356192667829847`*^-6", 
      "0.1630945072062682`", "0.24956827540831428`"},
     {"3", "0.06193512325901065`", "8.340742108695286`*^-7", 
      "0.0840324818389042`", "0.1365597982697097`"},
     {"4", "0.06130045478905901`", "5.906333485633218`*^-7", 
      "0.035322460059451985`", "0.09057737742020959`"},
     {"5", "0.06069490792010007`", "4.546517373769031`*^-7", 
      "0.014059230439921685`", "0.07259632499800335`"},
     {"6", "0.06010533089283596`", "3.690375716422306`*^-7", 
      "0.005665142595744146`", "0.06548821866093564`"},
     {"7", "0.059529637815411`", "3.116576982553497`*^-7", 
      "0.002473687438500629`", "0.0624835143378212`"},
     {"8", "0.058967248339771475`", "2.7206873218369554`*^-7", 
      "0.001275128928607072`", "0.061012873527895826`"},
     {"9", "0.05841779372174069`", "2.443867806775752`*^-7", 
      "0.0008231389534480526`", "0.06011766124054629`"},
     {"10", "0.057880941508660855`", "2.2489414821765476`*^-7", 
      "0.000648222399400649`", "0.059442785360427616`"},
     {"20", "0.05313921419575651`", "1.7705897807477366`*^-7", 
      "0.00043946034356056755`", "0.054485128031713306`"},
     {"30", "0.049354211662046586`", "1.720116715332853`*^-7", 
      "0.00035077427765174755`", "0.05059504372110751`"},
     {"40", "0.046312260826374595`", "1.6891363323148618`*^-7", 
      "0.00028185550519150643`", "0.047478836656747604`"},
     {"50", "0.04384901573322593`", "1.6646033353547865`*^-7", 
      "0.0002281455334795435`", "0.04496493332667652`"},
     {"60", "0.04183776555424525`", "1.6450778124203305`*^-7", 
      "0.0001861692525533557`", "0.042921122619997136`"},
     {"70", "0.040180576013570536`", "1.6296696288340383`*^-7", 
      "0.00015326796801676555`", "0.041245269582056814`"},
     {"80", "0.038801565191457735`", "1.6176718387315605`*^-7", 
      "0.0001274029716526563`", "0.039858277113066255`"},
     {"90", "0.0376417895536731`", "1.6085126528765667`*^-7", 
      "0.00010700733100986448`", "0.03869873534836546`"},
     {"100", "0.03665534671759144`", "1.601725691237943`*^-7", 
      "0.0000908738473935541`", "0.03771884573959092`"},
     {"180", "0.03197249937570247`", "1.5979024237601689`*^-7", 
      "0.000037383608130389224`", "0.03319425932265218`"},
     {"200", "0.031218174798007668`", "1.6044651830239956`*^-7", 
      "0.00003314448070622387`", "0.03249050762352731`"},
     {"300", "0.0281737947871142`", "1.6493942363616432`*^-7", 
      "0.0000244426579200375`", "0.02970073064395631`"},
     {"400", "0.025649211858481635`", "1.6938510153247403`*^-7", 
      "0.00002129553664345895`", "0.02741244089117566`"},
     {"500", "0.02340579527984788`", "1.7287866792923578`*^-7", 
      "0.000019042653665497505`", "0.025382730784302053`"},
     {"600", "0.021391308031080535`", "1.7533140125068943`*^-7", 
      "0.00001709625890345032`", "0.023561028448188418`"},
     {"700", "0.019579052331347428`", "1.7684688573887878`*^-7", 
      "0.000015360847058216716`", "0.02192277527555089`"},
     {"800", "0.017947725294943435`", "1.7756133148996586`*^-7", 
      "0.000013806149543905904`", "0.020448656275299976`"},
     {"900", "0.016478586682846713`", "1.7760440267957176`*^-7", 
      "0.000012412323052700468`", "0.019121710939694492`"},
     {"1000", "0.015154891387683833`", "1.7709101977082123`*^-7", 
      "0.000011162547186423275`", "0.01792677925925024`"},
     {"2000", "0.007275420625670282`", "1.5760208777358752`*^-7", 
      "3.954374248922423`*^-6", "0.010842217351754188`"},
     {"3000", "0.004269561067351141`", "1.35529287862404`*^-7", 
      "1.5103810286091596`*^-6", "0.008178194565994052`"},
     {"4000", "0.0029560806945086704`", "1.195512807834049`*^-7", 
      "6.627710394156089`*^-7", "0.007036155244018597`"},
     {"5000", "0.0022627725235783488`", "1.0866517846522224`*^-7", 
      "3.534333345830187`*^-7", "0.0064381589608805845`"},
     {"6000", "0.001821995292443331`", "1.0093431897946726`*^-7", 
      "2.2855866602867906`*^-7", "0.006050505428992895`"},
     {"7000", "0.001502699964140593`", "9.503082770305952`*^-8", 
      "1.6929264542635453`*^-7", "0.0057563144408809275`"},
     {"8000", "0.0012542603135158954`", "9.02067812782073`*^-8", 
      "1.3523688159210938`*^-7", "0.005512296237299078`"},
     {"9000", "0.0010541658641613448`", "8.606562572636082`*^-8", 
      "1.1228040200453368`*^-7", "0.005300619385618116`"},
     {"10000", "0.0008903490793374506`", "8.23964790207445`*^-8", 
      "9.51954455530807`*^-8", "0.005112630928268636`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Lung\nretention", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992827587565317`*^9, 3.417836268281955*^9, 
  3.479827926574758*^9, 3.4798285990154734`*^9, 3.4798297875459642`*^9, 
  3.5185352392216897`*^9, 3.643443807476335*^9},
 CellLabel->"Out[196]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[197]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAA2C12NM1yfD4+Wl2mFIIFwH1iX+iS
GFo/DOF+Jv9+BcCR+cQCWhhqPzd1MaPpewXAG8X3jz0Yej8nN0OSvnUFwOAq
kVYvGIo/F0zrRmhpBcDC3d05KBiaP3zb3Ai7UAXAMzeEqyQYqj//fqXjXR8F
wOxjV+QiGLo/SEeJlpi8BMD6A0a8FDHLP6QdBUM65gPA4qK9VhEz1D/mzNbL
xx0DwFIVovturNo/ofL1gflYAsBNhiT/ItngP2pO23UkgwHA470+KhEg5D/g
70DoPrsAwOY3OgQ8rec/dE1b8X/E/7+umlo00inrP8GXJFi4Gf6/Z7lBDmtq
7j+je6ZVDYv8v0cNhUug+PA/lPbBGDja+r/Tm8xkDJ7yP0lKgjjARfm/wZ4m
KS479D/FA81T/Lj3v+ZC8URu+/U/2pvs21oK9r8DRZ+1r533P3qiFKGOePS/
V+i9fQ9j+T+tVKEEN8Xyvw0A7/AkIPs/O5KkaDUa8b+8dQO5O7/8P0x5kyD1
GO+/oYyI2HCB/j/Sol2jp7vrv8CAeKbTEgBAWkRfhnKZ6L/LC2UMfvYAQDcv
ifh0NuW/B9HaRwPWAUDwTPdf8uXhvz9Fwi2JpgJAGCwnyEui3b8TCmI/nogD
QGU9QKO++ta/431z+7NbBEACj+ckdMvQv+QrDo2kKgVAcycIB5iFxb+AKmFK
JAsGQPRlrH9tAbG/GdglsqTcBkACd6MzE5ScP03WokW0vwdA8Gi0DleSwD+y
Dqmunp4IQFLjYuvuPM0/FPYgwoluCUAlbz3KAnvUPxEuUQEEUApAO62EKcvI
2j8KFfPqfiILQNRv3tj5TuA/NTYeqtTwC0B3W7fyYCTjP/unAZW50AxAa1gQ
ogww5j+9yFYqn6ENQBxCdrFbAOk/Gjpk6xOEDkDVV9OiYQXsP3Ra41aJVw9A
wwm+YejP7j9/2vXLbBMQQGHgVzfewvA/EjBWgtyDEEAJccPQkTfyPyNd743M
7BBAOlUO0jyQ8z+BsmQvhF4RQAmjoWWRAvU/+KSeOynOEUAvhp+uSWv2P+1u
EZ1ONhJA0CgF6ZO59z8wYWCUO6cSQAoXFfYOIvk/8Sro4KgQE0ALHvVGHXH6
P8uRNJgDeBNACXF0mIa4+z/yIF3lJegTQN+5UOrjGv0/l4e+h8hQFEADYut/
+2T+P3hcb7+bUhRA7GLAaLxq/j9aMSD3blQUQGuNWkl9cP4/HtuBZhVYFEDY
9fjx/nv+P6QuRUViXxRAj9SO4QGT/j+y1csC/G0UQJ5AFz8Gwf4/zCPZfS+L
FEBymWgSCR3/P674ibUCjRRAoISP/cgi/z+PzTrt1Y4UQGkU/eCIKP8/Unec
XHySFEBhp7CQCDT/P9nKXzvJmRRAH0yPkwdL/z/mceb4YqgUQKAJQicEef8/
yEaXMDaqFEACT/yWw37/P6obSGgJrBRAxJD6/oKE/z9txanXr68UQA0RvLcB
kP8/9Bhttvy2FEC8CRjM/qb/P9btHe7PuBRAa3y4/b2s/z+3ws4lo7oUQHA+
iid9sv8/emwwlUm+FEBI4bRj+73/P1xB4cwcwBRAIOUGdrrD/z8+FpIE8MEU
QFF+fIB5yf8/IOtCPMPDFEC5yBGDOM//PwHA83OWxRRADrHCfffU/z9Sq0+g

        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwVjGs0lHkcgMewKyMy5lXTiibeuW8uY5YT8v4rJB1tqUXjTm2dcikqThlR
2jG5LemCDMkql7I7hU0xv5Szdse1wRY6jZLmCCmVy1BrPzznOc+XZ11ErO9+
MolE8lnifz9df0LYEZfkRpFsbPFx54M4IlSTRxcRR8p/767bzIfcucdkEf0Q
sXt8MsByEx/MW2dyNtJPEh2rwuQTG/mg5uX62dLPE3NOKkGeEx9anj/fwKEX
ElfSDpcP8/jg4JRWjdOrCEFPdUYblQ/jkf4jVvRGQrnBLVEwzIN5Xc8HmL2S
SKfF7zqVyoOXZU1+VIdeok6/omyZkAe+ZmXamJoBoqbrQl/ley74/IJ/tXqm
JgYqXWRxci68anLjURkjRIaANOKWzIVRJ2c911tviHCNl1K1nQu3C0XCJ9y3
BMlTPZCxlgsH7m0yPnxoktgW5eZhN8+BrUbntpfOThGD0Sd2+/dxQFXUvm+5
7AMRXHPBRl3HgYcyFtfG5SPR2MybiyzgwOjm9+4x2k9Ej+cU5XESB3Q9Supq
i2cI/eGsyjeRHPDXNIlXRM4RxQuxcQ3eHDAivZvCGVpiS45XWKYDBx4c173n
olggrMV3V3PWcuBaZvrTI6lfiOoCVbANhQOQklihMiUhxanTe8/MsEFpuH95
8mcS+vXr3CGjETbo9wxs1e3XQbVWjctSethAeLSsl1aQUau0ZCwe2ECjRBCy
dF2U4i1QL95iwytxvPZOoB76dMQzSnKVDSN846xy3jfo7LHLL+bPsyGFF+6N
G36LcnPGLVwT2LD6KVNePvQtCgwv+342kg0+/WUedxX6yP63/vV6O9ggN668
LZMtQ9bT3s5bnNiAfWa0SGMMECMgp/A1gw1Um106ejspKGGuqF2kzwaK2fRY
spUhojqaj22dZMEPjpZVvVOG6Ov9VbmZvSzQ3tC5eK97OUo4OrBmbwMLmtr8
eCXXjNAWX036WCELvnPe95aWZoweax81qE6y4JjolZ/UfwV6ocLZdwJZcHrg
kzKKZoKO37dgWLqywNTO78zQWRO0piAg4w6dBdbB77Lax03QdKBiw6XPTEiV
77NNC6GibLFFmbibCbPlMhduJxUlSebH5yuZMBFDLd7haIp2lz4JMzvHBLvw
sHyXG6bIa1DpbhDEhPc8jfqmCQ392BjYpRAyQZkrvKKbSEMBb/666GfEhA+M
4NdMDQ3dfCfk5g/jcFnSLGnbiaEayWBzZwMOiUGxiiJfDPl/tOWbLrXInjET
swdDWvmDlJ/qcbAcTP3ZLABDh7MKZgbv4lBu4+EREYqhUEUSR/MHDvI+JXkh
GkMpLVX6i9U4tFs/E9tmYGilVZdwdSkOt2eldeQsDOmQ7Q+ISnDI6XCe6MvG
kNqgJK5IhoNvwtWgpDwM1Qs6QyyKcXj2T6jL3wUYunGqV8ooxGH06OhsxE0M
FSUK91jn49DmednOsQpDFerr4ZEXcKgy9zpoUIOh7uxbvtfzcIhurfy3thZD
hgRl0SoXh4/06PqFegwlh5zLX5eNQ/+ExWTXnxgSSjpMw7NwaGjpZF5vxNDL
eUFsaSYOJ6PsLm5rxpD7jufktRk4BG0abl8DGDpYfdAh5DwObivz9KYeYujL
8cWdxVIcGG83uz56hCHlUOueoXQcdGA6/lLr0r/HINB8qf8DUfw+Lg==
        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV1Xk4lOsbB/CZEKFsw6EkqYSESpTkfitEi0odSiG0UEcL6pRzLDmlCEfT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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -15.19569571126647}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-15.19569571126647, 3.5517837976248527`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Lungs\"", 11, StripOnInput -> False], 
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282822684732*^9, 3.41783633311008*^9, 
  3.4798279473398514`*^9, 3.479828620566348*^9, 3.4798298166592517`*^9, 
  3.5185352559720116`*^9, 3.6434438120545006`*^9},
 CellLabel->"Out[197]="]
}, Open  ]],

Cell["These  values are the same that Table A.12.13 of ICRP 78 ", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Americium (and Cm)", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["The model", "SubsubsectionIcon"],

Cell["\<\
Biokinetic model for americium is the same that plutonium (ICRP 78), except \
Liver2 that is not included in Americium . GI include ST, SI, ULI, LLI (not \
represented) . For curium it aplied the same model that for americium\
\>", "Text"],

Cell["The compartments has been numbered as follow: ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompartNumbers", "[", "americium", "]"}]], "Input",
 CellLabel->"In[198]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "\<\"Blood\"\>"},
    {"2", "\<\"ST0\"\>"},
    {"3", "\<\"ST1\"\>"},
    {"4", "\<\"ST2\"\>"},
    {"5", "\<\"Liver1\"\>"},
    {"6", "\<\"Kidneys(Urinary)\"\>"},
    {"7", "\<\"Other kidneys\"\>"},
    {"8", "\<\"Cort. bone\"\>"},
    {"9", "\<\"Cort. Surface\"\>"},
    {"10", "\<\"Cort. Vol.\"\>"},
    {"11", "\<\"Trab. Volum\"\>"},
    {"12", "\<\"Trab. Surf.\"\>"},
    {"13", "\<\"Trab. bone\"\>"},
    {"14", "\<\"Gonads\"\>"},
    {"15", "\<\"Bladder\"\>"},
    {"16", "\<\"URI\"\>"},
    {"17", "\<\"ULI\"\>"},
    {"18", "\<\"LLI\"\>"},
    {"19", "\<\"FEC\"\>"},
    {"20", "\<\"SI\"\>"},
    {"21", "\<\"ST\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.3992828228202367`*^9, 3.417836333250705*^9, 
  3.479827947542971*^9, 3.4798286207226267`*^9, 3.479829816893658*^9, 
  3.518535256003262*^9, 3.6434438121013765`*^9},
 CellLabel->"Out[198]//TableForm="]
}, Open  ]],

Cell["\<\
We build the compartmental matrix for americium. Transfer rates are taken \
from Table A.13.1. (ICRP 78) (For GI compartments are applied the transfer \
rate included in Options[qGI]).\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"TransferRatesE", "[", "americium", "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<From\>\"", ",", " ", "\"\<to\>\"", ",", 
        "\"\<Tranfer Rates(\!\(\*SuperscriptBox[\(days\), \(-1\)]\))\>\""}], 
       "}"}]}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[199]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"From\"\>",
       HoldForm], 
      TagBox["\<\"to\"\>",
       HoldForm], 
      TagBox["\<\"Tranfer Rates(\\!\\(\\*SuperscriptBox[\\(days\\), \\(-1\\)]\
\\))\"\>",
       HoldForm]},
     {"1", "9", "3.49`"},
     {"1", "6", "0.466`"},
     {"1", "5", "11.6`"},
     {"1", "7", "0.116`"},
     {"1", "2", "10"},
     {"1", "3", "1.67`"},
     {"1", "4", "0.466`"},
     {"1", "14", "0.0082`"},
     {"1", "12", "3.49`"},
     {"1", "17", "0.303`"},
     {"1", "15", "1.63`"},
     {"2", "1", "1.386`"},
     {"3", "1", "0.0139`"},
     {"4", "1", "0.000019`"},
     {"5", "1", "0.00185`"},
     {"5", "20", "0.000049`"},
     {"6", "15", "0.099`"},
     {"7", "1", "0.00139`"},
     {"8", "1", "0.0076`"},
     {"9", "8", "0.0000821`"},
     {"9", "10", "0.0000411`"},
     {"10", "8", "0.0000821`"},
     {"11", "13", "0.000493`"},
     {"12", "13", "0.000493`"},
     {"12", "11", "0.000247`"},
     {"13", "1", "1.0076`"},
     {"14", "1", "0.00019`"},
     {"15", "16", "12"},
     {"17", "18", 
      SubscriptBox["k", "ULI"]},
     {"18", "19", 
      SubscriptBox["k", "LLI"]},
     {"20", "1", 
      FractionBox[
       RowBox[{"f1", " ", 
        SubscriptBox["k", "SI"]}], 
       RowBox[{"1", "-", "f1"}]]},
     {"20", "17", 
      SubscriptBox["k", "SI"]},
     {"21", "20", 
      SubscriptBox["k", "ST"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"From", "to", 
       "Tranfer Rates(\!\(\*SuperscriptBox[\(days\), \(-1\)]\))"}}]]]], \
"Output",
 CellChangeTimes->{3.399282822835293*^9, 3.41783633326633*^9, 
  3.4798279475898447`*^9, 3.479828620785138*^9, 3.479829817003048*^9, 
  3.518535256050138*^9, 3.6434438121326275`*^9},
 CellLabel->"Out[199]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "element", ",", " ", "lambda", ",", " ", "fn1", ",", " ", "amad", ",", " ", 
   "class"}], "]"}]], "Input",
 CellLabel->"In[200]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"element", "=", " ", "americium"}], ";", 
   RowBox[{"lambda", " ", "=", " ", "0"}], ";", " ", 
   RowBox[{"fn1", " ", "=", " ", 
    RowBox[{"5", " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "4"}]]}]}], ";", " ", 
   RowBox[{"amad", "=", " ", 
    RowBox[{"AMADAdultW", "[", "5", "]"}]}], ";", 
   RowBox[{"class", " ", "=", " ", "M"}], ";"}], " "}]], "Input",
 CellLabel->"In[201]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[202]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.06221425180003659`", "0.003733528706262035`", 
      "0.9340522194937004`"},
     {"2", "0.00746876638950289`", "0.004426774077507606`", 
      "0.922156679026688`"},
     {"3", "0.003893031547046788`", "0.0026071139057999015`", 
      "0.9156565335738402`"},
     {"4", "0.0024336894114997953`", "0.0013187280037455507`", 
      "0.9119041161585946`"},
     {"5", "0.0017947598649068475`", "0.0006367874836671894`", 
      "0.90947256881002`"},
     {"6", "0.0014781364550856546`", "0.0003109343705577361`", 
      "0.9076834979843762`"},
     {"7", "0.0012919117613564568`", "0.000163033241039251`", 
      "0.9062285529819801`"},
     {"8", "0.0011617888866062298`", "0.00009794497270823599`", 
      "0.9049688191226655`"},
     {"9", "0.0010586782903406755`", "0.0000698697998444131`", 
      "0.9038402710324801`"},
     {"10", "0.0009708979273652663`", "0.00005790654064161127`", 
      "0.902811466564473`"},
     {"20", "0.0004602605833869955`", "0.00004819536113534473`", 
      "0.895829383841757`"},
     {"30", "0.000266797060138102`", "0.00004701279381469359`", 
      "0.8919652503469641`"},
     {"40", "0.00019074292156529005`", "0.00004594088972215138`", 
      "0.8893074863058109`"},
     {"50", "0.00015877561171051546`", "0.00004496565830344745`", 
      "0.8871430918868608`"},
     {"60", "0.00014359452498780012`", "0.00004407563369537848`", 
      "0.8852023207003127`"},
     {"70", "0.0001350064604275225`", "0.000043260744064216317`", 
      "0.8833807095220115`"},
     {"80", "0.00012918089076618955`", "0.00004251214177183882`", 
      "0.881635720552973`"},
     {"90", "0.00012465674470352184`", "0.00004182205429342778`", 
      "0.8799482739747968`"},
     {"100", "0.00012085798252225999`", "0.00004118365328878437`", 
      "0.8783083997937946`"},
     {"180", "0.00010195199320195414`", "0.00003734995511048278`", 
      "0.866378143018767`"},
     {"200", "0.00009903371447128606`", "0.000036621828916227894`", 
      "0.8636312784715603`"},
     {"300", "0.00008915547506638255`", "0.00003364698079974526`", 
      "0.8507707705122172`"},
     {"400", "0.0000828259023265554`", "0.00003125819157559495`", 
      "0.8389498707405725`"},
     {"500", "0.00007776372699819234`", "0.00002916867631785891`", 
      "0.8279113314229568`"},
     {"600", "0.00007332378821389707`", "0.00002728736529242215`", 
      "0.8175429000834378`"},
     {"700", "0.00006930679261729633`", "0.00002557759065069387`", 
      "0.8077754345032009`"},
     {"800", "0.00006563599900544226`", "0.000024018557122584827`", 
      "0.7985549735502891`"},
     {"900", "0.00006226961527688868`", "0.000022594793170488403`", 
      "0.7898348897094217`"},
     {"1000", "0.00005917709005986982`", "0.000021293206937167408`", 
      "0.7815734885592398`"},
     {"2000", "0.00003876740183683669`", "0.000012935921915119275`", 
      "0.7173920828936102`"},
     {"3000", "0.000028807451128542994`", "9.12146484394194`*^-6", 
      "0.6733386023518209`"},
     {"4000", "0.000023220932600320765`", "7.1276757995786255`*^-6", 
      "0.6395337126266318`"},
     {"5000", "0.000019672470256748564`", "5.933104166438996`*^-6", 
      "0.6117214848806207`"},
     {"6000", "0.000017204287729832846`", "5.134572346437993`*^-6", 
      "0.5878419632495937`"},
     {"7000", "0.000015383023986292876`", "4.559455369118615`*^-6", 
      "0.5667595121719233`"},
     {"8000", "0.000013986734515081256`", "4.124974583463725`*^-6", 
      "0.5477719186031349`"},
     {"9000", "0.000012886725665628429`", "3.786012517298376`*^-6", 
      "0.5304077948165477`"},
     {"10000", "0.000012000635941811222`", "3.515003167350872`*^-6", 
      "0.5143341589656909`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282823437537*^9, 3.417836333844455*^9, 
  3.479827948324201*^9, 3.4798286215040216`*^9, 3.4798298178000298`*^9, 
  3.518535256534522*^9, 3.6434438123045025`*^9},
 CellLabel->"Out[202]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[203]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV0Hs4lfkWB/D9vnt7X/frq9lRRuKIhojBEL8fR9I4uTVt9zHEMSO3RoUd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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV1Xk41dkbAPBrqSzVved7v8y1ZqsJhTaEnKOsJXQzNCIlNU0hkaZRydZm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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -6.972858397770131}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-6.972858397770131, -1.7447945114289172`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, 
     AxesOrigin -> {0, -6.6000000000000005`}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992828259519053`*^9, 3.41783633670383*^9, 
  3.479827950136655*^9, 3.4798286232699747`*^9, 3.479829819940943*^9, 
  3.518535258565811*^9, 3.6434438126638813`*^9},
 CellLabel->"Out[203]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[204]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.00002964278505885611`", "0.28226278645041425`", 
      "0.7177075707645207`"},
     {"2", "4.590344788280238`*^-6", "0.3888873295117294`", 
      "0.3288156509080032`"},
     {"3", "2.2177385444180006`*^-6", "0.19688259003942013`", 
      "0.13193084313003867`"},
     {"4", "1.3295521596361562`*^-6", "0.08134212254849801`", 
      "0.05058739102938099`"},
     {"5", "9.485822389007745`*^-7", "0.03139750971805749`", 
      "0.019188932729084594`"},
     {"6", "7.659178902710167`*^-7", "0.011794081144829256`", 
      "0.007394085666365068`"},
     {"7", "6.627844832585335`*^-7", "0.004379083102968404`", 
      "0.0030143397789134047`"},
     {"8", "5.932668384739099`*^-7", "0.0016176488162978006`", 
      "0.0013960976957771297`"},
     {"9", "5.394488788625497`*^-7", "0.0005962169349376333`", 
      "0.0007993413119606334`"},
     {"10", "4.941900304617701`*^-7", "0.00021953400132660778`", 
      "0.0005793131206035638`"},
     {"20", "2.333143039203833`*^-7", "3.408294110998731`*^-8", 
      "0.0004479724244747777`"},
     {"30", "1.3462772753308934`*^-7", "2.3518577974733978`*^-8", 
      "0.00044601490692902906`"},
     {"40", "9.586918215472202`*^-8", "2.298109919768624`*^-8", 
      "0.0004446782261418624`"},
     {"50", "7.960922732364257`*^-8", "2.2492537046190112`*^-8", 
      "0.0004435926867230884`"},
     {"60", "7.191206147417637`*^-8", "2.2046690391035856`*^-8", 
      "0.0004426206618373373`"},
     {"70", "6.757493309562284`*^-8", "2.1638509671220848`*^-8", 
      "0.0004417088911056513`"},
     {"80", "6.464307705295784`*^-8", "2.126355910333946`*^-8", 
      "0.0004408357183778903`"},
     {"90", "6.23712286993653`*^-8", "2.0917941917630444`*^-8", 
      "0.0004399914554737553`"},
     {"100", "6.046585029857244`*^-8", "2.0598234716203215`*^-8", 
      "0.000439171058457652`"},
     {"180", "5.0992491207411256`*^-8", "1.8678942306562803`*^-8", 
      "0.00043320356968287786`"},
     {"200", "4.9530894477101215`*^-8", "1.8314549336419087`*^-8", 
      "0.00043182975863061964`"},
     {"300", "4.4585515323225695`*^-8", "1.6826201857154206`*^-8", 
      "0.00042539816865132734`"},
     {"400", "4.141869857022173`*^-8", "1.56314031547148`*^-8", 
      "0.00041948681175559135`"},
     {"500", "3.888675693443106`*^-8", "1.4586396970670988`*^-8", 
      "0.0004139667977849026`"},
     {"600", "3.6666278842886584`*^-8", "1.3645548183391755`*^-8", 
      "0.0004087819241430677`"},
     {"700", "3.4657390468389396`*^-8", "1.279049444222885`*^-8", 
      "0.0004038975952340315`"},
     {"800", "3.282165787857902`*^-8", "1.2010829295792643`*^-8", 
      "0.00039928682035921047`"},
     {"900", "3.113816602094222`*^-8", "1.1298813566931894`*^-8", 
      "0.00039492627980565334`"},
     {"1000", "2.9591632229070564`*^-8", "1.0647899470491817`*^-8", 
      "0.0003907951218211967`"},
     {"2000", "1.9385121958603174`*^-8", "6.468522455166511`*^-9", 
      "0.000358701424407799`"},
     {"3000", "1.4404474522455163`*^-8", "4.561008092434098`*^-9", 
      "0.00033667325018821607`"},
     {"4000", "1.1610917839330586`*^-8", "3.5639935917715143`*^-9", 
      "0.000319770016161903`"},
     {"5000", "9.836537952982553`*^-9", "2.9666515981806568`*^-9", 
      "0.0003058634084871997`"},
     {"6000", "8.602362118942169`*^-9", "2.567355747822562`*^-9", 
      "0.0002939233075623785`"},
     {"7000", "7.691676708640287`*^-9", "2.2797792422043963`*^-9", 
      "0.0002833818325237515`"},
     {"8000", "6.993495493378809`*^-9", "2.062526971181042`*^-9", 
      "0.0002738878451262067`"},
     {"9000", "6.443465080534271`*^-9", "1.893037636524909`*^-9", 
      "0.00026520563341128964`"},
     {"10000", "6.000401218432538`*^-9", "1.7575269569702098`*^-9", 
      "0.0002571686950111202`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Urine\n24 hours", "Faecal\n24 hours", 
       "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992828266745987`*^9, 3.41783633739133*^9, 
  3.479827951074131*^9, 3.4798286241607647`*^9, 3.4798298208473144`*^9, 
  3.5185352590814457`*^9, 3.643443812835758*^9},
 CellLabel->"Out[204]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[205]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV0nk0lXsXB/DD8ZYp45MOlaue33NlpiRRfj8VFY2nXqSZulnJ0K1QIUlx
SIVkiqJCMpRKEZ2dKeVIMk9lSt5EinRE7n3eP/ba6/PPXuu7917g4sU/KMnh
cM6w9f/eYuBjWvO3v9X81sN9tRUMBLjsHYjmOWP/ybVrz5czEDVRLunMO4z7
fNSbLcoYmFvx8/JK3incE78nIB0Y6NKNcjDiheOQ8Wv9Z54xUNrZuXwRLxEn
tLyKs3zAwJJlIfcQLwuH2Nw80H2dgacRHo8+DmThSVFPWEoSA1ZdDiXphfew
W/Pp2bsSGVgn0KldtDMHS89z8G2JYyDX49BJtc338VT1ptqmaAbKhPLJGtEP
seHm+vNDYQx8cXXsW8grwodHLpxOPcGAv1nmtJ2gCEvdzAh1Ps6AvMwE79iv
Iny0MSmbOsaAfm7ixrKOZ3imTc22i94MeIg7C1xTS3D8b7VrAncGfG3z1/Bj
AUv+91eEcD8D4jbzOTGa5Vhv/tbbxpsZIGv2I23HcuwZLvNLdRMDYTkCk2eX
y/GBJnOReAMDvKA2+15OBS78YDFYaceAOeMftKS3AruK5y05YcvASS/h/+oz
XuJOZBurYcXAL65tMWVSje+b9J0TGDIg0So7NnCwGjuEuXRlGzAgnVurV5JY
jc13zhXU6TMwx2lH0kEpER57Ff9MU48B0+wjpwqaRVj2kbSgSpvNsz3G3Cnw
De433VfttIABb753W83Ht9hg3a3rLrMZGCvmjy/j1GGu0yM6h2Lzai9VSdOo
w2WludViVQYCpybW+2yuw2ZHrvrGqDBwMf1coWZhHQ6XP6XYpMjA3V/X4r0u
vsOmYF10SZaBnrQSB+UlDTjV+EroCw4D2aZba8Y3NOB0UUCuEWufyr7VHX81
4NH+tEcp/yCQ+SxnkpHYgPffee14ZhqBsYmz3ErJRuyYf++13RSCQOG40K2u
EY/8rT0sLUag0WGkA17NWMGp4o3aCII+j7IbdwTNWI1anpf8FUHuPw5qEbea
cWnCaUuGtTUdyHVobsYjq322mg0jcDss6hy0asEzuqbW7/uCoEDsFj1HoRVP
lrvqvhtAwJ+dNumZ3YaFrgYyqAeB0YNsxwtVbVhB40/u424E8hufPEzua8Mp
2xdctWVdGSJyF81rx8I4qRPuXQgsx8bbdSLbsdJXJ+ni9whQvX1xn0cH/nHU
1Mi3HcH4lR/+zkbv8dCWygn7RgQbL6B/FrZ24SAOP8fgNQL9r2+fWPV34bnh
NYMfXiGQdQrwdh7twtZTnzyiWVfqNHVHzerGSQ9dLMRVCEhNaDlnVTfOft7b
U/kSwWJqUPA+qxtHhB8c9KpAwEt7QCX69+CYXvXfXwBBb4mVrrJWH+bvcdM/
+RRB/zILqRU5n/DbzS/deZns/hKdTd/pDOJjbqLPvQkIDhVaK7gfHsajdrEm
E5EI1s46b39TPIIvrE2OcwxGUJ8kOiCf8h13JoYKY/0QvEj5U8fQcgxHmIWb
jHix81d9W+M5+QMv2qt/1+sQAq7Njcd5yT/xzPdpe/T3IXAcKAlQdJ3AshWO
6a1OCGZxvo4grUk83D4/XJaPoPgEt9BSOIU99/6xus8eQerFsBbvs9P4fFFw
/VYbBBDkl16vwiHKy2c9X4wRVMsdlA8c55BLU9+MQs0RzKxrW8ttkiCNu15w
h0wQYJtSA0G6JDmz2K+lSA+BqqwLTgnjkmmDbXoSDLufgGOTD3dKkRKFjDOl
mux/6SlE3tb9D5HIVX9awEMQpLvfDsnNIFEBJ43tVBCotzD5tztmkPLBFspX
nr1nU5rNI+FMop4cO71vBoJ8hbu5KSnSRNJnwYO7HATUuFapwFOGNO4IT4mZ
pEHZcKuE1BZZctYz/sG2cRpkZ49+DlwoR9ztzdMzv9Gw1Ewzq2FEjlia3fix
ZoiGyQyJ2MK38mTRiQr3rAEaSqocdG+kziIrjwab+/TRoGFxYFA1RIEolD9T
H/5Aw3HnXgeBoyLRMbp2Pb2dhjNtP6qPqCqR76NqDk7NNKgYOwR3nFMiv70V
yk6/o4He/TVS9EWJ2AiX/1FQQ8PZ/ANGIXuUCT9pIN2yigbx7RRLnTfKRG91
762gUhqGPJWTN5mpkIH4Ceu3xTQY79931TJDhSR+2nDfqoCGb7oDXZlKqmTp
ghV7nuTRUB1lGs/1UyWLq/L0hjJp+K61+yMzoEpWcnKsNVJpiAt9Hlq1hSLc
79ZjOxJo8NvlJUziU2R+4Tq+GWtnE62fntspot1rmKHCWrP97F+znSgysTRq
aXU8DbcNbWxc9lKkMe9onyXr/MZqySkPigg1asPmxtEgolsDjCIoUuGk3Vl/
lYZcseCxZCRFQtK4qnmsL9dYDDVeoojh+1M4nDXf9/ou/2iKrFA09SesW1/v
tXyVQJH4hsiQ7Bga+o/2i10yKbJQU/wmOJqGKts4Y7MsirwQnfPYzTpr7jo3
mWyK3DMLlTRn7VFxtzkvjyLBWsOKQ1E0jPE8CqYKKNJkNvXEgXXT0Pzh2qcU
ufNSVtaE9ZPSN8ytIooozQziy7E+dcQ4dv1ziozFxlQKr9Cwy7pbNA8o4j5g
8D2BtZVatNTIC4qsaWOo46y1BletKCujSJWan/4m1hIweuxaBUVyp2nLRaz/
BZ3VzWs=
        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV13k0VV8bwPE73yIZkihJkaJCEpLajyFEhhAlEZUmKSJUP7MkQ1GSMVOU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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -11.974937904526113`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-11.974937904526113`, 1.0880963453525059`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282831206485*^9, 3.417836341656955*^9, 
  3.4798279530584545`*^9, 3.47982862612988*^9, 3.479829822925719*^9, 
  3.518535261034609*^9, 3.6434438132107615`*^9},
 CellLabel->"Out[205]="]
}, Open  ]],

Cell["These  values are the same that Table A.13.7 of ICRP 78 ", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsubsectionIcon"],

Cell["Type M, AMAD 5", "Text"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[206]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Lung\\nretention\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.05762559969442553`", "0.0017736243738958254`", 
      "0.10835259686037646`", "0.4953489057470551`"},
     {"2", "0.05593276558815258`", "0.00023194817520859334`", 
      "0.1546929885497267`", "0.2616613535224719`"},
     {"3", "0.05498583800741929`", "0.00013093000524849047`", 
      "0.07964335636430617`", "0.15291191885635358`"},
     {"4", "0.05415636789713769`", "0.00008983468174281195`", 
      "0.03345280218165757`", "0.10870991932007329`"},
     {"5", "0.053359294815146105`", "0.00007189757395174856`", 
      "0.013294985806778702`", "0.09142167426208847`"},
     {"6", "0.05258269101268844`", "0.00006303573632820275`", 
      "0.005336751111524159`", "0.08457929779379722`"},
     {"7", "0.05182449123151804`", "0.00005782790683702549`", 
      "0.002309772407744125`", "0.08168099715344494`"},
     {"8", "0.05108397226897482`", "0.00005417755599120694`", 
      "0.0011718631820987827`", "0.08025972142897614`"},
     {"9", "0.050360605175065756`", "0.00005126566373096775`", 
      "0.0007417841678345125`", "0.0793948474275345`"},
     {"10", "0.049653900264422415`", "0.00004876491143975675`", 
      "0.0005745107376717157`", "0.0787451479253384`"},
     {"20", "0.04340630532925459`", "0.00003337391561625269`", 
      "0.00036727152785037687`", "0.07411190215227444`"},
     {"30", "0.038386792466525516`", "0.000026413902524953514`", 
      "0.0002799248854856509`", "0.07064962618033248`"},
     {"40", "0.034298371519371526`", "0.000022781839132998694`", 
      "0.00021492563429844486`", "0.06798110252958844`"},
     {"50", "0.03092126690692689`", "0.000020557543326492345`", 
      "0.0001663720459497038`", "0.06589563070548621`"},
     {"60", "0.028092204712756585`", "0.00001898921225044342`", 
      "0.0001299567298054874`", "0.06424417341044984`"},
     {"70", "0.025689367601014104`", "0.00001776879798124492`", 
      "0.00010252620900184917`", "0.0629188484725611`"},
     {"80", "0.02362144232042384`", "0.000016760229002328597`", 
      "0.00008176608487720297`", "0.061840478500322156`"},
     {"90", "0.021819627998477756`", "0.0000158965782966064`", 
      "0.00006597345233854204`", "0.06095043884521418`"},
     {"100", "0.020231790716410868`", "0.000015140502310551085`", 
      "0.000053892065217067686`", "0.0602050493307662`"},
     {"180", "0.01192429958518762`", "0.000011169097459851063`", 
      "0.000016843745544366587`", "0.05679901879547532`"},
     {"200", "0.010556103115000716`", "0.000010503429252441132`", 
      "0.00001400072365562166`", "0.05627741194487814`"},
     {"300", "0.005836340033898102`", "8.131814079916089`*^-6", 
      "7.4824093586611795`*^-6", "0.05435036764200003`"},
     {"400", "0.0032551303788948944`", "6.711974528714193`*^-6", 
      "4.871461018750994`*^-6", "0.05301273140139346`"},
     {"500", "0.001819771626553487`", "5.802102574253842`*^-6", 
      "3.458781106902703`*^-6", "0.0519814004589166`"},
     {"600", "0.0010188962233987154`", "5.181832986943247`*^-6", 
      "2.638102298620215`*^-6", "0.051133439437650564`"},
     {"700", "0.0005713252284099428`", "4.731392332875395`*^-6", 
      "2.141608860171257`*^-6", "0.05040232668804615`"},
     {"800", "0.0003208486912963452`", "4.384027513758271`*^-6", 
      "1.826898459417886`*^-6", "0.04975025441016056`"},
     {"900", "0.0001804720465158918`", "4.101960371323543`*^-6", 
      "1.61573015099864`*^-6", "0.04915515528214699`"},
     {"1000", "0.00010168149765891541`", "3.863461635993104`*^-6", 
      "1.4647737650776843`*^-6", "0.04860373928257399`"},
     {"2000", "3.6352848855164195`*^-7", "2.467468266834083`*^-6", 
      "8.288339107681564`*^-7", "0.04445968761574054`"},
     {"3000", "1.5887472477352625`*^-9", "1.8150043059397825`*^-6", 
      "5.770175308585784`*^-7", "0.041666752617504174`"},
     {"4000", "8.191795546467708`*^-12", "1.4540858769632181`*^-6", 
      "4.4734306448371286`*^-7", "0.03954217365025997`"},
     {"5000", "4.669764224003561`*^-14", "1.2273301638922318`*^-6", 
      "3.706269869514778`*^-7", "0.03780327924633521`"},
     {"6000", "2.800222529014985`*^-16", "1.070763606319386`*^-6", 
      "3.1981429375604886`*^-7", "0.03631501041990017`"},
     {"7000", "1.7199222254277957`*^-18", "9.557656191448716`*^-7", 
      "2.834332655122368`*^-7", "0.03500385535779234`"},
     {"8000", "1.0690929143315241`*^-20", "8.678664519291834`*^-7", 
      "2.5605096444676623`*^-7", "0.03382481583326676`"},
     {"9000", "6.691568944533769`*^-23", "7.98772581033641`*^-7", 
      "2.3474347558231218`*^-7", "0.03274788521313393`"},
     {"10000", "4.208918921515847`*^-25", "7.432203513804692`*^-7", 
      "2.1774233621967704`*^-7", "0.031751950220486574`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Lung\nretention", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992828459235306`*^9, 3.417836356344455*^9, 
  3.479827968245566*^9, 3.479828641742152*^9, 3.479829838396548*^9, 
  3.518535272909837*^9, 3.643443816804553*^9},
 CellLabel->"Out[206]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[207]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAA2C12NM1yfD5VNZ5L5VkGwH1iX+iS
GFo/r9BE0dJWBsCR+cQCWhhqP32V6VPAUwbAG8X3jz0Yej/DBClQm00GwOAq
kVYvGIo/WUVfJFFBBsDC3d05KBiaP5oupjq8KAbAMzeEqyQYqj8r2W8WkPcF
wOxjV+QiGLo/akqOSC6VBcD6A0a8FDHLPyBCcJSvvwTA4qK9VhEz1D/TJOOc
GfgDwFIVovturNo/OEb2vjA0A8BNhiT/ItngP4XLsh5mXwLA470+KhEg5D9J
lhdrjJgBwOY3OgQ8rec/uBEMAcjAAMCumlo00inrPz48R0Nq2f+/Z7lBDmtq
7j+6sbkMbU3+v0cNhUug+PA/BApsIsaf/L/Tm8xkDJ7yP2YP1BuRDvu/wZ4m
KS479D/NiRcGToX5v+ZC8URu+/U/ib8Kqtva978DRZ+1r533P2Og+nJdTfa/
V+i9fQ9j+T/bXjY4LZ/0vw0A7/AkIPs/4yTCmsf58r+8dQO5O7/8PyN/NrzT
cfG/oYyI2HCB/j/eAErmNJTvv8CAeKbTEgBAuu+ch06A7L/LC2UMfvYAQHqk
WMB7Lum/B9HaRwPWAUCzHpagsfDlvz9Fwi2JpgJAFCU8eTTv4r8TCmI/nogD
QGVoNoMuZd+/431z+7NbBECoE7Q/wGXZv+QrDo2kKgVAz+OMX8aQ07+AKmFK
JAsGQBFaRCqImMq/GdglsqTcBkCgPvs6AAq+v03WokW0vwdAj/7FvszwlL+y
Dqmunp4IQM96zZlWzLI/FPYgwoluCUCxFitpPHTEPxEuUQEEUApAqnW/2qYh
0D8KFfPqfiILQE2AUqSSjdU/NTYeqtTwC0D+KcejK8faP/unAZW50AxApV3S
lq4r4D+9yFYqn6ENQAM3BfegtuI/Gjpk6xOEDkA2sHrz6GjlP3Ra41aJVw9A
oz+5k2ne5z9/2vXLbBMQQJrxSFTrOOo/EjBWgtyDEEBH7HmTgbXsPyNd743M
7BBAXibFW0D37j+BsmQvhF4RQOah9dx8q/A/+KSeOynOEUCj5Aw8R8zxP+1u
EZ1ONhJAQ7lrDe7Q8j8wYWCUO6cSQGigse2+4fM/8Sro4KgQE0BB0uCY8Nb0
P8uRNJgDeBNAZbqW7BK+9T/yIF3lJegTQGMjj1wNrvY/l4e+h8hQFEDlj0u9
XIP3P3hcb7+bUhRA6SsEGf2G9z9aMSD3blQUQB4TQJ2civc/HtuBZhVYFEDz
RHUe2ZH3P6QuRUViXxRAKns4/keg9z+y1csC/G0UQE9V7gX9vPc/zCPZfS+L
FEBUT8DHwvX3P674ibUCjRRA1rAbz0f59z+PzTrt1Y4UQEyHavjL/Pc/Unec
XHySFEBx7wqw0QP4P9nKXzvJmRRAZdlsrdIR+D/mceb4YqgUQAzdJrGqLfg/
yEaXMDaqFEDM/ku+ITH4P6obSGgJrBRAOEr96Zc0+D9txanXr68UQNYGKJyB
O/g/9Bhttvy2FEC67ZNlSkn4P9btHe7PuBRAAbAQYbpM+D+3ws4lo7oUQPUx
X3kpUPg/emwwlUm+FED6BJP/BFf4P1xB4cwcwBRAPfYIbXFa+D8+FpIE8MEU
QO/ncfbcXfg/IOtCPMPDFEArA5abR2H4PwHA83OWxRRAxWE9XLFk+D8k/FL9

        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV0Hk41WkfBnC7bOXwnHN+v6NEMYUKkYrJ89SgRlcY2ZIoa4loG0uIIVFk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        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV1Xk4lNsfAPAZS2VG2UZ3lKSoG9luKVKckyIpQq6QpURpIbRJKUSRSCpK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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -7.37739486803494}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-7.37739486803494, 2.3338539405201972`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Lungs\"", 11, StripOnInput -> False], 
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282923331476*^9, 3.417836434313205*^9, 
  3.479827986338853*^9, 3.47982866177712*^9, 3.479829857102186*^9, 
  3.5185352876913705`*^9, 3.6434438211795835`*^9},
 CellLabel->"Out[207]="]
}, Open  ]],

Cell["These  values are the same that Table A.12.13 of ICRP 78 ", "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Thorium", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["The model", "SubsubsectionIcon"],

Cell["The compartments has been numbered as follow: ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompartNumbers", "[", "thorium", "]"}]], "Input",
 CellLabel->"In[208]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "\<\"Plasma\"\>"},
    {"2", "\<\"ST0\"\>"},
    {"3", "\<\"ST1\"\>"},
    {"4", "\<\"ST2\"\>"},
    {"5", "\<\"Liver1\"\>"},
    {"6", "\<\"Liver2\"\>"},
    {"7", "\<\"UrinaryPath\"\>"},
    {"8", "\<\"OtherKidney\"\>"},
    {"9", "\<\"TrabecularSurface\"\>"},
    {"10", "\<\"TrabecularMarrow\"\>"},
    {"11", "\<\"TrabecularVolume\"\>"},
    {"12", "\<\"CorticalSurface\"\>"},
    {"13", "\<\"CorticalMarrow\"\>"},
    {"14", "\<\"CorticalVolume\"\>"},
    {"15", "\<\"Gonads\"\>"},
    {"16", "\<\"Bladder\"\>"},
    {"17", "\<\"Urine\"\>"},
    {"18", "\<\"ULI\"\>"},
    {"19", "\<\"LLI\"\>"},
    {"20", "\<\"Feces\"\>"},
    {"21", "\<\"SI\"\>"},
    {"22", "\<\"ST\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.399282923439351*^9, 3.41783643442258*^9, 
  3.479827986479474*^9, 3.479828661964655*^9, 3.4798298571959496`*^9, 
  3.518535287722621*^9, 3.6434438212108345`*^9},
 CellLabel->"Out[208]//TableForm="]
}, Open  ]],

Cell["We build the compartmental matrix.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"TransferRatesE", "[", "thorium", "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<From\>\"", ",", " ", "\"\<to\>\"", ",", 
        "\"\<Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\>\""}], "}"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[209]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"From\"\>",
       HoldForm], 
      TagBox["\<\"to\"\>",
       HoldForm], 
      TagBox["\<\"Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\"\>",
       HoldForm]},
     {"1", "16", "0.1067`"},
     {"1", "18", "0.0097`"},
     {"1", "9", "0.6793`"},
     {"1", "12", "0.6793`"},
     {"1", "5", "0.097`"},
     {"1", "7", "0.0679`"},
     {"1", "8", "0.0194`"},
     {"1", "2", "0.832`"},
     {"1", "3", "0.243`"},
     {"1", "4", "0.0388`"},
     {"1", "15", "0.00068`"},
     {"10", "1", "0.0076`"},
     {"13", "1", "0.0076`"},
     {"9", "11", "0.000247`"},
     {"9", "10", "0.000493`"},
     {"12", "14", "0.0000411`"},
     {"12", "13", "0.0000821`"},
     {"11", "10", "0.000493`"},
     {"14", "13", "0.0000821`"},
     {"5", "1", "0.000475`"},
     {"5", "21", "0.000475`"},
     {"5", "6", "0.00095`"},
     {"6", "1", "0.000211`"},
     {"7", "16", "0.0462`"},
     {"8", "1", "0.00038`"},
     {"15", "1", "0.00019`"},
     {"2", "1", "0.462`"},
     {"3", "1", "0.00095`"},
     {"4", "1", "0.000019`"},
     {"16", "17", "12"},
     {"18", "19", 
      SubscriptBox["k", "ULI"]},
     {"19", "20", 
      SubscriptBox["k", "LLI"]},
     {"21", "18", 
      SubscriptBox["k", "SI"]},
     {"22", "21", 
      SubscriptBox["k", "ST"]},
     {"21", "1", 
      FractionBox[
       RowBox[{"f1", " ", 
        SubscriptBox["k", "SI"]}], 
       RowBox[{"1", "-", "f1"}]]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"From", "to", "Tranfer Rates(\!\(days\^\(-1\)\))"}}]]]], "Output",
 CellChangeTimes->{3.399282923470173*^9, 3.417836434438205*^9, 
  3.479827986526348*^9, 3.4798286619959106`*^9, 3.4798298572428303`*^9, 
  3.518535287769497*^9, 3.643443821242096*^9},
 CellLabel->"Out[209]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "element", ",", " ", "lambda", ",", " ", "fn1", ",", " ", "amad", ",", " ", 
   "class"}], "]"}]], "Input",
 CellLabel->"In[210]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"element", "=", " ", "thorium"}], ";", 
   RowBox[{"lambda", " ", "=", " ", "0"}], ";", " ", 
   RowBox[{"fn1", " ", "=", " ", 
    RowBox[{"5", " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "4"}]]}]}], ";", " ", 
   RowBox[{"amad", "=", " ", 
    RowBox[{"AMADAdultW", "[", "5", "]"}]}], ";", 
   RowBox[{"class", " ", "=", " ", "M"}], ";"}], " "}]], "Input",
 CellLabel->"In[211]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[212]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.03756269693978309`", "0.0008161754498150209`", 
      "0.9616211276104019`"},
     {"2", "0.007559295611597849`", "0.0014840167638548452`", 
      "0.9525778152349513`"},
     {"3", "0.004375067895157514`", "0.0010179747965831654`", 
      "0.9471847725432125`"},
     {"4", "0.003480780279889517`", "0.0006010538423162348`", 
      "0.943102938421008`"},
     {"5", "0.002885438436848964`", "0.00036817869961278116`", 
      "0.9398493212845475`"},
     {"6", "0.0024367443406729805`", "0.00024365665069517317`", 
      "0.93716892029318`"},
     {"7", "0.002092710646558027`", "0.0001726500065930281`", 
      "0.9349035596400295`"},
     {"8", "0.0018261450316655603`", "0.0001285445916073269`", 
      "0.932948870016757`"},
     {"9", "0.0016172007212481576`", "0.00009916930478384711`", 
      "0.9312324999907251`"},
     {"10", "0.0014512503850082625`", "0.0000786921422042397`", 
      "0.9297025574635128`"},
     {"20", "0.0007364197099878345`", "0.000026394150524411408`", 
      "0.919556671070522`"},
     {"30", "0.00046169093274806006`", "0.000023662348540259837`", 
      "0.9135901134176901`"},
     {"40", "0.0002971309999382221`", "0.000023221412115470574`", 
      "0.909708355369437`"},
     {"50", "0.00019414069981937843`", "0.000022892566102661327`", 
      "0.9071125712206078`"},
     {"60", "0.0001295502585707542`", "0.000022573893236343956`", 
      "0.9053240504029088`"},
     {"70", "0.00008911229475538907`", "0.000022260580580746314`", 
      "0.904042553808738`"},
     {"80", "0.00006386867993513068`", "0.000021952353173565475`", 
      "0.9030791810695026`"},
     {"90", "0.0000481779816439154`", "0.00002164914615357394`", 
      "0.9023151103654057`"},
     {"100", "0.00003848751195789646`", "0.00002135090266508488`", 
      "0.9016756531833635`"},
     {"180", "0.000024747266707869642`", "0.00001913642710871244`", 
      "0.8978692767653177`"},
     {"200", "0.000024996105833063886`", "0.00001862813972752786`", 
      "0.8969945809051949`"},
     {"300", "0.00002619290301808519`", "0.000016333048724032073`", 
      "0.8926823038902424`"},
     {"400", "0.000026425716473266192`", "0.00001440297330726481`", 
      "0.8885122256285186`"},
     {"500", "0.000026165176608472507`", "0.000012780672538736937`", 
      "0.8845242127534193`"},
     {"600", "0.00002569989407430473`", "0.000011416258240137811`", 
      "0.8807229844044054`"},
     {"700", "0.000025160800283141604`", "0.000010267247604694996`", 
      "0.8770979535621408`"},
     {"800", "0.000024606099449431262`", "9.297895650933752`*^-6", 
      "0.8736334845541166`"},
     {"900", "0.000024060881865239914`", "8.47831645234276`*^-6", 
      "0.8703132802267408`"},
     {"1000", "0.00002353525002984913`", "7.783605920963499`*^-6", 
      "0.8671221197995682`"},
     {"2000", "0.000019429326076902953`", "4.490415276725557`*^-6", 
      "0.8400475320463241`"},
     {"3000", "0.000016727373320257755`", "3.5140461193683414`*^-6", 
      "0.8181263956251614`"},
     {"4000", "0.000014820232300816194`", "3.030880445592521`*^-6", 
      "0.7991527549944395`"},
     {"5000", "0.00001341421653344721`", "2.712044484404208`*^-6", 
      "0.7822076779151163`"},
     {"6000", "0.000012346385428019246`", "2.4781390725869823`*^-6", 
      "0.7667617793465258`"},
     {"7000", "0.000011516745787920613`", "2.2991105265157685`*^-6", 
      "0.7524625867551787`"},
     {"8000", "0.000010859503010718363`", "2.1586621073571566`*^-6", 
      "0.7390609224080651`"},
     {"9000", "0.000010329259602759322`", "2.046285669909942`*^-6", 
      "0.7263754622162624`"},
     {"10000", "9.893703527996678`*^-6", "1.9546979387469188`*^-6", 
      "0.7142720434771663`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992829241020117`*^9, 3.417836435063205*^9, 
  3.479827987323203*^9, 3.479828662824189*^9, 3.4798298580085583`*^9, 
  3.5185352883163824`*^9, 3.643443821429589*^9},
 CellLabel->"Out[212]//TableForm="]
}, Open  ]],

Cell["(ICRP 78 Table  A8.22)", "Text"],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[213]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV0Hk8lHsfxnHmHsPcsxTuNKkTWYpJlpISx++HtEmLhCY9laWkLC2ncBCl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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV0ns41PkeB/Ax45pLzO/7+xmUM0naUZgQJ9T3G0tFqlVLB5vonmJFRZtL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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -8.82407853631294}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-8.82407853631294, -1.7854318906847713`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, -8.4}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399282927107098*^9, 3.41783643832883*^9, 
  3.4798279892606535`*^9, 3.4798286648558164`*^9, 3.4798298599932003`*^9, 
  3.5185352903164206`*^9, 3.643443821804614*^9},
 CellLabel->"Out[213]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[214]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.00001678209346779472`", "0.28226170842593423`", 
      "0.7177215094806024`"},
     {"2", "5.189304689733358`*^-6", "0.3888857335754712`", 
      "0.32883058660044184`"},
     {"3", "2.359605435474062`*^-6", "0.19688166787387684`", 
      "0.13194655912112946`"},
     {"4", "1.8182478808599916`*^-6", "0.0813416898551744`", 
      "0.050603051018074253`"},
     {"5", "1.498899120527385`*^-6", "0.03139733932184142`", 
      "0.01920421279711231`"},
     {"6", "1.2610833687571156`*^-6", "0.01179403212982077`", 
      "0.007408919583922777`"},
     {"7", "1.0792202081672604`*^-6", "0.004379082505568815`", 
      "0.0030287578581457957`"},
     {"8", "9.386313659860463`*^-7", "0.0016176630155766447`", 
      "0.0014101562112031657`"},
     {"9", "8.287192852713451`*^-7", "0.0005962321052746349`", 
      "0.0008130953866432595`"},
     {"10", "7.416804064924992`*^-7", "0.00021954537058673483`", 
      "0.0005928083356500324`"},
     {"20", "3.7212606424465774`*^-7", "2.3257538382909053`*^-8", 
      "0.00045986229299682055`"},
     {"30", "2.3301951077768718`*^-7", "1.1839041771618316`*^-8", 
      "0.0004568448941277281`"},
     {"40", "1.4991835547430946`*^-7", "1.1614288950365223`*^-8", 
      "0.00045488709863285575`"},
     {"50", "9.791902099787544`*^-8", "1.1449635152024798`*^-8", 
      "0.00045357861048327244`"},
     {"60", "6.530700828863076`*^-8", "1.1290236807783081`*^-8", 
      "0.0004526776932087511`"},
     {"70", "4.4888701136486416`*^-8", "1.1133526971852199`*^-8", 
      "0.00045203276573955054`"},
     {"80", "3.214153067006634`*^-8", "1.0979360683745394`*^-8", 
      "0.0004515484590761521`"},
     {"90", "2.4217398727219633`*^-8", "1.0827705183548636`*^-8", 
      "0.0004511647836850975`"},
     {"100", "1.9322712545733357`*^-8", "1.0678532045635815`*^-8", 
      "0.00045084403092200063`"},
     {"180", "1.2372799553460843`*^-8", "9.570906054303286`*^-9", 
      "0.000448939207178627`"},
     {"200", "1.2496487689962494`*^-8", "9.31667193660422`*^-9", 
      "0.0004485018324961763`"},
     {"300", "1.3095780245593255`*^-8", "8.168714231974366`*^-9", 
      "0.0004463455794701317`"},
     {"400", "1.3212942425778768`*^-8", "7.203327351227727`*^-9", 
      "0.00044426036348019156`"},
     {"500", "1.3082998167733995`*^-8", "6.391883697733167`*^-9", 
      "0.0004422661609814783`"},
     {"600", "1.2850484302530385`*^-8", "5.709431304701273`*^-9", 
      "0.0004403653563281268`"},
     {"700", "1.2580975920556056`*^-8", "5.134721337964683`*^-9", 
      "0.0004385526651871064`"},
     {"800", "1.230362504012119`*^-8", "4.649874735102835`*^-9", 
      "0.00043682027204667315`"},
     {"900", "1.2030999467667596`*^-8", "4.2399428974146175`*^-9", 
      "0.0004351600278251647`"},
     {"1000", "1.1768160658248098`*^-8", "3.892469023494762`*^-9", 
      "0.00043356432058937834`"},
     {"2000", "9.715002431318585`*^-9", "2.245368556816579`*^-9", 
      "0.00042002625650756567`"},
     {"3000", "8.363919786792684`*^-9", "1.7570885425490694`*^-9", 
      "0.00040906530535700245`"},
     {"4000", "7.410285034680983`*^-9", "1.5154797304497026`*^-9", 
      "0.00039957823618005093`"},
     {"5000", "6.70723492577404`*^-9", "1.356050292265461`*^-9", 
      "0.00039110551805745375`"},
     {"6000", "6.173290131416664`*^-9", "1.2390906790470547`*^-9", 
      "0.000383382433241421`"},
     {"7000", "5.758449376136367`*^-9", "1.1495716772030656`*^-9", 
      "0.0003762327319263624`"},
     {"8000", "5.42981267533018`*^-9", "1.0793440678781596`*^-9", 
      "0.00036953181669915615`"},
     {"9000", "5.164679612419069`*^-9", "1.023153348577875`*^-9", 
      "0.0003631890196948455`"},
     {"10000", "4.946893063316037`*^-9", "9.77357619078164`*^-10", 
      "0.00035713725543970855`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Urine\n24 hours", "Faecal\n24 hours", 
       "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399282927877633*^9, 3.417836439094455*^9, 
  3.4798279902293787`*^9, 3.4798286658716297`*^9, 3.479829860977707*^9, 
  3.518535290769554*^9, 3.6434438220077257`*^9},
 CellLabel->"Out[214]//TableForm="]
}, Open  ]],

Cell["(ICRP 78, table A8.21)", "Text"],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[215]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV0mk8VWsbBvBtDDvbtJSjlNNea+3Mkjghz6OojuJkvx1JZjmGDJXIESop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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV13c0V/8fwPHP/igJ9VH6Rqk0UKisJO+XmcgWJSHJqmQWkpCMjEpJRnZ2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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -12.903350069487946`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-12.903350069487946`, 1.1724910411288756`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992829320231113`*^9, 3.417836443500705*^9, 
  3.4798279925574436`*^9, 3.479828668184559*^9, 3.479829863290518*^9, 
  3.518535292894595*^9, 3.6434438224139695`*^9},
 CellLabel->"Out[215]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[216]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Lung\\nretention\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.05762559969442553`", "0.0010671232464230657`", 
      "0.10827047261215639`", "0.49613753060085714`"},
     {"2", "0.05593276558815258`", "0.00022825486425898794`", 
      "0.15460803676571053`", "0.26253862286220725`"},
     {"3", "0.05498583800741929`", "0.00013758374342868335`", 
      "0.07959616161828158`", "0.15382972856021437`"},
     {"4", "0.05415636789713769`", "0.00011299171819288689`", 
      "0.03343011927575293`", "0.10962725424038715`"},
     {"5", "0.053359294815146105`", "0.00009677673946961035`", 
      "0.013285002014009645`", "0.09232411315863043`"},
     {"6", "0.05258269101268844`", "0.00008457762982991973`", 
      "0.0053325034678458685`", "0.08546444179677992`"},
     {"7", "0.05182449123151804`", "0.00007523220615814757`", 
      "0.002307751092167222`", "0.08255075753895473`"},
     {"8", "0.05108397226897482`", "0.00006799523627615267`", 
      "0.001170484853436439`", "0.0811170418406331`"},
     {"9", "0.050360605175065756`", "0.00006232364018082803`", 
      "0.0007404135126513334`", "0.08024247990803832`"},
     {"10", "0.049653900264422415`", "0.00005781740964392462`", 
      "0.0005729385098165694`", "0.07958529953842011`"},
     {"20", "0.04340630532925459`", "0.00003809369702367782`", 
      "0.00036474248420363675`", "0.07491950045700974`"},
     {"30", "0.038386792466525516`", "0.000029805500536661533`", 
      "0.00027751490593546507`", "0.07144119487195774`"},
     {"40", "0.034298371519371526`", "0.000024260871736424272`", 
      "0.0002126626410498128`", "0.06877248209072814`"},
     {"50", "0.03092126690692689`", "0.000020321082991152373`", 
      "0.0001642324465894185`", "0.06670390036359765`"},
     {"60", "0.028092204712756585`", "0.000017452626940223093`", 
      "0.00012792021071137208`", "0.06508311669636062`"},
     {"70", "0.025689367601014104`", "0.000015313804891274596`", 
      "0.00010057686116601502`", "0.06379836067331507`"},
     {"80", "0.02362144232042384`", "0.00001367838430357815`", 
      "0.00007989139884720733`", "0.06276726390356657`"},
     {"90", "0.021819627998477756`", "0.000012395209562393594`", 
      "0.00006416349031112753`", "0.06192887407550211`"},
     {"100", "0.020231790716410868`", "0.000011362455041727393`", 
      "0.00005213884371612493`", "0.06123789738112834`"},
     {"180", "0.01192429958518762`", "6.982177737542561`*^-6", 
      "0.000015382021034545182`", "0.058288630849242504`"},
     {"200", "0.010556103115000716`", "6.352781280437314`*^-6", 
      "0.000012586310030751266`", "0.057879130417145784`"},
     {"300", "0.005836340033898102`", "4.238446395785078`*^-6", 
      "6.233332138129086`*^-6", "0.056486886662308784`"},
     {"400", "0.0032551303788948944`", "3.0874915862219576`*^-6", 
      "3.7214604783151334`*^-6", "0.05564448195570319`"},
     {"500", "0.001819771626553487`", "2.4343863525219667`*^-6", 
      "2.3763930365218455`*^-6", "0.055073917815220086`"},
     {"600", "0.0010188962233987154`", "2.054436846692098`*^-6", 
      "1.6080260736538177`*^-6", "0.054655958805838886`"},
     {"700", "0.0005713252284099428`", "1.8263258656850412`*^-6", 
      "1.1565233300429162`*^-6", "0.05432690284101214`"},
     {"800", "0.0003208486912963452`", "1.6833094737961352`*^-6", 
      "8.833465123484624`*^-7", "0.05405126338021515`"},
     {"900", "0.0001804720465158918`", "1.5884482170575032`*^-6", 
      "7.120053671112042`*^-7", "0.05380897854309181`"},
     {"1000", "0.00010168149765891541`", "1.521207742341546`*^-6", 
      "5.998513449446269`*^-7", "0.05358854406216696`"},
     {"2000", "3.6352848855164195`*^-7", "1.2146265225207453`*^-6", 
      "2.8686722712556456`*^-7", "0.051855533066633645`"},
     {"3000", "1.5887472477352625`*^-9", "1.0422701605117268`*^-6", 
      "2.2008676255069748`*^-7", "0.05048467502943446`"},
     {"4000", "8.191795546467708`*^-12", "9.213873782068505`*^-7", 
      "1.887370741117389`*^-7", "0.04930321275536121`"},
     {"5000", "4.669764224003561`*^-14", "8.325734526595796`*^-7", 
      "1.6846330607757365`*^-7", "0.04825044492685439`"},
     {"6000", "2.800222529014985`*^-16", "7.652838779279025`*^-7", 
      "1.5369109643455225`*^-7", "0.04729232743048831`"},
     {"7000", "1.7199222254277957`*^-18", "7.131032816742877`*^-7", 
      "1.4241858036119492`*^-7", "0.046406419509548755`"},
     {"8000", "1.0690929143315241`*^-20", "6.718347997716756`*^-7", 
      "1.3359271883433416`*^-7", "0.0455769233495967`"},
     {"9000", "6.691568944533769`*^-23", "6.385937289729582`*^-7", 
      "1.265428092658838`*^-7", "0.04479236760325616`"},
     {"10000", "4.208918921515847`*^-25", "6.113318841566295`*^-7", 
      "1.2080632922836787`*^-7", "0.044044275496591644`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Lung\nretention", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992829478190784`*^9, 3.417836459094455*^9, 
  3.479828010744478*^9, 3.4798286857815742`*^9, 3.4798298800271425`*^9, 
  3.518535305426086*^9, 3.64344382624213*^9},
 CellLabel->"Out[216]//TableForm="]
}, Open  ]],

Cell["(ICRP 78, table A8.20)", "Text"],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[217]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAA2C12NM1yfD5VNZ5L5VkGwH1iX+iS
GFo/r9BE0dJWBsCR+cQCWhhqP32V6VPAUwbAG8X3jz0Yej/DBClQm00GwOAq
kVYvGIo/WUVfJFFBBsDC3d05KBiaP5oupjq8KAbAMzeEqyQYqj8r2W8WkPcF
wOxjV+QiGLo/akqOSC6VBcD6A0a8FDHLPyBCcJSvvwTA4qK9VhEz1D/TJOOc
GfgDwFIVovturNo/OEb2vjA0A8BNhiT/ItngP4XLsh5mXwLA470+KhEg5D9J
lhdrjJgBwOY3OgQ8rec/uBEMAcjAAMCumlo00inrPz48R0Nq2f+/Z7lBDmtq
7j+6sbkMbU3+v0cNhUug+PA/BApsIsaf/L/Tm8xkDJ7yP2YP1BuRDvu/wZ4m
KS479D/NiRcGToX5v+ZC8URu+/U/ib8Kqtva978DRZ+1r533P2Og+nJdTfa/
V+i9fQ9j+T/bXjY4LZ/0vw0A7/AkIPs/4yTCmsf58r+8dQO5O7/8PyN/NrzT
cfG/oYyI2HCB/j/eAErmNJTvv8CAeKbTEgBAuu+ch06A7L/LC2UMfvYAQHqk
WMB7Lum/B9HaRwPWAUCzHpagsfDlvz9Fwi2JpgJAFCU8eTTv4r8TCmI/nogD
QGVoNoMuZd+/431z+7NbBECoE7Q/wGXZv+QrDo2kKgVAz+OMX8aQ07+AKmFK
JAsGQBFaRCqImMq/GdglsqTcBkCgPvs6AAq+v03WokW0vwdAj/7FvszwlL+y
Dqmunp4IQM96zZlWzLI/FPYgwoluCUCxFitpPHTEPxEuUQEEUApAqnW/2qYh
0D8KFfPqfiILQE2AUqSSjdU/NTYeqtTwC0D+KcejK8faP/unAZW50AxApV3S
lq4r4D+9yFYqn6ENQAM3BfegtuI/Gjpk6xOEDkA2sHrz6GjlP3Ra41aJVw9A
oz+5k2ne5z9/2vXLbBMQQJrxSFTrOOo/EjBWgtyDEEBH7HmTgbXsPyNd743M
7BBAXibFW0D37j+BsmQvhF4RQOah9dx8q/A/+KSeOynOEUCj5Aw8R8zxP+1u
EZ1ONhJAQ7lrDe7Q8j8wYWCUO6cSQGigse2+4fM/8Sro4KgQE0BB0uCY8Nb0
P8uRNJgDeBNAZbqW7BK+9T/yIF3lJegTQGMjj1wNrvY/l4e+h8hQFEDlj0u9
XIP3P3hcb7+bUhRA6SsEGf2G9z9aMSD3blQUQB4TQJ2civc/HtuBZhVYFEDz
RHUe2ZH3P6QuRUViXxRAKns4/keg9z+y1csC/G0UQE9V7gX9vPc/zCPZfS+L
FEBUT8DHwvX3P674ibUCjRRA1rAbz0f59z+PzTrt1Y4UQEyHavjL/Pc/Unec
XHySFEBx7wqw0QP4P9nKXzvJmRRAZdlsrdIR+D/mceb4YqgUQAzdJrGqLfg/
yEaXMDaqFEDM/ku+ITH4P6obSGgJrBRAOEr96Zc0+D9txanXr68UQNYGKJyB
O/g/9Bhttvy2FEC67ZNlSkn4P9btHe7PuBRAAbAQYbpM+D+3ws4lo7oUQPUx
X3kpUPg/emwwlUm+FED6BJP/BFf4P1xB4cwcwBRAPfYIbXFa+D8+FpIE8MEU
QO/ncfbcXfg/IOtCPMPDFEArA5abR2H4PwHA83OWxRRAxWE9XLFk+D8k/FL9

        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwVz3041PkaBvAxo5WXFH6/efuNkqYsyRAiyvdLyFaOmvI2Ry9eV0WSSC2W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        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV1Xk41F0bB/BhkIaHMPWOSEKLabEUelTOSVG0kISQvVWkRKWshUpUWhRR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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -8.222039594524292}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-8.222039594524292, 2.410639824746502}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Lungs\"", 11, StripOnInput -> False], 
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399283017891532*^9, 3.41783652982883*^9, 
  3.4798280319470606`*^9, 3.479828708348262*^9, 3.4798299113726788`*^9, 
  3.518535321332641*^9, 3.643443830914048*^9},
 CellLabel->"Out[217]="]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Neptunium", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["The model", "SubsubsectionIcon"],

Cell["The compartments has been numbered as follow: ", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompartNumbers", "[", "neptunium", "]"}]], "Input",
 CellLabel->"In[218]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "\<\"Blood\"\>"},
    {"2", "\<\"ST0\"\>"},
    {"3", "\<\"ST1\"\>"},
    {"4", "\<\"ST2\"\>"},
    {"5", "\<\"Liver1\"\>"},
    {"6", "\<\"Liver2\"\>"},
    {"7", "\<\"Kidneys Urinary\"\>"},
    {"8", "\<\"Other kidneys\"\>"},
    {"9", "\<\"Cort. bone\"\>"},
    {"10", "\<\"Cort. Surface\"\>"},
    {"11", "\<\"Cort Vol\"\>"},
    {"12", "\<\"Trab. Volum\"\>"},
    {"13", "\<\"Trab. Surf\"\>"},
    {"14", "\<\"Trab. bone\"\>"},
    {"15", "\<\"Gonads\"\>"},
    {"16", "\<\"Bladder\"\>"},
    {"17", "\<\"URI\"\>"},
    {"18", "\<\"ULI\"\>"},
    {"19", "\<\"LLI\"\>"},
    {"20", "\<\"FEC\"\>"},
    {"21", "\<\"SI\"\>"},
    {"22", "\<\"ST\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.3992830179994063`*^9, 3.417836529938205*^9, 
  3.479828032025183*^9, 3.479828708473285*^9, 3.4798299114976807`*^9, 
  3.518535321363892*^9, 3.6434438309609256`*^9},
 CellLabel->"Out[218]//TableForm="]
}, Open  ]],

Cell["We build the compartmental matrix.", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"TransferRatesE", "[", "neptunium", "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<From\>\"", ",", " ", "\"\<to\>\"", ",", 
        "\"\<Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\>\""}], "}"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[219]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"From\"\>",
       HoldForm], 
      TagBox["\<\"to\"\>",
       HoldForm], 
      TagBox["\<\"Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\"\>",
       HoldForm]},
     {"1", "2", "0.832`"},
     {"1", "3", "0.1611`"},
     {"1", "4", "0.0388`"},
     {"1", "13", "0.4804`"},
     {"1", "10", "0.393`"},
     {"1", "8", "0.0097`"},
     {"1", "5", "0.1941`"},
     {"1", "15", "0.00068`"},
     {"1", "18", "0.01359`"},
     {"1", "7", "0.0291`"},
     {"1", "16", "0.6211`"},
     {"2", "1", "0.6931`"},
     {"3", "1", "0.00693`"},
     {"4", "1", "0.000019`"},
     {"5", "6", "0.00177`"},
     {"5", "21", "0.000133`"},
     {"6", "1", "0.0019`"},
     {"7", "16", "0.0495`"},
     {"8", "1", "0.00139`"},
     {"9", "1", "0.0076`"},
     {"14", "1", "0.0076`"},
     {"10", "9", "0.0000821`"},
     {"10", "11", "0.0000411`"},
     {"11", "9", "0.0000821`"},
     {"12", "14", "0.000493`"},
     {"13", "14", "0.000493`"},
     {"13", "12", "0.000247`"},
     {"15", "1", "0.00019`"},
     {"16", "17", "12"},
     {"18", "19", 
      SubscriptBox["k", "ULI"]},
     {"19", "20", 
      SubscriptBox["k", "LLI"]},
     {"21", "1", 
      FractionBox[
       RowBox[{"f1", " ", 
        SubscriptBox["k", "SI"]}], 
       RowBox[{"1", "-", "f1"}]]},
     {"21", "18", 
      SubscriptBox["k", "SI"]},
     {"22", "21", 
      SubscriptBox["k", "ST"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"From", "to", "Tranfer Rates(\!\(days\^\(-1\)\))"}}]]]], "Output",
 CellChangeTimes->{3.3992830180302277`*^9, 3.41783652995383*^9, 
  3.4798280320720572`*^9, 3.4798287084889135`*^9, 3.4798299115289316`*^9, 
  3.5185353214107676`*^9, 3.6434438309765477`*^9},
 CellLabel->"Out[219]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "element", ",", " ", "lambda", ",", " ", "fn1", ",", " ", "amad", ",", " ", 
   "class"}], "]"}]], "Input",
 CellLabel->"In[220]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"element", "=", " ", "neptunium"}], ";", 
   RowBox[{"lambda", " ", "=", " ", "0"}], ";", " ", 
   RowBox[{"fn1", " ", "=", " ", 
    RowBox[{"5", " ", 
     SuperscriptBox["10", 
      RowBox[{"-", "4"}]]}]}], ";", " ", 
   RowBox[{"amad", "=", " ", 
    RowBox[{"AMADAdultW", "[", "5", "]"}]}], ";", 
   RowBox[{"class", " ", "=", " ", "M"}], ";"}], " "}]], "Input",
 CellLabel->"In[221]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsubsectionIcon"],

Cell["(ICRP 78. Tabla A.11. 7) ", "Text"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[222]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.21892925094474747`", "0.0011516649216646302`", 
      "0.7799190841335881`"},
     {"2", "0.04420898431880338`", "0.0021387128439507713`", 
      "0.7335713869708352`"},
     {"3", "0.02180343638381732`", "0.0015092191961042986`", 
      "0.7102587313909152`"},
     {"4", "0.0139157584802444`", "0.0008970306852722348`", 
      "0.6954459422254`"},
     {"5", "0.009169181191564735`", "0.0005291792204183618`", 
      "0.6857475818134183`"},
     {"6", "0.006134688640022756`", "0.00032208540698060867`", 
      "0.6792908077664163`"},
     {"7", "0.004182482507391283`", "0.00020330883128674704`", 
      "0.6749050164277395`"},
     {"8", "0.0029231191941354595`", "0.00013289560642731207`", 
      "0.671849001627178`"},
     {"9", "0.002107853324256337`", "0.0000899682105486993`", 
      "0.6696511800923742`"},
     {"10", "0.001577399716307104`", "0.00006328211280152984`", 
      "0.668010498263267`"},
     {"20", "0.0004910722286798341`", "0.00001735590326480685`", 
      "0.6605602452797577`"},
     {"30", "0.00035809982272094754`", "0.000016522276107627798`", 
      "0.6562902046171848`"},
     {"40", "0.0002810623857002481`", "0.000016213835082781736`", 
      "0.6529988644659733`"},
     {"50", "0.00023216476860765667`", "0.000015920611391835593`", 
      "0.6503145212574335`"},
     {"60", "0.00020047942042744626`", "0.000015636297960357204`", 
      "0.6480204969137423`"},
     {"70", "0.00017940679922390235`", "0.000015360450981091733`", 
      "0.645983558695684`"},
     {"80", "0.0001649170199929939`", "0.000015092713659119184`", 
      "0.6441212921185394`"},
     {"90", "0.00015454626677913197`", "0.000014832748145891805`", 
      "0.6423823351579463`"},
     {"100", "0.00014678579787841262`", "0.000014580233758838823`", 
      "0.640734326353149`"},
     {"180", "0.00011646867359116353`", "0.000012794836728929199`", 
      "0.6293341026872946`"},
     {"200", "0.00011201126511173332`", "0.00001240487508055027`", 
      "0.6268008384187652`"},
     {"300", "0.00009688262231621891`", "0.000010718797586923429`", 
      "0.6152935406708407`"},
     {"400", "0.00008876290915971197`", "9.376030872192131`*^-6", 
      "0.6050528862135528`"},
     {"500", "0.0000839748538868923`", "8.283885057799173`*^-6", 
      "0.5955559671210827`"},
     {"600", "0.00008069485949935284`", "7.381102729710903`*^-6", 
      "0.586550601623631`"},
     {"700", "0.00007804122316679152`", "6.625488853384542`*^-6", 
      "0.5779193036591828`"},
     {"800", "0.00007561198416539128`", "5.98680993834852`*^-6", 
      "0.5696093776667164`"},
     {"900", "0.0000732430549305052`", "5.442634969037019`*^-6", 
      "0.56159749820689`"},
     {"1000", "0.00007088328201154681`", "4.9758329378341015`*^-6", 
      "0.5538722803232439`"},
     {"2000", "0.00005026578388156455`", "2.580714056562433`*^-6", 
      "0.49043444866387487`"},
     {"3000", "0.00003780150346988087`", "1.7574401009329277`*^-6", 
      "0.4448602727620879`"},
     {"4000", "0.000030210980911049568`", "1.3545466625713987`*^-6", 
      "0.40959663913870625`"},
     {"5000", "0.0000250849391731367`", "1.1067232937971017`*^-6", 
      "0.38087883396929095`"},
     {"6000", "0.000021387627113844676`", "9.348745062566499`*^-7", 
      "0.3567220849987133`"},
     {"7000", "0.000018622075627916512`", "8.085833557696515`*^-7", 
      "0.33591369459244796`"},
     {"8000", "0.000016502688045816338`", "7.127474526899547`*^-7", 
      "0.3176388844311124`"},
     {"9000", "0.000014844301633454293`", "6.383086253586301`*^-7", 
      "0.3013246493506463`"},
     {"10000", "0.00001351967623264283`", "5.792523374553021`*^-7", 
      "0.28655926892376127`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399283018677477*^9, 3.417836530594455*^9, 
  3.47982803293141*^9, 3.4798287092703085`*^9, 3.479829912372698*^9, 
  3.518535321957653*^9, 3.643443831179679*^9},
 CellLabel->"Out[222]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[223]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV0Gs8lOkfBvCZYZNjDo+aVFZoReVQUlHuOyFS0WQp1So5dTAliSy2UkmU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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV1XlUjdv/B/AzRBQNz7NPjqtZdDulgW4U2lu3kqEkDSqkKERdChEZ0qVB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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -8.583406551862897}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-8.583406551862897, -0.3312649685279546}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, 
     AxesOrigin -> {0, -8.200000000000001}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992830215438676`*^9, 3.417836533750705*^9, 
  3.479828034821987*^9, 3.47982871119254*^9, 3.479829914403987*^9, 
  3.518535323926441*^9, 3.643443831539052*^9},
 CellLabel->"Out[223]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsubsectionIcon"],

Cell["(ICRP 78,Tabla A.11. 7 )", "Text"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[224]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.00009769511274020299`", "0.2822618182956512`", 
      "0.7176404865916016`"},
     {"2", "0.00003054860454731231`", "0.38888605345235283`", 
      "0.3287238845347012`"},
     {"3", "0.000012293234014450097`", "0.1968819349918247`", 
      "0.13182965630886223`"},
     {"4", "7.635128997164923`*^-6", "0.08134185633729682`", 
      "0.05048016484256819`"},
     {"5", "5.008869223442332`*^-6", "0.03139743184363318`", 
      "0.019077724129711565`"},
     {"6", "3.339579515400067`*^-6", "0.011794078530520615`", 
      "0.007280306019675549`"},
     {"7", "2.2665462542108728`*^-6", "0.004379101923832826`", 
      "0.00289893754958851`"},
     {"8", "1.5747673133351668`*^-6", "0.0016176673982695971`", 
      "0.0012796953840055773`"},
     {"9", "1.1273238317765165`*^-6", "0.0005962286058238403`", 
      "0.0006823394543499601`"},
     {"10", "8.365600141724489`*^-7", "0.00021953813765586367`", 
      "0.0004619647566799236`"},
     {"20", "2.4767775822718543`*^-7", "1.86800132820922`*^-8", 
      "0.00033033818686065315`"},
     {"30", "1.8006462271724036`*^-7", "8.265098736610145`*^-9", 
      "0.00032818378319315184`"},
     {"40", "1.4116774312478066`*^-7", "8.110022661971612`*^-9", 
      "0.00032653018054769567`"},
     {"50", "1.164906204157508`*^-7", "7.96331311281968`*^-9", 
      "0.0003251829602817629`"},
     {"60", "1.0050750591533318`*^-7", "7.821066219979673`*^-9", 
      "0.00032403266439419556`"},
     {"70", "8.988436290792911`*^-8", "7.683056402270659`*^-9", 
      "0.00032301200029041934`"},
     {"80", "8.258539710437069`*^-8", "7.549105027508315`*^-9", 
      "0.0003220793477728863`"},
     {"90", "7.736598548271651`*^-8", "7.4190429869775754`*^-9", 
      "0.000321208773331169`"},
     {"100", "7.346400189437233`*^-8", "7.292709765607287`*^-9", 
      "0.0003203839415934008`"},
     {"180", "5.825932631068828`*^-8", "6.399502315500871`*^-9", 
      "0.0003146805021140963`"},
     {"200", "5.602724156801098`*^-8", "6.204417198967481`*^-9", 
      "0.00031341336637707664`"},
     {"300", "4.845255180749427`*^-8", "5.360956575722593`*^-9", 
      "0.0003076579701712303`"},
     {"400", "4.438774660515694`*^-8", "4.68927075945691`*^-9", 
      "0.0003025366593658144`"},
     {"500", "4.199141657057915`*^-8", "4.142972819263095`*^-9", 
      "0.00029778758836371895`"},
     {"600", "4.035041984020533`*^-8", "3.691408931979156`*^-9", 
      "0.0002932844704637025`"},
     {"700", "3.9023214937693954`*^-8", "3.3134660812033224`*^-9", 
      "0.00028896846666286657`"},
     {"800", "3.780847452293772`*^-8", "2.9940175976109825`*^-9", 
      "0.00028481318429429567`"},
     {"900", "3.66239862696887`*^-8", "2.721841358981796`*^-9", 
      "0.00028080694127390624`"},
     {"1000", "3.5444096206161454`*^-8", "2.488367272490734`*^-9", 
      "0.0002769440380398988`"},
     {"2000", "2.5134582837184772`*^-8", "1.2904878014026471`*^-9", 
      "0.0002452227263741493`"},
     {"3000", "1.8901735845781864`*^-8", "8.787760598534116`*^-10", 
      "0.0002224342551108131`"},
     {"4000", "1.5106126712038405`*^-8", "6.773050498173905`*^-10", 
      "0.00020480160610576503`"},
     {"5000", "1.2542917449738945`*^-8", "5.533827402306963`*^-10", 
      "0.00019044214403216787`"},
     {"6000", "1.0694143845018907`*^-8", "4.674524325741397`*^-10", 
      "0.00017836336671077195`"},
     {"7000", "9.311288273674157`*^-9", "4.0430304906022323`*^-10", 
      "0.0001679588704218378`"},
     {"8000", "8.251538093296184`*^-9", "3.563824667003203`*^-10", 
      "0.00015882123470033657`"},
     {"9000", "7.42230429442753`*^-9", "3.191611773409252`*^-10", 
      "0.00015066393674360756`"},
     {"10000", "6.759962037188039`*^-9", "2.8963167447962655`*^-10", 
      "0.00014328110246448645`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Urine\n24 hours", "Faecal\n24 hours", 
       "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399283022298992*^9, 3.417836534500705*^9, 
  3.479828035712589*^9, 3.4798287122396092`*^9, 3.479829915310254*^9, 
  3.5185353244889517`*^9, 3.64344383174218*^9},
 CellLabel->"Out[224]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[225]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV03k41dkbAPB7LRGS5RY1GN/vVZObpcUwhHMoEqEkJCQKY18mlUGRFqEp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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV13k0Vl8XB/BnfoQy9Cj9UlEaUChjUmcbU2bJVCgVUiRDSZIpylRIEgnJ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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -10.966964471098727`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-10.966964471098727`, 0.9964564303867872}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399283026043792*^9, 3.417836538531955*^9, 
  3.47982803782191*^9, 3.479828714333748*^9, 3.479829917497796*^9, 
  3.518535326317112*^9, 3.6434438321484327`*^9},
 CellLabel->"Out[225]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsubsectionIcon"],

Cell["Type M, AMAD 5", "Text"],

Cell["(ICRP 78. Table A.11. 6.) ", "Text"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[226]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Lung\\nretention\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.05762559969442553`", "0.00621919474864438`", 
      "0.10827986366312897`", "0.49097606774330954`"},
     {"2", "0.05593276558815258`", "0.0013354111957499734`", 
      "0.15462677158955274`", "0.25625126870896`"},
     {"3", "0.05498583800741929`", "0.0006976328361282258`", 
      "0.07961048124411486`", "0.1469680055821388`"},
     {"4", "0.05415636789713769`", "0.0004766703407765374`", 
      "0.033439005143511426`", "0.10239296668543388`"},
     {"5", "0.053359294815146105`", "0.00034372389404988685`", 
      "0.013290107563152145`", "0.08483777282866427`"},
     {"6", "0.05258269101268844`", "0.0002583805104228454`", 
      "0.0053352853315801405`", "0.07780151666354154`"},
     {"7", "0.05182449123151804`", "0.00020310679551123478`", 
      "0.002309180181778614`", "0.07475852867800688`"},
     {"8", "0.05108397226897482`", "0.00016708693568216748`", 
      "0.0011711613004419079`", "0.07322504479310073`"},
     {"9", "0.050360605175065756`", "0.00014341476244895263`", 
      "0.0007406948542031909`", "0.072269110363836`"},
     {"10", "0.049653900264422415`", "0.00012766799830785103`", 
      "0.0005730312292887424`", "0.0715419866595875`"},
     {"20", "0.04340630532925459`", "0.00008826443683385837`", 
      "0.0003649101123175437`", "0.0663368664192155`"},
     {"30", "0.038386792466525516`", "0.00007686696004158972`", 
      "0.0002776661302749603`", "0.06237233117179663`"},
     {"40", "0.034298371519371526`", "0.0000682844776355579`", 
      "0.0002127610517885705`", "0.059248622183005195`"},
     {"50", "0.03092126690692689`", "0.00006150529107673552`", 
      "0.0001642844938927572`", "0.05675488380191898`"},
     {"60", "0.028092204712756585`", "0.00005602645192006456`", 
      "0.00012793295978016407`", "0.0547365066286276`"},
     {"70", "0.025689367601014104`", "0.000051502812605776216`", 
      "0.00010055599759584491`", "0.05307937191668466`"},
     {"80", "0.02362144232042384`", "0.0000476931566715591`", 
      "0.00007984147748870199`", "0.05169888173835723`"},
     {"90", "0.021819627998477756`", "0.00004442680596898618`", 
      "0.00006408820392810478`", "0.05053204278907476`"},
     {"100", "0.020231790716410868`", "0.000041581477260091426`", 
      "0.00005204122622791841`", "0.04953173021930079`"},
     {"180", "0.01192429958518762`", "0.00002691084889191314`", 
      "0.000015172074619834112`", "0.04463541880421245`"},
     {"200", "0.010556103115000716`", "0.000024486784526024652`", 
      "0.000012359760296221795`", "0.04385094375488448`"},
     {"300", "0.005836340033898102`", "0.000016008261825933845`", 
      "5.960649123198936`*^-6", "0.04102267105907561`"},
     {"400", "0.0032551303788948944`", "0.000011241647631748952`", 
      "3.439492633502614`*^-6", "0.0392304683810213`"},
     {"500", "0.001819771626553487`", "8.504324243353845`*^-6", 
      "2.103082171773119`*^-6", "0.03798703306523708`"},
     {"600", "0.0010188962233987154`", "6.907845213954822`*^-6", 
      "1.351296357743597`*^-6", "0.03705538112847228`"},
     {"700", "0.0005713252284099428`", "5.9520647341937405`*^-6", 
      "9.189236761350701`*^-7", "0.036305436395390515`"},
     {"800", "0.0003208486912963452`", "5.354437967286518`*^-6", 
      "6.646547359046451`*^-7", "0.03566463985263959`"},
     {"900", "0.0001804720465158918`", "4.956270173030186`*^-6", 
      "5.106842362989205`*^-7", "0.03509245342018676`"},
     {"1000", "0.00010168149765891541`", "4.669170762763852`*^-6", 
      "4.1384651542166785`*^-7", "0.03456618662156583`"},
     {"2000", "3.6352848855164195`*^-7", "3.187357500024357`*^-6", 
      "1.6707546709581605`*^-7", "0.030488022245477957`"},
     {"3000", "1.5887472477352625`*^-9", "2.3809140636855963`*^-6", 
      "1.1138459558445064`*^-7", "0.027606004763972732`"},
     {"4000", "8.191795546467708`*^-12", "1.894012866980599`*^-6", 
      "8.512092857979568`*^-8", "0.025389961459924205`"},
     {"5000", "4.669764224003561`*^-14", "1.5680860849347222`*^-6", 
      "6.926070422199303`*^-8", "0.023592152420425568`"},
     {"6000", "2.800222529014985`*^-16", "1.3341493623475476`*^-6", 
      "5.835819958624911`*^-8", "0.022083656510569455`"},
     {"7000", "1.7199222254277957`*^-18", "1.1596508272641859`*^-6", 
      "5.037955179551176`*^-8", "0.02078673281809413`"},
     {"8000", "1.0690929143315241`*^-20", "1.0261917110683527`*^-6", 
      "4.434005548012779`*^-8", "0.01964951807532117`"},
     {"9000", "6.691568944533769`*^-23", "9.219528449393166`*^-7", 
      "3.965822648521657`*^-8", "0.018635655850411777`"},
     {"10000", "4.208918921515847`*^-25", "8.388452495677878`*^-7", 
      "3.59508081388283`*^-8", "0.0177190638677799`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Lung\nretention", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399283044166775*^9, 3.41783655470383*^9, 
  3.479828055462083*^9, 3.479828731649461*^9, 3.4798299362169056`*^9, 
  3.5185353390048556`*^9, 3.643443835960967*^9},
 CellLabel->"Out[226]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[227]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwB4QQe+yFib1JlAgAAAE0AAAACAAAA2C12NM1yfD5VNZ5L5VkGwH1iX+iS
GFo/r9BE0dJWBsCR+cQCWhhqP32V6VPAUwbAG8X3jz0Yej/DBClQm00GwOAq
kVYvGIo/WUVfJFFBBsDC3d05KBiaP5oupjq8KAbAMzeEqyQYqj8r2W8WkPcF
wOxjV+QiGLo/akqOSC6VBcD6A0a8FDHLPyBCcJSvvwTA4qK9VhEz1D/TJOOc
GfgDwFIVovturNo/OEb2vjA0A8BNhiT/ItngP4XLsh5mXwLA470+KhEg5D9J
lhdrjJgBwOY3OgQ8rec/uBEMAcjAAMCumlo00inrPz48R0Nq2f+/Z7lBDmtq
7j+6sbkMbU3+v0cNhUug+PA/BApsIsaf/L/Tm8xkDJ7yP2YP1BuRDvu/wZ4m
KS479D/NiRcGToX5v+ZC8URu+/U/ib8Kqtva978DRZ+1r533P2Og+nJdTfa/
V+i9fQ9j+T/bXjY4LZ/0vw0A7/AkIPs/4yTCmsf58r+8dQO5O7/8PyN/NrzT
cfG/oYyI2HCB/j/eAErmNJTvv8CAeKbTEgBAuu+ch06A7L/LC2UMfvYAQHqk
WMB7Lum/B9HaRwPWAUCzHpagsfDlvz9Fwi2JpgJAFCU8eTTv4r8TCmI/nogD
QGVoNoMuZd+/431z+7NbBECoE7Q/wGXZv+QrDo2kKgVAz+OMX8aQ07+AKmFK
JAsGQBFaRCqImMq/GdglsqTcBkCgPvs6AAq+v03WokW0vwdAj/7FvszwlL+y
Dqmunp4IQM96zZlWzLI/FPYgwoluCUCxFitpPHTEPxEuUQEEUApAqnW/2qYh
0D8KFfPqfiILQE2AUqSSjdU/NTYeqtTwC0D+KcejK8faP/unAZW50AxApV3S
lq4r4D+9yFYqn6ENQAM3BfegtuI/Gjpk6xOEDkA2sHrz6GjlP3Ra41aJVw9A
oz+5k2ne5z9/2vXLbBMQQJrxSFTrOOo/EjBWgtyDEEBH7HmTgbXsPyNd743M
7BBAXibFW0D37j+BsmQvhF4RQOah9dx8q/A/+KSeOynOEUCj5Aw8R8zxP+1u
EZ1ONhJAQ7lrDe7Q8j8wYWCUO6cSQGigse2+4fM/8Sro4KgQE0BB0uCY8Nb0
P8uRNJgDeBNAZbqW7BK+9T/yIF3lJegTQGMjj1wNrvY/l4e+h8hQFEDlj0u9
XIP3P3hcb7+bUhRA6SsEGf2G9z9aMSD3blQUQB4TQJ2civc/HtuBZhVYFEDz
RHUe2ZH3P6QuRUViXxRAKns4/keg9z+y1csC/G0UQE9V7gX9vPc/zCPZfS+L
FEBUT8DHwvX3P674ibUCjRRA1rAbz0f59z+PzTrt1Y4UQEyHavjL/Pc/Unec
XHySFEBx7wqw0QP4P9nKXzvJmRRAZdlsrdIR+D/mceb4YqgUQAzdJrGqLfg/
yEaXMDaqFEDM/ku+ITH4P6obSGgJrBRAOEr96Zc0+D9txanXr68UQNYGKJyB
O/g/9Bhttvy2FEC67ZNlSkn4P9btHe7PuBRAAbAQYbpM+D+3ws4lo7oUQPUx
X3kpUPg/emwwlUm+FED6BJP/BFf4P1xB4cwcwBRAPfYIbXFa+D8+FpIE8MEU
QO/ncfbcXfg/IOtCPMPDFEArA5abR2H4PwHA83OWxRRAxWE9XLFk+D8k/FL9

        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwVz3s41GkbB/Axo5Uc+s38nhlDrZSxooRSCnkeikS2skIOWadeHRxaFtsO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        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV1Xk8lN37B/CxhVGyjBqRKC2W0JMolXOrCIlClDXyREiLJIoHFUWER5ut
yC+0SEQRXfREZYssWVIiLWbue1YzBsP3/v1xXuf1/ue6PtfrnNc5Ov4nnP+W
pFAow+T6/71//VnT9tMXLF8dsBy/nk1tiPH3/Z1J90Cm6VN/6tOpDRmit5Ie
9GCktVESwxOpDRpNwuvb6dHoQv3OEadwasOIfoabMT0ZfZP14uk6UBveDA9v
WUfPRlTmzijFOfmGjeaXHunSH6JOmeBXI/7yDcwj7j9W0mvRXZ2lbmUmcg3T
UjZ1tA2tqMuvewmlXKZhtLDeTXljDzqtfnPVozipBme1wpmwx4PoquxYy8tk
iYa9ibrzKwdG0FCa5pdE23kYq7fUV9b+gTQVP9nFGc7CT3ML6W1PfqGAhUnr
FlmL4FTNtJfRq1/o+yHBYJaFCGYtXlVpf/iFvI/S760yEYGK5bZAmfFf6FvN
Ww83DRGgXZYtHZq/ka5RpqcSdwpu79uR7nftNyrnHenpuTcF9sfsNZNC/iDj
m1fuZkhNQVm2h+knPQYK8mwwODosAD3zN7d6zBhIp5KqvqVXAEXdejN9Oxko
MPxpjXK7ALIXihqHvBlourZ1UU+dAC7H3nIaz2Ag5vWEjtxcAXj59wRPiRjI
sdlNfbu3AKj6jgVaLUy0QbGZeDQ6CYE1VoohwQQy2U2JHRDzgTkYEJB4jkBq
O9z6IgV8ODmbVFuQSKCSuU5XTRYfolHH0f5CAp2p3lEbOcKHa00eYD1EILau
6/fI//hQ3hV+UtuBhWQbeSdykvkg5jv/mVjCRt33PjK8l/Nh96LLe+5NsdFy
1tx2K1ceJBhMzGyaZyN1BVF1jSMP6uycHrfKcNDxn0vFZnY8MElUXyRU4aCs
60a/kSUP6PNPOvau56CMvExx8joeTLD79s/4cZB4S9AO6TkupPasO+jWykET
nW2yZx5z4T03VY7ZxUFP5VUm44u5IKnMexnfz0GGp6WDswq5cHZvvfqTcQ4q
37NmtPk2F3ya9w9JUbjomqC+3e8yF0xeRvs8M+WiPRLE/eO+XOjOaQtYmM9F
bpNOTe1LuPBV6isjroiLDqztjYxV4cJECOv05EMuak27iW1UJPttU4n/+oKL
nI64LyyVIet9cc8r7+Kiwyvi9jfxOZCmOdbrKsNDN390Vr/u5oB9nsgmL5SH
7DUq5v8viwNuMgodyuE8JFJf69GbzgH/45oHEqN4qFKYmCiXyoGo7ejIiUQe
WvE5yCH6MgdKhi/9Y3WPh6xW7duXcpYDC7SUXo5385C4NN/V7xAHGvPX6Blt
5aNbhst1OnQ44Pzhhp7xDj5Ke1HyXF+LA6M8aX0TOz5aSERGpCzjgLTdmP5f
7nykHVodfkiVAza8u4Zm4XyUEBRJWyvDgZbd6iaWj/iImm5zJvEPG3rYCuaO
GpOIeeckdUcVGwI0zps7rZxER9NH+rUq2DBpPWG+T28SUWveRc+XsWFJzvvN
zuaTaHd41fq2EjYctL5s4eYyiQ57aUr8m8uG4Ttz231SJpFPmOHP7kts+LmD
sytsZhJNv7T6qXiQDcR0pb1QQoBALfx82gE2CCvO7ouTE6AYZ2KJsgsb5FbN
emaqCdCF7hvuKxzZoC8lG15tLEB7R8LBdxcbjv+nWTB3RIBONIrXhm1gA3+n
rTitTYAcqepuzxaxYXaGKkXvFiCDwZRdqQpskHneLlcwIEB0Xxo7RJ7Mr+tC
q/wpQF1O9hEbZNiwWdrH4DNFiKw9dTg1IhZceBt+aMUmIaL3yrUGDrBAyvpu
1dM8IWK1Oc4V5rIgHcC0qUiIXp84EV95mwVaFiOVg4+EiBOf9eFDFgs2G+tU
yNQKUYraskzZVBaEqd8v8+wTot2OWQHvYljQjz8oll08hYbadZe6HGbBk5tl
d3zjptDwya+m4XossFD+SI9ImkLLI1X8N6xhwfsU1q3ktCk0d1n/Hn8lC0bj
TG5W5U6hTsXxzcmaLKCHVGQq1EwhHU+BFWcxCxJQdcoLzhSKOzYwViokwP13
fcziIyJkbvDM+W4LAdWPk7ulgkXobTD1rMR7Amin3PWmTorQUPDqnsAmAj6J
2D0jsSKUfjvX0KqBAEcFXcOKbBEy9Pz9ZnU1AbuMkgddP4mQ29EWo4pCAv46
42aebTWNlCOOvK+KJSBj86rUNNtpRDimvLpxgQD2LGs0wWka/azP3hsVTUDZ
5atpId7TSMrn5tY9ZwnQu1U3vi1qGu2xyHmlHkaAdu3KrG/l02jOw2WLtw8B
iygstq72DCpljq72sSLgx/7FDgVrZtDumLtHmhEBtfeNi5evn0Htmtp2GywJ
CNp90nuJxQx6J79TrLiVgDdpnA+yrjNI0u3v4j+mBJxbzi+cSJpBD7nOk3Q9
sp6FyLWcNYOicgov7VYl4NU19XJDwQx6+3k1dU6ZgMyvWxRKZ2fI9/96S7US
ASghurFAfhYpGKxgGSkSkP1hZv2/q2ZRbdxo6BZ5AvYdnFtw1n2WzLvg1PN5
HOoipGq2wiy6SVn0yZDAgZ4cn7qreRbZL73upojjEJ4/77e3fRaZNotkuAwc
9N/NUH2HZtGRkoI++IPDbTrfK0E4i4qHqj6fGcch4tUPygdjMbo6NLjOahiH
zo/+vV1mYlT7OLho5xccDH+MlA5uFyP/Qo6S7RAOPxYOOzP3iBFETZS5DeDg
7NNbtDhIjLJ3/ZOX3IuDkUSzrds9MXoQtNnOvgOHZLVdy32LxShmfd7m4HYc
xvXecALLxMhma+NoShsOuc6vs6PqxKg3Z5tHTwsOCkXVzNx+MUozuHo+6h0O
v22K08eU5tDy++oNyo04FFy70n8yfg7pPH4wFFCFwxkjjwqJK3PIP6OnovE5
DradBtcy0+ZQrLHlixWkCdWP6HnOHBLrPLX8VoHDthy1YmHVHCqoXCwfWo5D
f2lhROzEHHpLt8mrfYSD0rs6lWsu88jXWWNU8z45b1AaU9NjHtkM7DfOKcTh
BfVw85PD86hqRejRZaR9HKWiPx6fRx45d5I1CnB43Gv3XeXKPLq4/HrEurtk
nh99T+/UzaPk46GmITk4NMSde9CtQsH4GbG9SVk4MP9S2ue/hIItVD1ktJQ0
fbxYxFanYA1Kju7F/+Jwyu6zg6IOBQtyP6bckonDShUznq0xBauscSHoGThc
vM9Dr/dQsCbq4xuDqTjYNIcNlFwi69UcuzeShMPpcwsuml+hYMUZso6JpPP1
8w2bUyjY4lSzDEPSgrT2f8YyKdijFx+7ohNxKHY3XKNVQMHqvJ0Xa13GQe7P
n9P/1lMwwc4X2rEJOLQq/L0wVkDBLmiM+GXH4DAy6qwzK6Jg2nI1f+0nza/B
zKLFZL+HBwLlSGsFaR4+Ky2BhZxWF0ZeIPO87a4MU5HALuYpp3uex2FZzA5P
XyMJ7IOPqHRjFA7HiBUPsaMSWPQrcwXtCBxkuwZ3S/VJYFlHn+lXHSfPK+y0
r/WABMavammKI12ykBqZ9EUCE8/UXnIgbW+75YHCmAR2JksQ8iMUhzS4JU1j
S2CeX2c71Uirlbk26lIlsdfs0wmxwTisSumwsLGUxJbWrTEICMQBWb9Zf/WB
JNbz9e/QY344qFL9Uf4VKUwjP62o3xWHsZjwmUpPaWzz/e8luC15PwwUU4v0
ZbCgeCnjim04xOn72esqLMBauB52JUY4qPevrij6sgA7rLXuSps2Dnv7Cq2f
gyw2Hv+mX6iEQ4ViaVl+vhwW6zCpUUzBgSbQfnM1TB47W+7U0MFmgrLRfgnp
fVSsfH+nidw3JlDVeBOxKxWwaBcvNXE7EzaZaT0k/1zMwe7J5uk6JswUS9yo
6VyINYxu++b6kAn179307xYswo5WPNdh3GbCMosAhuolRYxlbVZnnsiEMx5j
blfdF2PClvM2GhFM+GdwsjVUVQkbXkKL6Q1ggoqJW8KXi0pYsIXPdcKFCau8
WaltTCWMh054SVszIb4iwPiSjzIW+mfpAfYmJkwV5W/V61DGqr61HXNfxwQ8
TDnP0UwFQ6eqAlo0mWDidzhra7EKZrD227WLykzg6P8eKVFSxXrSpCW15ZjQ
mmF6W+qcKlY/+lSKOc8Arrb3+Orfqlj7hswA+SkG3Ep6nfR+Hw1zrPN0uchh
wDmvE5DjTMO2rsnvCyTtsUFbGOZKw/BrUYEOpLWG4o+qHaRhZh5dz9RIFxlZ
W/v70jDZ4G+/StgMqOhtlZw9TsMuZu/v7GIxoG3VQIxxCg27Z6Vkv55gQNnU
1SrJVBpGt3QKVSV9vd0C702jYZvwL9kinAHOkbleFzJpmKJKnWYz6YEW360f
7tCw9V4nK3xJ/zz1c8q/hIa12gk1bzAZ8N7mlonZQxrmLDw1f570Qw3bIPnH
NGyvfS7uT/p4U+nnp09pmNWHfqYJaT79ePVsNTkfbySincGAPnw58fElDcv3
fP/8OekXbzpW36+lYX29yvM5pKNDTW7YvaZhBuVFVcGkvay+t2k20DCfiUEd
Z9KWSzKl2Y007IXY4c4W0tqMHdv++4+GqYdwNHRISzTwwm820bCmZ69L5Uj/
Dz8KT8s=
        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -6.285211895729321}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-6.285211895729321, 2.2345645794015043`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Lungs\"", 11, StripOnInput -> False], 
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992831198024907`*^9, 3.41783663423508*^9, 
  3.4798280761646786`*^9, 3.479828751606289*^9, 3.479829958326705*^9, 
  3.518535354755158*^9, 3.643443840507883*^9},
 CellLabel->"Out[227]="]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Special cases: Calcium and iron", "Section"],

Cell[CellGroupData[{

Cell["Calcium", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Model", "SubsubsectionIcon"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@000?H00@0005P0003nooooooooonP<000H2@00
00000000002[=P00TRH00215CDH000400?H008d6000300000000000000000000QQ80090J00390000
804000X0000@00000@0000400009000040000>T<000K2@004P0000`000010000600000`000000002
DP0004`100010000W?ooo`0000000000000009010000000014004U@0J@1]06D0L`0P04h0I@1g0200
DP1_06d0H@1^0000ool00?oo003oo`40ool00?oo003oo`00ool00?oo00000000ool00?oo003oo`00
ool00000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000000000000000000000000000000000000000000000000000000000
00000000000000000000000000010@410@410@41000U000030000040001D0000E0000?kooooooooo
:P00070000010000U:>7@9BSQd3ooooo00000040001<00001000000000000000jP`001`9001@0000
800002d0000V000070000080000000001P0000H0000000029@0000`0000200009@0000`000000020
:P0001P0003=2000`@H004@:000h20009@0000`000070020:00000`0000200003000010000000000
000002D0000<00001`00P2D0000<00000000P240000800007P0001P0000`2@003`L00>09003Y1`00
E0000600000_2@004@L00:/900221`000@0009BSQd2DXhM0<0T0018700030000C00000@0000`2@00
3`L00=l9003Y1`00E0000200<@0e00006@000380000b0000E00005@0002/2@004@L00=P900221`00
0@0009BSQd2DXhM0[@T0018700010000C00000@0000`2@003`L00=l9003Y1`00D00002003@0]0000
8P0000`0003ooooo9@0000`000000020C@0006`0002B1@000`000=L:000?0P00T`D000@000161@00
3@800240l000000000000000P3l0000000000000P3l0000000000000000000000000000000000000
00000000000000004`0000`0000200009@0000`0000800209@0000`000040020EP0002`0002?1@00
0`0009D500090000100009H5102@1@@0T0D:09H52P1F0000;00008l5000?0000U@D001D000040000
UPD@0905402@1AH0UPDF05H0000/0000S`D001/0002E1@008@0000@0002F1A`0T0DL09058P2F1B80
EP0002`0002?1@009`0009D5000]0000100009H5:02@1BP0T0D^09H5;P1F0000;00008l5000c0000
U@D003T000040000UPDd0905=02@1CX0UPDj05H0000/0000S`D003l0002E1@00A@0000@0002F1D00
T0E00905AP2F1DH0EP0002`0002?1@00B`0009D5001A0000100009H5C02@1D`0T0EB09H5DP1F0000
;00008l5001G0000U@D005d000040000UPEH0905F02@1Eh0UPEN05H0000/0000S`D006<0002E1@00
J@0000@0002F1F@0T0ET0905JP2F1FX0EP0002`0002?1@00K`0009D5001e0000100009H5L02@1G00
T0Ef09H5MP1F0000;00008l5001k0000U@D0084000040000UPEl0905O02@1H80UPF205H0000/0000
S`D008L0002E1@00S@0000@0002F1HP0T0F80905SP2F1Hh0EP0002`0002?1@00T`0009D5002I0000
100009H5U02@1I@0T0FJ09H5VP1F0000;00008l5002O0000U@D00:D000040000UPFP0905X02@1JH0
UPFV05H0000/0000S`D00:/0002E1@00/@0000@0002F1J`0T0F/0905/P2F1K80EP0002`0002?1@00
]`0009D5002m0000100009H5^02@1KP0T0Fn09H5_P1F0000;00008l500330000U@D00<T000040000
UPG40905a02@1LX0UPG:05H0000/0000S`D00<l0002E1@00e@0000@0002F1M00T0G@0905eP2F1MH0
EP0002`0002?1@00f`0009D5003Q0000100009H5g02@1M`0T0GR09H5hP1F0000;00008l5003W0000
U@D00>d000040000UPGX0905j02@1Nh0UPG^05H0000/0000S`D00?<0002E1@00n@0000@0002F1O@0
T0Gd0905nP2F1OX0EP0002`0002?1@00o`0009D500050@00100009H5006@1@01T0D60IH51P5F0000
;00008l5000;0@00U@D0014100040000UPD<0I05306@1A81UPDB0EH0000/0000S`D001L1002E1@00
7@4000@0002F1AP1T0DH0I057P6F1Ah1EP0002`0002?1@008`4009D5000Y0@00100009H5906@1B@1
T0DZ0IH5:P5F0000;00008l5000_0@00U@D003D100040000UPD`0I05<06@1CH1UPDf0EH0000/0000
S`D003/1002E1@00@@4000@0002F1C`1T0Dl0I05@P6F1D81EP0002`0002?1@00A`4009D5001=0@00
100009H5B06@1DP1T0E>0IH5CP5F0000;00008l5001C0@00U@D005T100040000UPED0I05E06@1EX1
UPEJ0EH0000/0000S`D005l1002E1@00I@4000@0002F1F01T0EP0I05IP6F1FH1EP0002`0002?1@00
J`4009D5001a0@00100009H5K06@1F`1T0Eb0IH5LP5F0000;00008l5001g0@00U@D007d100040000
UPEh0I05N06@1Gh1UPEn0EH0000/0000S`D008<1002E1@00R@4000@0002F1H@1T0F40I05RP6F1HX1
EP0002`0002?1@00S`4009D5002E0@00100009H5T06@1I01T0FF0IH5UP5F0000;00008l5002K0@00
U@D00:4100040000UPFL0I05W06@1J81UPFR0EH0000/0000S`D00:L1002E1@00[@4000@0002F1JP1
T0FX0I05[P6F1Jh1EP0002`0002?1@00/`4009D5002i0@00100009H5]06@1K@1T0Fj0IH5^P5F0000
;00008l5002o0@00U@D00<D100040000UPG00I05`06@1LH1UPG60EH0000/0000S`D00</1002E1@00
d@4000@0002F1L`1T0G<0I05dP6F1M81EP0002`0002?1@00e`4009D5003M0@00100009H5f06@1MP1
T0GN0IH5gP5F0000;00008l5003S0@00U@D00>T100040000UPGT0I05i06@1NX1UPGZ0EH0000/0000
S`D00>l1002E1@00m@4000@0002F1O01T0G`0I05mP6F1OH1EP0002`0002?1@00n`4009D500010P00
100009H5o06@1O`1T0D20YH50P9F0000;00008l500070P00U@D000d200040000UPD80Y0520:@1@h2
UPD>0UH0000/0000U@D000d2002K1@004`8000@0002F1@h2UPDD0Y`550:L1@h2EP0002`0002Q1@00
3@800:L5000C0P0010000:853P:R1A@2Z0DD0ZP53P9F0000;0000:d5000=0P00/`D001<200040000
[PD>0Zh550:d1A@2]0D>0UH0000/0000^@D000d2002o1@004`8000@0002j1@h2^PDD0/0550;01@h2
EP0002`000351@003@800</5000C0P0010000<H53P;61A@2c0DD0/`53P9F0000;0000=45000=0P00
e`D001<200040000dPD>0]8550;H1A@2f0D>0UH0000/0000g@D000d2003S1@004`8000@0003N1@h2
gPDD0^@550;T1@h2EP0002`0003Y1@003@800>l5000C0P0010000>X53P;Z1A@2l0DD0_053P9F0000
;0000?D5000=0P00n`D001<200040000mPD>0_H550;l1A@2o0D>0UH0000/00000@H000d200071P00
4`8000@000021Ph20PHD0PP650881Ph2EP0002`0000=1P003@8001<6000C0P00100000h63P8>1Q@2
50HD0Q@63P9F0000;00001T6000=0P007`H001<2000400006PH>0QX6508P1Q@280H>0UH0000/0000
9@H000d2000[1P004`8000@0000V1Ph29PHD0R`6508/1Ph2EP0002`0000a1P003@8003L6000C0P00
100003863P8b1Q@2>0HD0SP63P9F0000;00003d6000=0P00@`H001<200040000?PH>0Sh650941Q@2
A0H>0UH0000/0000B@H000d2001?1P004`8000@0001:1Ph2BPHD0U06509@1Ph2EP0002`0001E1P00
3@8005/6000C0P00100005H63P9F1Q@2G0HD0U`63P9F0000;0000646000=0P00I`H001<200040000
HPH>0V86509X1Q@2J0H>0UH0000/0000K@H000d2001c1P004`8000@0001^1Ph2KPHD0W@6509d1Ph2
EP0002`0001i1P003@8007l6000C0P00100007X63P9j1Q@2P0HD0X063P9F0000;00008D6000=0P00
R`H001<200040000QPH>0XH650:<1Q@2S0H>0UH0000/0000T@H000d2002G1P004`8000@0002B1Ph2
TPHD0YP650:H1Ph2EP0002`0002M1P003@800:<6000C0P00100009h63P:N1Q@2Y0HD0Z@63P9F0000
;0000:T6000=0P00[`H001<200040000ZPH>0ZX650:`1Q@2/0H>0UH0000/0000]@H000d2002k1P00
4`8000@0002f1Ph2]PHD0[`650:l1Ph2EP0002`000311P003@800<L6000C0P0010000<863P;21Q@2
b0HD0/P63P9F0000;0000<d6000=0P00d`H001<200040000cPH>0/h650;D1Q@2e0H>0UH0000/0000
f@H000d2003O1P004`8000@0003J1Ph2fPHD0^0650;P1Ph2EP0002`0003U1P003@800>/6000C0P00
10000>H63P;V1Q@2k0HD0^`63P9F0000;0000?46000=0P00m`H001<200040000lPH>0_8650;h1Q@2
n0H>0UH0000/0000o@H000d200031`004`8000@0003n1Ph2oPHD0P@750841`h2EP0002`000091`00
3@8000l7000C0P00100000X73P8:1a@240LD0Q073P9F0000;00001D7000=0P006`L001<200040000
5PL>0QH7508L1a@270L>0UH0000/00008@L000d2000W1`004`8000@0000R1`h28PLD0RP7508X1`h2
EP0002`0000]1`003@8003<7000C0P00100002h73P8^1a@2=0LD0S@73P9F0000;00003T7000=0P00
?`L001<200040000>PL>0SX750901a@2@0L>0UH0000/0000A@L000d2001;1`004`8000@000161`h2
APLD0T`7509<1`h2EP0002`0001A1`003@8005L7000C0P00100005873P9B1a@2F0LD0UP73P9F0000
;00005d7000=0P00H`L001<200040000GPL>0Uh7509T1a@2I0L>0UH0000/0000J@L000d2001_1`00
4`8000@0001Z1`h2JPLD0W07509`1`h2EP0002`0001e1`003@8007/7000C0P00100007H73P9f1a@2
O0LD0W`73P9F0000;0000847000=0P00Q`L001<200040000PPL>0X8750:81a@2R0L>0UH0000/0000
S@L000d2002C1`004`8000@0002>1`h2SPLD0Y@750:D1`h2EP0002`0002I1`003@8009l7000C0P00
100009X73P:J1a@2X0LD0Z073P9F0000;0000:D7000=0P00Z`L001<200040000YPL>0ZH750:/1a@2
[0L>0UH0000/0000/@L000d2002g1`004`8000@0002b1`h2/PLD0[P750:h1`h2EP0002`0002m1`00
3@800<<7000C0P0010000;h73P:n1a@2a0LD0/@73P9F0000;0000<T7000=0P00c`L001<200040000
bPL>0/X750;@1a@2d0L>0UH0000/0000e@L000d2003K1`004`8000@0003F1`h2ePLD0]`750;L1`h2
EP0002`0003Q1`003@800>L7000C0P0010000>873P;R1a@2j0LD0^P73P9F0000;0000>d7000=0P00
l`L001<200040000kPL>0^h750;d1a@2m0L>0UH0000/0000n@L000d2003o1`004`8000@0003j1`h2
nPLD0P08508020h2EP0002`0000520003@8000/8000C0P00100000H83P8621@230PD0P`83P9F0000
;0000148000=0P005`P001<2000400004PP>0Q88508H21@260P>0UH0000/00007@P000d2000S2000
4`8000@0000N20h27PPD0R@8508T20h2EP0002`0000Y20003@8002l8000C0P00100002X83P8Z21@2
<0PD0S083P9F0000;00003D8000=0P00>`P001<200040000=PP>0SH8508l21@2?0P>0UH0000/0000
@@P000d2001720004`8000@0001220h2@PPD0TP8509820h2EP0002`0001=20003@8005<8000C0P00
100004h83P9>21@2E0PD0U@83P9F0000;00005T8000=0P00G`P001<200040000FPP>0UX8509P21@2
H0P>0UH0000/0000I@P000d2001[20004`8000@0001V20h2IPPD0V`8509/20h2EP0002`0001a2000
3@8007L8000C0P00100007883P9b21@2N0PD0WP83P9F0000;00007d8000=0P00P`P001<200040000
OPP>0Wh850:421@2Q0P>0UH0000/0000R@P000d2002?20004`8000@0002:20h2RPPD0Y0850:@20h2
EP0002`0002E20003@8009/8000C0P00100009H83P:F21@2W0PD0Y`83P9F0000;0000:48000=0P00
Y`P001<200040000XPP>0Z8850:X21@2Z0P>0UH0000/0000[@P000d2002c20004`8000@0002^20h2
[PPD0[@850:d20h2EP0002`0002i20003@800;l8000C0P0010000;X83P:j21@2`0PD0/083P9F0000
;0000<D8000=0P00b`P001<200040000aPP>0/H850;<21@2c0P>0UH0000/0000d@P000d2003G2000
4`8000@0003B20h2dPPD0]P850;H20h2EP0002`0003M20003@800><8000C0P0010000=h83P;N21@2
i0PD0^@83P9F0000;0000>T8000=0P00k`P001<200040000jPP>0^X850;`21@2l0P>0UH0000/0000
m@P000d2003k20004`8000@0003f20h2mPPD0_`850;l20h2EP0002`000012@003@8000L9000C0P00
100000893P822A@220TD0PP93P9F0000;00000d9000=0P004`T001<2000400003PT>0Ph9508D2A@2
50T>0UH0000/00006@T000d2000O2@004`8000@0000J2@h26PTD0R09508P2@h2EP0002`0000U2@00
3@8002/9000C0P00100002H93P8V2A@2;0TD0R`93P9F0000;0000349000=0P00=`T001<200040000
<PT>0S89508h2A@2>0T>0UH0000/0000?@T000d200132@004`8000@0000n2@h2?PTD0T@950942@h2
EP0002`000192@003@8004l9000C0P00100004X93P9:2A@2D0TD0U093P9F0000;00005D9000=0P00
F`T001<200040000EPT>0UH9509L2A@2G0T>0UH0000/0000H@T000d2001W2@004`8000@0001R2@h2
HPTD0VP9509X2@h2EP0002`0001]2@003@8007<9000C0P00100006h93P9^2A@2M0TD0W@93P9F0000
;00007T9000=0P00O`T001<200040000NPT>0WX950:02A@2P0T>0UH0000/0000Q@T000d2002;2@00
4`8000@000262@h2QPTD0X`950:<2@h2EP0002`0002A2@003@8009L9000C0P00100009893P:B2A@2
V0TD0YP93P9F0000;00009d9000=0P00X`T001<200040000WPT>0Yh950:T2A@2Y0T>0UH0000/0000
Z@T000d2002_2@004`8000@0002Z2@h2ZPTD0[0950:`2@h2EP0002`0002e2@003@800;/9000C0P00
10000;H93P:f2A@2_0TD0[`93P9F0000;0000<49000=0P00a`T001<200040000`PT>0/8950;82A@2
b0T>0UH0000/0000c@T000d2003C2@004`8000@0003>2@h2cPTD0]@950;D2@h2EP0002`0003I2@00
3@800=l9000C0P0010000=X93P;J2A@2h0TD0^093P9F0000;0000>D9000=0P00j`T001<200040000
iPT>0^H950;/2A@2k0T>0UH0000/0000l@T000d2003g2@004`8000@0003b2@h2lPTD0_P950;h2@h2
EP0002`0003m2@003@8000<:000C0P0010000?h93P;n2A@210XD0P@:3P9F0000;00000T:000=0P00
3`X001<2000400002PX>0PX:508@2Q@240X>0UH0000/00005@X000d2000K2P004`8000@0000F2Ph2
5PXD0Q`:508L2Ph2EP0002`0000Q2P003@8002L:000C0P001000028:3P8R2Q@2:0XD0RP:3P9F0000
;00002d:000=0P00<`X001<200040000;PX>0Rh:508d2Q@2=0X>0UH0000/0000>@X000d2000o2P00
4`8000@0000j2Ph2>PXD0T0:50902Ph2EP0002`000152P003@8004/:000C0P00100004H:3P962Q@2
C0XD0T`:3P9F0000;000054:000=0P00E`X001<200040000DPX>0U8:509H2Q@2F0X>0UH0000/0000
G@X000d2001S2P004`8000@0001N2Ph2GPXD0V@:509T2Ph2EP0002`0001Y2P003@8006l:000C0P00
100006X:3P9Z2Q@2L0XD0W0:3P9F0000;00007D:000=0P00N`X001<200040000MPX>0WH:509l2Q@2
O0X>0UH0000/0000P@X000d200272P004`8000@000222Ph2PPXD0XP:50:82Ph2EP0002`0002=2P00
3@8009<:000C0P00100008h:3P:>2Q@2U0XD0Y@:3P9F0000;00009T:000=0P00W`X001<200040000
VPX>0YX:50:P2Q@2X0X>0UH0000/0000Y@X000d2002[2P004`8000@0002V2Ph2YPXD0Z`:50:/2Ph2
EP0002`0002a2P003@800;L:000C0P0010000;8:3P:b2Q@2^0XD0[P:3P9F0000;0000;d:000=0P00
``X001<200040000_PX>0[h:50;42Q@2a0X>0UH0000/0000b@X000d2003?2P004`8000@0003:2Ph2
bPXD0]0:50;@2Ph2EP0004@0003E2P003@800=/:000C0P002P000=H:3P;F2Q@2f@XD0]`:50;L2Q42
g0X>0]H:3P;F2Q42f@XA0]T:3P9F0000;0000=D:00010P00f`X000L200040000ePX80]`:20;L2P82
ePX20UH0000/0000e@X00?D1003K2P00n`4000@0003F2_`1g0[l0M`:mP7F2_H1EP0002`0003E2P00
j@400=/:003_0@0010000=H:l07L2_01g0[Z0MH:jP5F0000;0000=D:003M0@00f`X00><100040000
eP[T0M`:i07L2]h1eP[N0EH0000/0000e@X00=41003K2P00e`4000@0003F2]P1g0[H0M`:dP7F2]81
EP0002`0003E2P00a@400=/:003;0@0010000=H:c07L2/`1g0[60MH:aP5F0000;0000=D:002i0@00
f`X00;l100040000eP[00M`:`07L2[X1ePZj0EH0000/0000e@X00:d1003K2P00/`4000@0003F2[@1
g0Zd0M`:[P7F2Zh1EP0002`0003E2P00X@400=/:002W0@0010000=H:Z07L2ZP1g0ZR0MH:XP5F0000
;0000=D:002E0@00f`X009/100040000ePZL0M`:W07L2YH1ePZF0EH0000/0000e@X008T1003K2P00
S`4000@0003F2Y01g0Z@0M`:RP7F2XX1EP0002`0003E2P00O@400=/:00230@0010000=H:Q07L2X@1
g0Yn0MH:OP5F0000;0000=D:001a0@00f`X007L100040000ePYh0M`:N07L2W81ePYb0EH0000/0000
e@X006D1003K2P00J`4000@0003F2V`1g0Y/0M`:IP7F2VH1EP0002`0003E2P00F@400=/:001O0@00
10000=H:H07L2V01g0YJ0MH:FP5F0000;0000=D:001=0@00f`X005<100040000ePYD0M`:E07L2Th1
ePY>0EH0000/0000e@X00441003K2P00A`4000@0003F2TP1g0Y80M`:@P7F2T81EP0002`0003E2P00
=@400=/:000k0@0010000=H:?07L2S`1g0Xf0MH:=P5F0000;0000=D:000Y0@00f`X002l100040000
ePX`0M`:<07L2RX1ePXZ0EH0000/0000e@X001d1003K2P008`4000@0003F2R@1g0XT0M`:7P7F2Qh1
EP0002`0003E2P004@400=/:000G0@0010000=H:607L2QP1g0XB0MH:4P5F0000;0000=D:00050@00
f`X000/100040000ePX<0M`:307L2PH1ePX60EH0000/0000e@X00?T0003K2P00o`0000@0003F2P01
g0X00M`:nP3F2_X0EP0002`0003E2P00k@000=/:003c000010000=H:m03L2_@0g0[^0=H:kP1F0000
;0000=D:003Q0000f`X00>L000040000eP[X0=`:j03L2^80eP[R05H0000/0000e@X00=D0003K2P00
f`0000@0003F2]`0g0[L0=`:eP3F2]H0EP0002`0003E2P00b@000=/:003?000010000=H:d03L2]00
g0[:0=H:bP1F0000;0000=D:002m0000f`X00<<000040000eP[40=`:a03L2[h0ePZn05H0000/0000
e@X00;40003K2P00]`0000@0003F2[P0g0Zh0=`:/P3F2[80EP0002`0003E2P00Y@000=/:002[0000
10000=H:[03L2Z`0g0ZV0=H:YP1F0000;0000=D:002I0000f`X009l000040000ePZP0=`:X03L2YX0
ePZJ05H0000/0000e@X008d0003K2P00T`0000@0003F2Y@0g0ZD0=`:SP3F2Xh0EP0002`0003E2P00
P@000=/:0027000010000=H:R03L2XP0g0Z20=H:PP1F0000;0000=D:001e0000f`X007/000040000
ePYl0=`:O03L2WH0ePYf05H0000/0000e@X006T0003K2P00K`0000@0003F2W00g0Y`0=`:JP3F2VX0
EP0002`0003E2P00G@000=/:001S000010000=H:I03L2V@0g0YN0=H:GP1F0000;0000=D:001A0000
f`X005L000040000ePYH0=`:F03L2U80ePYB05H0000/0000e@X004D0003K2P00B`0000@0003F2T`0
g0Y<0=`:AP3F2TH0EP0002`0003E2P00>@000=/:000o000010000=H:@03L2T00g0Xj0=H:>P1F0000
;0000=D:000]0000f`X003<000040000ePXd0=`:=03L2Rh0ePX^05H0000/0000e@X00240003K2P00
9`0000@0003F2RP0g0XX0=`:8P3F2R80EP0002`0003E2P005@000=/:000K000010000=H:703L2Q`0
g0XF0=H:5P1F0000;0000=D:00090000f`X000l000040000ePX@0=`:403L2PX0ePX:05H0000/0000
dPX00000003H2P001P0000@0003I2PL0f@X10=<:0@3C2PL0EP0002`000362P0000000<`:00060000
10000<d:1`3=2P40a`X10<L:1`1F0000;0000;X:00000000`0X000H000040000`@X70<4:0@2k2P40
^`X705H0000/0000[PX00000002d2P001P0000@0002e2PL0]@X10:l:0@2_2PL0EP0002`0002R2P00
00000:P:0006000010000:T:1`2Y2P40X`X10:<:1`1F0000;00009H:00000000W0X000H000040000
W@X709d:0@2G2P40U`X705H0000/0000RPX00000002@2P001P0000@0002A2PL0T@X108/:0@2;2PL0
EP0002`0001n2P00000008@:00060000100008D:1`252P40O`X107l:1`1F0000;000078:00000000
N0X000H000040000N@X707T:0@1c2P40L`X705H0000/0000IPX00000001/2P001P0000@0001]2PL0
K@X106L:0@1W2PL0EP0002`0001J2P000000060:000600001000064:1`1Q2P40F`X105/:1`1F0000
;00004h:00000000E0X000H000040000E@X705D:0@1?2P40C`X705H0000/0000@PX0000000182P00
1P0000@000192PL0B@X104<:0@132PL0EP0002`0000f2P00000003`:00060000100003d:1`0m2P40
=`X103L:1`1F0000;00002X:00000000<0X000H000040000<@X7034:0@0[2P40:`X705H0000/0000
7PX00000000T2P001P0000@0000U2PL09@X101l:0@0O2PL0EP0002`0000B2P00000001P:00060000
100001T:1`0I2P404`X101<:1`1F0000;00000H:0000000030X000H0000400003@X700d:0@072P40
1`X705H0000/0000nPT0000000002P001P0000@000012PL00@X10?/90@3k2@L0EP0002`0003^2@00
00000?@90006000010000?D91`3e2@40k`T10>l91`1F0000;0000>8900000000j0T000H000040000
j@T70>T90@3S2@40h`T705H0000/0000ePT00000003L2@001P0000@0003M2@L0g@T10=L90@3G2@L0
EP0002`0003:2@0000000=090006000010000=491`3A2@40b`T10</91`1F0000;0000;h900000000
a0T000H000040000a@T70<D90@2o2@40_`T705H0000/0000/PT00000002h2@001P0000@0002i2@L0
^@T10;<90@2c2@L0EP0002`0002V2@0000000:`90006000010000:d91`2]2@40Y`T10:L91`1F0000
;00009X900000000X0T000H000040000X@T70:490@2K2@40V`T705H0000/0000SPT00000002D2@00
1P0000@0002E2@L0U@T108l90@2?2@L0EP0002`000222@00000008P900060000100008T91`292@40
P`T108<91`1F0000;00007H900000000O0T000H000040000O@T707d90@1g2@40M`T705H0000/0000
JPT00000001`2@001P0000@0001a2@L0L@T106/90@1[2@L0EP0002`0001N2@00000006@900060000
100006D91`1U2@40G`T105l91`1F0000;000058900000000F0T000H000040000F@T705T90@1C2@40
D`T705H0000/0000APT00000001<2@001P0000@0001=2@L0C@T104L90@172@L0EP0002`0000j2@00
0000040900060000100004491`112@40>`T103/91`1F0000;00002h900000000=0T000H000040000
=@T703D90@0_2@40;`T705H0000/00008PT00000000X2@001P0000@0000Y2@L0:@T102<90@0S2@L0
EP0002`0000F2@00000001`900060000100001d91`0M2@405`T101L91`1F0000;00000X900000000
40T000H0000400004@T701490@0;2@402`T705H0000/0000oPP0000000042@001P0000@000052@L0
1@T10?l80@3o20L0EP0002`0003b200000000?P80006000010000?T81`3i2040l`P10?<81`1F0000
;0000>H800000000k0P000H000040000k@P70>d80@3W2040i`P705H0000/0000fPP00000003P2000
1P0000@0003Q20L0h@P10=/80@3K20L0EP0002`0003>200000000=@80006000010000=D81`3E2040
c`P10<l81`1F0000;0000<8800000000b0P000H000040000b@P70<T80@332040``P705H0000/0000
]PP00000002l20001P0000@0002m20L0_@P10;L80@2g20L0EP0002`0002Z200000000;0800060000
10000;481`2a2040Z`P10:/81`1F0000;00009h800000000Y0P000H000040000Y@P70:D80@2O2040
W`P705H0000/0000TPP00000002H20001P0000@0002I20L0V@P109<80@2C20L0EP0002`000262000
000008`800060000100008d81`2=2040Q`P108L81`1F0000;00007X800000000P0P000H000040000
P@P708480@1k2040N`P705H0000/0000KPP00000001d20001P0000@0001e20L0M@P106l80@1_20L0
EP0002`0001R2000000006P800060000100006T81`1Y2040H`P106<81`1F0000;00005H800000000
G0P000H000040000G@P705d80@1G2040E`P705H0000/0000BPP00000001@20001P0000@0001A20L0
D@P104/80@1;20L0EP0002`0000n2000000004@800060000100004D81`152040?`P103l81`1F0000
;000038800000000>0P000H000040000>@P703T80@0c2040<`P705H0000/00009PP00000000/2000
1P0000@0000]20L0;@P102L80@0W20L0EP0002`0000J20000000020800060000100002481`0Q2040
6`P101/81`1F0000;00000h80000000050P000H0000400005@P701D80@0?20403`P705H0000/0000
0PP00000000820001P0000@0000920L02@P100<80@0320L0EP0002`0003f1`0000000?`700060000
10000?d71`3m1`40m`L10?L71`1F0000;0000>X700000000l0L000H000040000l@L70?470@3[1`40
j`L705H0000/0000gPL00000003T1`001P0000@0003U1`L0i@L10=l70@3O1`L0EP0002`0003B1`00
00000=P70006000010000=T71`3I1`40d`L10=<71`1F0000;0000<H700000000c0L000H000040000
c@L70<d70@371`40a`L705H0000/0000^PL0000000301`001P0000@000311`L0`@L10;/70@2k1`L0
EP0002`0002^1`0000000;@70006000010000;D71`2e1`40[`L10:l71`1F0000;0000:8700000000
Z0L000H000040000Z@L70:T70@2S1`40X`L705H0000/0000UPL00000002L1`001P0000@0002M1`L0
W@L109L70@2G1`L0EP0002`0002:1`000000090700060000100009471`2A1`40R`L108/71`1F0000
;00007h700000000Q0L000H000040000Q@L708D70@1o1`40O`L705H0000/0000LPL00000001h1`00
1P0000@0001i1`L0N@L107<70@1c1`L0EP0002`0001V1`00000006`700060000100006d71`1]1`40
I`L106L71`1F0000;00005X700000000H0L000H000040000H@L706470@1K1`40F`L705H0000/0000
CPL00000001D1`001P0000@0001E1`L0E@L104l70@1?1`L0EP0002`000121`00000004P700060000
100004T71`191`40@`L104<71`1F0000;00003H700000000?0L000H000040000?@L703d70@0g1`40
=`L705H0000/0000:PL00000000`1`001P0000@0000a1`L0<@L102/70@0[1`L0EP0002`0000N1`00
000002@700060000100002D71`0U1`407`L101l71`1F0000;00001870000000060L000H000040000
6@L701T70@0C1`404`L705H0000/00001PL00000000<1`001P0000@0000=1`L03@L100L70@071`L0
EP0002`0003j1P000000000700060000100000471`011`40n`H10?/61`1F0000;0000>h600000000
m0H000H000040000m@H70?D60@3_1P40k`H705H0000/0000hPH00000003X1P001P0000@0003Y1PL0
j@H10><60@3S1PL0EP0002`0003F1P0000000=`60006000010000=d61`3M1P40e`H10=L61`1F0000
;0000<X600000000d0H000H000040000d@H70=460@3;1P40b`H705H0000/0000_PH0000000341P00
1P0000@000351PL0a@H10;l60@2o1PL0EP0002`0002b1P0000000;P60006000010000;T61`2i1P40
/`H10;<61`1F0000;0000:H600000000[0H000H000040000[@H70:d60@2W1P40Y`H705H0000/0000
VPH00000002P1P001P0000@0002Q1PL0X@H109/60@2K1PL0EP0002`0002>1P00000009@600060000
100009D61`2E1P40S`H108l61`1F0000;000088600000000R0H000H000040000R@H708T60@231P40
P`H705H0000/0000MPH00000001l1P001P0000@0001m1PL0O@H107L60@1g1PL0EP0002`0001Z1P00
0000070600060000100007461`1a1P40J`H106/61`1F0000;00005h600000000I0H000H000040000
I@H706D60@1O1P40G`H705H0000/0000DPH00000001H1P001P0000@0001I1PL0F@H105<60@1C1PL0
EP0002`000161P00000004`600060000100004d61`1=1P40A`H104L61`1F0000;00003X600000000
@0H000H000040000@@H704460@0k1P40>`H705H0000/0000;PH00000000d1P001P0000@0000e1PL0
=@H102l60@0_1PL0EP0002`0000R1P00000002P600060000100002T61`0Y1P408`H102<61`1F0000
;00001H60000000070H000H0000400007@H701d60@0G1P405`H705H0000/00002PH00000000@1P00
1P0000@0000A1PL04@H100/60@0;1PL0EP0002`0003n1@00000000@600060000100000D61`051P40
o`D10?l51`1F0000;0000?8500000000n0D000H000040000n@D70?T50@3c1@40l`D705H0000/0000
iPD00000003/1@001P0000@0003]1@L0k@D10>L50@3W1@L0EP0002`0003J1@0000000>0500060000
10000>451`3Q1@40f`D10=/51`1F0000;0000<h500000000e0D000H000040000e@D70=D50@3?1@40
c`D705H0000/0000`PD0000000381@001P0000@000391@L0b@D10<<50@331@L0EP0002`0002f1@00
00000;`50006000010000;d51`2m1@40]`D10;L51`1F0000;0000:X500000000/0D000H000040000
/@D70;450@2[1@40Z`D705H0000/0000WPD00000002T1@001P0000@0002U1@L0Y@D109l50@2O1@L0
EP0002`0002B1@00000009P500060000100009T51`2I1@40T`D109<51`0C000030000040000<0000
40000000000000009@0000`0000700209@0000`0000000208@0000P0000N000060000=85000U0000
V`X00>l1000U000030000040001D0000^0000=45000W0000QPP009P000010000U:>7@9BSQd3B1@00
:0000180001<000010000=85000U0000VPX00>l1001`0000C`1d06P0I@1b0200L`1_06H0M00P07@0
J@1c07<0M@1U07<0B00001`0000b0000;0000240000I00009`000380000Q0000700001T0000L0000
700002L0000W0000<P0002`0000W0000E00005@0002720009`000;<8002H00000@0009BSQd2DXhM0
R0P002P000010000C00000@0003B1@009@0009X:003_0@00D0000200000]00008P0000`0003ooooo
9P0001`000020000000000H00006000000000RD0000<00000P0002D0000<00000000P2X0000H0000
g`D008L0000;1`00c`4002D0000<00001`00P2P0000<00000P0000`0000@000000000000000U0000
300000L0080U000030000000080Q0000200001h0000H0000=`H00<l0002b1P00Q`4002D0000<0000
0@0005@0001H0000=PH00=4000201P00@P400040002DXhM0U:>7@3L6003B00000P0004`000040000
=`H00<l0002a1P00Q`400500000P03@06@000380001D0000E0000846003A0000[@H0048100010000
U:>7@9BSQd221P00dP000040001<0000100003L6003?0000/@H008L1001@0000800002d0000R0000
30000?oooolV000070000080000000001P0000H0000000029@0000`0000200009@0000`000000020
:P0001P0002Q1`00Q`000<d8003?0@009@0000`000070020:00000`0000200003000010000000000
000002D0000<00001`00P2D0000<00000000P240000800007P0001P0003i1`00c`0007@800270@00
9@0000`000010000E00005P0003h1`00d@00048800120@000@0009BSQd2DXhM0n@L00=8000020000
C00000@0003i1`00c`0007<800270@00D0000200<`0I0000<P0005@0001D0000@`P00=40001_2000
@P400040002DXhM0U:>7@4@8003B00000@0004`000040000n@L00<l0001c2000Q`400500000P0000
;@000280000<0000ooooobH0000L00000P000000000600001P000000008U000030000080000U0000
30000000080Z0000600006<900270000S`X00<l1000U0000300000L0080X000030000080000<0000
40000000000000009@0000`0000700209@0000`0000000208@0000P0000N000060000;/9003?0000
=PX008L1000U000030000040001D0000F0000;X9003A000010X0048100010000U:>7@9BSQd2k2@00
dP000080001<000010000;/9003?0000=@X008L1001@0000800b01T0000b0000E00005@000052P00
d@00034:00120@000@0009BSQd2DXhM01PX00=8000010000C00000@0002k2@00c`0003D:00270@00
D0000200000]00008P0000`0003ooooo9P0001`000020000000000H000060000000002D0000<0000
0P0002D0000<00001@00P5L0000T0000<PP00<81000h2000B`<00080000f2<H1=PQ90bD0000<0000
2000P2P0000<00000P0002D0000<00002000P2D0000<00001000P5H0000X00005@P004H3001F2000
Q`<000<0000F24L3=PR80eL8A`<V000070000080000000001P0000H0000000009@0000`000020000
9@0000`000050020E`0002@0001m20000@8008<8002:0`000P000848R0>120D29@0000`000080020
:00000`0000200009@0000`0000800209@0000`000040020EP0002P0001P2000a@400:4800070P00
0`000:8820:22<H1H@P80RH0000L00000P000000000600001P000000000U000030000080000U0000
300000D0081G000090000;/600320@00b`L005H300020000_`K60LT7E0<U0000300000P0080X0000
30000080000U0000300000P0080U0000300000@0081F0000:0000:/7000o0`00j`L008L300030000
[0MT0n`7R0?R1d039P0001`000020000000000H000060000000002D0000<00000P0002D0000<0000
1@00P5L0000T0000TPH00?H1002R1`00RP<00080002P1hP3UPKj0BD0000<00002000P2P0000<0000
0P0002D0000<00002000P2D0000<00001000P5H0000X0000L`H00<D1002c1P003P8000<0002d1^/1
M0K60Gh63`8V000070000080000000001P0000H0000000009@0000`0000200009@0000`000050020
E`0002@0003U2000`P400:l9001B0`000P000:d9aP7Y25039@0000`000080020:00000`000020000
9@0000`0000800209@0000`000040020EP0002P0003;2000?P<000H900270`000`000<`8?`?<28P3
1`UL0bH0000L00000P000000000600001P000000000U000030000080000U0000300000D0081G0000
900001<9003j0@00g@T008X3000200005`V80m/9oP4U0000300000P0080X000030000080000U0000
300000P0080U0000300000@0081F0000:0000;d900350@00m`T000l200030000n0T@0_P9aP6n2O<1
9@0000`000000020C@0006`000030000F`800=h5000:1`00100005`2003L1@00/0@00240l0000000
00000000P3l0000000000000P3l00000000000000000000000000000000000000000000000000000
4`0000`0000200009@0000`0000800209@0000`000040020EP0002`000000000F`8000H0001Q0P00
100000L0G08105`20@1R0PL0HP9F0000;0000000001W0P001P0006d2000400001`1X0P40J08106h2
1`1^0UH0000/0000000007<200060000N@8000@0000707@20@1d0P40NP8707X2EP0002`000000000
O`8000H000250P00100000L0P08108020@260PL0QP9F0000;0000000002;0P001P00094200040000
1`2<0P40S08109821`2B0UH0000/0000000009L200060000W@8000@0000709P20@2H0P40WP8709h2
EP0002`000000000X`8000H0002Y0P00100000L0Y0810:@20@2Z0PL0ZP9F0000;0000000002_0P00
1P000;D2000400001`2`0P40/0810;H21`2f0UH0000/000000000;/200060000`@8000@000070;`2
0@2l0P40`P870<82EP0002`000000000a`8000H0003=0P00100000L0b0810<P20@3>0PL0cP9F0000
;0000000003C0P001P000=T2000400001`3D0P40e0810=X21`3J0UH0000/000000000=l200060000
i@8000@000070>020@3P0P40iP870>H2EP0002`000000000j`8000H0003a0P00100000L0k0810>`2
0@3b0PL0lP9F0000;0000000003g0P001P000?d2000400001`3h0P40n0810?h21`3n0UH0000/0000
000000<3000600002@<000@0000700@30@040`402P<700X3EP0002`0000000003`<000H0000E0`00
100000L040<101030@0F0`L05P=F0000;0000000000K0`001P000243000400001`0L0`4070<10283
1`0R0eH0000/0000000002L300060000;@<000@0000702P30@0X0`40;P<702h3EP0002`000000000
<`<000H0000i0`00100000L0=0<103@30@0j0`L0>P=F0000;0000000000o0`001P0004D300040000
1`100`40@0<104H31`160eH0000/0000000004/300060000D@<000@0000704`30@1<0`40DP<70583
EP0002`000000000E`<000H0001M0`00100000L0F0<105P30@1N0`L0GP=F0000;0000000001S0`00
1P0006T3000400001`1T0`40I0<106X31`1Z0eH0000/0000000006l300060000M@<000@000070703
0@1`0`40MP<707H3EP0002`000000000N`<000H000210`00100000L0O0<107`30@220`L0PP=F0000
;000000000270`001P0008d3000400001`280`40R0<108h31`2>0eH0000/0000000009<300060000
V@<000@0000709@30@2D0`40VP<709X3EP0002`000000000W`<000H0002U0`00100000L0X0<10:03
0@2V0`L0YP=F0000;0000000002[0`001P000;43000400001`2/0`40[0<10;831`2b0eH0000/0000
00000;L300060000_@<000@000070;P30@2h0`40_P<70;h3EP0002`000000000``<000H000390`00
100000L0a0<10<@30@3:0`L0bP=F0000;0000000003?0`001P000=D3000400001`3@0`40d0<10=H3
1`3F0eH0000/000000000=/300060000h@<000@000070=`30@3L0`40hP<70>83EP0002`000000000
i`<000H0003]0`00100000L0j0<10>P30@3^0`L0kP=F0000;0000000003c0`001P000?T300040000
1`3d0`40m0<10?X31`3j0eH0000/000000000?l3000600001@@000@0000700040@0010401P@700H4
EP0002`0000000002`@000H0000A1000100000L030@100`40@0B10L04PAF0000;0000000000G1000
1P0001d4000400001`0H104060@101h41`0N15H0000/0000000002<400060000:@@000@0000702@4
0@0T1040:P@702X4EP0002`000000000;`@000H0000e1000100000L0<0@103040@0f10L0=PAF0000
;0000000000k10001P000444000400001`0l1040?0@104841`1215H0000/0000000004L400060000
C@@000@0000704P40@181040CP@704h4EP0002`000000000D`@000H0001I1000100000L0E0@105@4
0@1J10L0FPAF0000;0000000001O10001P0006D4000400001`1P1040H0@106H41`1V15H0000/0000
000006/400060000L@@000@0000706`40@1/1040LP@70784EP0002`000000000M`@000H0001m1000
100000L0N0@107P40@1n10L0OPAF0000;0000000002310001P0008T4000400001`241040Q0@108X4
1`2:15H0000/0000000008l400060000U@@000@0000709040@2@1040UP@709H4EP0002`000000000
V`@000H0002Q1000100000L0W0@109`40@2R10L0XPAF0000;0000000002W10001P000:d400040000
1`2X1040Z0@10:h41`2^15H0000/000000000;<400060000^@@000@000070;@40@2d1040^P@70;X4
EP0002`000000000_`@000H000351000100000L0`0@10<040@3610L0aPAF0000;0000000003;1000
1P000=44000400001`3<1040c0@10=841`3B15H0000/000000000=L400060000g@@000@000070=P4
0@3H1040gP@70=h4EP0002`000000000h`@000H0003Y1000100000L0i0@10>@40@3Z10L0jPAF0000
;0000000003_10001P000?D4000400001`3`1040l0@10?H41`3f15H0000/000000000?/400060000
0@D000@000070?`40@3l10400PD70085EP0002`0000000001`D000H0000=1@00100000L020D100P5
0@0>1@L03PEF0000;0000000000C1@001P0001T5000400001`0D1@4050D101X51`0J1EH0000/0000
000001l5000600009@D000@0000702050@0P1@409PD702H5EP0002`000000000:`D000H0000a1@00
100000L0;0D102`50@0b1@L0<PEF0000;0000000000g1@001P0003d5000400001`0h1@40>0D103h5
1`0n1EH0000/0000000004<500060000B@D000@0000704@50@141@40BPD704X5EP0002`000000000
C`D000H0001E1@00100000L0D0D105050@1F1@L0EPEF0000;0000000001K1@001P00064500040000
1`1L1@40G0D106851`1R1EH0000/0000000006L500060000K@D000@0000706P50@1X1@40KPD706h5
EP0002`000000000L`D000H0001i1@00100000L0M0D107@50@1j1@L0NPEF0000;0000000001o1@00
1P0008D5000400001`201@40P0D108H51`261EH0000/0000000008/500060000T@D000@0000708`5
0@2<1@40TPD70985EP0002`000000000U`D000H0002M1@00100000L0V0D109P50@2N1@L0WPEF0000
;0000000002S1@001P000:T5000400001`2T1@40Y0D10:X51`2Z1EH0000/000000000:l500060000
]@D000@000070;050@2`1@40]PD70;H5EP0002`000000000^`D000H000311@00100000L0_0D10;`5
0@321@L0`PEF0000;000000000371@001P000<d5000400001`381@40b0D10<h51`3>1EH0000/0000
00000=<500060000f@D000@000070=@50@3D1@40fPD70=X5EP0002`000000000g`D000H0003U1@00
100000L0h0D10>050@3V1@L0iPEF0000;0000000003[1@001P000?45000400001`3/1@40k0D10?85
1`3b1EH0000/000000000?L500060000o@D000@000070?P50@3h1@40oPD70?h5EP0002`000000000
0`H000H000091P00100000L010H100@60@0:1PL02PIF0000;0000000000?1P001P0001D600040000
1`0@1P4040H101H61`0F1UH0000/0000000001/6000600008@H000@0000701`60@0L1P408PH70286
EP0002`0000000009`H000H0000]1P00100000L0:0H102P60@0^1PL0;PIF0000;0000000000c1P00
1P0003T6000400001`0d1P40=0H103X61`0j1UH0000/0000000003l600060000A@H000@000070406
0@101P40APH704H6EP0002`000000000B`H000H0001A1P00100000L0C0H104`60@1B1PL0DPIF0000
;0000000001G1P001P0005d6000400001`1H1P40F0H105h61`1N1UH0000/0000000006<600060000
J@H000@0000706@60@1T1P40JPH706X6EP0002`000000000K`H000H0001e1P00100000L0L0H10706
0@1f1PL0MPIF0000;0000000001k1P001P000846000400001`1l1P40O0H108861`221UH0000/0000
000008L600060000S@H000@0000708P60@281P40SPH708h6EP0002`000000000T`H000H0002I1P00
100000L0U0H109@60@2J1PL0VPIF0000;0000000002O1P001P000:D6000400001`2P1P40X0H10:H6
1`2V1UH0000/000000000:/600060000/@H000@000070:`60@2/1P40/PH70;86EP0002`000000000
]`H000H0002m1P00100000L0^0H10;P60@2n1PL0_PIF0000;000000000331P001P000<T600040000
1`341P40a0H10<X61`3:1UH0000/000000000<l600060000e@H000@000070=060@3@1P40ePH70=H6
EP0002`000000000f`H000H0003Q1P00100000L0g0H10=`60@3R1PL0hPIF0000;0000000003W1P00
1P000>d6000400001`3X1P40j0H10>h61`3^1UH0000/000000000?<600060000n@H000@000070?@6
0@3d1P40nPH70?X6EP0002`000000000o`H000H000051`00100000L000L100070@061`L01PMF0000
;00000<000081`002@0000h70004000010091`@03`L:00l72P091eH0000/00003`0000P7000E0000
3PL000@0000@00T7400?1aH03`LF00T7EP0002`0000K000020L00240000>1`00100001`02@LL00l7
8P0?1b802@MF0000;00002L000081`00;@0000h700040000:0091bP03`L^00l7;P091eH0000/0000
<`0000P7000i00003PL000@0000d00T7=00?1cX03`Lj00T7EP0002`0000o000020L004D0000>1`00
100004002@M000l7AP0?1dH02@MF0000;00004/000081`00D@0000h700040000C0091d`03`MB00l7
DP091eH0000/0000E`0000P7001M00003PL000@0001H00T7F00?1eh03`MN00T7EP0002`0001S0000
20L006T0000>1`00100006@02@MT00l7JP0?1fX02@MF0000;00006l000081`00M@0000h700040000
L0091g003`Mf00l7MP091eH0000/0000N`0000P7002100003PL000@0001l00T7O00?1h803`N200T7
EP0002`00027000020L008d0000>1`00100008P02@N800l7SP0?1hh02@MF0000;00009<000081`00
V@0000h700040000U0091i@03`NJ00l7VP091eH0000/0000W`0000P7002U00003PL000@0002P00T7
X00?1jH03`NV00T7EP0002`0002[000020L00;40000>1`0010000:`02@N/00l7/P0?1k802@MF0000
;0000;L000081`00_@0000h700040000^0091kP03`Nn00l7_P091eH0000/0000``0000P700390000
3PL000@0003400T7a00?1lX03`O:00T7EP0002`0003?000020L00=D0000>1`0010000=002@O@00l7
eP0?1mH02@MF0000;0000=/000081`00h@0000h700040000g0091m`03`OR00l7hP091eH0000/0000
i`0000P7003]00003PL000@0003X00T7j00?1nh03`O^00T7EP0002`0003c000020L00?T0000>1`00
10000?@02@Od00l7nP0?1oX02@MF0000;0000?l000081`001@4000h70004000000491`013`L60@l7
1P491eH0000/00002`4000P7000A0@003PL000@0000<0@T7304?1a813`LB0@T7EP0002`0000G0@00
20L001d1000>1`00100001P12@LH0@l77P4?1ah12@MF0000;00002<100081`00:@4000h700040000
90491b@13`LZ0@l7:P491eH0000/0000;`4000P7000e0@003PL000@0000`0@T7<04?1cH13`Lf0@T7
EP0002`0000k0@0020L00441000>1`00100003`12@Ll0@l7@P4?1d812@MF0000;00004L100081`00
C@4000h700040000B0491dP13`M>0@l7CP491eH0000/0000D`4000P7001I0@003PL000@0001D0@T7
E04?1eX13`MJ0@T7EP0002`0001O0@0020L006D1000>1`00100006012@MP0@l7IP4?1fH12@MF0000
;00006/100081`00L@4000h700040000K0491f`13`Mb0@l7LP491eH0000/0000M`4000P7001m0@00
3PL000@0001h0@T7N04?1gh13`Mn0@T7EP0002`000230@0020L008T1000>1`00100008@12@N40@l7
RP4?1hX12@MF0000;00008l100081`00U@4000h700040000T0491i013`NF0@l7UP491eH0000/0000
V`4000P7002Q0@003PL000@0002L0@T7W04?1j813`NR0@T7EP0002`0002W0@0020L00:d1000>1`00
10000:P12@NX0@l7[P4?1jh12@MF0000;0000;<100081`00^@4000h700040000]0491k@13`Nj0@l7
^P491eH0000/0000_`4000P700350@003PL000@000300@T7`04?1lH13`O60@T7EP0002`0003;0@00
20L00=41000>1`0010000<`12@O<0@l7dP4?1m812@MF0000;0000=L100081`00g@4000h700040000
f0491mP13`ON0@l7gP491eH0000/0000h`4000P7003Y0@003PL000@0003T0@T7i04?1nX13`OZ0@T7
EP0002`0003_0@0020L00?D1000>1`0010000?012@O`0@l7mP4?1oH12@MF0000;0000?/100081`00
0@8000h700040000o0491o`13`L20Pl70P891eH0000/00001`8000P7000=0P003PL000@000080PT7
208?1`h23`L>0PT7EP0002`0000C0P0020L001T2000>1`00100001@22@LD0Pl76P8?1aX22@MF0000
;00001l200081`009@8000h70004000080891b023`LV0Pl79P891eH0000/0000:`8000P7000a0P00
3PL000@0000/0PT7;08?1c823`Lb0PT7EP0002`0000g0P0020L003d2000>1`00100003P22@Lh0Pl7
?P8?1ch22@MF0000;00004<200081`00B@8000h700040000A0891d@23`M:0Pl7BP891eH0000/0000
C`8000P7001E0P003PL000@0001@0PT7D08?1eH23`MF0PT7EP0002`0001K0P0020L00642000>1`00
100005`22@ML0Pl7HP8?1f822@MF0000;00006L200081`00K@8000h700040000J0891fP23`M^0Pl7
KP891eH0000/0000L`8000P7001i0P003PL000@0001d0PT7M08?1gX23`Mj0PT7EP0002`0001o0P00
20L008D2000>1`00100008022@N00Pl7QP8?1hH22@MF0000;00008/200081`00T@8000h700040000
S0891h`23`NB0Pl7TP891eH0000/0000U`8000P7002M0P003PL000@0002H0PT7V08?1ih23`NN0PT7
EP0002`0002S0P0020L00:T2000>1`0010000:@22@NT0Pl7ZP8?1jX22@MF0000;0000:l200081`00
]@8000h700040000/0891k023`Nf0Pl7]P891eH0000/0000^`8000P700310P003PL000@0002l0PT7
_08?1l823`O20PT7EP0002`000370P0020L00<d2000>1`0010000<P22@O80Pl7cP8?1lh22@MF0000
;0000=<200081`00f@8000h700040000e0891m@23`OJ0Pl7fP891eH0000/0000g`8000P7003U0P00
3PL000@0003P0PT7h08?1nH23`OV0PT7EP0002`0003[0P0020L00?42000>1`0010000>`22@O/0Pl7
lP8?1o822@MF0000;0000?L200081`00o@8000h700040000n0891oP23`On0Pl7oP891eH0000/0000
0`<000P700090`003PL000@000040`T710<?1`X33`L:0`T7EP0002`0000?0`0020L001D3000>1`00
100001032@L@0`l75P<?1aH32@MF0000;00001/300081`008@<000h70004000070<91a`33`LR0`l7
8P<91eH0000/00009`<000P7000]0`003PL000@0000X0`T7:0<?1bh33`L^0`T7EP0002`0000c0`00
20L003T3000>1`00100003@32@Ld0`l7>P<?1cX32@MF0000;00003l300081`00A@<000h700040000
@0<91d033`M60`l7AP<91eH0000/0000B`<000P7001A0`003PL000@0001<0`T7C0<?1e833`MB0`T7
EP0002`0001G0`0020L005d3000>1`00100005P32@MH0`l7GP<?1eh32@MF0000;00006<300081`00
J@<000h700040000I0<91f@33`MZ0`l7JP<91eH0000/0000K`<000P7001e0`003PL000@0001`0`T7
L0<?1gH33`Mf0`T7EP0002`0001k0`0020L00843000>1`00100007`32@Ml0`l7PP<?1h832@MF0000
;00008L300081`00S@<000h700040000R0<91hP33`N>0`l7SP<91eH0000/0000T`<000P7002I0`00
3PL000@0002D0`T7U0<?1iX33`NJ0`T7EP0002`0002O0`0020L00:D3000>1`0010000:032@NP0`l7
YP<?1jH32@MF0000;0000:/300081`00/@<000h700040000[0<91j`33`Nb0`l7/P<91eH0000/0000
]`<000P7002m0`003PL000@0002h0`T7^0<?1kh33`Nn0`T7EP0002`000330`0020L00<T3000>1`00
10000<@32@O40`l7bP<?1lX32@MF0000;0000<l300081`00e@<000h700040000d0<91m033`OF0`l7
eP<91eH0000/0000f`<000P7003Q0`003PL000@0003L0`T7g0<?1n833`OR0`T7EP0002`0003W0`00
20L00>d3000>1`0010000>P32@OX0`l7kP<?1nh32@MF0000;0000?<300081`00n@<000h700040000
m0<91o@33`Oj0`l7nP<91eH0000/0000o`<000P7000510003PL000@0000010T700@?1`H43`L610T7
EP0002`0000;100020L00144000>1`00100000`42@L<10l74P@?1a842@MF0000;00001L400081`00
7@@000h70004000060@91aP43`LN10l77P@91eH0000/00008`@000P7000Y10003PL000@0000T10T7
90@?1bX43`LZ10T7EP0002`0000_100020L003D4000>1`00100003042@L`10l7=P@?1cH42@MF0000
;00003/400081`00@@@000h700040000?0@91c`43`M210l7@P@91eH0000/0000A`@000P7001=1000
3PL000@0001810T7B0@?1dh43`M>10T7EP0002`0001C100020L005T4000>1`00100005@42@MD10l7
FP@?1eX42@MF0000;00005l400081`00I@@000h700040000H0@91f043`MV10l7IP@91eH0000/0000
J`@000P7001a10003PL000@0001/10T7K0@?1g843`Mb10T7EP0002`0001g100020L007d4000>1`00
100007P42@Mh10l7OP@?1gh42@MF0000;00008<400081`00R@@000h700040000Q0@91h@43`N:10l7
RP@91eH0000/0000S`@000P7002E10003PL000@0002@10T7T0@?1iH43`NF10T7EP0002`0002K1000
20L00:44000>1`00100009`42@NL10l7XP@?1j842@MF0000;0000:L400081`00[@@000h700040000
Z0@91jP43`N^10l7[P@91eH0000/0000/`@000P7002i10003PL000@0002d10T7]0@?1kX43`Nj10T7
EP0002`0002o100020L00<D4000>1`0010000<042@O010l7aP@?1lH42@MF0000;0000</400081`00
d@@000h700040000c0@91l`43`OB10l7dP@91eH0000/0000e`@000P7003M10003PL000@0003H10T7
f0@?1mh43`ON10T7EP0002`0003S100020L00>T4000>1`0010000>@42@OT10l7jP@?1nX42@MF0000
;0000>l400081`00m@@000h700040000l0@91o043`Of10l7mP@91eH0000/0000n`@000P700011@00
3PL000@0003l10T7o0@?1`853`L21@T7EP0002`000071@0020L000d5000>1`00100000P52@L81@l7
3PD?1`h52@MF0000;00001<500081`006@D000h70004000050D91a@53`LJ1@l76PD91eH0000/0000
7`D000P7000U1@003PL000@0000P1@T780D?1bH53`LV1@T7EP0002`0000[1@0020L00345000>1`00
100002`52@L/1@l7<PD?1c852@MF0000;00003L500081`00?@D000h700040000>0D91cP53`Ln1@l7
?PD91eH0000/0000@`D000P700191@003PL000@000141@T7A0D?1dX53`M:1@T7EP0002`0001?1@00
20L005D5000>1`00100005052@M@1@l7EPD?1eH52@MF0000;00005/500081`00H@D000h700040000
G0D91e`53`MR1@l7HPD91eH0000/0000I`D000P7001]1@003PL000@0001X1@T7J0D?1fh53`M^1@T7
EP0002`0001c1@0020L007T5000>1`00100007@52@Md1@l7NPD?1gX52@MF0000;00007l500081`00
Q@D000h700040000P0D91h053`N61@l7QPD91eH0000/0000R`D000P7002A1@003PL000@0002<1@T7
S0D?1i853`NB1@T7EP0002`0002G1@0020L009d5000>1`00100009P52@NH1@l7WPD?1ih52@MF0000
;0000:<500081`00Z@D000h700040000Y0D91j@53`NZ1@l7ZPD91eH0000/0000[`D000P7002e1@00
3PL000@0002`1@T7/0D?1kH53`Nf1@T7EP0002`0002k1@0020L00<45000>1`0010000;`52@Nl1@l7
`PD?1l852@MF0000;0000<L500081`00c@D000h700040000b0D91lP53`O>1@l7cPD91eH0000/0000
d`D000P7003I1@003PL000@0003D1@T7e0D?1mX53`OJ1@T7EP0002`0003L1@001@L00>85000;1`00
10000=d530OS1@`7h`D61md51PMF0000;0000=`5003i1P00hPD00?l600040000g@D01n<500OS1OX6
g@Gj1UH0000/0000g0D00>d6003R1@00l`H000@0003M1O@6h`Gd1^<5kPKM1Nh6EP0002`0003L1@00
h@H00>85003W1P0010000=d5j0KS1NP6h`GR1]d5hPIF0000;0000=`5003E1P00hPD00=/600040000
g@GL1^<5g0KS1MH6g@GF1UH0000/0000g0D00<T6003R1@00c`H000@0003M1M06h`G@1^<5bPKM1LX6
EP0002`0003L1@00_@H00>8500331P0010000=d5a0KS1L@6h`Fn1]d5_PIF0000;0000=`5002a1P00
hPD00;L600040000g@Fh1^<5^0KS1K86g@Fb1UH0000/0000g0D00:D6003R1@00Z`H000@0003M1J`6
h`F/1^<5YPKM1JH6EP0002`0003L1@00V@H00>85002O1P0010000=d5X0KS1J06h`FJ1]d5VPIF0000
;0000=`5002=1P00hPD009<600040000g@FD1^<5U0KS1Hh6g@F>1UH0000/0000g0D00846003R1@00
Q`H000@0003M1HP6h`F81^<5PPKM1H86EP0002`0003L1@00M@H00>85001k1P0010000=d5O0KS1G`6
h`Ef1]d5MPIF0000;0000=`5001Y1P00hPD006l600040000g@E`1^<5L0KS1FX6g@EZ1UH0000/0000
g0D005d6003R1@00H`H000@0003M1F@6h`ET1^<5GPKM1Eh6EP0002`0003L1@00D@H00>85001G1P00
10000=d5F0KS1EP6h`EB1]d5DPIF0000;0000=`500151P00hPD004/600040000g@E<1^<5C0KS1DH6
g@E61UH0000/0000g0D003T6003R1@00?`H000@0003M1D06h`E01^<5>PKM1CX6EP0002`0003L1@00
;@H00>85000c1P0010000=d5=0KS1C@6h`D^1]d5;PIF0000;0000=`5000Q1P00hPD002L600040000
g@DX1^<5:0KS1B86g@DR1UH0000/0000g0D001D6003R1@006`H000@0003M1A`6h`DL1^<55PKM1AH6
EP0002`0003L1@002@H00>85000?1P0010000=d540KS1A06h`D:1]d52PIF0000;0000=`5003m1@00
hPD000<600040000g@D41^<510KS1Oh5g@Gn1EH0000/0000g0D00?45003R1@00m`D000@0003M1OP5
h`Gh1N<5lPGM1O85EP0002`0003L1@00i@D00>85003[1@0010000=d5k0GS1N`5h`GV1Md5iPEF0000
;0000=`5003I1@00hPD00=l500040000g@GP1N<5h0GS1MX5g@GJ1EH0000/0000g0D00<d5003R1@00
d`D000@0003M1M@5h`GD1N<5cPGM1Lh5EP0002`0003L1@00`@D00>8500371@0010000=d5b0GS1LP5
h`G21Md5`PEF0000;0000=`5002e1@00hPD00;/500040000g@Fl1N<5_0GS1KH5g@Ff1EH0000/0000
g0D00:T5003R1@00[`D000@0003M1K05h`F`1N<5ZPGM1JX5EP0002`0003L1@00W@D00>85002S1@00
10000=d5Y0GS1J@5h`FN1Md5WPEF0000;0000=`5002A1@00hPD009L500040000g@FH1N<5V0GS1I85
g@FB1EH0000/0000g0D008D5003R1@00R`D000@0003M1H`5h`F<1N<5QPGM1HH5EP0002`0003L1@00
N@D00>85001o1@0010000=d5P0GS1H05h`Ej1Md5NPEF0000;0000=`5001]1@00hPD007<500040000
g@Ed1N<5M0GS1Fh5g@E^1EH0000/0000g0D00645003R1@00I`D000@0003M1FP5h`EX1N<5HPGM1F85
EP0002`0003L1@00E@D00>85001K1@0010000=d5G0GS1E`5h`EF1Md5EPEF0000;0000=`500191@00
hPD004l500040000g@E@1N<5D0GS1DX5g@E:1EH0000/0000g0D003d5003R1@00@`D000@0003M1D@5
h`E41N<5?PGM1Ch5EP0002`0003L1@00<@D00>85000g1@0010000=d5>0GS1CP5h`Db1Md5<PEF0000
;0000=`5000U1@00hPD002/500040000g@D/1N<5;0GS1BH5g@DV1EH0000/0000g0D001T5003R1@00
7`D000@0003M1B05h`DP1N<56PGM1AX5EP0002`0003L1@003@D00>85000C1@0010000=d550GS1A@5
h`D>1Md53PEF0000;0000=`500011@00hPD000L500040000g@D81N<520GS1@85g@D21EH0000/0000
g0D00?D4003R1@00n`@000@0003M1O`4h`Gl1><5mPCM1OH4EP0002`0003L1@00j@@00>85003_1000
10000=d5l0CS1O04h`GZ1=d5jPAF0000;0000=`5003M1000hPD00><400040000g@GT1><5i0CS1Mh4
g@GN15H0000/0000g0D00=44003R1@00e`@000@0003M1MP4h`GH1><5dPCM1M84EP0002`0003L1@00
a@@00>85003;100010000=d5c0CS1L`4h`G61=d5aPAF0000;0000=`5002i1000hPD00;l400040000
g@G01><5`0CS1KX4g@Fj15H0000/0000g0D00:d4003R1@00/`@000@0003M1K@4h`Fd1><5[PCM1Jh4
EP0002`0003L1@00X@@00>85002W100010000=d5Z0CS1JP4h`FR1=d5XPAF0000;0000=`5002E1000
hPD009/400040000g@FL1><5W0CS1IH4g@FF15H0000/0000g0D008T4003R1@00S`@000@0003M1I04
h`F@1><5RPCM1HX4EP0002`0003L1@00O@@00>850023100010000=d5Q0CS1H@4h`En1=d5OPAF0000
;0000=`5001a1000hPD007L400040000g@Eh1><5N0CS1G84g@Eb15H0000/0000g0D006D4003R1@00
J`@000@0003M1F`4h`E/1><5IPCM1FH4EP0002`0003L1@00F@@00>85001O100010000=d5H0CS1F04
h`EJ1=d5FPAF0000;0000=`5001=1000hPD005<400040000g@ED1><5E0CS1Dh4g@E>15H0000/0000
g0D00444003R1@00A`@000@0003M1DP4h`E81><5@PCM1D84EP0002`0003L1@00=@@00>85000k1000
10000=d5?0CS1C`4h`Df1=d5=PAF0000;0000=`5000Y1000hPD002l400040000g@D`1><5<0CS1BX4
g@DZ15H0000/0000g0D001d4003R1@008`@000@0003M1B@4h`DT1><57PCM1Ah4EP0002`0003L1@00
4@@00>85000G100010000=d560CS1AP4h`DB1=d54PAF0000;0000=`500051000hPD000/400040000
g@D<1><530CS1@H4g@D615H0000/0000g0D00?T3003R1@00o`<000@0003M1@04h`D01><5nP?M1OX3
EP0002`0003L1@00k@<00>85003c0`0010000=d5m0?S1O@3h`G^0md5kP=F0000;0000=`5003Q0`00
hPD00>L300040000g@GX0n<5j0?S1N83g@GR0eH0000/0000g0D00=D3003R1@00f`<000@0003M1M`3
h`GL0n<5eP?M1MH3EP0002`0003L1@00b@<00>85003?0`0010000=d5d0?S1M03h`G:0md5bP=F0000
;0000=`5002m0`00hPD00<<300040000g@G40n<5a0?S1Kh3g@Fn0eH0000/0000g0D00;43003R1@00
]`<000@0003M1KP3h`Fh0n<5/P?M1K83EP0002`0003L1@00Y@<00>85002[0`0010000=d5[0?S1J`3
h`FV0md5YP=F0000;0000=`5002I0`00hPD009l300040000g@FP0n<5X0?S1IX3g@FJ0eH0000/0000
g0D008d3003R1@00T`<000@0003M1I@3h`FD0n<5SP?M1Hh3EP0002`0003L1@00P@<00>8500270`00
10000=d5R0?S1HP3h`F20md5PP=F0000;0000=`5001e0`00hPD007/300040000g@El0n<5O0?S1GH3
g@Ef0eH0000/0000g0D006T3003R1@00K`<000@0003M1G03h`E`0n<5JP?M1FX3EP0002`0003L1@00
G@<00>85001S0`0010000=d5I0?S1F@3h`EN0md5GP=F0000;0000=`5001A0`00hPD005L300040000
g@EH0n<5F0?S1E83g@EB0eH0000/0000g0D004D3003R1@00B`<000@0003M1D`3h`E<0n<5AP?M1DH3
EP0002`0003L1@00>@<00>85000o0`0010000=d5@0?S1D03h`Dj0md5>P=F0000;0000=`5000]0`00
hPD003<300040000g@Dd0n<5=0?S1Bh3g@D^0eH0000/0000g0D00243003R1@009`<000@0003M1BP3
h`DX0n<58P?M1B83EP0002`0003L1@005@<00>85000K0`0010000=d570?S1A`3h`DF0md55P=F0000
;0000=`500090`00hPD000l300040000g@D@0n<540?S1@X3g@D:0eH0000/0000g0D00?d2003R1@00
0`<000@0003M1@@3h`D40n<5oP;M1Oh2EP0002`0003L1@00l@800>85003g0P0010000=d5n0;S1OP2
h`Gb0]d5lP9F0000;0000=`5003U0P00hPD00>/200040000g@G/0^<5k0;S1NH2g@GV0UH0000/0000
g0D00=T2003R1@00g`8000@0003M1N02h`GP0^<5fP;M1MX2EP0002`0003L1@00c@800>85003C0P00
10000=d5e0;S1M@2h`G>0]d5cP9F0000;0000=`500310P00hPD00<L200040000g@G80^<5b0;S1L82
g@G20UH0000/0000g0D00;D2003R1@00^`8000@0003M1K`2h`Fl0^<5]P;M1KH2EP0002`0003L1@00
Z@800>85002_0P0010000=d5/0;S1K02h`FZ0]d5ZP9F0000;0000=`5002M0P00hPD00:<200040000
g@FT0^<5Y0;S1Ih2g@FN0UH0000/0000g0D00942003R1@00U`8000@0003M1IP2h`FH0^<5TP;M1I82
EP0002`0003L1@00Q@800>85002;0P0010000=d5S0;S1H`2h`F60]d5QP9F0000;0000=`5001i0P00
hPD007l200040000g@F00^<5P0;S1GX2g@Ej0UH0000/0000g0D006d2003R1@00L`8000@0003M1G@2
h`Ed0^<5KP;M1Fh2EP0002`0003L1@00H@800>85001W0P0010000=d5J0;S1FP2h`ER0]d5HP9F0000
;0000=T5001H0P00g`D005h200040000h0EO0^05F@;J1ET2fPEO0UH0000/0000c@D005P2003C1@00
GP8000@0003D1El2e0EI0/h5F@;>1El2EP0002`000311@00F0800<L5001N0P0010000<P5G`;81ET2
`PEI0/85G`9F0000;0000;D5001H0P00^`D005h200040000_0EO0[`5F@:f1ET2]PEO0UH0000/0000
Z@D005P2002_1@00GP8000@0002`1El2/0EI0ZX5F@:Z1El2EP0002`0002M1@00F0800:<5001N0P00
10000:@5G`:T1ET2WPEI0Yh5G`9F0000;0000945001H0P00U`D005h200040000V0EO0YP5F@:B1ET2
TPEO0UH0000/0000Q@D005P2002;1@00GP8000@0002<1El2S0EI0XH5F@:61El2EP0002`0001i1@00
F08007l5001N0P0010000805G`:01ET2NPEI0WX5G`9F0000;00006d5001H0P00L`D005h200040000
M0EO0W@5F@9^1ET2KPEO0UH0000/0000H@D005P2001W1@00GP8000@0001X1El2J0EI0V85F@9R1El2
EP0002`0001E1@00F08005/5001N0P00100005`5G`9L1ET2EPEI0UH5G`9F0000;00004T5001H0P00
C`D005h200040000D0EO0U05F@9:1ET2BPEO0UH0000/0000?@D005P200131@00GP8000@000141El2
A0EI0Sh5F@8n1El2EP0002`0000a1@00F08003L5001N0P00100003P5G`8h1ET2<PEI0S85G`9F0000
;00002D5001H0P00:`D005h200040000;0EO0R`5F@8V1ET29PEO0UH0000/00006@D005P2000O1@00
GP8000@0000P1El280EI0QX5F@8J1El2EP0002`0000=1@00F08001<5001N0P00100001@5G`8D1ET2
3PEI0Ph5G`9F0000;0000045001H0P001`D005h20004000020EO0PP5F@821ET20PEO0UH0000/0000
m@@005P2003k1000GP8000@0003l15l2o0AI0_H4F@;f15l2EP0002`0003Y1000F0800>l4001N0P00
10000?04G`;`15T2jPAI0^X4G`9F0000;0000=d4001H0P00h`@005h200040000i0AO0^@4F@;N15T2
gPAO0UH0000/0000d@@005P2003G1000GP8000@0003H15l2f0AI0]84F@;B15l2EP0002`000351000
F0800</4001N0P0010000<`4G`;<15T2aPAI0/H4G`9F0000;0000;T4001H0P00_`@005h200040000
`0AO0/04F@:j15T2^PAO0UH0000/0000[@@005P2002c1000GP8000@0002d15l2]0AI0Zh4F@:^15l2
EP0002`0002Q1000F0800:L4001N0P0010000:P4G`:X15T2XPAI0Z84G`9F0000;00009D4001H0P00
V`@005h200040000W0AO0Y`4F@:F15T2UPAO0UH0000/0000R@@005P2002?1000GP8000@0002@15l2
T0AI0XX4F@::15l2EP0002`0001m1000F08008<4001N0P00100008@4G`:415T2OPAI0Wh4G`9F0000
;0000744001H0P00M`@005h200040000N0AO0WP4F@9b15T2LPAO0UH0000/0000I@@005P2001[1000
GP8000@0001/15l2K0AI0VH4F@9V15l2EP0002`0001I1000F08005l4001N0P0010000604G`9P15T2
FPAI0UX4G`9F0000;00004d4001H0P00D`@005h200040000E0AO0U@4F@9>15T2CPAO0UH0000/0000
@@@005P200171000GP8000@0001815l2B0AI0T84F@9215l2EP0002`0000e1000F08003/4001N0P00
100003`4G`8l15T2=PAI0SH4G`9F0000;00002T4001H0P00;`@005h200040000<0AO0S04F@8Z15T2
:PAO0UH0000/00007@@005P2000S1000GP8000@0000T15l290AI0Qh4F@8N15l2EP0002`0000A1000
F08001L4001N0P00100001P4G`8H15T24PAI0Q84G`9F0000;00000D4001H0P002`@005h200040000
30AO0P`4F@8615T21PAO0UH0000/0000n@<005P2003o0`00GP8000@0000015l200AI0_X3F@;j0el2
EP0002`0003]0`00F0800?<3001N0P0010000?@3G`;d0eT2kP=I0^h3G`9F0000;0000>43001H0P00
i`<005h200040000j0=O0^P3F@;R0eT2hP=O0UH0000/0000e@<005P2003K0`00GP8000@0003L0el2
g0=I0]H3F@;F0el2EP0002`000390`00F0800<l3001N0P0010000=03G`;@0eT2bP=I0/X3G`9F0000
;0000;d3001H0P00``<005h200040000a0=O0/@3F@:n0eT2_P=O0UH0000/0000/@<005P2002g0`00
GP8000@0002h0el2^0=I0[83F@:b0el2EP0002`0002U0`00F0800:/3001N0P0010000:`3G`:/0eT2
YP=I0ZH3G`9F0000;00009T3001H0P00W`<005h200040000X0=O0Z03F@:J0eT2VP=O0UH0000/0000
S@<005P2002C0`00GP8000@0002D0el2U0=I0Xh3F@:>0el2EP0002`000210`00F08008L3001N0P00
100008P3G`:80eT2PP=I0X83G`9F0000;00007D3001H0P00N`<005h200040000O0=O0W`3F@9f0eT2
MP=O0UH0000/0000J@<005P2001_0`00GP8000@0001`0el2L0=I0VX3F@9Z0el2EP0002`0001M0`00
F08006<3001N0P00100006@3G`9T0eT2GP=I0Uh3G`9F0000;0000543001H0P00E`<005h200040000
F0=O0UP3F@9B0eT2DP=O0UH0000/0000A@<005P2001;0`00GP8000@0001<0el2C0=I0TH3F@960el2
EP0002`0000i0`00F08003l3001N0P0010000403G`900eT2>P=I0SX3G`9F0000;00002d3001H0P00
<`<005h200040000=0=O0S@3F@8^0eT2;P=O0UH0000/00008@<005P2000W0`00GP8000@0000X0el2
:0=I0R83F@8R0el2EP0002`0000E0`00F08001/3001N0P00100001`3G`8L0eT25P=I0QH3G`9F0000
;00000T3001H0P003`<005h20004000040=O0Q03F@8:0eT22P=O0UH0000/0000o@8005P200030`00
GP8000@000040el210=I0_h2F@;n0Ul2EP0002`0003a0P00F0800?L2001N0P0010000?P2G`;h0UT2
lP9I0_82G`9F0000;0000>D2001H0P00j`8005h200040000k09O0^`2F@;V0UT2iP9O0UH0000/0000
f@8005P2003O0P00GP8000@0003P0Ul2h09I0]X2F@;J0Ul2EP0002`0003=0P00F0800=<2001N0P00
10000=@2G`;D0UT2cP9I0/h2G`9F0000;0000<42001H0P00a`8005h200040000b09O0/P2F@;20UT2
`P9O0UH0000/0000]@8005P2002k0P00GP8000@0002l0Ul2_09I0[H2F@:f0Ul2EP0002`0002Y0P00
F0800:l2001N0P0010000;02G`:`0UT2ZP9I0ZX2G`9F0000;00009d2001H0P00X`8005h200040000
Y09O0Z@2F@:N0UT2WP9O0UH0000/0000T@8005P2002G0P00GP8000@0002H0Ul2V09I0Y82F@:B0Ul2
EP0002`000250P00F08008/2001N0P00100008`2G`:<0UT2QP9I0XH2G`9F0000;00007T2001H0P00
O`8005h200040000P09O0X02F@9j0UT2NP9O0UH0000/0000K@8005P2001c0P00GP8000@0001d0Ul2
M09I0Vh2F@9^0Ul2EP0002`0001Q0P00F08006L2001N0P00100006P2G`9X0UT2HP9I0V82G`9F0000
;00005D2001H0P00F`8005h200040000G09O0U`2F@9F0UT2EP9O0UH0000/0000B@8005P2001?0P00
GP8000@0001@0Ul2D09I0TX2F@9:0Ul2EP0002`0000m0P00F08004<2001N0P00100004@2G`940UT2
?P9I0Sh2G`9F0000;0000342001H0P00=`8005h200040000>09O0SP2F@8b0UT2<P9O0UH0000/0000
9@8005P2000[0P00GP8000@0000/0Ul2;09I0RH2F@8V0Ul2EP0002`0000I0P00F08001l2001N0P00
10000202G`8P0UT26P9I0QX2G`9F0000;00000d2001H0P004`8005h200040000509O0Q@2F@8>0UT2
3P9O0UH0000/00000@8005P200070P00GP8000@000080Ul2209I0P82F@820Ul2EP0002`0003e0@00
F0800?/1001N0P0010000?`1G`;l0ET2mP5I0_H1G`9F0000;0000>T1001H0P00k`4005h200040000
l05O0_01F@;Z0ET2jP5O0UH0000/0000g@4005P2003S0@00GP8000@0003T0El2i05I0]h1F@;N0El2
EP0002`0003A0@00F0800=L1001N0P0010000=P1G`;H0ET2dP5I0]81G`9F0000;0000<D1001H0P00
b`4005h200040000c05O0/`1F@;60ET2aP5O0UH0000/0000^@4005P2002o0@00GP8000@000300El2
`05I0[X1F@:j0El2EP0002`0002]0@00F0800;<1001N0P0010000;@1G`:d0ET2[P5I0Zh1G`9F0000
;0000:41001H0P00Y`4005h200040000Z05O0ZP1F@:R0ET2XP5O0UH0000/0000U@4005P2002K0@00
GP8000@0002L0El2W05I0YH1F@:F0El2EP0002`000290@00F08008l1001N0P0010000901G`:@0ET2
RP5I0XX1G`9F0000;00007d1001H0P00P`4005h200040000Q05O0X@1F@9n0ET2OP5O0UH0000/0000
L@4005P2001g0@00GP8000@0001h0El2N05I0W81F@9b0El2EP0002`0001U0@00F08006/1001N0P00
100006`1G`9/0ET2IP5I0VH1G`9F0000;00005T1001H0P00G`4005h200040000H05O0V01F@9J0ET2
FP5O0UH0000/0000C@4005P2001C0@00GP8000@0001D0El2E05I0Th1F@9>0El2EP0002`000110@00
F08004L1001N0P00100004P1G`980ET2@P5I0T81G`9F0000;00003D1001H0P00>`4005h200040000
?05O0S`1F@8f0ET2=P5O0UH0000/0000:@4005P2000_0@00GP8000@0000`0El2<05I0RX1F@8Z0El2
EP0002`0000M0@00F08002<1001N0P00100002@1G`8T0ET27P5I0Qh1G`9F0000;0000141001H0P00
5`4005h200040000605O0QP1F@8B0ET24P5O0UH0000/00001@4005P2000;0@00GP8000@0000<0El2
305I0PH1F@860El2EP0002`0003i0000F0800?l0001N0P0010000001G`800ET2nP1I0_X0G`9F0000
;0000>d0001H0P00l`0005h200040000m01O0_@0F@;^05T2kP1O0UH0000/0000h@0005P2003W0000
GP8000@0003X05l2j01I0^80F@;R05l2EP0002`0003E0000F0800=/0001N0P0010000=`0G`;L05T2
eP1I0]H0G`9F0000;0000<T0001H0P00c`0005h200040000d01O0]00F@;:05T2bP1O0UH0000/0000
_@0005P200330000GP8000@0003405l2a01I0[h0F@:n05l2EP0002`0002a0000F0800;L0001N0P00
10000;P0G`:h05T2/P1I0[80G`9F0000;0000:D0001H0P00Z`0005h200040000[01O0Z`0F@:V05T2
YP1O0UH0000/0000V@0005P2002O0000GP8000@0002P05l2X01I0YX0F@:J05l2EP0002`0002=0000
F08009<0001N0P00100009@0G`:D05T2SP1I0Xh0G`9F0000;0000840001H0P00Q`0005h200040000
R01O0XP0F@:205T2PP1O0UH0000/0000M@0005P2001k0000GP8000@0001l05l2O01I0WH0F@9f05l2
EP0002`0001Y0000F08006l0001N0P0010000700G`9`05T2JP1I0VX0G`9F0000;00005d0001H0P00
H`0005h200040000I01O0V@0F@9N05T2GP1O0UH0000/0000D@0005P2001G0000GP8000@0001H05l2
F01I0U80F@9B05l2EP0002`000150000F08004/0001N0P00100004`0G`9<05T2AP1I0TH0G`9F0000
;00003T0001H0P00?`0005h200040000@01O0T00F@8j05T2>P1O0UH0000/0000;@0005P2000c0000
GP8000@0000d05l2=01I0Rh0F@8^05l2EP0002`0000Q0000F08002L0001N0P00100002P0G`8X05T2
8P1I0R80G`9F0000;00001D0001H0P006`0005h200040000701O0Q`0F@8F05T25P1O0UH0000/0000
2@0005P2000?0000GP8000@0000@05l2401I0PX0F@8:05l24`0000`0000100003000010000000000
000002D0000<00001`00P2D0000<00000000P240000800007P0001P000130000O@800:45003Z1P00
9@0000`000010000E00007`000120000O`8009l1003`0P000@0009BSQd2DXhM0@`00080200080000
C00000@000130000O@800:05003Z1P00G00005<0J`1U06`0I@1d06l0KP0h0000<P0002`0000L0000
;00001`0000b0000<P0005@0001D0000X04007l2003<0@00l0800040002DXhM0U:>7@:4100200P00
0@0004`000040000@`0007d2002P1@00jPH00500000P0000;@000280000<0000ooooobH0000L0000
0P000000000600001P000000008U000030000080000U000030000000080Z0000600004h0001:1@00
NP400:H6000U0000300000L0080X000030000080000<000040000000000000009@0000`000070020
9@0000`0000000208@0000P0000N000060000:H0002D1@008@4005/6000U000030000040001D0000
F0000:D0002F1@00204000L600010000U:>7@9BSQd2V0000U`D00080001<000010000:H0002D1@00
804005/6001@0000<@0`0380000b0000E00005@000090@00UPD001l100071P000@0009BSQd2DXhM0
2P4009L500010000C00000@0002V0000U0D00201001K1P00D0000200ogl]00008P0000`0003ooooo
9P0001`000020000000000H00006000000000RD0000<00000P0002D0000<00000000P2X0000H0000
F`8004X500270`00YPH002D0000<00001`00P2P0000<00000P0000`0000@000000000000000U0000
300000L0080U000030000000080Q0000200001h0000H0000/`8009@5000^0`00F`H002D0000<0000
0@0005@0001H0000/P8009H5003l0P001`H00040002DXhM0U:>7@;<2002G1@000P0004`000040000
/`8009@5000]0`00F`H00500000P03T06@000380001D0000E0000?d2002F1@00:@<000L600010000
U:>7@9BSQd3n0P00U`D00040001<000010000;<2002D1@00;@<005/6001@0000803oObd0000R0000
30000?oooolV000070000080000000001P0000H0000000029@0000`0000200009@0000`000000020
:P0001P0001X1000BPD009@5002V1P009@0000`000070020:00000`0000200003000010000000000
000002D0000<00001`00P2D0000<00000000P240000800007P0001P000301000U0D003/5001K1P00
9@0000`000010000E00005P0002o1000UPD000T500071P000@0009BSQd2DXhM0`0@009L500020000
C00000@000301000U0D003X5001K1P00D0000200>00I0000<P0005@0001D00002PD009H5000f1@00
1`H00040002DXhM0U:>7@0/5002G1@000@0004`000040000`0@009@5000j1@00F`H00500000P0000
;@000280000<0000ooooobH0000L00000P000000000600001P000000000U000030000080000U0000
300000D0081G000090000<43003L1@00J@@00>8500020000I`CP1LD3h0DU0000300000P0080X0000
30000080000U0000300000P0080U0000300000@0081F0000:00008D3002o1@00a`<0000600030000
b0?01HH3h0G80`469P0001`000020000000000H000060000000002D0000<00000P0002D0000<0000
1@00P5L0000T0000PP<002L6000Z1000;@H0008000260b/6:0@[1RD0000<00002000P2P0000<0000
0P0002D0000<00002000P2D0000<00001000P5H0000X00009@@000X6001W1000B`H000<0000V14`6
J0@/1RH42`HV000070000080000000001P0000H0000000009@0000`0000200009@0000`000050020
E`0002@0002d0@00g0D005`2003R1@000P0005X2h0Fh0N059@0000`000080020:00000`000020000
9@0000`0000800209@0000`000040020EP0002P0001i0@00_`D00;X100001P000`000;/1`0Ej0N05
^`411RH0000L00000P000000000600001P000000008U000030000080000U000030000000080Z0000
600004h0003b0P00NP4004h4000U0000300000L0080X000030000080000<00004000000000000000
9@0000`0000700209@0000`0000000208@0000P0000N000060000:H0000l0`008@4000<4000U0000
30000040001D0000F0000:D0000n0`00k`000:l300010000U:>7@9BSQd2V0000?`<00080001<0000
10000:H0000l0`00804000<4001@0000800g01T0000b0000E00005@0003`0000?P<001`1002_0`00
0@0009BSQd2DXhM0l@0003l300010000C00000@0002V0000?0<0020100031000D0000200000]0000
8P0000`0003ooooo9P0001`000020000000000H00006000000000RD0000<00000P0002D0000<0000
0000P2X0000H0000F`800?8200270`00CP@002D0000<00001`00P2P0000<00000P0000`0000@0000
00000000000U0000300000L0080U000030000000080Q0000200001h0000H0000/`8003`3000^0`00
0`@002D0000<00000@0005@0001H0000/P8003h3003l0P00[`<00040002DXhM0U:>7@;<2000o0`00
0P0004`000040000/`8003`3000]0`000`@00500000P03H06@000380001D0000E0000?d2000n0`00
:@<00:l300010000U:>7@9BSQd3n0P00?`<00040001<000010000;<2000l0`00;@<000<4001@0000
803<02d0000R000030000?oooolV000070000080000000001P0000H0000000029@0000`000020000
9@0000`000000020:P0001P0001X1000lP8009@5001>10009@0000`000070020:00000`000020000
3000010000000000000002D0000<00001`00P2D0000<00000000P240000800007P0001P000301000
?0<003/5000310009@0000`000010000E00005P0002o1000?P<000T5002_0`000@0009BSQd2DXhM0
`0@003l300020000C00000@000301000?0<003X500031000D0000200=@0I0000<P0005@0001D0000
2PD003h3000f1@00[`<00040002DXhM0U:>7@0/5000o0`000@0004`000040000`0@003`3000j1@00
0`@00500000P0000;@000280000<0000ooooobH0000L00000P000000000600001P000000000U0000
30000080000U0000300000D0081G000090000883002o0`00:P@00<D300020000QP?30bP4``<U0000
300000P0080X000030000080000U0000300000P0080U0000300000@0081F0000:00002D4002R0`00
I`@00><3000300009PCT0fP4a0<V1:<39P0001`000020000000000H000060000000002D0000<0000
0P0002D0000<00001@00P5L0000T0000]04007T3001L0P00O`<00080001J0Wd3^05m0bD0000<0000
2000P2P0000<00000P0002D0000<00002000P2D0000<00001000P5H0000X0000N@4005`3002j0@00
W@<000<0002k0Ed3NP5n0k/1WP<V000070000080000000001P0000H0000000009@0000`000020000
9@0000`000050020E`0002@000310`00I0<006T4001Z0`000P0006L4J0?50fP39@0000`000080020
:00000`0000200009@0000`0000800209@0000`000040020EP0002P000250`00A`<00<L300280`00
0`000<P3B0>60fP3b0>90bH0000L00000P000000000600001P000000000U000030000080000U0000
300000D0081G000090000=l0002`1000c@H00;H400020000h`2d1</6]0@U0000300000P0080X0000
30000080000U0000300000P0080U0000300000@0081F0000:0000<P6002C10002@L00=@400030000
b@KE10X7]0C91Y@49P0001`000020000000000H000060000000002D0000<00000P0002D0000<0000
1@00P5L0000T0000S`D005h5003B1P00hPD00080002C1N05d0IR1BD0000<00002000P2P0000<0000
0P0002D0000<00002000P2D0000<00001000P5H0000X0000`0H004<500091`00P0D000<0003J1X45
2PM:1L46A0DV000070000080000000001P0000H0000000009@0000`0000200009@0000`000050020
E`0002@000391@00T@D000`7000E1P000P0000X7U@G=1A<69@0000`000080020:00000`000020000
9@0000`0000800209@0000`000040020EP0002P0002C1@00m0D00=`5000a1P000`000<@5m@FD1B`6
g@Db1RH0000L00000P000000000600001P000000000U000030000080000U0000300000D0081G0000
90000<T5003W0`0030L006/4000200002PMY1<d5j`<U0000300000P0080X000030000080000U0000
300000P0080U0000300000@0081F0000:00009<5003<0`00g0D000T400030000g@G=0i@5e0?41@X4
9P0001`000020000000000H000060000000002D0000<00000P0002D0000<00001@00P5L0000T0000
S`D008@3000K1`002`@00080002C1HP36@L912D0000<00002000P2P0000<00000P0002D0000<0000
2000P2D0000<00001000P5H0000X000030L00>T3001E1`00:0@000<0000=1bT4EPLN1287jP<V0000
70000080000000001P0000H0000000009@0000`0000200009@0000`000050020E`0002@0003O0000
I@@00>D0002f10000P000><0]0CS06T49@0000`000070020:00000`0000200009P0001`000020000
000000H000060000000002D0000<00000P0002D0000<00001@00P5L0000T0000g`000?/4003U0000
C0D00080003S0?l4h`1:1BD0000<00001`00P2P0000<00000P0002D0000<00000000P4d0001/0000
8`/007X1003T3000P@P002@;001k0@00`P4000P7000Q0?00000000000000080o000000000000080o
000000000000000000000000000000000000000000000000000001<0000<00000P0002D0000<0000
2000P2D0000<00001000P5H0000/000080/007X1000V2`00P04000@0000W2g/18@]k0B4;P@4W2h41
EP0002`0000P2`00QP4002H;002<0@00100002L;Q`4Q2hL18@^=0BL;S@5F0000;000020;002B0@00
9P/009P1000400009`^C0B4;T`4Q2iT19`^I0EH0000/000080/009h1000V2`00Y04000@0000W2il1
8@^O0B4;Y@4W2jD1EP0002`0000P2`00ZP4002H;002`0@00100002L;Z`4Q2j/18@^a0BL;/@5F0000
;000020;002f0@009P/00;`1000400009`^g0B4;]`4Q2kd19`^m0EH0000/000080/00<81000V2`00
b04000@0000W2l<18@_30B4;b@4W2lT1EP0002`0000P2`00cP4002H;003D0@00100002L;c`4Q2ll1
8@_E0BL;e@5F0000;000020;003J0@009P/00>01000400009`_K0B4;f`4Q2n419`_Q0EH0000/0000
80/00>H1000V2`00k04000@0000W2nL18@_W0B4;k@4W2nd1EP0002`0000P2`00lP4002H;003h0@00
100002L;l`4Q2o<18@_i0BL;n@5F0000;000020;003n0@009P/000@2000400009`_o0B4;o`4Q2`D2
9`/50UH0000/000080/000X2000V2`00408000@0000W2`/28@/;0R4;4@8W2a42EP0002`0000P2`00
5P8002H;000L0P00100002L;5`8Q2aL28@/M0RL;7@9F0000;000020;000R0P009P/002P200040000
9`/S0R4;8`8Q2bT29`/Y0UH0000/000080/002h2000V2`00=08000@0000W2bl28@/_0R4;=@8W2cD2
EP0002`0000P2`00>P8002H;00100P00100002L;>`8Q2c/28@]10RL;@@9F0000;000020;00160P00
9P/004`2000400009`]70R4;A`8Q2dd29`]=0UH0000/000080/00582000V2`00F08000@0000W2e<2
8@]C0R4;F@8W2eT2EP0002`0000P2`00GP8002H;001T0P00100002L;G`8Q2el28@]U0RL;I@9F0000
;000020;001Z0P009P/00702000400009`][0R4;J`8Q2g429`]a0UH0000/000080/007H2000V2`00
O08000@0000W2gL28@]g0R4;O@8W2gd2EP0002`0000P2`00PP8002H;00280P00100002L;P`8Q2h<2
8@^90RL;R@9F0000;000020;002>0P009P/009@2000400009`^?0R4;S`8Q2iD29`^E0UH0000/0000
80/009X2000V2`00X08000@0000W2i/28@^K0R4;X@8W2j42EP0002`0000P2`00YP8002H;002/0P00
100002L;Y`8Q2jL28@^]0RL;[@9F0000;000020;002b0P009P/00;P2000400009`^c0R4;/`8Q2kT2
9`^i0UH0000/000080/00;h2000V2`00a08000@0000W2kl28@^o0R4;a@8W2lD2EP0002`0000P2`00
bP8002H;003@0P00100002L;b`8Q2l/28@_A0RL;d@9F0000;000020;003F0P009P/00=`200040000
9`_G0R4;e`8Q2md29`_M0UH0000/000080/00>82000V2`00j08000@0000W2n<28@_S0R4;j@8W2nT2
EP0002`0000P2`00kP8002H;003d0P00100002L;k`8Q2nl28@_e0RL;m@9F0000;000020;003j0P00
9P/00003000400009`_k0R4;n`8Q2`439`/10eH0000/000080/000H3000V2`0030<000@0000W2`L3
8@/70b4;3@<W2`d3EP0002`0000P2`004P<002H;000H0`00100002L;4`<Q2a<38@/I0bL;6@=F0000
;000020;000N0`009P/002@3000400009`/O0b4;7`<Q2bD39`/U0eH0000/000080/002X3000V2`00
<0<000@0000W2b/38@/[0b4;<@<W2c43EP0002`0000P2`00=P<002H;000l0`00100002L;=`<Q2cL3
8@/m0bL;?@=F0000;000020;00120`009P/004P3000400009`]30b4;@`<Q2dT39`]90eH0000/0000
80/004h3000V2`00E0<000@0000W2dl38@]?0b4;E@<W2eD3EP0002`0000P2`00FP<002H;001P0`00
100002L;F`<Q2e/38@]Q0bL;H@=F0000;000020;001V0`009P/006`3000400009`]W0b4;I`<Q2fd3
9`]]0eH0000/000080/00783000V2`00N0<000@0000W2g<38@]c0b4;N@<W2gT3EP0002`0000P2`00
OP<002H;00240`00100002L;O`<Q2gl38@^50bL;Q@=F0000;000020;002:0`009P/0090300040000
9`^;0b4;R`<Q2i439`^A0eH0000/000080/009H3000V2`00W0<000@0000W2iL38@^G0b4;W@<W2id3
EP0002`0000P2`00XP<002H;002X0`00100002L;X`<Q2j<38@^Y0bL;Z@=F0000;000020;002^0`00
9P/00;@3000400009`^_0b4;[`<Q2kD39`^e0eH0000/000080/00;X3000V2`00`0<000@0000W2k/3
8@^k0b4;`@<W2l43EP0002`0000P2`00aP<002H;003<0`00100002L;a`<Q2lL38@_=0bL;c@=F0000
;000020;003B0`009P/00=P3000400009`_C0b4;d`<Q2mT39`_I0eH0000/000080/00=h3000V2`00
i0<000@0000W2ml38@_O0b4;i@<W2nD3EP0002`0000P2`00jP<002H;003`0`00100002L;j`<Q2n/3
8@_a0bL;l@=F0000;000020;003f0`009P/00?`3000400009`_g0b4;m`<Q2od39`_m0eH0000/0000
80/00084000V2`0020@000@0000W2`<48@/3124;2@@W2`T4EP0002`0000P2`003P@002H;000D1000
100002L;3`@Q2`l48@/E12L;5@AF0000;000020;000J10009P/00204000400009`/K124;6`@Q2b44
9`/Q15H0000/000080/002H4000V2`00;0@000@0000W2bL48@/W124;;@@W2bd4EP0002`0000P2`00
<P@002H;000h1000100002L;<`@Q2c<48@/i12L;>@AF0000;000020;000n10009P/004@400040000
9`/o124;?`@Q2dD49`]515H0000/000080/004X4000V2`00D0@000@0000W2d/48@];124;D@@W2e44
EP0002`0000P2`00EP@002H;001L1000100002L;E`@Q2eL48@]M12L;G@AF0000;000020;001R1000
9P/006P4000400009`]S124;H`@Q2fT49`]Y15H0000/000080/006h4000V2`00M0@000@0000W2fl4
8@]_124;M@@W2gD4EP0002`0000P2`00NP@002H;00201000100002L;N`@Q2g/48@^112L;P@AF0000
;000020;002610009P/008`4000400009`^7124;Q`@Q2hd49`^=15H0000/000080/00984000V2`00
V0@000@0000W2i<48@^C124;V@@W2iT4EP0002`0000P2`00WP@002H;002T1000100002L;W`@Q2il4
8@^U12L;Y@AF0000;000020;002Z10009P/00;04000400009`^[124;Z`@Q2k449`^a15H0000/0000
80/00;H4000V2`00_0@000@0000W2kL48@^g124;_@@W2kd4EP0002`0000P2`00`P@002H;00381000
100002L;``@Q2l<48@_912L;b@AF0000;000020;003>10009P/00=@4000400009`_?124;c`@Q2mD4
9`_E15H0000/000080/00=X4000V2`00h0@000@0000W2m/48@_K124;h@@W2n44EP0002`0000P2`00
iP@002H;003/1000100002L;i`@Q2nL48@_]12L;k@AF0000;000020;003b10009P/00?P400040000
9`_c124;l`@Q2oT49`_i15H0000/000080/00?h4000V2`0010D000@0000W2ol48@_o124;1@DW2`D5
EP0002`0000P2`002PD002H;000@1@00100002L;2`DQ2`/58@/A1BL;4@EF0000;000020;000F1@00
9P/001`5000400009`/G1B4;5`DQ2ad59`/M1EH0000/000080/00285000V2`00:0D000@0000W2b<5
8@/S1B4;:@DW2bT5EP0002`0000P2`00;PD002H;000d1@00100002L;;`DQ2bl58@/e1BL;=@EF0000
;000020;000j1@009P/00405000400009`/k1B4;>`DQ2d459`]11EH0000/000080/004H5000V2`00
C0D000@0000W2dL58@]71B4;C@DW2dd5EP0002`0000P2`00DPD002H;001H1@00100002L;D`DQ2e<5
8@]I1BL;F@EF0000;000020;001N1@009P/006@5000400009`]O1B4;G`DQ2fD59`]U1EH0000/0000
80/006X5000V2`00L0D000@0000W2f/58@][1B4;L@DW2g45EP0002`0000P2`00MPD002H;001l1@00
100002L;M`DQ2gL58@]m1BL;O@EF0000;000020;00221@009P/008P5000400009`^31B4;P`DQ2hT5
9`^91EH0000/000080/008h5000V2`00U0D000@0000W2hl58@^?1B4;U@DW2iD5EP0002`0000P2`00
VPD002H;002P1@00100002L;V`DQ2i/58@^Q1BL;X@EF0000;000020;002V1@009P/00:`500040000
9`^W1B4;Y`DQ2jd59`^]1EH0000/000080/00;85000V2`00^0D000@0000W2k<58@^c1B4;^@DW2kT5
EP0002`0000P2`00_PD002H;00341@00100002L;_`DQ2kl58@_51BL;a@EF0000;000020;003:1@00
9P/00=05000400009`_;1B4;b`DQ2m459`_A1EH0000/000080/00=H5000V2`00g0D000@0000W2mL5
8@_G1B4;g@DW2md5EP0002`0000P2`00hPD002H;003X1@00100002L;h`DQ2n<58@_Y1BL;j@EF0000
;000020;003^1@009P/00?@5000400009`__1B4;k`DQ2oD59`_e1EH0000/000080/00?X5000V2`00
00H000@0000W2o/58@_k1B4;0@HW2`46EP0002`0000P2`001PH002H;000<1P00100002L;1`HQ2`L6
8@/=1RL;3@IF0000;000020;000B1P009P/001P6000400009`/C1R4;4`HQ2aT69`/I1UH0000/0000
80/001h6000V2`0090H000@0000W2al68@/O1R4;9@HW2bD6EP0002`0000P2`00:PH002H;000`1P00
100002L;:`HQ2b/68@/a1RL;<@IF0000;000020;000f1P009P/003`6000400009`/g1R4;=`HQ2cd6
9`/m1UH0000/000080/00486000V2`00B0H000@0000W2d<68@]31R4;B@HW2dT6EP0002`0000P2`00
CPH002H;001D1P00100002L;C`HQ2dl68@]E1RL;E@IF0000;000020;001J1P009P/0060600040000
9`]K1R4;F`HQ2f469`]Q1UH0000/000080/006H6000V2`00K0H000@0000W2fL68@]W1R4;K@HW2fd6
EP0002`0000P2`00LPH002H;001h1P00100002L;L`HQ2g<68@]i1RL;N@IF0000;000020;001n1P00
9P/008@6000400009`]o1R4;O`HQ2hD69`^51UH0000/000080/008X6000V2`00T0H000@0000W2h/6
8@^;1R4;T@HW2i46EP0002`0000P2`00UPH002H;002L1P00100002L;U`HQ2iL68@^M1RL;W@IF0000
;000020;002R1P009P/00:P6000400009`^S1R4;X`HQ2jT69`^Y1UH0000/000080/00:h6000V2`00
]0H000@0000W2jl68@^_1R4;]@HW2kD6EP0002`0000P2`00^PH002H;00301P00100002L;^`HQ2k/6
8@_11RL;`@IF0000;000020;00361P009P/00<`6000400009`_71R4;a`HQ2ld69`_=1UH0000/0000
80/00=86000V2`00f0H000@0000W2m<68@_C1R4;f@HW2mT6EP0002`0000P2`00gPH002H;003T1P00
100002L;g`HQ2ml68@_U1RL;i@IF0000;000020;003Z1P009P/00?06000400009`_[1R4;j`HQ2o46
9`_a1UH0000/000080/00?H6000V2`00o0H000@0000W2oL68@_g1R4;o@HW2od6EP0002`0000P2`00
0PL002H;00081`00100002L;0`LQ2`<78@/91bL;2@MF0000;000020;000>1`009P/001@700040000
9`/?1b4;3`LQ2aD79`/E1eH0000/000080/001X7000V2`0080L000@0000W2a/78@/K1b4;8@LW2b47
EP0002`0000P2`009PL002H;000/1`00100002L;9`LQ2bL78@/]1bL;;@MF0000;000020;000b1`00
9P/003P7000400009`/c1b4;<`LQ2cT79`/i1eH0000/000080/003h7000V2`00A0L000@0000W2cl7
8@/o1b4;A@LW2dD7EP0002`0000P2`00BPL002H;001@1`00100002L;B`LQ2d/78@]A1bL;D@MF0000
;000020;001F1`009P/005`7000400009`]G1b4;E`LQ2ed79`]M1eH0000/000080/00687000V2`00
J0L000@0000W2f<78@]S1b4;J@LW2fT7EP0002`0000P2`00KPL002H;001d1`00100002L;K`LQ2fl7
8@]e1bL;M@MF0000;000020;001j1`009P/00807000400009`]k1b4;N`LQ2h479`^11eH0000/0000
80/008H7000V2`00S0L000@0000W2hL78@^71b4;S@LW2hd7EP0002`0000P2`00TPL002H;002H1`00
100002L;T`LQ2i<78@^I1bL;V@MF0000;000020;002N1`009P/00:@7000400009`^O1b4;W`LQ2jD7
9`^U1eH0000/000080/00:X7000V2`00/0L000@0000W2j/78@^[1b4;/@LW2k47EP0002`0000P2`00
]PL002H;002l1`00100002L;]`LQ2kL78@^m1bL;_@MF0000;000020;00321`009P/00<P700040000
9`_31b4;``LQ2lT79`_91eH0000/000080/00<h7000V2`00e0L000@0000W2ll78@_?1b4;e@LW2mD7
EP0002`0000P2`00fPL002H;003P1`00100002L;f`LQ2m/78@_Q1bL;h@MF0000;000020;003V1`00
9P/00>`7000400009`_W1b4;i`LQ2nd79`_]1eH0000/000080/00?87000V2`00n0L000@0000W2o<7
8@_c1b4;n@LW2oT7EP0002`0000P2`00oPL002H;00042000100002L;o`LQ2ol78@/522L;1@QF0000
;000020;000:20009P/00108000400009`/;224;2`PQ2a489`/A25H0000/000080/001H8000V2`00
70P000@0000W2aL88@/G224;7@PW2ad8EP0002`0000P2`008PP002H;000X2000100002L;8`PQ2b<8
8@/Y22L;:@QF0000;000020;000^20009P/003@8000400009`/_224;;`PQ2cD89`/e25H0000/0000
80/003X8000V2`00@0P000@0000W2c/88@/k224;@@PW2d48EP0002`0000P2`00APP002H;001<2000
100002L;A`PQ2dL88@]=22L;C@QF0000;000020;001B20009P/005P8000400009`]C224;D`PQ2eT8
9`]I25H0000/000080/005h8000V2`00I0P000@0000W2el88@]O224;I@PW2fD8EP0002`0000P2`00
JPP002H;001`2000100002L;J`PQ2f/88@]a22L;L@QF0000;000020;001f20009P/007`800040000
9`]g224;M`PQ2gd89`]m25H0000/00008`/007l8000Y2`00Q@P000@0000T2h0890^622X;QPPZ2h08
EP0002`0000_2`00O`P003D;002520001000030;P0P`2hH8=P^623H;P0QF0000;00003/;001o2000
@@/008D800040000?0^023`;QPQ22hH8@P^025H0000/0000A`/007l8001=2`00Q@P000@000182h08
B0^624h;QPQ>2h08EP0002`0001C2`00O`P005T;00252000100005@;P0QD2hH8FP^625X;P0QF0000
;00005l;001o2000I@/008D800040000H0^0260;QPQV2hH8IP^025H0000/0000J`/007l8001a2`00
Q@P000@0001/2h08K0^6278;QPQb2h08EP0002`0001g2`00O`P007d;00252000100007P;P0Qh2hH8
OP^627h;P0QF0000;00008<;001o2000R@/008D800040000Q0^028@;QPR:2hH8RP^025H0000/0000
S`/007l8002E2`00Q@P000@0002@2h08T0^629H;QPRF2h08EP0002`0002K2`00O`P00:4;00252000
100009`;P0RL2hH8XP^62:8;P0QF0000;0000:L;001o2000[@/008D800040000Z0^02:P;QPR^2hH8
[P^025H0000/0000/`/007l8002i2`00Q@P000@0002d2h08]0^62;X;QPRj2h08EP0002`0002o2`00
O`P00<D;0025200010000<0;P0S02hH8aP^62<H;P0QF0000;0000</;001o2000d@/008D800040000
c0^02<`;QPSB2hH8dP^025H0000/0000e`/007l8003M2`00Q@P000@0003H2h08f0^62=h;QPSN2h08
EP0002`0003S2`00O`P00>T;0025200010000>@;P0ST2hH8jP^62>X;P0QF0000;0000>l;001o2000
m@/008D800040000l0^02?0;QPSf2hH8mP^025H0000/0000n`/007l800013000Q@P000@0003l2h08
o0^6208<QPP23808EP0002`000073000O`P000d<00252000100000P<P0P838H83Pb620h<P0QF0000
;00001<<001o20006@`008D80004000050b021@<QPPJ38H86Pb025H0000/00007``007l8000U3000
Q@P000@0000P380880b622H<QPPV3808EP0002`0000[3000O`P0034<00252000100002`<P0P/38H8
<Pb6238<P0QF0000;00003L<001o2000?@`008D800040000>0b023P<QPPn38H8?Pb025H0000/0000
@``007l800193000Q@P000@000143808A0b624X<QPQ:3808EP0002`0001?3000O`P005D<00252000
1000050<P0Q@38H8EPb625H<P0QF0000;00005/<001o2000H@`008D800040000G0b025`<QPQR38H8
HPb025H0000/0000I``007l8001]3000Q@P000@0001X3808J0b626h<QPQ^3808EP0002`0001c3000
O`P007T<00252000100007@<P0Qd38H8NPb627X<P0QF0000;00007l<001o2000Q@`008D800040000
P0b0280<QPR638H8QPb025H0000/0000R``007l8002A3000Q@P000@0002<3808S0b6298<QPRB3808
EP0002`0002G3000O`P009d<00252000100009P<P0RH38H8WPb629h<P0QF0000;0000:<<001o2000
Z@`008D800040000Y0b02:@<QPRZ38H8ZPb025H0000/0000[``007l8002e3000Q@P000@0002`3808
/0b62;H<QPRf3808EP0002`0002k3000O`P00<4<0025200010000;`<P0Rl38H8`Pb62<8<P0QF0000
;0000<L<001o2000c@`008D800040000b0b02<P<QPS>38H8cPb025H0000/0000d``007l8003I3000
Q@P000@0003D3808e0b62=X<QPSJ3808EP0002`0003O3000O`P00>D<0025200010000>0<P0SP38H8
iPb62>H<P0QF0000;0000>8<001f2000j0`007`800040000h`am2>T<O@SY37L8h`ag25H0000/0000
hP`006X8003X3000L0P000@0003S3748j@aa2>T<J`SS36/8EP0002`0003R3000GPP00>P<001T2000
10000><<I@SY36D8j@aO2><<G`QF0000;0000>8<001B2000j0`005P800040000h`aI2>T<F@SY35<8
h`aC25H0000/0000hP`004H8003X3000C0P000@0003S34d8j@a=2>T<A`SS34L8EP0002`0003R3000
>PP00>P<0010200010000><<@@SY3448j@`k2><<>`QF0000;0000>8<000^2000j0`003@800040000
h``e2>T<=@SY32l8h``_25H0000/0000hP`00288003X3000:0P000@0003S32T8j@`Y2>T<8`SS32<8
EP0002`0003R30005PP00>P<000L200010000><<7@SY31d8j@`G2><<5`QF0000;0000>8<000:2000
j0`0010800040000h``A2>T<4@SY30/8h``;25H0000/0000hP`00?h7003X300010P000@0003S30D8
j@`52>T<o`OS3?l7EP0002`0003R3000lPL00>P<003h1`0010000><<n@OY3?T7j@cc1n<<l`MF0000
;0000>8<003V1`00j0`00>`700040000h`c]1nT<k@OY3>L7h`cW1eH0000/0000hP`00=X7003X3000
h0L000@0003S3>47j@cQ1nT<f`OS3=/7EP0002`0003R3000cPL00>P<003D1`0010000><<e@OY3=D7
j@c?1n<<c`MF0000;0000>8<00321`00j0`00<P700040000h`c91nT<b@OY3<<7h`c31eH0000/0000
hP`00;H7003X3000_0L000@0003S3;d7j@bm1nT<]`OS3;L7EP0002`0003R3000ZPL00>P<002`1`00
10000><</@OY3;47j@b[1n<<Z`MF0000;0000>8<002N1`00j0`00:@700040000h`bU1nT<Y@OY39l7
h`bO1eH0000/0000hP`00987003X3000V0L000@0003S39T7j@bI1nT<T`OS39<7EP0002`0003R3000
QPL00>P<002<1`0010000><<S@OY38d7j@b71n<<Q`MF0000;0000>8<001j1`00j0`0080700040000
h`b11nT<P@OY37/7h`ak1eH0000/0000hP`006h7003X3000M0L000@0003S37D7j@ae1nT<K`OS36l7
EP0002`0003R3000HPL00>P<001X1`0010000><<J@OY36T7j@aS1n<<H`MF0000;0000>8<001F1`00
j0`005`700040000h`aM1nT<G@OY35L7h`aG1eH0000/0000hP`004X7003X3000D0L000@0003S3547
j@aA1nT<B`OS34/7EP0002`0003R3000?PL00>P<00141`0010000><<A@OY34D7j@`o1n<<?`MF0000
;0000>8<000b1`00j0`003P700040000h``i1nT<>@OY33<7h``c1eH0000/0000hP`002H7003X3000
;0L000@0003S32d7j@`]1nT<9`OS32L7EP0002`0003R30006PL00>P<000P1`0010000><<8@OY3247
j@`K1n<<6`MF0000;0000>8<000>1`00j0`001@700040000h``E1nT<5@OY30l7h``?1eH0000/0000
hP`00087003X300020L000@0003S30T7j@`91nT<0`OS30<7EP0002`0003R3000mPH00>P<003l1P00
10000><<o@KY3?d6j@cg1^<<m`IF0000;0000>8<003Z1P00j0`00?0600040000h`ca1^T<l@KY3>/6
h`c[1UH0000/0000hP`00=h6003X3000i0H000@0003S3>D6j@cU1^T<g`KS3=l6EP0002`0003R3000
dPH00>P<003H1P0010000><<f@KY3=T6j@cC1^<<d`IF0000;0000>8<00361P00j0`00<`600040000
h`c=1^T<c@KY3<L6h`c71UH0000/0000hP`00;X6003X3000`0H000@0003S3<46j@c11^T<^`KS3;/6
EP0002`0003R3000[PH00>P<002d1P0010000><<]@KY3;D6j@b_1^<<[`IF0000;0000>8<002R1P00
j0`00:P600040000h`bY1^T<Z@KY3:<6h`bS1UH0000/0000hP`009H6003X3000W0H000@0003S39d6
j@bM1^T<U`KS39L6EP0002`0003R3000RPH00>P<002@1P0010000><<T@KY3946j@b;1^<<R`IF0000
;0000>8<001n1P00j0`008@600040000h`b51^T<Q@KY37l6h`ao1UH0000/0000hP`00786003X3000
N0H000@0003S37T6j@ai1^T<L`KS37<6EP0002`0003R3000IPH00>P<001/1P0010000><<K@KY36d6
j@aW1^<<I`IF0000;0000>8<001J1P00j0`0060600040000h`aQ1^T<H@KY35/6h`aK1UH0000/0000
hP`004h6003X3000E0H000@0003S35D6j@aE1^T<C`KS34l6EP0002`0003R3000@PH00>P<00181P00
10000><<B@KY34T6j@a31^<<@`IF0000;0000>8<000f1P00j0`003`600040000h``m1^T<?@KY33L6
h``g1UH0000/0000hP`002X6003X3000<0H000@0003S3346j@`a1^T<:`KS32/6EP0002`0003R3000
7PH00>P<000T1P0010000><<9@KY32D6j@`O1^<<7`IF0000;0000>8<000B1P00j0`001P600040000
h``I1^T<6@KY31<6h``C1UH0000/0000hP`000H6003X300030H000@0003S30d6j@`=1^T<1`KS30L6
EP0002`0003R3000nPD00>P<00001P0010000><<0@KY3046j@ck1N<<n`EF0000;0000>8<003^1@00
j0`00?@500040000h`ce1NT<m@GY3>l5h`c_1EH0000/0000hP`00>85003X3000j0D000@0003S3>T5
j@cY1NT<h`GS3><5EP0002`0003R3000ePD00>P<003L1@0010000><<g@GY3=d5j@cG1N<<e`EF0000
;0000>8<003:1@00j0`00=0500040000h`cA1NT<d@GY3</5h`c;1EH0000/0000hP`00;h5003X3000
a0D000@0003S3<D5j@c51NT<_`GS3;l5EP0002`0003R3000/PD00>P<002h1@0010000><<^@GY3;T5
j@bc1N<</`EF0000;0000>8<002V1@00j0`00:`500040000h`b]1NT<[@GY3:L5h`bW1EH0000/0000
hP`009X5003X3000X0D000@0003S3:45j@bQ1NT<V`GS39/5EP0002`0003R3000SPD00>P<002D1@00
10000><<U@GY39D5j@b?1N<<S`EF0000;0000>8<00221@00j0`008P500040000h`b91NT<R@GY38<5
h`b31EH0000/0000hP`007H5003X3000O0D000@0003S37d5j@am1NT<M`GS37L5EP0002`0003R3000
JPD00>P<001`1@0010000><<L@GY3745j@a[1N<<J`EF0000;0000>8<001N1@00j0`006@500040000
h`aU1NT<I@GY35l5h`aO1EH0000/0000hP`00585003X3000F0D000@0003S35T5j@aI1NT<D`GS35<5
EP0002`0003R3000APD00>P<001<1@0010000><<C@GY34d5j@a71N<<A`EF0000;0000>8<000j1@00
j0`0040500040000h`a11NT<@@GY33/5h``k1EH0000/0000hP`002h5003X3000=0D000@0003S33D5
j@`e1NT<;`GS32l5EP0002`0003R30008PD00>P<000X1@0010000><<:@GY32T5j@`S1N<<8`EF0000
;0000>8<000F1@00j0`001`500040000h``M1NT<7@GY31L5h``G1EH0000/0000hP`000X5003X3000
40D000@0003S3145j@`A1NT<2`GS30/5EP0002`0003R3000oP@00>P<00041@0010000><<1@GY30D5
j@co1><<o`AF0000;0000>8<003b1000j0`00?P400040000h`ci1>T<n@CY3?<4h`cc15H0000/0000
hP`00>H4003X3000k0@000@0003S3>d4j@c]1>T<i`CS3>L4EP0002`0003R3000fP@00>P<003P1000
10000><<h@CY3>44j@cK1><<f`AF0000;0000>8<003>1000j0`00=@400040000h`cE1>T<e@CY3<l4
h`c?15H0000/0000hP`00<84003X3000b0@000@0003S3<T4j@c91>T<``CS3<<4EP0002`0003R3000
]P@00>P<002l100010000><<_@CY3;d4j@bg1><<]`AF0000;0000>8<002Z1000j0`00;0400040000
h`ba1>T</@CY3:/4h`b[15H0000/0000hP`009h4003X3000Y0@000@0003S3:D4j@bU1>T<W`CS39l4
EP0002`0003R3000TP@00>P<002H100010000><<V@CY39T4j@bC1><<T`AF0000;0000>8<00261000
j0`008`400040000h`b=1>T<S@CY38L4h`b715H0000/0000hP`007X4003X3000P0@000@0003S3844
j@b11>T<N`CS37/4EP0002`0003R3000KP@00>P<001d100010000><<M@CY37D4j@a_1><<K`AF0000
;0000>8<001R1000j0`006P400040000h`aY1>T<J@CY36<4h`aS15H0000/0000hP`005H4003X3000
G0@000@0003S35d4j@aM1>T<E`CS35L4EP0002`0003R3000BP@00>P<001@100010000><<D@CY3544
j@a;1><<B`AF0000;0000>8<000n1000j0`004@400040000h`a51>T<A@CY33l4h``o15H0000/0000
hP`00384003X3000>0@000@0003S33T4j@`i1>T<<`CS33<4EP0002`0003R30009P@00>P<000/1000
10000><<;@CY32d4j@`W1><<9`AF0000;0000>8<000J1000j0`0020400040000h``Q1>T<8@CY31/4
h``K15H0000/0000hP`000h4003X300050@000@0003S31D4j@`E1>T<3`CS30l4EP0002`0003R3000
0P@00>P<0008100010000><<2@CY30T4j@`31><<0`AF0000;0000>8<003f0`00j0`00?`300040000
h`cm0nT<o@?Y3?L3h`cg0eH0000/0000hP`00>X3003X3000l0<000@0003S3?43j@ca0nT<j`?S3>/3
EP0002`0003R3000gP<00>P<003T0`0010000><<i@?Y3>D3j@cO0n<<g`=F0000;0000>8<003B0`00
j0`00=P300040000h`cI0nT<f@?Y3=<3h`cC0eH0000/0000hP`00<H3003X3000c0<000@0003S3<d3
j@c=0nT<a`?S3<L3EP0002`0003R3000^P<00>P<00300`0010000><<`@?Y3<43j@bk0n<<^`=F0000
;0000>8<002^0`00j0`00;@300040000h`be0nT<]@?Y3:l3h`b_0eH0000/0000hP`00:83003X3000
Z0<000@0003S3:T3j@bY0nT<X`?S3:<3EP0002`0003R3000UP<00>P<002L0`0010000><<W@?Y39d3
j@bG0n<<U`=F0000;0000>8<002:0`00j0`0090300040000h`bA0nT<T@?Y38/3h`b;0eH0000/0000
hP`007h3003X3000Q0<000@0003S38D3j@b50nT<O`?S37l3EP0002`0003R3000LP<00>P<001h0`00
10000><<N@?Y37T3j@ac0n<<L`=F0000;0000>8<001V0`00j0`006`300040000h`a]0nT<K@?Y36L3
h`aW0eH0000/0000hP`005X3003X3000H0<000@0003S3643j@aQ0nT<F`?S35/3EP0002`0003R3000
CP<00>P<001D0`0010000><<E@?Y35D3j@a?0n<<C`=F0000;0000>8<00120`00j0`004P300040000
h`a90nT<B@?Y34<3h`a30eH0000/0000hP`003H3003X3000?0<000@0003S33d3j@`m0nT<=`?S33L3
EP0002`0003R3000:P<00>P<000`0`0010000><<<@?Y3343j@`[0n<<:`=F0000;0000>8<000N0`00
j0`002@300040000h``U0nT<9@?Y31l3h``O0eH0000/0000hP`00183003X300060<000@0003S31T3
j@`I0nT<4`?S31<3EP0002`0003R30001P<00>P<000<0`0010000><<3@?Y30d3j@`70n<<1`=F0000
;0000>8<003j0P00j0`0000300040000h``10nT<0@?Y3?/2h`ck0UH0000/0000hP`00>h2003X3000
m08000@0003S3?D2j@ce0^T<k`;S3>l2EP0002`0003R3000hP800>P<003X0P0010000><<j@;Y3>T2
j@cS0^<<h`9F0000;0000>8<003F0P00j0`00=`200040000h`cM0^T<g@;Y3=L2h`cG0UH0000/0000
hP`00<X2003X3000d08000@0003S3=42j@cA0^T<b`;S3</2EP0002`0003R3000_P800>P<00340P00
10000><<a@;Y3<D2j@bo0^<<_`9F0000;0000>8<002b0P00j0`00;P200040000h`bi0^T<^@;Y3;<2
h`bc0UH0000/0000hP`00:H2003X3000[08000@0003S3:d2j@b]0^T<Y`;S3:L2EP0002`0003R3000
VP800>P<002P0P0010000><<X@;Y3:42j@bK0^<<V`9F0000;0000>8<002>0P00j0`009@200040000
h`bE0^T<U@;Y38l2h`b?0UH0000/0000hP`00882003X3000R08000@0003S38T2j@b90^T<P`;S38<2
EP0002`0003R3000MP800>P<001l0P0010000><<O@;Y37d2j@ag0^<<M`9F0000;0000>8<001Z0P00
j0`0070200040000h`aa0^T<L@;Y36/2h`a[0UH0000/0000hP`005h2003X3000I08000@0003S36D2
j@aU0^T<G`;S35l2EP0002`0003R3000DP800>P<001H0P0010000><<F@;Y35T2j@aC0^<<D`9F0000
;0000>8<00160P00j0`004`200040000h`a=0^T<C@;Y34L2h`a70UH0000/0000hP`003X2003X3000
@08000@0003S3442j@a10^T<>`;S33/2EP0002`0003R3000;P800>P<000d0P0010000><<=@;Y33D2
j@`_0^<<;`9F0000;0000>8<000R0P00j0`002P200040000h``Y0^T<:@;Y32<2h``S0UH0000/0000
hP`001H2003X3000708000@0003S31d2j@`M0^T<5`;S31L2EP0002`0003R30002P800>P<000@0P00
10000><<4@;Y3142j@`;0^<<2`9F0000;0000>8<003n0@00j0`000@200040000h``50^T<1@;Y3?l1
h`co0EH0000/0000hP`00?81003X3000n04000@0003S3?T1j@ci0NT<l`7S3?<1EP0002`0003R3000
iP400>P<003/0@0010000><<k@7Y3>d1j@cW0N<<i`5F0000;0000>8<003J0@00j0`00>0100040000
h`cQ0NT<h@7Y3=/1h`cK0EH0000/0000hP`00<h1003X3000e04000@0003S3=D1j@cE0NT<c`7S3<l1
EP0002`0003R3000`P400>P<00380@0010000><<b@7Y3<T1j@c30N<<``5F0000;0000>8<002f0@00
j0`00;`100040000h`bm0NT<_@7Y3;L1h`bg0EH0000/0000hP`00:X1003X3000/04000@0003S3;41
j@ba0NT<Z`7S3:/1EP0002`0003R3000WP400>P<002T0@0010000><<Y@7Y3:D1j@bO0N<<W`5F0000
;0000>8<002B0@00j0`009P100040000h`bI0NT<V@7Y39<1h`bC0EH0000/0000hP`008H1003X3000
S04000@0003S38d1j@b=0NT<Q`7S38L1EP0002`0003R3000NP400>P<00200@0010000><<P@7Y3841
j@ak0N<<N`5F0000;0000=T<001g0@00g``007d100040000h0an0N0<N07J37P1fPan0EH0000/0000
c@`007L1003C3000O@4000@0003D37h1e0ah0Lh<N07>37h1EP0002`000313000M`400<L<001m0@00
10000<P<OP7837P1`Pah0L8<OP5F0000;0000;D<001g0@00^``007d100040000_0an0K`<N06f37P1
]Pan0EH0000/0000Z@`007L1002_3000O@4000@0002`37h1/0ah0JX<N06Z37h1EP0002`0002M3000
M`400:<<001m0@0010000:@<OP6T37P1WPah0Ih<OP5F0000;000094<001g0@00U``007d100040000
V0an0IP<N06B37P1TPan0EH0000/0000Q@`007L1002;3000O@4000@0002<37h1S0ah0HH<N06637h1
EP0002`0001i3000M`4007l<001m0@001000080<OP6037P1NPah0GX<OP5F0000;00006d<001g0@00
L``007d100040000M0an0G@<N05^37P1KPan0EH0000/0000H@`007L1001W3000O@4000@0001X37h1
J0ah0F8<N05R37h1EP0002`0001E3000M`4005/<001m0@00100005`<OP5L37P1EPah0EH<OP5F0000
;00004T<001g0@00C``007d100040000D0an0E0<N05:37P1BPan0EH0000/0000?@`007L100133000
O@4000@0001437h1A0ah0Ch<N04n37h1EP0002`0000a3000M`4003L<001m0@00100003P<OP4h37P1
<Pah0C8<OP5F0000;00002D<001g0@00:``007d100040000;0an0B`<N04V37P19Pan0EH0000/0000
6@`007L1000O3000O@4000@0000P37h180ah0AX<N04J37h1EP0002`0000=3000M`4001<<001m0@00
100001@<OP4D37P13Pah0@h<OP5F0000;000004<001g0@001``007d10004000020an0@P<N04237P1
0Pan0EH0000/0000m@/007L1003k2`00O@4000@0003l2gh1o0]h0OH;N07f2gh1EP0002`0003Y2`00
M`400>l;001m0@0010000?0;OP7`2gP1jP]h0NX;OP5F0000;0000=d;001g0@00h`/007d100040000
i0]n0N@;N07N2gP1gP]n0EH0000/0000d@/007L1003G2`00O@4000@0003H2gh1f0]h0M8;N07B2gh1
EP0002`000352`00M`400</;001m0@0010000<`;OP7<2gP1aP]h0LH;OP5F0000;0000;T;001g0@00
_`/007d100040000`0]n0L0;N06j2gP1^P]n0EH0000/0000[@/007L1002c2`00O@4000@0002d2gh1
]0]h0Jh;N06^2gh1EP0002`0002Q2`00M`400:L;001m0@0010000:P;OP6X2gP1XP]h0J8;OP5F0000
;00009D;001g0@00V`/007d100040000W0]n0I`;N06F2gP1UP]n0EH0000/0000R@/007L1002?2`00
O@4000@0002@2gh1T0]h0HX;N06:2gh1EP0002`0001m2`00M`4008<;001m0@00100008@;OP642gP1
OP]h0Gh;OP5F0000;000074;001g0@00M`/007d100040000N0]n0GP;N05b2gP1LP]n0EH0000/0000
I@/007L1001[2`00O@4000@0001/2gh1K0]h0FH;N05V2gh1EP0002`0001I2`00M`4005l;001m0@00
1000060;OP5P2gP1FP]h0EX;OP5F0000;00004d;001g0@00D`/007d100040000E0]n0E@;N05>2gP1
CP]n0EH0000/0000@@/007L100172`00O@4000@000182gh1B0]h0D8;N0522gh1EP0002`0000e2`00
M`4003/;001m0@00100003`;OP4l2gP1=P]h0CH;OP5F0000;00002T;001g0@00;`/007d100040000
<0]n0C0;N04Z2gP1:P]n0A<0000<00000@0002H0000L00000P000000000600001P000000008U0000
30000080000U000030000000080Z00006000070;000<1`00W0`003P8000U0000300000L0080X0000
30000080000<000040000000000000009@0000`0000700209@0000`0000000208@0000P0000N0000
60000<P;001?1`00@``00?@7000U000030000040001D0000F0000<L;001A1`00:P`00<8700010000
U:>7@9BSQd382`00DPL00080001<000010000<P;001?1`00@P`00?@7001@0000<@0d0380000b0000
E00005@0000[3000D@L0044<00321`000@0009BSQd2DXhM0;0`0058700010000C00000@000382`00
C`L0048<003d1`00D0000200c00]00008P0000`0003ooooo9P0001`000020000000000H000060000
00000RD0000<00000P0002D0000<00000000P2X0000H0000L0/004X5002L3000MPH002D0000<0000
1`00P2P0000<00000P0000`0000@000000000000000U0000300000L0080U000030000000080Q0000
200001h0000H0000b0/008d500133000<PH002D0000<00000@0005@0001H0000a`/008l5000Z3000
00H00040002DXhM0U:>7@<P;002@1@000P0004`000040000b0/008d500123000<PH00500000a03<0
<P000380001D0000E00002/<002?1@00@@`0000600010000U:>7@9BSQd0/3000T0D00040001<0000
10000<P;002=1@00@P`00386001@0000800002d0000R000030000?oooolV00007000008000000000
1P0000H0000000029@0000`0000200009@0000`000000020:P0001P0001`2`00aP4009`<003b0P00
9@0000`000070020:00000`0000200003000010000000000000002D0000<00001`00P2D0000<0000
0000P240000800007P0001P000382`002@8004<<002^0P009@0000`000010000E00005P000372`00
2`8002X<001l0P000@0009BSQd2DXhM0b0/000`200020000C00000@000382`002@80048<002^0P00
D0000340=`0b0000<P0005@0001D0000:``000/200113000O0800040002DXhM0U:>7@2`<000<0P00
0@0004`000040000b0/000T200123000[P800500000P0000;@000280000<0000ooooobH0000L0000
0P000000000600001P000000008U000030000080000U000030000000080Z00006000070;00280`00
W0`00;@4000U0000300000L0080X000030000080000<000040000000000000009@0000`000070020
9@0000`0000000208@0000P0000N000060000<P;003;0`00@``00704000U000030000040001D0000
F0000<L;003=0`00:P`003h400010000U:>7@9BSQd382`00cP<00080001<000010000<P;003;0`00
@P`00704001@0000<@0f0380000b0000E00005@0000[3000c@<0044<000n10000@0009BSQd2DXhM0
;0`00<h300010000C00000@000382`00b`<0048<001`1000D0000200000]00008P0000`0003ooooo
9P0001`000020000000000H000060000000002D0000<00000P0002D0000<00001@00P5L0000T0000
0@`00>h200073000B`<0008000053?821@a90bD0000<00002000P2P0000<00000P0002D0000<0000
2000P2D0000<00001000P5H0000X0000i0/004H3000U3000Q`<000<0003U2dL31Pb80bH<A`<V0000
70000080000000001P0000H0000000009@0000`0000200009@0000`000050020E`0002@000013000
/0@000L<000=1@000P0000D<]0@530/59@0000`000080020:00000`0000200009@0000`000080020
9@0000`000040020EP0002P0003T2`0020D002D<00191@000`000>D;2@D634X59P`91BH0000L0000
0P000000000600001P000000000U000030000080000U0000300000D0081G00009000004<001b1P00
1``00<l6000200001@af1PD<c@HU0000300000P0080X000030000080000U0000300000P0080U0000
300000@0081F0000:0000>@;003:1P009@`000/700030000i@_;1PH<30LV3</69P0001`000020000
000000H000060000000002D0000<00000P0002D0000<00001@00P5L0000T0000m0T00;0400102`00
^`D00080003h2K@4?P^i1BD0000<00002000P2P0000<00000P0002D0000<00002000P2D0000<0000
1000P5H0000X00009`/009d5001_2`00g`D000<0000X2m45L0_P1E4;WPDV00007000008000000000
1P0000H0000000009@0000`0000200009@0000`000050020E`0002@0001n2P00WPL0074;002T1`00
0P0006l;XPN22Z879@0000`000080020:00000`0000200009@0000`0000800209@0000`000040020
EP0002P000132P00P@L008@:00321`000`0008D:PPM42Z87Q@[31bH0000L00000P00000000060000
1P000000008U000030000080000U000030000000080Z0000600000/700280`00n@T002/6000U0000
300000L0080X000030000080000<000040000000000000009@0000`0000700209@0000`000000020
8@0000P0000N000060000:D700021000GPT00;05000U000030000040001D0000F0000:@700011000
e@L0078400010000U:>7@9BSQd2U1`000P@00080001<000010000:D700021000G@T00;05001@0000
800P01T0000I0000E00005@0003F1`000@@00088001b10000@0009BSQd2DXhM0e`L0008400010000
C00000@0002U1`000P@005d9002`1@00D0000200000]0000E00007`0002T1`00M`@008@8003X1000
0@0009BSQd2DXhM0Y@L007P400080000C00000@0002U1`000P@005d9002`1@00G0000200800P0200
800P0200<@0I00006@0001T0000I00006@0001T0000I0000<P0005@0001D0000Q@P007L4002a2000
j0@00040002DXhM0U:>7@8H8001h10000@0004`000040000Y@L00084001M2@00/0D00500000P0000
;@000280000<0000ooooobH0000L00000P000000000600001P000000008U000030000080000U0000
30000000080Z0000600002X6000<1`00X@L008<8000U0000300000L0080X000030000080000<0000
40000000000000009@0000`0000700209@0000`0000000208@0000P0000N0000600008d6001J1`00
?@L003@8000U000030000040001D0000H00008`6001L1`0020L00<d700010000U:>7@9BSQd2=1P00
G@L000<0001<0000100008d6001J1`00?0L003@8001D0000800a0340000I0000<P000380001D0000
E00000T7001L1`00=@L00<d700010000U:>7@9BSQd0:1`00G@L00040001<0000100008d6001J1`00
?0L003@8001@0000800002d0000R000030000?oooolV000070000080000000001P0000H000000002
9@0000`0000200009@0000`000000020:P0001P000270`00XPL00?h4000I2@009@0000`000070020
:00000`0000200003000010000000000000002D0000<00001`00P2D0000<00000000P24000080000
7P0001P0003Z0`00l0L009X4003:20009@0000`000010000E0000600003Y0`00lPL006D4001S2000
0@0009BSQd2DXhM0jP<00?<700030000C00000@0003Z0`00l0L009T4003:2000E0000200<@0b0000
6@000380000b0000E00005@0001V1000lPL00984001S20000@0009BSQd2DXhM0I`@00?<700010000
C00000@0003Z0`00l0L009T4003:2000D0000200000]00008P0000`0003ooooo9P0001`000020000
000000H000060000000002D0000<00000P0002D0000<00001@00P5L0000T0000L`L002L6003]1`00
fPH00080003[1b/6M`OH1RD0000<00002000P2P0000<00000P0002D0000<00002000P2D0000<0000
1000P5H0000X0000E@L00<<6002D1`002`L000<0001O1l@6EPL<1iD7j0HV00007000008000000000
1P0000H0000000009@0000`0000200009@0000`000050020E`0002@0000f1@00j@L002/6000Z2000
0P0002T6k@Lj1BP89@0000`000080020:00000`0000200009@0000`0000800209@0000`000040020
EP0002P0003m100020P004@5001720000`0003D52@Sn13P8A@E822H0000L00000P00000000060000
1P000000000U000030000080000U0000300000D0081G000090000>40003k1000c`H0004500020000
i@3o1<d6o`@U0000300000P0080X000030000080000U0000300000P0080U0000300000@0081F0000
:0000<X6003N10002`L001l500030000b`HP1@`700G;1]l43000010000000000000000h0000D0000
00000100000D0000
\>"], "Text",
 ImageSize->{345.25, 243},
 ImageMargins->{{0, 0}, {0, 10.0625}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell["Compartment numbers", "Text",
 CellDingbat->"\[FilledSmallSquare]"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompartNumbers", "[", "calcium", "]"}]], "Input",
 CellLabel->"In[228]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "\<\"Plasma\"\>"},
    {"2", "\<\"ST2\"\>"},
    {"3", "\<\"ST1\"\>"},
    {"4", "\<\"ST0\"\>"},
    {"5", "\<\"CorticalSurf\"\>"},
    {"6", "\<\"CorticalVolExch\"\>"},
    {"7", "\<\"CorticalVolNonExch\"\>"},
    {"8", "\<\"TrabecularSurf\"\>"},
    {"9", "\<\"TrabecularVolExch\"\>"},
    {"10", "\<\"TrabecularVolNonExch\"\>"},
    {"11", "\<\"Bladder\"\>"},
    {"12", "\<\"Urine\"\>"},
    {"13", "\<\"ULI\"\>"},
    {"14", "\<\"LLI\"\>"},
    {"15", "\<\"Faeces\"\>"},
    {"16", "\<\"SI\"\>"},
    {"17", "ST"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.3992831198949547`*^9, 3.41783663439133*^9, 
  3.479828076242801*^9, 3.4798287517781963`*^9, 3.479829958436082*^9, 
  3.5185353547864084`*^9, 3.6434438405391345`*^9},
 CellLabel->"Out[228]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"TransferRates", "[", "calcium", "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<From\>\"", ",", " ", "\"\<to\>\"", ",", 
        "\"\<Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\>\""}], "}"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[229]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"From\"\>",
       HoldForm], 
      TagBox["\<\"to\"\>",
       HoldForm], 
      TagBox["\<\"Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\"\>",
       HoldForm]},
     {"1", "2", "0.00075`"},
     {"1", "3", "1.5`"},
     {"1", "4", "8.7`"},
     {"1", "5", "1.67`"},
     {"1", "8", "2.08`"},
     {"1", "11", "0.6`"},
     {"1", "13", "0.45`"},
     {"2", "1", "0.00038`"},
     {"3", "1", "0.1733`"},
     {"4", "1", "2.9`"},
     {"5", "1", "0.578`"},
     {"7", "1", "0.0000821`"},
     {"8", "1", "0.578`"},
     {"10", "1", "0.000493`"},
     {"5", "6", "0.116`"},
     {"6", "5", "0.002773`"},
     {"6", "7", "0.004159`"},
     {"8", "9", "0.116`"},
     {"9", "8", "0.002733`"},
     {"9", "10", "0.004159`"},
     {"13", "14", 
      SubscriptBox["k", "ULI"]},
     {"11", "12", "12"},
     {"14", "15", 
      SubscriptBox["k", "LLI"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"From", "to", "Tranfer Rates(\!\(days\^\(-1\)\))"}}]]]], "Output",
 CellChangeTimes->{3.3992831199257765`*^9, 3.417836634406955*^9, 
  3.4798280762740507`*^9, 3.479828751809452*^9, 3.4798299584985833`*^9, 
  3.51853535484891*^9, 3.6434438405703845`*^9},
 CellLabel->"Out[229]//TableForm="]
}, Open  ]],

Cell["The compartmental matrix is", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"calciumMatrix", "=", 
   RowBox[{"CompartMatrix", "[", 
    RowBox[{"15", ",", 
     RowBox[{"TransferRates", "[", "calcium", "]"}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[230]:="],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "element", ",", " ", "lambda", ",", " ", "fn1", ",", " ", "amad", ",", " ", 
   "class"}], "]"}]], "Input",
 CellLabel->"In[231]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"element", "=", " ", "calcium"}], ";", 
   RowBox[{"lambda", " ", "=", " ", 
    RowBox[{
     RowBox[{"Log", "[", "2", "]"}], "/", "8.0"}]}], ";", " ", 
   RowBox[{"fn1", " ", "=", " ", "0.3"}], ";", " ", 
   RowBox[{"amad", "=", " ", 
    RowBox[{"AMADAdultW", "[", "5", "]"}]}], ";", 
   RowBox[{"class", " ", "=", " ", "M"}], ";"}], " "}]], "Input",
 CellLabel->"In[232]:="]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[233]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.07332133122139121`", "0.013958221362123598`", 
      "0.8297244906211501`"},
     {"2", "0.027603102545498245`", "0.02407466398543609`", 
      "0.709182946114595`"},
     {"3", "0.018718534089122725`", "0.020241952289826982`", 
      "0.6113631425799334`"},
     {"4", "0.014042090323929399`", "0.015064503283447417`", 
      "0.5315158800047352`"},
     {"5", "0.011006365220744475`", "0.01119162488193483`", 
      "0.4652042208891509`"},
     {"6", "0.008825158655552183`", "0.008537320631794722`", 
      "0.40923167218388296`"},
     {"7", "0.007181442988943843`", "0.006690866142316295`", 
      "0.3613947888687687`"},
     {"8", "0.005908697400541646`", "0.0053567164865608585`", 
      "0.3201350686986565`"},
     {"9", "0.004903978001899328`", "0.0043572734177227245`", 
      "0.28430390094865077`"},
     {"10", "0.004098435197337651`", "0.003586690246473755`", 
      "0.25302270122496145`"},
     {"20", "0.000810785756899261`", "0.0006757128738213496`", 
      "0.08523118786083428`"},
     {"30", "0.0001766080446676121`", "0.00014593813621679985`", 
      "0.03143171429145349`"},
     {"40", "0.000040568812293225245`", "0.000033215696896123775`", 
      "0.012235177457348442`"},
     {"50", "0.000010049520388055318`", "8.119751927249963`*^-6", 
      "0.004912080559310453`"},
     {"60", "2.750596445899125`*^-6", "2.1864034486339056`*^-6", 
      "0.002005260071497206`"},
     {"70", "8.397831227335815`*^-7", "6.566785653370338`*^-7", 
      "0.0008258491003886286`"},
     {"80", "2.826066345601799`*^-7", "2.1805329150859304`*^-7", 
      "0.0003417065053311685`"},
     {"90", "1.0219813995428206`*^-7", "7.813292794450748`*^-8", 
      "0.0001417442830518889`"},
     {"100", "3.870313729355693`*^-8", "2.942419646083052`*^-8", 
      "0.00005888307851653474`"},
     {"180", "2.4685664127380407`*^-11", "1.8633869503973704`*^-11", 
      "5.328914648318214`*^-8"},
     {"200", "4.004512951206734`*^-12", "3.0222458968455847`*^-12", 
      "9.273868057250982`*^-9"},
     {"300", "4.661091648509932`*^-16", "3.5146247695512504`*^-16", 
      "1.5014455236289034`*^-12"},
     {"400", "5.789034356455865`*^-20", "4.3607379387802596`*^-20", 
      "2.4726456035903896`*^-16"},
     {"500", "7.702223469211354`*^-24", "5.7960868794692395`*^-24", 
      "4.115458551752723`*^-20"},
     {"600", "1.0925071144918483`*^-27", "8.214175744355221`*^-28", 
      "6.894381293725897`*^-24"},
     {"700", "1.633299848466971`*^-31", "1.2271894076667165`*^-31", 
      "1.1595710714982632`*^-27"},
     {"800", "2.538767318246328`*^-35", "1.9066029839507425`*^-35", 
      "1.9550847097406503`*^-31"},
     {"900", "4.0530110306240917`*^-39", "3.04282357893292`*^-39", 
      "3.3014798084278293`*^-35"},
     {"1000", "6.583772150227121`*^-43", "4.941805005188473`*^-43", 
      "5.5807916895642226`*^-39"},
     {"2000", "0", "0", "0"},
     {"3000", "0", "0", "0"},
     {"4000", "0", "0", "0"},
     {"5000", "0", "0", "0"},
     {"6000", "0", "0", "0"},
     {"7000", "0", "0", "0"},
     {"8000", "0", "0", "0"},
     {"9000", "0", "0", "0"},
     {"10000", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992831202802224`*^9, 3.41783663476633*^9, 
  3.4798280767271643`*^9, 3.4798287522001495`*^9, 3.4798299589204664`*^9, 
  3.518535355052039*^9, 3.6434438406954103`*^9},
 CellLabel->"Out[233]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[234]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwd03k8VVsUB3BTd3C5w7kqDxWFh1SiKNFdZCoUKkpRKZFCZUgyJzJmTjIl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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwd1HlYTV8XB/DTdLu34Q7nFlE0KCqlAUWDuyQlFU2KfgoNoihJSZRKAxpI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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -5.6810779562959315`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-5.6810779562959315`, -1.2384537482739597`}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, -5.5}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992831231157913`*^9, 3.417836637781955*^9, 
  3.479828078586491*^9, 3.479828753825451*^9, 3.4798299609517555`*^9, 
  3.5185353569895763`*^9, 3.643443840992263*^9},
 CellLabel->"Out[234]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[235]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.020105279088843957`", "0.19887118919655924`", 
      "0.6980275749188215`"},
     {"2", "0.008873941374370746`", "0.23194948440743587`", 
      "0.39927068268730787`"},
     {"3", "0.0058461506842270375`", "0.1079105981816766`", 
      "0.25237608149154034`"},
     {"4", "0.004335042339151988`", "0.042891832407402776`", 
      "0.18420301238938197`"},
     {"5", "0.003380038251097327`", "0.016951415416389577`", 
      "0.14858345346407595`"},
     {"6", "0.002702084551643502`", "0.0072716452510362545`", 
      "0.1262778977771998`"},
     {"7", "0.0021942258457133593`", "0.003633704161698542`", 
      "0.10996941282167047`"},
     {"8", "0.0018024509912534861`", "0.0021749640837035386`", 
      "0.0968649811113602`"},
     {"9", "0.0014940529162696431`", "0.0015119639143138248`", 
      "0.08581956249347873`"},
     {"10", "0.0012473652432238775`", "0.0011549924377848`", 
      "0.07629452811156757`"},
     {"20", "0.0002458955189236107`", "0.00020497541379752872`", 
      "0.025638166157348596`"},
     {"30", "0.00005351870669239618`", "0.000044229956952117306`", 
      "0.00944447432086406`"},
     {"40", "0.000012281735563683584`", "0.000010057445823765006`", 
      "0.00367398328421728`"},
     {"50", "3.0380901172977408`*^-6", "2.455288589565325`*^-6", 
      "0.0014744715896876125`"},
     {"60", "8.301128389086694`*^-7", "6.600207980640329`*^-7", 
      "0.0006018092152298957`"},
     {"70", "2.5301172492098726`*^-7", "1.978936552309982`*^-7", 
      "0.0002478250900045446`"},
     {"80", "8.502817181172252`*^-8", "6.561773881879756`*^-8", 
      "0.00010253556829980375`"},
     {"90", "3.0719915025358`*^-8", "2.3488813182588738`*^-8", 
      "0.00004253181035126411`"},
     {"100", "1.162729479222224`*^-8", "8.840284433926745`*^-9", 
      "0.000017668148759140075`"},
     {"180", "0", "0", "1.5988798282073317`*^-8"},
     {"200", "0", "0", "2.7824936613820035`*^-9"},
     {"300", "0", "0", "0"},
     {"400", "0", "0", "0"},
     {"500", "0", "0", "0"},
     {"600", "0", "0", "0"},
     {"700", "0", "0", "0"},
     {"800", "0", "0", "0"},
     {"900", "0", "0", "0"},
     {"1000", "0", "0", "0"},
     {"2000", "0", "0", "0"},
     {"3000", "0", "0", "0"},
     {"4000", "0", "0", "0"},
     {"5000", "0", "0", "0"},
     {"6000", "0", "0", "0"},
     {"7000", "0", "0", "0"},
     {"8000", "0", "0", "0"},
     {"9000", "0", "0", "0"},
     {"10000", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992831246568613`*^9, 3.41783663939133*^9, 
  3.4798280801802006`*^9, 3.4798287554820085`*^9, 3.4798299626236625`*^9, 
  3.518535358130223*^9, 3.6434438413516665`*^9},
 CellLabel->"Out[235]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[236]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwd1HlYTVsUAPDGc6e695xzo8yhehWpRGhwlyTNKtyIMjVQVHjSI0koDaJB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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwl1nc4le8bAHB7HeOcQ6UtUShRComeO9mljKIU0i5FJZJKtkKShpGsZESR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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -4.889947163913916}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-4.889947163913916, -0.07690723102597341}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, 
     AxesOrigin -> {0, -4.6000000000000005`}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992831287715178`*^9, 3.417836643781955*^9, 
  3.4798280831801233`*^9, 3.47982875837317*^9, 3.479829965717472*^9, 
  3.518535360677147*^9, 3.6434438419610224`*^9},
 CellLabel->"Out[236]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[237]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Lung\\nretention\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.05284290791188208`", "0.009902505285749236`", 
      "0.0767584959007056`", "0.46856213898185184`"},
     {"2", "0.047033662078303826`", "0.004358484421388343`", 
      "0.09295744796894906`", "0.2661262428582927`"},
     {"3", "0.042399877309584715`", "0.0028957736564685465`", 
      "0.04418650936057276`", "0.17461366427075659`"},
     {"4", "0.03829433498449951`", "0.0021618214052698476`", 
      "0.018022008313491142`", "0.1324002990229514`"},
     {"5", "0.034599222062283004`", "0.0016967814604718337`", 
      "0.007434731524198089`", "0.10973740828800488`"},
     {"6", "0.03126585513913936`", "0.001365669742175024`", 
      "0.003421408340498961`", "0.0949848002817326`"},
     {"7", "0.028257504214706634`", "0.0011167181456480917`", 
      "0.0018742411293830533`", "0.08382112039909534`"},
     {"8", "0.02554198613448741`", "0.000923854103623209`", 
      "0.0012258713077799785`", "0.07461696356968019`"},
     {"9", "0.023090439281884693`", "0.0007713225470991977`", 
      "0.0009110692735942382`", "0.06670873408602986`"},
     {"10", "0.02087689336785914`", "0.0006486974521428907`", 
      "0.0007282365803332889`", "0.05978413511612979`"},
     {"20", "0.007673223211142425`", "0.0001389099063271063`", 
      "0.0001589949128349714`", "0.021163750178709858`"},
     {"30", "0.002853115420207813`", "0.00003381129848555818`", 
      "0.000041738063611968794`", "0.007946384302844722`"},
     {"40", "0.0010718241099803602`", "8.962592211924194`*^-6", 
      "0.000011776862612697869`", "0.003089566595903123`"},
     {"50", "0.00040627472651778336`", "2.6058340040106796`*^-6", 
      "3.5481205385344423`*^-6", "0.001227110951061742`"},
     {"60", "0.0001551889722724287`", "8.2797467216773`*^-7", 
      "1.1324429882127434`*^-6", "0.0004937755518706785`"},
     {"70", "0.000059667927209074944`", "2.83053303198111`*^-7", 
      "3.7897637954532353`*^-7", "0.00020031720771043735`"},
     {"80", "0.000023067814766038906`", "1.0205933929053425`*^-7", 
      "1.3163527946481897`*^-7", "0.00008169948411517186`"},
     {"90", "8.959007307660906`*^-6", "3.813617088361051`*^-8", 
      "4.705343956951201`*^-8", "0.00003344327854442505`"},
     {"100", "3.4926846706838767`*^-6", "1.4580653478737227`*^-8", 
      "1.7195818296558095`*^-8", "0.000013726151245783063`"},
     {"180", "2.010286592861678`*^-9", "8.701103909116456`*^-12", 
      "8.233366884254877`*^-12", "1.161011107347091`*^-8"},
     {"200", "3.145963881910059`*^-10", "1.3928881899970734`*^-12", 
      "1.287792845677787`*^-12", "1.99590516082218`*^-9"},
     {"300", "3.00272630940881`*^-14", "1.5281016074115549`*^-16", 
      "1.3368890529705897`*^-16", "3.081529269118281`*^-13"},
     {"400", "2.8911365558447345`*^-18", "1.764540722953916`*^-20", 
      "1.499828423522129`*^-20", "4.9176623794791475`*^-17"},
     {"500", "2.7902438548616693`*^-22", "2.15034089856478`*^-24", 
      "1.780151630138099`*^-24", "8.019481905138463`*^-21"},
     {"600", "2.6969958470365366`*^-26", "2.783382578592621`*^-28", 
      "2.247112318259939`*^-28", "1.326183388944262`*^-24"},
     {"700", "2.6107108935895283`*^-30", "3.8292140411233745`*^-32", 
      "3.024342284030126`*^-32", "2.2125907560183495`*^-28"},
     {"800", "2.531049890550114`*^-34", "5.5644672787422187`*^-36", 
      "4.3193162568197075`*^-36", "3.7119551242748124`*^-32"},
     {"900", "2.457737132194935`*^-38", "8.451072787095715`*^-40", 
      "6.478619252697024`*^-40", "6.24899584413431`*^-36"},
     {"1000", "2.390520521624115`*^-42", "1.3260521333625245`*^-43", 
      "1.0081128656079806`*^-43", "1.0543193901062636`*^-39"},
     {"2000", "0", "0", "0", "0"},
     {"3000", "0", "0", "0", "0"},
     {"4000", "0", "0", "0", "0"},
     {"5000", "0", "0", "0", "0"},
     {"6000", "0", "0", "0", "0"},
     {"7000", "0", "0", "0", "0"},
     {"8000", "0", "0", "0", "0"},
     {"9000", "0", "0", "0", "0"},
     {"10000", "0", "0", "0", "0"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Lung\nretention", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992831384628873`*^9, 3.417836653813205*^9, 
  3.4798280945860815`*^9, 3.4798287682812586`*^9, 3.4798299757645397`*^9, 
  3.518535368286668*^9, 3.6434438443985443`*^9},
 CellLabel->"Out[237]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[238]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV1nk4Vd0XB3DzzL33nCtCpmQIoXpVirvI2PSaopQhKWVMg2SIlKk0iAqV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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwd13k4VF8YB3A7M3Nnu3eKpKgQUgqRrXn5WbIVKkqoLJFCCypKyB4lW1Kp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        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwl13lYTdv7APAmzZ3OkIQkDTSpkCKxXt0KERVCGgxFA6HUTWiiQSpUl6RB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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -5.636557923990568}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-5.636557923990568, -0.09060919827694974}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, -5.4}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Lungs\"", 11, StripOnInput -> False], 
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.399283168281077*^9, 3.41783668486008*^9, 
  3.479828109804442*^9, 3.479828782440136*^9, 3.4798299901554413`*^9, 
  3.518535381005662*^9, 3.643443847679824*^9},
 CellLabel->"Out[238]="]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Iron", "SubsectionIcon"],

Cell[CellGroupData[{

Cell["Model", "SubsubsectionIcon"],

Cell["\<\
This picture represent the metabolic model for Iron (ICRP 1995a). There are \
16 compartments, ST and SI have been added as n+2 and n+1 respectively\
\>", "Text"],

Cell[GraphicsData["CompressedBitmap", "\<\
eJztXUuTHbUVbs99eJzYZoDYmATswTYkPPyAVB4VgrkmECqpongklQpZZGYg
U4GkSBygkhAb+Aks8gPYZ5V/4KWXTlYscRULZ8eS5WSkbrWOdD+ppW51S32t
Lrvv3HPV0neOjtR6nHP00s77b+2+s/P+22/ubL747s6Vt95+873Nn/753X3S
5EBRrD2w//8/mwX7e68oxG1v/195O8lujJwJmZAJmZAJmZAJmZAJmPA8/5gU
GxsbhbgW/F7SqtTlg/9UnynHXuXvC0DLz+wVt4B8Xwfy/UW7bCntdUDL2eZs
c7Y525XM9l5256QJ/z5Vft2/1jB5Uj93nyOwk4A2VUtfU3Mufy7IddqPuXv4
fabQRI4GvqxkNfcTHRifGGlzvWjxeRA8ciqqPKZdq39S54Lku6b+upaAAiyR
vbhvbmbGytflw66zgWXBBUzaXJVgUlN5gi5aL3ORf6GG/1A4zh7tAPeH4WDM
QHrEpREaV5gf+AEa15soZ5uzzdnmbJuyfbGi0dWAXX5XVwPO91s8pe0CWi4+
F5+Lz8Xn4h2Kv3jxYiGuBb+XtJ6Lf7X66fbt2/zVwT4/7LeoK1eu8J/ZZ09F
vcI/Zpyb9fV1noR9su/XwGPGmRqhlVXCrqU1GY8VE57o2+E4FMIUF/vehUPj
KgRM57pGEIDhl4miiipdqypFVC1L8Y+WzNff5EKAB4971bQ9GKPT4saNG8XH
H3/M//NS2R8TThZPfGDidVrKxa0qp+7ai7J82MIy7dTEdhXt1CqWXwNZmJXY
tpZlqs9JISUirmnNvLHq3qhoN2/erGlX+8X8DKDtEN0XnfS1FjCMamErlHbX
noWinny7kgfqmj1Fa8se9YsBst8iNWHrhT4IVZRTP/D37qW9AWgB5JWzzdmq
2W5vb4fM9lYSWYj3naN5RoiiKM0ymshFdSwKWTa9AKr2uX6Lpz+9AGi5+Fx8
Ll7Q7qpotNFe5ne10d7lCPN+fneaIsmZY0nHiwVoo7mwTy2/1a+oKO2yYzpv
UTlJUN8oRuksWaLJ/mrISTME8bSXqPNdYUUyCmPqIisn7bx/TNJTaZOaJ/mX
NDsphSOXSOonpKHKA+PlfQ5oXwM0tAo0ehaXFPuRcXDZ8+ggw0wR5iV2593N
SLracvF0qY0hK0ELem7bqvW3NkNJfZw5E7/SlGWCmUmYQ0hno0agvW8Ma+LS
BNK4FTWTCQtxGTdslNz4X/f6VczcAjaIAa3H/guiHY9ZsUsjDHY/uqSGjp/I
RNS8DdV2jsEuJLRGHdDH0l1AyESWhrskiiJyO4b1cKRVddtt3pGsSafgVMft
G3v3inYC2DBnQfO0kTZsa8+HaqCrcwD7f3f3qudtU7PMRxOoNfDr8soPGhHE
qtCpit1jbUvzVrC3VCQdTvtGm8rBL+GjIP3XAS2l9oSwfMdPJHLAiIC4CkBU
8+eff15cv36df0PWACMRyguVaCiNscZ2HdnF9s4vDcBeh7mWgFt+m3DIIt2P
04a+ubnJPy/x+6xYLBZ1Op7B/oV65cHhyt7u008/ZbCFDccohK2qN+EiVfXm
vTc0PippBX6/2qeCaDFSZM/aUMLV2DylRANFjzHlUlI0s0ICTHAdykdY9be2
eyOuipaqnGYmJrqrkMd2W6rS8dUiY6ekDYQfXE0ZrBv1SKUhC+BU2TeawK4Y
s3mT4Q6EeRrQNscB/QygnRoHdDkRb7EuTUYduGNGIRISFELvuyQNI7qRqHk4
MemToywZQZ7ZUqtD3VWRTWPcGjSI1QpZgUHsj8bPApqoPzUOtoYcJDk6FsaC
aXHYiw0JuPPFgrRdtQOLK2BsaBY3wljQtohuObggxoXp476IIiEITxvatkMj
fQPQqjr+by4qF5WLykXlonJRTkUB9+bQRd0aVbbINXqL31VXvJf6LZ7StgAt
F3/HF488vRdAU1Ekrggw6U8LQMswM8wMM3mYp/g9PdfysYkqlmv5asipR9fy
1RBQLNdyi/SQa8tjUSWq0iY1n/Kvzu7mFnkglwJ09kEseXRxQbewfaSWcKmJ
rSwl8XvBFOlU7yz3L+RvkJ6gnRzhLbI+7CFhk3D9kupH3shaUZEh87UER1kb
VQVpXKqC8ZAXeAfpbzEwhoqlrJ7Cki0bmc2Hsui16xa7joxDXIcBDR0oRXRO
9oDzmnnzCVzVw5yMOu4hZIKsNJA1x8maFc9Rha2L0xWBXagDTkkQD2LdR76Y
Tk1R9zZkF8Icq9HcVyOdgL90R2q9c9zrJbpCglOA4xY1b2OY2KyI5nShAxms
vrgjBg9YfeG2D0XSr+/+GCWPut+evehHJiY0PEFO341DFveQKzaL6sb4REjk
SIZiQsac6oU7Kpq4ucr1UZAf4nAQWUsPZPTZpnM5rJObPlHfbK6HqbA/4xv0
+/JDrc6vKuZ6lgLZDniko0R1Y/84QlyvORaXxvlPWgqQZtePAK0+AQbyIRcJ
1m8qFutAXMIimbnkM/FI2ahFLcRDqsf6b1vwbzxIluwJ6WP6Pf8IMOi9bFaY
mVLDTBosUAHKt23To/m21BxNcue8OCwjRggEIfp3mh+S1FabxtE8O3nck22q
ryHYpvkFYDvWSCfDzDBXBKZtIRAtLSEP3pGx5bFEMypu8VTHNhc6A6QkQoQh
75EU2CShHVwHepRNPUxYqmzamiQfwcjFg9NVHmIMWkqiTE0jXbmO2xNhFW3f
nSKsijBkpfPQMGHIWissGqA9RJgXzCSslgutrmg0shHAFf+Z6iQLN/k3TYa5
CjCfrGj0wFM0NUwEOnUV3eJ31VU0MkxPn+shIG3zu7fPdRdo9wAaWoLgPTJf
qON0tFht48jTVTs0R2uSh5rGCy/shnlIEmhTF+EQnUoHV/DhxeAUm/KYlwS6
epkvKpnRrsNPCDaGkYCWhIDMWXpyaeSI57XuzUuBLadDxtx9QoJdhOtpGUPL
rxPYLhofg4HwPVd4NW759lhtb+RcVC4qF5WLykXloloXNfqQFsix/3l+Vx37
+1oGdwx9gaZniJbgan2GmWFmmBlmhukHkx8mYDxCIkHAZ/l9aZkAeWoniF5z
qJTGjxZD/AJb8qOFjgQ5brZ2CRQFwfAUWoZJUEwbLURhcJm3HOc6HZHi6L7H
fsHXZV6NYlSLRd4VCUrHaFU7qRnTzIo17x2tE7pvTGy7286hIhNky+xnPyIm
RjLiyTCtMO/VVNHjHPGliF8uwa7Y/3LHWL63xFWnJC4k7oeV82/ICT5Bqdv2
cNuMkmRO9NNcH8ZRFYr+4uHEjA7ZTVD8x71EbAzNYRXxTM9GZu7oCGXJwVPN
B/VXRYEuku3JdEboZ4vmYw5wE8JHHZkhj8FzNtZgE5kd8NqQsXe8mnVBx9KF
6txIQszh+D2y8aDj4xN1141bc7h/0d8xqL7Kp5dphwCtVbiiWM6/sSpEdq66
H4O/+LuGRhrS/RgZSSU4e0AieXJE0OFbWaVdGIAdoQHC8Yx9QwE9PVnsZ5h7
UKHpzmQoLmsSsEuagCtepdQ5DAUISQi68I+6UEGnzl6egRT6gSk7tsovCnng
JStkVa0JF6HU2tfNGEXHDd3xiA6PBiUIUEOBXI+HkEBE1+MxsdfC5XhM7Hm4
Gq8AW2g+//CI2DK6E4+Eibw1kGFmmBlmhplhZpjjhUk9a4WZPfWs7QumYzCA
V6vk9Gx2tIH3TmCYO6DcayokGidgSEggPsEr/APHCUBjzNDQti3lX1UhIsf/
ISFaAg+8TOrc5qCPTpMIDXfLEcsHFLqTZz3axukHvY+j/2sglyHUwuKhlSFl
SBlShpQhZUgZUoak/iTMMT777DM0xGFkkfQPKSCdFF999VVx4sSJooTJrgn/
zugsxR/jwixH1bPik08+KejFvkeuawGNSlBILjI0sQ0ipMY+/5QGJCYdNqNn
nwNCQvEDFpW6Uz/+0LH6LAEYYoUPvBW3eBRRYddYE9FhUtqusdzxw4wXJ7wD
3Bjxvj3hPlvRUojf7Qn9EoEuTLR+U0EXp96wFM/FqfwYUbU7Nq2ho2oH6AnY
/6Giao+kf/0uoCGTd/PJXEmx8xSgobihyPcjQXaQ+3mDWxZ2C5vIBOqT8gf9
nF1ZluWIXQdsfsd2jUT8IU8qRenM1cXu67COySfyrrhD62bPwfOJuH14edyV
tXHQ9Igs8Y5uK0hmTu7C07Y10tg+DMpgjo+9WlVijwBSPqC+CIxarPviyEen
Cq2gZrrLHpVI8glK2dUDCEn+hF2bj9fSQe5NSYxX/F2KOGw+sDiGW5zUCfTK
ugs/hLzuIimGr6NSz7MCanJ0uYJETY4odJuj0u/6gbmr1aenA1JPwtsFyk3Q
GZW7Vzi4l21yABoQEnrhcKeLEPMIxNvQfIQbeSfLTcuRa7L8tB33odadBEOe
4yo0FInMx9PpQULjq++1gem+zeAKt+ftg55gPFvR2mwL9AQJLffbjt/8vSMM
ETWB5anTWlSay7K/q4QQjA7Q2F9NS/wRodFWlwS0cH1WZEjiJcL6MjHeRKOA
JGDOhVUS7/sE3P0L7Wt4out/8Z13kmja2VYI4qpeBL0Koe8lcPYfxcIyyuYp
TlInSReHk8Ce30LzUgIUHLGLHrCOm3XgfesBGlx5LO/2IIdy1CH476nvCri4
ymnduwFV8wdkGwXoQi33mYpG3yx6RFETiz29KBsXKJE2PlMl1V4987isoJdp
iRS/H/YRo1X3ARGLQbqwv2GXcNBkrdc2+khCsDPY4aIloCTgqv1i5JZng0n7
sRQ6iKFi43oNd4bkP4Eoscj/eASy6Sv0aghxTCYlnV3CapnRArHeX5jTVHVh
oKijKDBUF/bPV0U7OPqgxz2lgpZku6Nvdv650KZxo8mNSkPBrLqwU8LETkKR
F6YENOQkFBAa3cQW3RLdxEbQxDyfOgkhW1BPSLcsRVHnnwBF/bqi0ZVl4RR4
8+bNmvZX8KwQ/pdffrlECwCJ0kTfQ6OG/M1Rpxpbm3vUTXQ8nQ0ujSjSM1yP
VRFXLoR3Hgo+gvShFTf+kTF94aPAJKHgt4h86QpfeJc2BSp5f4BmoEW59GPB
KVrJe/1ygcYuyEAfcYF8pIPqDyogMjjXfjkX31vxeJv/Vx1goDEj0rNT7eHq
5gBd4J4FNNTznPSD+2xFazIb+GUH6Gf4fWmjxmyjpj6uLeOTX9lF3jnNwvE0
VviiQkiNFU4DdRRYysl2C1v5pdciWsb2ZIgqom7i0EURz3QUgHGnVs0kGO/s
L2pDEZP3dhuzJlpHoYj/TOP7FYraYlFj1ZYnppYsW/XH4d5eZ3E9HrMgRnXn
2U2H5kJ/+aG6Yv/5Yjjse9n/yFUxxnHMyhT/c3bnjRV5Kg8I5Gf87nRgVU+o
/lLRmoy1OKQQlvly7kncucBZd0uPFUvr4fyvAH7lfrIyWox9EzzSwejfts9n
Nn/y2y2xO5PFkaq4qsmHWaotnQ8O2jm37b8SpbYcnuqpkciIQQze6T42Opqv
m9fCXG2Kbvpk3ZRDOaiIA/hkdlEsYtNmViw05LM4TSAjGGiqpT6G7Lrkbh4y
k+r5FdBk84beSsdBY7BVfwBHGV+2mmzaEFvoDXS3sbUMzFiCAyqH4umm3KJq
CnRTrqfiRfS9pl2xe0C6GUi30y9M+hPaKUPvlilIh4L/9QyT7pDZYNJ0A8K0
bYGZt+px+gGVwLb1ZYON0g8I23XLC1nHrjk+uzU0O07bX+aoD06PoxM+e2IK
ZYtUCk1OBlSlDDPD7BVmk7lQZJj8/mjGEBqDMEBj17+ramdzcDEC/F/3ot52
fPYSoN3Oxefic/G5+Fx8Lt5ePH2T/Yvfy4mS7VnPoj5yTIds5HPxufhcfC4+
F5+Lv+OLF6eQOrjKoVNIr3Z7/Ilujys8NDvMoUNgr3Z49okOz1bQxRG7yDkO
1do1z/TnPNNrsJBjnA2Wa/pznukrWOIYZ+oUh1xnP3RMd94xnVY8dZSzFd+U
7rxjOq2noE5xQlj0BKuPHNNdcExXFc+/8NtJA8H1GK+nLekOHDhgfRYdUHUZ
pHtdhUTFuQA0FNURpUM05L6JwixnSBlShpQh3SGQuFm80ag5MjiD5wGyvRoQ
qTSAnNbCM3p4IB+Zio06G3IuRXUh33PkwnpETSctBI2gpIGrlj1alRxQqLPq
juTkZ6M8t+RUCno55r74bskWBUk6HAy00ylATidSDFhnh1qwqGtjgwDXwF+G
rDkVNZKNFjCxZ0KlpXolyeIjNyLdNNuvydibBe7hfEpx6MCc80Jedh56hwzI
Bu/sAE0q+VxyaWkeZRbzmiguuy7zUtAEHtGQmTkyR9feKfxXZNCZyDtl3dYS
1GweMkqqmwV7lI5BX+ViF++FkZcWctnUW2xSfKJ0iJYhDQQJvRAfHwCmDLCr
qbQxHnqjRyKOo1fgkWGqIoHjL/QaDRHSASVFrxiLsHhyGAyqrgEEp1hyjzL0
1WgEjQSPwsE6xtgEuoZ8v8wxP0yVdxRUFKksj6ml69TfbBhpm27pKmcQmADj
2ZzQqNKqKzOFLD7NPnx2GvuPhjmuStTtUANJa9FeXTUs+FT6AR91m3Xi26lN
InF49lP6hEKqClY3X9ftLv3UMCpm9Jz2VaxW8/4uPVijyzwCY5z9eHZfRzUe
1yEM8qkPaspvKk3W+ug6KqcGa1apvtcwuugZcsVH6ZqGQ3IIQfRmPG+1chyN
xyWQIdwe7asMjR1MmbzVygkKAWB/faHe27Pm0TBHP8mmulyHxPxBFLLDtZa/
bxS8SkPGTgHmluaRHxqhqjQUCtG4hMTrEDF7uP5V63yfAIkfqWg0Zg6C5ikF
OUNa78DnwpH2SKVyWjAbNNCPvHhRIjWeQYMUZXDEav+yWCwe44SpcgzN/oVO
sAwAzHUlwixefBINepv0JNvuLKgRTAI0SFfojYv7aKsWdeunwQ9yldZhjxpl
IIRD46CkJJwAI1G1xE1AC7e/ewbkPvhOyBIqGVWtB+G12XZVc0AbL0MLjQOd
2zB7rbwgQbXdA01Cp5rOTmjZf6HlF7RDip5NRAZoWuLbyRh2KVOoeQ7KHLbE
R+3RnmRkFs1jtgwpQ8qQMqQMKUNKB1JTnMSnLekOHTpkffY8ePYySFdB4l/4
zeSBlAmZMAZCceD/PH6GBQ==\
\>"], "Graphics",
 ImageSize->{540, 720},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompartNumbers", "[", "iron", "]"}]], "Input",
 CellLabel->"In[239]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "\<\"Plasma\"\>"},
    {"2", "\<\"RBC\"\>"},
    {"3", "\<\"ST0\"\>"},
    {"4", "\<\"ST1\"\>"},
    {"5", "\<\"Excreta\"\>"},
    {"6", "\<\"Liver1\"\>"},
    {"7", "\<\"Liver2\"\>"},
    {"8", "\<\"RedMarrowTran\"\>"},
    {"9", "\<\"RedMarrowStorage\"\>"},
    {"10", "\<\"Spleen\"\>"},
    {"11", "\<\"RedMarrowSynthes\"\>"},
    {"12", "\<\"UrinaryBladderContents\"\>"},
    {"13", "\<\"Urine\"\>"},
    {"14", "\<\"UpperLargeIntestine\"\>"},
    {"15", "Biokmod`Biokdata`Private`LowerLargeIntestine"},
    {"16", "Biokmod`Biokdata`Private`Feces"},
    {"17", "\<\"SmallIntestine\"\>"},
    {"18", "\<\"ST\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.399283168374307*^9, 3.417836685000705*^9, 
  3.4798281098981895`*^9, 3.479828782612043*^9, 3.4798299902491927`*^9, 
  3.518535381036913*^9, 3.643443847726699*^9},
 CellLabel->"Out[239]//TableForm="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{
   RowBox[{"TransferRatesE", "[", "iron", "]"}], ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{"None", ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<From\>\"", ",", " ", "\"\<to\>\"", ",", 
        "\"\<Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\>\""}], "}"}]}], 
     "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[240]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"From\"\>",
       HoldForm], 
      TagBox["\<\"to\"\>",
       HoldForm], 
      TagBox["\<\"Tranfer Rates(\\!\\(days\\^\\(-1\\)\\))\"\>",
       HoldForm]},
     {"1", "11", "6.`"},
     {"1", "8", "2.`"},
     {"1", "6", "1.5`"},
     {"1", "3", "1.4`"},
     {"1", "12", "0.02`"},
     {"2", "8", "0.00833`"},
     {"2", "14", "0.00013`"},
     {"11", "2", "0.7`"},
     {"8", "1", "0.33`"},
     {"8", "9", "0.0247`"},
     {"8", "7", "0.00495`"},
     {"8", "10", "0.00791`"},
     {"8", "4", "0.0316`"},
     {"6", "1", "0.01`"},
     {"6", "17", "0.00045`"},
     {"3", "1", "0.91`"},
     {"9", "8", "0.0018`"},
     {"7", "8", "0.0018`"},
     {"10", "8", "0.0018`"},
     {"4", "8", "0.0018`"},
     {"4", "5", "0.000563`"},
     {"12", "13", "12"},
     {"14", "15", 
      SubscriptBox["k", "ULI"]},
     {"15", "16", 
      SubscriptBox["k", "LLI"]},
     {"17", "1", 
      FractionBox[
       RowBox[{"f1", " ", 
        SubscriptBox["k", "SI"]}], 
       RowBox[{"1", "-", "f1"}]]},
     {"17", "14", 
      SubscriptBox["k", "SI"]},
     {"18", "17", 
      SubscriptBox["k", "ST"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"From", "to", "Tranfer Rates(\!\(days\^\(-1\)\))"}}]]]], "Output",
 CellChangeTimes->{3.399283168389846*^9, 3.41783668501633*^9, 
  3.4798281100075617`*^9, 3.479828782627671*^9, 3.479829990296069*^9, 
  3.5185353810837884`*^9, 3.643443847742324*^9},
 CellLabel->"Out[240]//TableForm="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"ironMatrixE", "=", 
   RowBox[{"compartMatrixE", "[", "iron", "]"}]}], ";"}]], "Input",
 CellLabel->"In[241]:="],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "element", ",", " ", "lambda", ",", " ", "fn1", ",", " ", "amad", ",", " ", 
   "class"}], "]"}]], "Input",
 CellLabel->"In[242]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"element", "=", " ", "iron"}], ";", 
   RowBox[{"lambda", " ", "=", " ", 
    RowBox[{
     RowBox[{"Log", "[", "2", "]"}], "/", 
     RowBox[{"(", 
      RowBox[{"2.7", "*", "365.24"}], ")"}]}]}], ";", " ", 
   RowBox[{"fn1", " ", "=", " ", "0.1"}], ";", " ", 
   RowBox[{"amad", "=", " ", 
    RowBox[{"AMADAdultW", "[", "5", "]"}]}], ";", 
   RowBox[{"class", " ", "=", " ", "M"}], ";"}], " "}]], "Input",
 CellLabel->"In[243]:="],

Cell[TextData[{
 "  For a particular case Iron 55,  \[Lambda] = Log (2)/ ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]],
 " , with  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", 
    RowBox[{"1", "/", "2"}]], TraditionalForm]]],
 " = 2.7 year."
}], "MathCaption"]
}, Closed]],

Cell[CellGroupData[{

Cell["Injection", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[244]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nstart intake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.0020244460949350976`", "6.402300730651595`*^-6", 
      "0.9972665150459691`"},
     {"2", "0.00017590676613000653`", "0.00004276992159322278`", 
      "0.9963471224463415`"},
     {"3", "0.00011454506337592404`", "0.00008377253066353724`", 
      "0.9954487349392498`"},
     {"4", "0.00007966822155621914`", "0.00011407784372596844`", 
      "0.9945555502008218`"},
     {"5", "0.000058721582809171646`", "0.0001340256312286972`", 
      "0.9936639918978885`"},
     {"6", "0.00004554289212220019`", "0.00014658243185333605`", 
      "0.992773681926475`"},
     {"7", "0.00003692660508277719`", "0.00015433465509260535`", 
      "0.9918848615831961`"},
     {"8", "0.00003112371966156798`", "0.00015907303966907602`", 
      "0.9909977302584286`"},
     {"9", "0.00002712945817763923`", "0.00016194096439885695`", 
      "0.9901123486013165`"},
     {"10", "0.00002433669569427441`", "0.00016364459707418535`", 
      "0.9892286781755326`"},
     {"20", "0.000017480824502889898`", "0.0001635687669164167`", 
      "0.980468498947995`"},
     {"30", "0.000016899529752507698`", "0.00015940515794920035`", 
      "0.9718227577382464`"},
     {"40", "0.000016548788408646086`", "0.00015530224599943234`", 
      "0.9632830547782437`"},
     {"50", "0.00001621698703003703`", "0.00015137274718913165`", 
      "0.954846488408285`"},
     {"60", "0.000015896108596941432`", "0.00014761004775716487`", 
      "0.9465105071006389`"},
     {"70", "0.00001558541791103026`", "0.0001440041473018647`", 
      "0.9382726946096899`"},
     {"80", "0.000015284464890463637`", "0.00014054568652801654`", 
      "0.9301307532346165`"},
     {"90", "0.000014992833338030582`", "0.00013722602193351404`", 
      "0.9220824949714232`"},
     {"100", "0.000014710130287787042`", "0.00013403716630305452`", 
      "0.9141258336706598`"},
     {"180", "0.000012729172561875943`", "0.00011245209335365288`", 
      "0.8535481705878962`"},
     {"200", "0.000012301228910173936`", "0.00010795338520651369`", 
      "0.8391982777942498`"},
     {"300", "0.000010474821075663728`", "0.00008935651502338309`", 
      "0.7716796217133092`"},
     {"400", "9.052213523228508`*^-6", "0.00007552013944975935`", 
      "0.710444710787357`"},
     {"500", "7.917176537864631`*^-6", "0.0000648874707331996`", 
      "0.6546574905050014`"},
     {"600", "6.991543663144515`*^-6", "0.00005649453836838856`", 
      "0.603666062095031`"},
     {"700", "6.22160367243506`*^-6", "0.00004971169780539077`", 
      "0.5569442523787917`"},
     {"800", "5.569864195176426`*^-6", "0.00004411365219398765`", 
      "0.5140559243521915`"},
     {"900", "5.0097933825187`*^-6", "0.00003940672451763557`", 
      "0.47463173567291805`"},
     {"1000", "4.522355283585781`*^-6", "0.00003538472831545447`", 
      "0.4383533568594881`"},
     {"2000", "1.7633740027227834`*^-6", "0.00001357941730546583`", 
      "0.19977113830601334`"},
     {"3000", "7.103706568254724`*^-7", "5.464654253997173`*^-6", 
      "0.09206159854722662`"},
     {"4000", "2.8684571307785494`*^-7", "2.2064203570218664`*^-6", 
      "0.042819398532624675`"},
     {"5000", "1.1585331981994702`*^-7", "8.911365329898892`*^-7", 
      "0.020085468444281832`"},
     {"6000", "4.679294175717289`*^-8", "3.5992794652052523`*^-7", 
      "0.009494365741157597`"},
     {"7000", "1.8899653839670192`*^-8", "1.4537475328179023`*^-7", 
      "0.004519002914477582`"},
     {"8000", "7.633568221002113`*^-9", "5.871684614976039`*^-8", 
      "0.002164024833374874`"},
     {"9000", "3.0831976673442866`*^-9", "2.3715729931739777`*^-8", 
      "0.0010418080836982978`"},
     {"10000", "1.2453033365611298`*^-9", "9.578781765289234`*^-9", 
      "0.0005038527997363362`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nstart intake", "Urine\n24 hours", "Faecal\n24 hours",
        "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992831688249207`*^9, 3.417836685469455*^9, 
  3.479828110601297*^9, 3.4798287831277637`*^9, 3.4798299907960787`*^9, 
  3.5185353814431705`*^9, 3.6434438478829503`*^9},
 CellLabel->"Out[244]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Injection\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[245]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV0nk0llsXAHBz5gzP8z7nkWtJZKgMKyTUOcnQQEIhNCnpytSE+uhSEuIr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        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwVjns8k3scgGeTYt6X2YtpcUbjtLfcjmXV8P5KUnykdmpK00W6Nyrl6LKk
OkdOqeycIk4ql5RcDqLcv+YobLoXc+qT0FKi6SI1n5zOH8/n+eP553GMjJFs
oNNotJDv/O9O1zhh+64Dft0dp8WrdCQoItf0KznhVHvDeV5tDwmpX/6hh3O2
UsXYeJD9cxK4zZ9P+XL2UTMcFx7s7iChm0yVunN+py7uyBdtbSVB9ezZ7Gmc
DGqP6UaX44UkeImOXuNzCqiBCU/f0WNJeLs+rM+JU02dm6lerKaR8JWxoJbw
VFPyTa2a6ZgAerLrpCyvR1QJZlQQ4j4NJNbZhujCLipoi6bZXfYjhPzGH3fS
dlO9pWRrdYIL9Nb5kSxeHyUa6JxlVuMMOtEcY5+iV1RcYk/CNj0fijPChQ8E
A9Re2YjFaiEfNlXNxbdtHaJUtWP4yZNTIRD7NfjiqJ4SlZb36/qc4GGmJso8
6z0Vn6l+mxfqBI1ZLgI38UeqsHQ0I67ZEXTzhudHGz5RAhsi1GWWIzACLlSU
nP9M5aWD60AND8L66xQW679Q/rdizHFfHmC0d3o+z0A1+Or3NJ36AWr3MKrE
DWPU+hq9z65GB7h04ljnjsRvVFODQxRjyB7gUPzlh1Y0JP+7jZB42YOaucH8
4AgNsfkRivTYKTDxflcg44kReqRa6WbSyAUqQOWafJmO+MYpHq5OXGCbRVJZ
xxjoRpGKs18xGXoVsYbyVcYouPCIePy1HfRNx1NyyQmIec2cyl5tB4fIdUF8
pgmKk5DmFzUcsOt0Lst9aoJu7UyXFC3kQMiT7IDrDRPRkg6F3/06WyjDrxZn
ZU1C0X1bBN6zbYEY4amSo01RW3vs5v1gAyy3pUbGS8yQ2sHTsAPZgJn1hzcH
nZhoY4jfC5naGmZ6OxQ80jORT96nmUXh1mDINzpTdc8cFWtdYk70EFDXIiUv
XMLQ3Y+OKuluAibPiRpgH8WRd8vyN7e+sWF3eK80OcwCLc5JEl5XsiGh65N6
O9sSDZaVDwWSbLDykB5+esQS5Qc7zi+qtoKpEe9SNG8tkf/hinHmMitILIty
P7qahSYHuSj361gwmpslFtxhoZgH9wLPHmDBYDTr/GJvK7SzLEUcymWBx7q1
f4rzrRDX//lwQrklDJP93Vcs2aiyeam/+zJLUKcK0xnxbKSsWlGaqreA97yI
l879bFTMfN1ROcMC0pLqk1qWEGiW2kG7eS8O8bKYhkwJgb6KgkdD43AI9+R9
jl5GoJ5kqUwUi4PDv4kbrVcQ6M1N4QcTOQ65bgEBkWsIdCjCL+LqWhzKHqvp
Y3ICdd2ZNMMQiINmqlbhfpxALVwbo4c2OBSPJlfQUwiU3OV7X8XG4VT7nMHH
JwlkZpfzqswSB8kvf8kOKAnko/j51R9mOGjb1ohbzxHoXt5hr5XfMNDt1I1G
XiGQ8qfXk4ZfYtCyIM3Du4BAL3IE8172YFDAXbjZtPB7J1eptM8xkDdf7Sgp
IZA+rD6tSYvBR468cqySQI8dVWkZ7Rg8GbQfunvz+2/MbdPUNgxuqO4451QT
yFZr25R0G4N92z3OLKonkNCrlRnXiIFs7gvNFCDQvkKUKa/HwM9GaaxvJNDw
Is9dG2ow4A3M82lqItAKl8unI25iYAQfYs82EyiJfm1keQUG/wEDTzjv
        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -14.423551993241107`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-14.423551993241107`, -2.73990567556389}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, -13.5}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992831720569077`*^9, 3.417836688813205*^9, 
  3.4798281123356276`*^9, 3.47982878464367*^9, 3.479829992514861*^9, 
  3.51853538324008*^9, 3.643443848164219*^9},
 CellLabel->"Out[245]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Ingestion", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"BiokdataReport", "[", 
   RowBox[{
   "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Acute\>\"", ",", 
    "\"\<BioassayTable\>\"", ",", "1", ",", "fn1", ",", "180", ",", 
    "lambda"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[246]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.00019621155888617205`", "0.2605859358387611`", 
      "0.7385152160439844`"},
     {"2", "0.00002094970873832613`", "0.34783336537453313`", 
      "0.39014199317101184`"},
     {"3", "0.000012406528606945874`", "0.17430919636042444`", 
      "0.21554626225462523`"},
     {"4", "8.519157447600638`*^-6", "0.07176376305372638`", 
      "0.14362252935957232`"},
     {"5", "6.209821492378773`*^-6", "0.027658875231621024`", 
      "0.1158565298667261`"},
     {"6", "4.7699128109575855`*^-6", "0.010387071157620454`", 
      "0.10538328376288508`"},
     {"7", "3.835254871052721`*^-6", "0.0038630945676535445`", 
      "0.10144230779254818`"},
     {"8", "3.209188691861057`*^-6", "0.0014360713084014762`", 
      "0.09993175022143495`"},
     {"9", "2.779942642672423`*^-6", "0.0005392008722057607`", 
      "0.09931955370553958`"},
     {"10", "2.4806588548176823`*^-6", "0.00020877715628470707`", 
      "0.09903851034100611`"},
     {"20", "1.7501262182200056`*^-6", "0.000016370842448552556`", 
      "0.0980503225856024`"},
     {"30", "1.6904498747081342`*^-6", "0.00001594639078826198`", 
      "0.09718565277786315`"},
     {"40", "1.6553040468955539`*^-6", "0.00001553583390375036`", 
      "0.09633159723407042`"},
     {"50", "1.6221055550157976`*^-6", "0.000015142607543893954`", 
      "0.09548785902250881`"},
     {"60", "1.5900020086128113`*^-6", "0.0000147660780744895`", 
      "0.09465418271687229`"},
     {"70", "1.5589180363463793`*^-6", "0.00001440524505652235`", 
      "0.0938303264875795`"},
     {"80", "1.5288085225032323`*^-6", "0.000014059171273885674`", 
      "0.0930160603770088`"},
     {"90", "1.4996318050918333`*^-6", "0.000013726991174289605`", 
      "0.09221116541153972`"},
     {"100", "1.4713485503856756`*^-6", "0.000013407904941990931`", 
      "0.091415432815992`"},
     {"180", "1.2731675706401266`*^-6", "0.000011248156467598304`", 
      "0.08535721527713866`"},
     {"200", "1.2303561038679343`*^-6", "0.000010798052488442536`", 
      "0.08392213165551483`"},
     {"300", "1.047647919923681`*^-6", "8.937493642138328`*^-6", 
      "0.07716987492116466`"},
     {"400", "9.053415611960766`*^-7", "7.553304070067948`*^-6", 
      "0.07104609156830372`"},
     {"500", "7.918064653188237`*^-7", "6.4896722144135224`*^-6", 
      "0.0654671441274127`"},
     {"600", "6.992212749213217`*^-7", "5.650131082145067`*^-6", 
      "0.06036782277250018`"},
     {"700", "6.222118135039964`*^-7", "4.971675605223466`*^-6", 
      "0.05569549710292089`"},
     {"800", "5.570268148450662`*^-7", "4.411750835822326`*^-6", 
      "0.05140654455743544`"},
     {"900", "5.010117267011393`*^-7", "3.94097267341416`*^-6", 
      "0.04746402477052819`"},
     {"1000", "4.522620249838716`*^-7", "3.538711562158221`*^-6", 
      "0.04383610048132108`"},
     {"2000", "1.7634452500796262`*^-7", "1.3579973816352015`*^-6", 
      "0.019977407879366388`"},
     {"3000", "7.10398478845542`*^-8", "5.464868517920327`*^-7", 
      "0.009206278201113319`"},
     {"4000", "2.868569168932211`*^-8", "2.2065065465461596`*^-7", 
      "0.004281987637541707`"},
     {"5000", "1.1585784349348491`*^-8", "8.911713292971386`*^-8", 
      "0.002008566143726495`"},
     {"6000", "4.67947687840583`*^-9", "3.599419999082859`*^-8", 
      "0.000949444369058044`"},
     {"7000", "1.890039177075418`*^-9", "1.4538042939530784`*^-8", 
      "0.00045190343982188955`"},
     {"8000", "7.633866270999935`*^-10", "5.8719138728585425`*^-9", 
      "0.00021640375496544183`"},
     {"9000", "3.0833180497052496`*^-10", "2.3716655904017037`*^-9", 
      "0.00010418132198026944`"},
     {"10000", "1.2453519589892345`*^-10", "9.57915576542963`*^-10", 
      "0.00005038548742085662`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Urine\n24 hours", "Faecal\n24 hours", 
       "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.3992831726473675`*^9, 3.41783668945383*^9, 
  3.4798281130699835`*^9, 3.479828785331298*^9, 3.479829993124248*^9, 
  3.5185353836150875`*^9, 3.6434438482892046`*^9},
 CellLabel->"Out[246]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Ingestion\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", "fn1", ",", "180", ",", "lambda"}],
   "]"}]], "Input",
 CellLabel->"In[247]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV03k41PsXB/CxlF2Mr6XUd76fIUV2kZry+ZSGChU3S9JCtBLdFuqi/LI0
USJtKkqlckVUpCwnITdUskyWRIZ0lXQx2a7u/P44z3le/5zznPM8b+QX7BYg
zWKxBJL6f39vcnhh3e/hdnozfq5IUOBChN/WvmQdb3w5WIe3RJ4LSWMV0t46
e/Dzpf3BfdO5oFv5M3GZzlG8yX9+Il+WC51GSR5mOqeww5BFhvQvBOUfPiye
r5OKc8+vW3RyGIHVoug/9XWysOdjnlbVRwRft3uKuDpPcWiIwe4/ChGE29yd
WiN4irdFTtyYX4BAWWFM58D4Uzz+kfus+REC45xUlxftz7CBtM5163wEQaMf
CrbfKMHOMedyp7IRhDrkr3Q7Dzh0Tv+d5xkIRltttc/RFVileuOIQSICstJX
f55nBebKzjQZPY3g5H2BxbPECixT+ansVQICneOtTt2sStyaJ5Y6eAqB7dzw
41bdldi67K69MAbBkeCyLw13XmLbBTtbP4UjGJdxKKYsarB2yyJ73UAEUi2K
w30BNXiDc9M7470I5HPeLChJrcEiOgTwHgTaXhuvBMjW4tc9loW7dyFYmB14
tEBYi9lXObqv/SX3bDhn6xX5GpulVDe+34wgxC2kta7nLU5sa94zvB7BcLGb
eBGrHvMjRy5ZSBw6z5qdMaseL7/urxuyDkHk5Njqw+vqsZ9oy8wfLggSMk8U
0UX1WP2L6QdpJwT3xi9cCk54h3n7R2L9+Qg+ZZR4qFs1YjVhGFebhyB7oWud
2LkR333Jijq2BMHhKpF9+45GvD5X/9++xQgU/layuJPaiHvn/nAss0VgbuGt
tEy6CTfiqvEwG8n+MnHZrvomnGQ1EsCxRLDK9ZTN2v4mrHl6SdslCwTs7jn3
raY147G4B79pSHx7Oj91yrYZh61wcVQyR1Drcu5gyvVmHM1ukJczRTCr3cwQ
goX4WPlQkLERAlHQi/TbAiGeKo3hPzZEkPPLQyv+phCnitfKYomX60XKeAiF
2OjzIXP3+Qh27an90G/3Hh8ov6aeYICgYHRXsrZqCz5R4R7I1UPgppkxsS+7
FR/MtHDumY3ALC/bM7a6FdtOnC09JrGyS+HDa6JWvC/95q9ZEldF1+6tnd2G
2a77e37TRcAbFrcZnm7DHpazp72ZiUC/walYFNSOW7XOVPdpIRCfHQn3NuvA
Rx5QKVfVETQYs1r2O3XggQfKY84SP6hWtBbs7MCpw3ED/6oh2MNivhWmd+Dw
O5rRvhJ/DF6zWVPtI45i5RuazUBQvTZ92dvBj/gx70D/J2UELrH6v7gtnTjq
UEnADXlJPr6/LbTr7cRKU+4qARIrekWEeA914t2LnOQNJa4ybO5KUunCBZnq
w3lykjzUxVWwVnRh4zMKsS+nI7Ck+gUdWV2YThx+yJomyUNGHpUa/glnHT9S
eksKQXeJnZE6I8Iq79iCuAkGav/MbOKbijBLt2ebu8SPLqtGHV0qwtcsx7fp
SRx9qEPY7SXCyzh+wrJxBvRNImMKkkR4x8re+PExBvyvlnRukunBBWYWSYdH
GRAdXXoxs7cHTw057o4ZYaB30RLZpfc/49Dk7xs+f2cgJ9V74TvDfhxXqV0S
3sPAzqLlqnv3DGBGrK5o2c6Ao0qM0/XRQZyhX3Xjj3cMNFyp9VdO+wcXhh4m
lX8x8DzNwNCUN4zrU0wjLz6XzF/xY+W+iRF8tudNvEERAzL89Me5135ij6GI
mrw8Bjz7SiJmbB/DSY3eAnYWAyqs74P6zASWe/T5i+JNBooPyRTxyibxKf9f
1h1XGbiRcPJ9SNQUbnD3KUu4wAAcD8tsYLNIbpViuvgsAzVKAcqRYhaJ8ZUa
MItnQK6+1VGmWYrYCzTNimIYwPxyE0GmNIm7aZpUfJwBDUU/nHZShliJ5Rf6
/MFAd8SBiYebZInNfvNYx8OSfy1QPX3LaBrxDU0PnbefgeNGvmv0laaTjlfC
cve9DMx8Pzf/Vvt0EodO5iYHMODSnMF/VCZHhF+zH3zcwkC+6r2ctDR58rjB
NAc8GaDETLlgnwLp7Cd1Z9YzoG7qKiW7XpEkx+IsrVUMKGoO/R3JVSKGbSYG
UZgBaxs6q3FQiXgz1kq7bRiYuCN1vuitMgniHntWvICBkmoPo/QbKmTTVhOH
SYaBWUv8+zWiVUn3xoH+QIqBg97dHgLPGeRl5/WWt3IMHGsdqQnUUCM8o7oG
qxEOsM09/td+Qo14hc8sTGnmgN7m76drv6oR1bD4r9wnHIjK9zeL3qJO5C76
l2uf58DorTSe4Wt1smV4sc/VEA5826d+ba0Nm/hyRGdLnDlg7rsthXeHTYyf
2Bt16XHgh1Ff5101DVJ173X64AQNNUkLL8mEaRDlNHa7cQMN/zCbe+b2aZDr
pR4cu9s0XIwrjateT5F1wdt5ojAawnyCy664UaTNsma2rsTeFszPfRsoMlnM
ErmG0kC3Re3Q9KLIBhkZ/bJDNNwy5fP9tlJEpfTu3ku/05DfVCM9GUQR7fJs
PYdAGmr1WiLM4imSQu8SnNlKQ86o4LH0aYoEH3XilW+hIbFuybemMxTRig1r
HNlMg1voVZ/wZIqkfess9vGhoeXVVt5flymip2S/03AjDb37e0f97lLk1xvG
pNSNhmqHi+Y2WRRZ/H73xkFXGrJ0V+1SyKaIq82LIK7EQZX3hLm5FJmwblkb
u46GYZ2ggskCikRsGx5ydqah+ducgTdPKNJyH/lFOtFQWP567s2nFCHxFU9y
19BwNND8/OpSiqzkp3HYq2nwWd5VOxsocqF0wMx+FQ12Wsmyg88p8lS5b/5B
RxqY/hVLX7ygyLj4guJtBxqkYOjAhUqKdAXKNzXxafgPHFUCvg==
        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV13k0lV0XAPA7kCmFLi+lEhqQqURE5yhTypCEEBmSEskQeUslUhkqDUol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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -9.91008988490676}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-9.91008988490676, 0.7872099025849234}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}]}], "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992831760813537`*^9, 3.417836693031955*^9, 
  3.479828114976185*^9, 3.4798287870503664`*^9, 3.479829994936783*^9, 
  3.518535385286994*^9, 3.6434438485860815`*^9},
 CellLabel->"Out[247]="],

Cell[BoxData[
 TagBox[
  RowBox[{"\[SkeletonIndicator]", "Graphics", "\[SkeletonIndicator]"}],
  False,
  Editable->False]], "Output",
 GeneratedCell->False,
 CellAutoOverwrite->False,
 CellLabel->"Out[34]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Inhalation", "SubsubsectionIcon"],

Cell["Acute input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
   "\"\<BioassayTable\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[248]:="],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      TagBox["\<\"Days after\\nintake\"\>",
       HoldForm], 
      TagBox["\<\"Lung\\nretention\"\>",
       HoldForm], 
      TagBox["\<\"Urine\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Faecal\\n24 hours\"\>",
       HoldForm], 
      TagBox["\<\"Wholebody\"\>",
       HoldForm]},
     {"1", "0.05758510984138254`", "0.0001342885042698102`", 
      "0.09998115367738339`", "0.5049342572053263`"},
     {"2", "0.055854192390229186`", "0.000014413385655704697`", 
      "0.13831074052246864`", "0.2876023477110364`"},
     {"3", "0.05487001424763298`", "8.981076839326898`*^-6", 
      "0.07046911175041785`", "0.18800806179443902`"},
     {"4", "0.05400431926758089`", "6.422949161356908`*^-6", 
      "0.029493090301738828`", "0.14774701263366136`"},
     {"5", "0.05317209710762687`", "4.91328913032757`*^-6", 
      "0.011706247327058841`", "0.1320244360241159`"},
     {"6", "0.05236140092146168`", "3.969770850933114`*^-6", 
      "0.0047018427436712334`", "0.12578934073303003`"},
     {"7", "0.05157013142639105`", "3.3541120152337077`*^-6", 
      "0.0020418428747991614`", "0.12312766496892485`"},
     {"8", "0.05079752970752331`", "2.938869507603286`*^-6", 
      "0.0010429624236311418`", "0.121801110429013`"},
     {"9", "0.05004303195421124`", "2.651679553108143`*^-6", 
      "0.0006656271419980995`", "0.12097587943804473`"},
     {"10", "0.049306114875818874`", "2.4492049816780867`*^-6", 
      "0.0005187799022473072`", "0.12034341046305519`"},
     {"20", "0.04280038270166282`", "1.908223903172799`*^-6", 
      "0.00033382189348117575`", "0.11564011643791645`"},
     {"30", "0.03758582364383166`", "1.8204150746890793`*^-6", 
      "0.00025495004897250177`", "0.11193649192040421`"},
     {"40", "0.0333474909133912`", "1.7602897190511974`*^-6", 
      "0.00019661362409963585`", "0.10892772393380207`"},
     {"50", "0.029853438338594978`", "1.7099201340561976`*^-6", 
      "0.00015329610859822162`", "0.10643582510689674`"},
     {"60", "0.02693210620455814`", "1.6664238934269148`*^-6", 
      "0.00012099122123783124`", "0.10433041836354416`"},
     {"70", "0.02445599420561266`", "1.6280632766957625`*^-6", 
      "0.00009678471203605951`", "0.10251571221385278`"},
     {"80", "0.022329846475670906`", "1.593582238799923`*^-6", 
      "0.00007855155770190338`", "0.10092110983333845`"},
     {"90", "0.02048208116779319`", "1.562061922609958`*^-6", 
      "0.00006473825741583293`", "0.09949441505167274`"},
     {"100", "0.018858557936733626`", "1.5328282670859784`*^-6", 
      "0.00005420613506509367`", "0.09819690562559875`"},
     {"180", "0.010507184548523528`", "1.3420613490677174`*^-6", 
      "0.000021876694445421065`", "0.0901492647707321`"},
     {"200", "0.00917174426391331`", "1.3010426998575979`*^-6", 
      "0.00001929135066895006`", "0.0884584101318062`"},
     {"300", "0.004726754604663342`", "1.1196601256478548`*^-6", 
      "0.000012840749296669664`", "0.08084441311084616`"},
     {"400", "0.002457338664351824`", "9.707598232889752`*^-7", 
      "9.769163302167085`*^-6", "0.07418061267759565`"},
     {"500", "0.001280523849638595`", "8.482655858979886`*^-7", 
      "7.833125023309714`*^-6", "0.06821624556249417`"},
     {"600", "0.000668305278277948`", "7.469510048808467`*^-7", 
      "6.507258027611649`*^-6", "0.06282173717208976`"},
     {"700", "0.00034930314595331245`", "6.623590191270338`*^-7", 
      "5.548320343290241`*^-6", "0.057910870181023505`"},
     {"800", "0.00018284939334686984`", "5.909098340759432`*^-7", 
      "4.821161088382698`*^-6", "0.05342120910646086`"},
     {"900", "0.00009586881322618536`", "5.29829474072589`*^-7", 
      "4.2468218095605795`*^-6", "0.049304873231305724`"},
     {"1000", "0.00005034814784011271`", "4.770079527616991`*^-7", 
      "3.777663396129035`*^-6", "0.04552340547682127`"},
     {"2000", "8.912952248038226`*^-8", "1.8429188635847642`*^-7", 
      "1.4196857734714618`*^-6", "0.020724450906813456`"},
     {"3000", "1.928765835307177`*^-10", "7.419240791909065`*^-8", 
      "5.707512725334115`*^-7", "0.009545528575462363`"},
     {"4000", "4.924309741464663`*^-13", "2.9957119962277394`*^-8", 
      "2.3043096627789128`*^-7", "0.0044377046634138054`"},
     {"5000", "1.3899615159935424`*^-15", "1.2099231664086604`*^-8", 
      "9.306656036457143`*^-8", "0.0020807205324925543`"},
     {"6000", "4.1270709237468465`*^-18", "4.88685383774412`*^-9", 
      "3.758932992326296`*^-8", "0.0009831729849177353`"},
     {"7000", "1.2551619350358471`*^-20", "1.973798463045827`*^-9", 
      "1.5182313307901122`*^-8", "0.00046779695222145867`"},
     {"8000", "3.8632068909800815`*^-23", "7.972169819931508`*^-10", 
      "6.132134482717003`*^-9", "0.00022394740780328536`"},
     {"9000", "1.1972973942575528`*^-25", "3.2199588220056707`*^-10", 
      "2.4767686688137763`*^-9", "0.00010778488845857953`"},
     {"10000", "3.728946948055252`*^-28", "1.3005411575502349`*^-10", 
      "1.0003667025861183`*^-9", "0.00005211661359238256`"}
    },
    GridBoxAlignment->{
     "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxDividers->{
     "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
      "Rows" -> {False, True, {False}, False}, "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}],
   {None, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {
     None, {"Days after\nintake", "Lung\nretention", "Urine\n24 hours", 
       "Faecal\n24 hours", "Wholebody"}}]]]], "Output",
 CellChangeTimes->{3.399283186973772*^9, 3.417836704281955*^9, 
  3.4798287977867336`*^9, 3.4798300060463715`*^9, 3.5185353931465197`*^9, 
  3.6434438511798553`*^9},
 CellLabel->"Out[248]//TableForm="]
}, Open  ]],

Cell["Constant input", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"BiokdataReport", "[", 
  RowBox[{
  "element", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Constant\>\"", ",", 
   "\"\<GraphicReport\>\"", ",", "1", ",", " ", "amad", ",", "class", ",", 
   " ", "fn1", ",", "180", ",", "lambda"}], "]"}]], "Input",
 CellLabel->"In[249]:="],

Cell[BoxData[
 TemplateBox[{GraphicsBox[{{{}, {}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[1, 0.5, 0], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwVxX081HccAHB3x1UOHX56nWztknpx5ak8rcPnm7pqIY8v2o3kYvUSp6VQ
r5AoFBmFkchz1NxmlQi/n1Nb7ShPlYeUuF3M4Tjdj9xq2x/v13u9INo3nKqh
oeH5n/8fsIy16zpx1pXm8BQv4NOJBEHIRC6LDzPquCsXAulEztIjKp8VAeZT
bvwYfzph8pjMdmGdAcGg+eT+/XRilJMTYM26BD3r10i13OiEeGTka3NWEQQ6
JHrGWNCJbY6pt81YdWDMFcncF7UI+eFAqSmrGT4205XKPC3iI213C2YrgTZL
j6hMQpMYK28N0N/WD+JJpx/1lmiEr1H5svDOEKRkNY2DPY3wvGj22XRwFALG
IkauHaIS462uHH22FBr2vvo4XEghZI7bNZ1/fg+fd1hxQKxB1Bfx7XotpsC5
PS1S9PozfqRph96xiBlgJFZxdXw+4Xt0L7jfXFQA8rsy3FOhxvuud4bplMxD
JJN1QddwGW8v2WRhxV0Apsc/ol2XlnCZ29wu4fIHeOd9Ojt8lMRpvNJ7ohsk
KF5dG0ryU+GBE60Jqw8vQYeT2n5F9QKuqzGrMGMvw0pqrnsERYm3nKI1cXE1
rPZ61s07M4eXZaYPHE/+BLQ+n18ZNbM4cS6+us9AAxXZVTlY5MlxCSNcJ1Gl
gfaFqpGYN4mv6BnaQ3tJQYON2TeKtWU48MSWGdVUFHs3K2WQMY4bagugJJ2G
2Mola1rVW3w8IWb5t+80UWpSUXLAnUFculkvq5KjhYbubTauedOHn+OE7jNj
0FG75sWaNp4ENx7Y2FD5mo6Qn4c6JB3HPV+W8+7iKxDnwbrdzvnX8Qa92vqS
kpVIOhWR47vwC2AqtjhDuApl+a+KcD/eAfpWPhRNb21k8GZnc4/pc9A2Uv6d
aMpAwqbaF6KZfrB3WFfXr2AgfUHvpTzWECzXUPKaunVQyJbuRpP8t9D6JIBT
WqaLrsob/WI9xmDt9rApw1Q9tNBaEBqplMJJ/nhARuBqdFnkVB0U/B6Shj5I
Ig2Z6NHvZYy025NgYBNw/nUKE5nUuEhSjeWwIXg2q1PORC3Kbu9IjxlIbgiz
Tj2oj9qfFvb7eCpgsbKEa/FMH41sFZe2hc3BtFD/xn4HA5QSLbebDpkHm9BD
17g1BshKfvPdzXAlzHEmRm8xDZGxtGuu2GsBJDl2P9HiDZEnFhw3z/kA8+zg
vzZOGKJ+Y+lhW10VFKS1pT3xxhA/X3Tyeb8K4oOi8eu+GDoo7hXbDKiAb8sm
hf4YWoN6zXOGVbBuOPl7owMY+opSwfUaU0GlFY8nCMHQJsutccSsChpeSKjq
KAydSNczidMmoXPDYIL1ZQwpT/AfbgMS6hcz7lGzMOS173xVnBsJ2V3bp19c
wZBRpn9ZM48E37jioLO5GCqyte5y8SBh8M8Q7tNCDNW7cxVO35Ig+0G2KLiF
oSb7i47UGBKe7C6wcajDkIVRg5ljLAl1JnuPrrqDobV7DrGPnSYh6nHtK5EI
Q8LaeLfuJBIWWFH31fcxJBMwtmRnkvBy+suZ5w8wVKB+mNaSTUKj+NnGimYM
HYk6oJjIJeFMpE3eN20YOu+S8d61kISgHe86vyAwdPWPxlNHi0lwXZOrqWjH
UEsinZlTSgJ7ys25owNDpdFu9x+Uk0AhlDH5jzHUWOF09G0VCf8CTs9POg==

        "]]}, {
       Directive[
        Opacity[1.], 
        AbsoluteThickness[1.6], 
        RGBColor[0, 0, 1]], 
       LineBox[CompressedData["
1:eJwV0nc4lvsbAHAzez9K0eN9nkhGIZQyvl9ONKiQC6mOElFmKZXLjMYrEo6U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        "]]}, {
       Directive[
        Opacity[1.], 
        RGBColor[0.560181, 0.691569, 0.194885], 
        AbsoluteThickness[1.6], 
        Dashing[{Small, Small}]], 
       LineBox[CompressedData["
1:eJwV1Xk0ld33APBrKtFguLxEJVQvGVIZQs6JCFGiKIUMb0WFyJgGhKIUTaaU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        "]]}}}, {Ticks -> {
       Charting`ScaledTicks[{Log, Exp}], 
       Charting`ScaledTicks[{Log, Exp}]}, GridLines -> {None, None}, 
     FrameTicks -> {{
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}, {
        Charting`ScaledTicks[{Log, Exp}], 
        Charting`ScaledFrameTicks[{Log, Exp}]}}, 
     AxesOrigin -> {-0.5192955579145676, -10.382959575036445`}, 
     PlotRange -> {{-0.5192955579145676, 
      5.712252408804778}, {-10.382959575036445`, 2.556264973096364}}, 
     DisplayFunction -> Identity, DisplayFunction -> Identity, 
     DisplayFunction -> Identity, AspectRatio -> 
     NCache[GoldenRatio^(-1), 0.6180339887498948], Axes -> {True, True}, 
     AxesLabel -> {
       FormBox["\"days\"", TraditionalForm], 
       FormBox["\"Bq\"", TraditionalForm]}, AxesOrigin -> {0, 0}, 
     CoordinatesToolOptions -> {"DisplayFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& ), "CopiedValueFunction" -> ({
         Exp[
          Part[#, 1]], 
         Exp[
          Part[#, 2]]}& )}, DisplayFunction :> Identity, 
     Frame -> {{False, False}, {False, False}}, 
     FrameLabel -> {{None, None}, {None, None}}, 
     FrameTicks -> {{Automatic, Automatic}, {Automatic, Automatic}}, 
     GridLines -> {None, None}, GridLinesStyle -> Directive[
       GrayLevel[0.5, 0.4]], ImageSize -> 500, 
     Method -> {
      "DefaultBoundaryStyle" -> Automatic, "ScalingFunctions" -> None}, 
     PlotLabel -> FormBox[
       StyleBox["\"Constant intake\"", 14, StripOnInput -> False], 
       TraditionalForm], PlotRange -> {All, All}, PlotRangeClipping -> True, 
     PlotRangePadding -> {{
        Scaled[0.02], 
        Scaled[0.02]}, {
        Scaled[0.05], 
        Scaled[0.05]}}, Ticks -> {Automatic, Automatic}}],FormBox[
    FrameBox[
     FormBox[
      TemplateBox[{
        StyleBox["\"Lungs\"", 11, StripOnInput -> False], 
        StyleBox["\"Urine\\nExcretion\"", 11, StripOnInput -> False], 
        StyleBox["\"Faecal\\nExcretion\"", 11, StripOnInput -> False]}, 
       "LineLegend", DisplayFunction -> (FormBox[
         StyleBox[
          StyleBox[
           PaneBox[
            TagBox[
             GridBox[{{
                TagBox[
                 GridBox[{{
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[1, 0.5, 0], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    AbsoluteThickness[1.6], 
                    RGBColor[0, 0, 1]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #2}, {
                    GraphicsBox[{{
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {
                    LineBox[{{0, 10}, {40, 10}}]}}, {
                    Directive[
                    EdgeForm[
                    Directive[
                    Opacity[0.3], 
                    GrayLevel[0]]], 
                    PointSize[0.5], 
                    Opacity[1.], 
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    AbsoluteThickness[1.6], 
                    Dashing[{Small, Small}]], {}}}, AspectRatio -> Full, 
                    ImageSize -> {40, 10}, PlotRangePadding -> None, 
                    ImagePadding -> Automatic, 
                    BaselinePosition -> (Scaled[0.1] -> Baseline)], #3}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {Center, Left}, "Rows" -> {{Baseline}}}, 
                  AutoDelete -> False, 
                  GridBoxDividers -> {
                   "Columns" -> {{False}}, "Rows" -> {{False}}}, 
                  GridBoxItemSize -> {
                   "Columns" -> {{All}}, "Rows" -> {{All}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{0.5}}, "Rows" -> {{0.8}}}], "Grid"]}}, 
              GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
              AutoDelete -> False, 
              GridBoxItemSize -> {
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
              GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {{0}}}], 
             "Grid"], Alignment -> Left, AppearanceElements -> None, 
            ImageMargins -> {{5, 5}, {5, 5}}, ImageSizeAction -> 
            "ResizeToFit"], LineIndent -> 0, StripOnInput -> False], {
          FontFamily -> "Arial"}, Background -> Automatic, StripOnInput -> 
          False], TraditionalForm]& ), 
       InterpretationFunction :> (RowBox[{"LineLegend", "[", 
          RowBox[{
            RowBox[{"{", 
              RowBox[{
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[1, 0.5, 0], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[0.6666666666666666, 0.33333333333333337`, 0.], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[1, 0.5, 0]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[1, 0.5, 0]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[1, 0.5, 0], Editable -> False, Selectable -> 
                    False], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}], 
                ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0, 0, 1], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> RGBColor[0., 0., 0.6666666666666666], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], "RGBColor[0, 0, 1]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0, 0, 1]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0, 0, 1], Editable -> False, Selectable -> 
                    False]}], "]"}], ",", 
                RowBox[{"Directive", "[", 
                  RowBox[{
                    RowBox[{"Opacity", "[", "1.`", "]"}], ",", 
                    InterpretationBox[
                    ButtonBox[
                    TooltipBox[
                    RowBox[{
                    GraphicsBox[{{
                    GrayLevel[0], 
                    RectangleBox[{0, 0}]}, {
                    GrayLevel[0], 
                    RectangleBox[{1, -1}]}, {
                    RGBColor[0.560181, 0.691569, 0.194885], 
                    RectangleBox[{0, -1}, {2, 1}]}}, AspectRatio -> 1, Frame -> 
                    True, FrameStyle -> 
                    RGBColor[
                    0.37345400000000006`, 0.461046, 0.12992333333333334`], 
                    FrameTicks -> None, PlotRangePadding -> None, ImageSize -> 
                    Dynamic[{
                    Automatic, 1.35 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                    "\[InvisibleSpace]"}], 
                    "RGBColor[0.560181, 0.691569, 0.194885]"], Appearance -> 
                    None, BaseStyle -> {}, BaselinePosition -> Baseline, 
                    DefaultBaseStyle -> {}, ButtonFunction :> 
                    With[{Typeset`box$ = EvaluationBox[]}, 
                    If[
                    Not[
                    AbsoluteCurrentValue["Deployed"]], 
                    SelectionMove[Typeset`box$, All, Expression]; 
                    FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
                    FrontEnd`Private`$ColorSelectorInitialColor = 
                    RGBColor[0.560181, 0.691569, 0.194885]; 
                    FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
                    MathLink`CallFrontEnd[
                    FrontEnd`AttachCell[Typeset`box$, 
                    FrontEndResource["RGBColorValueSelector"], {
                    0, {Left, Bottom}}, {Left, Top}, 
                    "ClosingActions" -> {
                    "SelectionDeparture", "ParentChanged", 
                    "EvaluatorQuit"}]]]], BaseStyle -> Inherited, Evaluator -> 
                    Automatic, Method -> "Preemptive"], 
                    RGBColor[0.560181, 0.691569, 0.194885], Editable -> False,
                     Selectable -> False], ",", 
                    RowBox[{"AbsoluteThickness", "[", "1.6`", "]"}], ",", 
                    RowBox[{"Dashing", "[", 
                    RowBox[{"{", 
                    RowBox[{"Small", ",", "Small"}], "}"}], "]"}]}], "]"}]}], 
              "}"}], ",", 
            RowBox[{"{", 
              RowBox[{#, ",", #2, ",", #3}], "}"}], ",", 
            RowBox[{"LegendMarkers", "\[Rule]", "None"}], ",", 
            RowBox[{"LabelStyle", "\[Rule]", 
              RowBox[{"{", "}"}]}], ",", 
            RowBox[{"LegendLayout", "\[Rule]", "\"Column\""}]}], "]"}]& ), 
       Editable -> True], TraditionalForm], RoundingRadius -> 3, StripOnInput -> 
     False], TraditionalForm]},
  "Legended",
  DisplayFunction->(GridBox[{{
      TagBox[
       ItemBox[
        PaneBox[
         TagBox[#, "SkipImageSizeLevel"], Alignment -> {Center, Baseline}, 
         BaselinePosition -> Baseline], DefaultBaseStyle -> "Labeled"], 
       "SkipImageSizeLevel"], 
      ItemBox[#2, DefaultBaseStyle -> "LabeledLabel"]}}, 
    GridBoxAlignment -> {"Columns" -> {{Center}}, "Rows" -> {{Center}}}, 
    AutoDelete -> False, GridBoxItemSize -> Automatic, 
    BaselinePosition -> {1, 1}]& ),
  Editable->True,
  InterpretationFunction->(RowBox[{"Legended", "[", 
     RowBox[{#, ",", 
       RowBox[{"Placed", "[", 
         RowBox[{#2, ",", "After"}], "]"}]}], "]"}]& )]], "Output",
 CellChangeTimes->{3.3992832144612017`*^9, 3.417836732500705*^9, 
  3.479828811679937*^9, 3.479830025781125*^9, 3.5185354041779823`*^9, 
  3.6434438545080104`*^9},
 CellLabel->"Out[249]="]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Brackets",
PrintingStyleEnvironment->"Printout",
WindowToolbars->"EditBar",
WindowSize->{1672, 887},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
PrintingCopies->1,
PrintingStartingPageNumber->1,
PrintingPageRange->{Automatic, Automatic},
PageHeaders->{{
   Cell[
    TextData[
     StyleBox[
      CounterBox["Page"], "PageNumber"]], "Header", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, 
   Cell[
    TextData[
     StyleBox[
      RowBox[{"Printed", " ", "from", " ", "the", " ", 
        StyleBox["Mathematica", FontSlant -> "Italic"], " ", "Help", " ", 
        "Browser"}], "PageHeader"]], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}, {
   Cell[
    TextData["Biokmod"], "Header", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, 
   Cell[
    TextData[
     StyleBox[
      CounterBox["Page"], "PageNumber"]], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}},
PageFooters->{{None, 
   Cell[
    TextData[
     StyleBox[
      RowBox[{
       "\[Copyright]2004", " ", "Guillermo", " ", "Sanchez", " ", "&", " ", 
        "ENUSA", ".", " ", "All", " ", "rights", " ", "reserved", "."}], 
      "PageFooter"]], "Footer"], None}, {None, 
   Cell[
    TextData[
     StyleBox[
      RowBox[{
       "\[Copyright]2013", " ", "Guillermo", " ", "Sanchez", " ", "&", " ", 
        "ENUSA", " ", ".", " ", "All", " ", "rights", " ", "reserved", "."}], 
      "PageFooter"]], "Footer"], None}},
PageHeaderLines->{True, True},
PageFooterLines->{True, True},
PrintingOptions->{"FacingPages"->True,
"FirstPageFace"->Right,
"FirstPageFooter"->True,
"FirstPageHeader"->True},
ShowSelection->True,
Magnification->1.25,
FrontEndVersion->"10.0 for Microsoft Windows (64-bit) (December 4, 2014)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "Info3263734794-7542638"->{
  Cell[39042, 1090, 230, 4, 88, "Print",
   CellTags->"Info3263734794-7542638"]},
 "ICRP 78"->{
  Cell[649332, 14524, 230, 7, 340, "MathCaption",
   CellTags->"ICRP 78"],
  Cell[681859, 15194, 452913, 5595, 3690, "Graphics",
   CellTags->"ICRP 78"],
  Cell[1139762, 20960, 641, 21, 510, "MathCaption",
   CellTags->"ICRP 78"],
  Cell[1211738, 22581, 596, 26, 356, "MathCaption",
   CellTags->"ICRP 78"],
  Cell[2874474, 46779, 90, 1, 188, "Text",
   CellTags->"ICRP 78"],
  Cell[3076806, 51125, 237, 7, 188, "Text",
   CellTags->"ICRP 78"]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"Info3263734794-7542638", 5688608, 91442},
 {"ICRP 78", 5688704, 91445}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 173, 2, 108, "Chapter"],
Cell[743, 26, 478, 14, 28, "Text"],
Cell[1224, 42, 557, 7, 34, "Commentary"],
Cell[CellGroupData[{
Cell[1806, 53, 57, 1, 30, "Input"],
Cell[1866, 56, 444, 7, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2347, 68, 44, 0, 46, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[2416, 72, 105, 2, 37, "Input"],
Cell[2524, 76, 147, 2, 70, "Print"],
Cell[2674, 80, 158, 2, 70, "Print"],
Cell[2835, 84, 146, 2, 70, "Print"],
Cell[2984, 88, 146, 2, 70, "Print"]
}, Open  ]],
Cell[3145, 93, 230, 5, 35, "Text"],
Cell[CellGroupData[{
Cell[3400, 102, 92, 2, 37, "Input"],
Cell[3495, 106, 22359, 605, 70, "Print"]
}, Open  ]],
Cell[25869, 714, 1738, 47, 200, "DefinitionBox"],
Cell[27610, 763, 8367, 241, 1488, "Text"],
Cell[35980, 1006, 3059, 82, 62, "DefinitionBox"],
Cell[39042, 1090, 230, 4, 88, "Print",
 CellTags->"Info3263734794-7542638"]
}, Closed]],
Cell[CellGroupData[{
Cell[39309, 1099, 45, 0, 45, "Section"],
Cell[39357, 1101, 241, 8, 28, "Text"],
Cell[CellGroupData[{
Cell[39623, 1113, 35, 0, 46, "SubsectionIcon"],
Cell[39661, 1115, 1240, 41, 48, "Text"],
Cell[40904, 1158, 70, 0, 47, "MathCaption"],
Cell[40977, 1160, 106, 3, 30, "Input"],
Cell[41086, 1165, 825, 25, 30, "Input"],
Cell[41914, 1192, 467, 11, 46, "Text"],
Cell[42384, 1205, 18399, 724, 335, 15699, 678, "GraphicsData", "PostScript", \
"Graphics"],
Cell[60786, 1931, 75, 0, 27, "Text"],
Cell[60864, 1933, 130, 3, 27, "Text"],
Cell[CellGroupData[{
Cell[61019, 1940, 95, 2, 30, "Input"],
Cell[61117, 1944, 994, 27, 171, "Output"]
}, Open  ]],
Cell[62126, 1974, 652, 16, 50, "Text"],
Cell[CellGroupData[{
Cell[62803, 1994, 427, 12, 32, "Input"],
Cell[63233, 2008, 1691, 49, 202, "Output"]
}, Open  ]],
Cell[64939, 2060, 64, 0, 47, "MathCaption"],
Cell[CellGroupData[{
Cell[65028, 2064, 135, 4, 30, "Input"],
Cell[65166, 2070, 1858, 45, 180, "Output"]
}, Open  ]],
Cell[67039, 2118, 101, 2, 47, "MathCaption"],
Cell[CellGroupData[{
Cell[67165, 2124, 85, 2, 30, "Input"],
Cell[67253, 2128, 687, 19, 47, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[67989, 2153, 35, 0, 32, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[68049, 2157, 93, 1, 28, "SubsubsectionIcon"],
Cell[CellGroupData[{
Cell[68167, 2162, 278, 7, 213, "Input"],
Cell[68448, 2171, 3154, 79, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[71639, 2255, 250, 6, 213, "Input"],
Cell[71892, 2263, 3256, 77, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[75185, 2345, 289, 7, 213, "Input"],
Cell[75477, 2354, 3566, 90, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[79080, 2449, 290, 7, 213, "Input"],
Cell[79373, 2458, 3118, 79, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[82540, 2543, 97, 1, 22, "SubsubsectionIcon"],
Cell[82640, 2546, 132, 1, 340, "MathCaption"],
Cell[CellGroupData[{
Cell[82797, 2551, 252, 6, 213, "Input"],
Cell[83052, 2559, 4509, 104, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[87598, 2668, 255, 6, 213, "Input"],
Cell[87856, 2676, 4865, 113, 70, "Output"]
}, Open  ]],
Cell[92736, 2792, 68, 0, 245, "Commentary"],
Cell[CellGroupData[{
Cell[92829, 2796, 264, 6, 213, "Input"],
Cell[93096, 2804, 5714, 126, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[98847, 2935, 265, 6, 213, "Input"],
Cell[99115, 2943, 4467, 104, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[103631, 3053, 97, 1, 22, "SubsubsectionIcon"],
Cell[103731, 3056, 114, 1, 340, "MathCaption"],
Cell[CellGroupData[{
Cell[103870, 3061, 252, 6, 213, "Input"],
Cell[104125, 3069, 26639, 500, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[130801, 3574, 255, 6, 213, "Input"],
Cell[131059, 3582, 27864, 519, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[158960, 4106, 295, 7, 213, "Input"],
Cell[159258, 4115, 22472, 431, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[181767, 4551, 265, 6, 213, "Input"],
Cell[182035, 4559, 26803, 503, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[208887, 5068, 102, 1, 22, "SubsubsectionIcon"],
Cell[208992, 5071, 147, 1, 340, "MathCaption"],
Cell[CellGroupData[{
Cell[209164, 5076, 258, 6, 213, "Input"],
Cell[209425, 5084, 1187, 34, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[210649, 5123, 261, 6, 213, "Input"],
Cell[210913, 5131, 1251, 35, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[212201, 5171, 300, 7, 213, "Input"],
Cell[212504, 5180, 1237, 35, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[213778, 5220, 270, 6, 213, "Input"],
Cell[214051, 5228, 339, 5, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[214439, 5239, 99, 1, 22, "SubsubsectionIcon"],
Cell[214541, 5242, 168, 2, 340, "MathCaption"],
Cell[CellGroupData[{
Cell[214734, 5248, 255, 6, 213, "Input"],
Cell[214992, 5256, 1236, 34, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[216265, 5295, 258, 6, 213, "Input"],
Cell[216526, 5303, 1250, 35, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[217813, 5343, 297, 7, 213, "Input"],
Cell[218113, 5352, 338, 5, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[218488, 5362, 267, 6, 213, "Input"],
Cell[218758, 5370, 335, 5, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[219154, 5382, 35, 0, 32, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[219214, 5386, 93, 1, 158, "SubsubsectionIcon"],
Cell[CellGroupData[{
Cell[219332, 5391, 247, 6, 213, "Input"],
Cell[219582, 5399, 3637, 90, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[223256, 5494, 250, 6, 213, "Input"],
Cell[223509, 5502, 3587, 85, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[227133, 5592, 257, 6, 213, "Input"],
Cell[227393, 5600, 3968, 98, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[231398, 5703, 258, 6, 213, "Input"],
Cell[231659, 5711, 4016, 97, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[235724, 5814, 97, 1, 121, "SubsubsectionIcon"],
Cell[CellGroupData[{
Cell[235846, 5819, 284, 7, 213, "Input"],
Cell[236133, 5828, 3809, 94, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[239979, 5927, 255, 6, 213, "Input"],
Cell[240237, 5935, 4855, 113, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[245129, 6053, 295, 7, 213, "Input"],
Cell[245427, 6062, 3831, 95, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[249295, 6162, 265, 6, 213, "Input"],
Cell[249563, 6170, 4472, 104, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[254084, 6280, 97, 1, 121, "SubsubsectionIcon"],
Cell[CellGroupData[{
Cell[254206, 6285, 252, 6, 213, "Input"],
Cell[254461, 6293, 27076, 507, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[281574, 6805, 255, 6, 213, "Input"],
Cell[281832, 6813, 27883, 520, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[309752, 7338, 295, 7, 213, "Input"],
Cell[310050, 7347, 22576, 433, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[332663, 7785, 265, 6, 213, "Input"],
Cell[332931, 7793, 27230, 510, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[360210, 8309, 102, 1, 121, "SubsubsectionIcon"],
Cell[CellGroupData[{
Cell[360337, 8314, 258, 6, 213, "Input"],
Cell[360598, 8322, 1416, 40, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[362051, 8367, 261, 6, 213, "Input"],
Cell[362315, 8375, 1420, 40, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[363772, 8420, 300, 7, 213, "Input"],
Cell[364075, 8429, 1382, 39, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[365494, 8473, 270, 6, 213, "Input"],
Cell[365767, 8481, 312, 4, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[366128, 8491, 99, 1, 121, "SubsubsectionIcon"],
Cell[CellGroupData[{
Cell[366252, 8496, 255, 6, 171, "Input"],
Cell[366510, 8504, 1371, 37, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[367918, 8546, 258, 6, 171, "Input"],
Cell[368179, 8554, 1384, 38, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[369600, 8597, 297, 7, 171, "Input"],
Cell[369900, 8606, 312, 4, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[370249, 8615, 267, 6, 171, "Input"],
Cell[370519, 8623, 313, 4, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[370893, 8634, 36, 0, 32, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[370954, 8638, 94, 1, 28, "SubsubsectionIcon"],
Cell[CellGroupData[{
Cell[371073, 8643, 286, 6, 213, "Input"],
Cell[371362, 8651, 12867, 308, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[384266, 8964, 289, 6, 213, "Input"],
Cell[384558, 8972, 11035, 259, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[395630, 9236, 296, 6, 213, "Input"],
Cell[395929, 9244, 299, 4, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[396277, 9254, 98, 1, 22, "SubsubsectionIcon"],
Cell[CellGroupData[{
Cell[396400, 9259, 291, 6, 213, "Input"],
Cell[396694, 9267, 4780, 105, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[401511, 9377, 294, 6, 213, "Input"],
Cell[401808, 9385, 5909, 114, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[407754, 9504, 336, 8, 213, "Input"],
Cell[408093, 9514, 305, 4, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[408435, 9523, 298, 6, 213, "Input"],
Cell[408736, 9531, 4581, 103, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[413366, 9640, 98, 1, 22, "SubsubsectionIcon"],
Cell[CellGroupData[{
Cell[413489, 9645, 291, 6, 213, "Input"],
Cell[413783, 9653, 31998, 604, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[445818, 10262, 294, 6, 213, "Input"],
Cell[446115, 10270, 32192, 607, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[478344, 10882, 297, 6, 213, "Input"],
Cell[478644, 10890, 300, 4, 70, "Output"]
}, Open  ]],
Cell[478959, 10897, 238, 3, 245, "Commentary"],
Cell[CellGroupData[{
Cell[479222, 10904, 406, 9, 213, "Input"],
Cell[479631, 10915, 32234, 607, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[511914, 11528, 103, 1, 22, "SubsubsectionIcon"],
Cell[CellGroupData[{
Cell[512042, 11533, 296, 6, 213, "Input"],
Cell[512341, 11541, 3698, 102, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[516076, 11648, 299, 6, 213, "Input"],
Cell[516378, 11656, 3002, 90, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[519417, 11751, 368, 8, 213, "Input"],
Cell[519788, 11761, 302, 4, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[520127, 11770, 298, 6, 213, "Input"],
Cell[520428, 11778, 309, 4, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[520786, 11788, 100, 1, 22, "SubsubsectionIcon"],
Cell[CellGroupData[{
Cell[520911, 11793, 298, 6, 213, "Input"],
Cell[521212, 11801, 2847, 84, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[524096, 11890, 296, 6, 213, "Input"],
Cell[524395, 11898, 2870, 87, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[527302, 11990, 338, 8, 213, "Input"],
Cell[527643, 12000, 301, 4, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[527981, 12009, 300, 6, 213, "Input"],
Cell[528284, 12017, 307, 4, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[528664, 12029, 61, 0, 78, "Section"],
Cell[CellGroupData[{
Cell[528750, 12033, 39, 0, 28, "SubsubsectionIcon"],
Cell[528792, 12035, 411, 5, 332, "Text"],
Cell[529206, 12042, 13138, 165, 3300, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[542381, 12212, 32, 0, 32, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[542438, 12216, 38, 0, 197, "SubsubsectionIcon"],
Cell[CellGroupData[{
Cell[542501, 12220, 96, 2, 213, "Input"],
Cell[542600, 12224, 990, 27, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[543627, 12256, 175, 4, 382, "Input"],
Cell[543805, 12262, 2063, 62, 70, "Output"]
}, Open  ]],
Cell[545883, 12327, 182, 5, 213, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[546102, 12337, 38, 0, 197, "SubsubsectionIcon"],
Cell[546143, 12339, 270, 5, 340, "MathCaption"],
Cell[546416, 12346, 192, 4, 245, "Commentary"],
Cell[546611, 12352, 213, 6, 213, "Input"],
Cell[546827, 12360, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[546879, 12364, 252, 6, 213, "Input"],
Cell[547134, 12372, 5029, 112, 70, "Output"]
}, Open  ]],
Cell[552178, 12487, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[552233, 12491, 255, 6, 213, "Input"],
Cell[552491, 12499, 16941, 340, 70, "Output"]
}, Open  ]],
Cell[569447, 12842, 241, 4, 340, "MathCaption"],
Cell[CellGroupData[{
Cell[569713, 12850, 506, 15, 213, "Input"],
Cell[570222, 12867, 1278, 35, 70, "Output"]
}, Open  ]],
Cell[571515, 12905, 130, 3, 340, "MathCaption"],
Cell[CellGroupData[{
Cell[571670, 12912, 297, 7, 213, "Input"],
Cell[571970, 12921, 16943, 340, 70, "Output"]
}, Open  ]],
Cell[588928, 13264, 134, 3, 340, "MathCaption"],
Cell[CellGroupData[{
Cell[589087, 13271, 474, 14, 213, "Input"],
Cell[589564, 13287, 26407, 496, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[616020, 13789, 38, 0, 197, "SubsubsectionIcon"],
Cell[616061, 13791, 501, 17, 340, "MathCaption"],
Cell[616565, 13810, 269, 8, 213, "Input"],
Cell[616837, 13820, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[616889, 13824, 284, 7, 213, "Input"],
Cell[617176, 13833, 4925, 109, 70, "Output"]
}, Open  ]],
Cell[622116, 13945, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[622171, 13949, 255, 6, 213, "Input"],
Cell[622429, 13957, 20508, 399, 70, "Output"]
}, Open  ]],
Cell[642952, 14359, 583, 19, 352, "MathCaption"],
Cell[643538, 14380, 268, 8, 213, "Input"],
Cell[CellGroupData[{
Cell[643831, 14392, 284, 7, 213, "Input"],
Cell[644118, 14401, 4927, 109, 70, "Output"]
}, Open  ]],
Cell[649060, 14513, 193, 4, 245, "Commentary"]
}, Closed]],
Cell[CellGroupData[{
Cell[649290, 14522, 39, 0, 197, "SubsubsectionIcon"],
Cell[649332, 14524, 230, 7, 340, "MathCaption",
 CellTags->"ICRP 78"],
Cell[649565, 14533, 428, 12, 213, "Input"],
Cell[649996, 14547, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[650048, 14551, 291, 6, 213, "Input"],
Cell[650342, 14559, 6046, 114, 70, "Output"]
}, Open  ]],
Cell[656403, 14676, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[656458, 14680, 294, 6, 213, "Input"],
Cell[656755, 14688, 24704, 486, 70, "Output"]
}, Open  ]],
Cell[681474, 15177, 180, 3, 245, "Commentary"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[681703, 15186, 33, 0, 32, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[681761, 15190, 38, 0, 197, "SubsubsectionIcon"],
Cell[681802, 15192, 54, 0, 188, "Text"],
Cell[681859, 15194, 452913, 5595, 3690, "Graphics",
 CellTags->"ICRP 78"],
Cell[1134775, 20791, 251, 6, 197, "Text"],
Cell[CellGroupData[{
Cell[1135051, 20801, 97, 2, 213, "Input"],
Cell[1135151, 20805, 959, 26, 70, "Output"]
}, Open  ]],
Cell[1136125, 20834, 1603, 58, 363, "Text"],
Cell[CellGroupData[{
Cell[1137753, 20896, 429, 12, 245, "Input"],
Cell[1138185, 20910, 1562, 47, 70, "Output"]
}, Open  ]],
Cell[1139762, 20960, 641, 21, 510, "MathCaption",
 CellTags->"ICRP 78"],
Cell[1140406, 20983, 182, 5, 213, "Input"],
Cell[1140591, 20990, 478, 13, 213, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1141106, 21008, 38, 0, 197, "SubsubsectionIcon"],
Cell[1141147, 21010, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[1141199, 21014, 252, 6, 213, "Input"],
Cell[1141454, 21022, 5010, 112, 70, "Output"]
}, Open  ]],
Cell[1146479, 21137, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[1146534, 21141, 255, 6, 213, "Input"],
Cell[1146792, 21149, 15269, 314, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1162110, 21469, 38, 0, 197, "SubsubsectionIcon"],
Cell[1162151, 21471, 180, 3, 245, "Commentary"],
Cell[1162334, 21476, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[1162386, 21480, 284, 7, 213, "Input"],
Cell[1162673, 21489, 4429, 104, 70, "Output"]
}, Open  ]],
Cell[1167117, 21596, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[1167172, 21600, 255, 6, 213, "Input"],
Cell[1167430, 21608, 15267, 314, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1182746, 21928, 39, 0, 197, "SubsubsectionIcon"],
Cell[1182788, 21930, 180, 3, 245, "Commentary"],
Cell[1182971, 21935, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[1183023, 21939, 291, 6, 213, "Input"],
Cell[1183317, 21947, 5320, 114, 70, "Output"]
}, Open  ]],
Cell[1188652, 22064, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[1188707, 22068, 294, 6, 213, "Input"],
Cell[1189004, 22076, 19876, 406, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[1208941, 22489, 37, 0, 32, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[1209003, 22493, 38, 0, 197, "SubsubsectionIcon"],
Cell[1209044, 22495, 210, 6, 188, "Text"],
Cell[CellGroupData[{
Cell[1209279, 22505, 433, 12, 245, "Input"],
Cell[1209715, 22519, 1823, 52, 70, "Output"]
}, Open  ]],
Cell[1211553, 22574, 182, 5, 213, "Input"],
Cell[1211738, 22581, 596, 26, 356, "MathCaption",
 CellTags->"ICRP 78"],
Cell[1212337, 22609, 556, 16, 233, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[1212930, 22630, 38, 0, 197, "SubsubsectionIcon"],
Cell[1212971, 22632, 180, 3, 245, "Commentary"],
Cell[1213154, 22637, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[1213206, 22641, 252, 6, 213, "Input"],
Cell[1213461, 22649, 5036, 112, 70, "Output"]
}, Open  ]],
Cell[1218512, 22764, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[1218567, 22768, 256, 6, 213, "Input"],
Cell[1218826, 22776, 21827, 421, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1240702, 23203, 38, 0, 197, "SubsubsectionIcon"],
Cell[1240743, 23205, 204, 6, 188, "Text"],
Cell[1240950, 23213, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[1241002, 23217, 285, 7, 213, "Input"],
Cell[1241290, 23226, 4897, 108, 70, "Output"]
}, Open  ]],
Cell[1246202, 23337, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[1246257, 23341, 256, 6, 213, "Input"],
Cell[1246516, 23349, 26216, 493, 70, "Output"],
Cell[1272735, 23844, 208, 7, 210, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[1272992, 23857, 39, 0, 197, "SubsubsectionIcon"],
Cell[1273034, 23859, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[1273086, 23863, 292, 6, 213, "Input"],
Cell[1273381, 23871, 6078, 114, 70, "Output"]
}, Open  ]],
Cell[1279474, 23988, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[1279529, 23992, 295, 6, 213, "Input"],
Cell[1279827, 24000, 25961, 506, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[1305825, 24511, 826, 23, 245, "Input"],
Cell[1306654, 24536, 5919, 114, 70, "Output"]
}, Open  ]],
Cell[1312588, 24653, 204, 6, 188, "Text"]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[1312853, 24666, 75, 0, 78, "Section"],
Cell[CellGroupData[{
Cell[1312953, 24670, 100, 2, 28, "SubsubsectionIcon"],
Cell[1313056, 24674, 58, 0, 188, "Text"],
Cell[1313117, 24676, 1533277, 21439, 4441, 1516165, 21156, "GraphicsData", \
"PostScript", "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[2846431, 46120, 35, 0, 32, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[2846491, 46124, 38, 0, 197, "SubsubsectionIcon"],
Cell[2846532, 46126, 63, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[2846620, 46130, 100, 2, 213, "Input"],
Cell[2846723, 46134, 1315, 35, 70, "Output"]
}, Open  ]],
Cell[2848053, 46172, 208, 4, 188, "Text"],
Cell[CellGroupData[{
Cell[2848286, 46180, 414, 12, 213, "Input"],
Cell[2848703, 46194, 1971, 58, 70, "Output"]
}, Open  ]],
Cell[2850689, 46255, 183, 5, 213, "Input"],
Cell[2850875, 46262, 111, 3, 213, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[2851023, 46270, 38, 0, 197, "SubsubsectionIcon"],
Cell[2851064, 46272, 101, 2, 340, "MathCaption"],
Cell[2851168, 46276, 77, 0, 245, "Commentary"],
Cell[2851248, 46278, 187, 6, 213, "Input"],
Cell[2851438, 46286, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[2851490, 46290, 253, 6, 213, "Input"],
Cell[2851746, 46298, 4920, 110, 70, "Output"]
}, Open  ]],
Cell[2856681, 46411, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[2856736, 46415, 256, 6, 213, "Input"],
Cell[2856995, 46423, 17389, 348, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2874433, 46777, 38, 0, 197, "SubsubsectionIcon"],
Cell[2874474, 46779, 90, 1, 188, "Text",
 CellTags->"ICRP 78"],
Cell[2874567, 46782, 106, 3, 213, "Input"],
Cell[2874676, 46787, 77, 0, 245, "Commentary"],
Cell[2874756, 46789, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[2874808, 46793, 285, 7, 213, "Input"],
Cell[2875096, 46802, 4368, 102, 70, "Output"]
}, Open  ]],
Cell[2879479, 46907, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[2879534, 46911, 256, 6, 213, "Input"],
Cell[2879793, 46919, 20376, 397, 70, "Output"]
}, Open  ]],
Cell[2900184, 47319, 27, 0, 188, "Text"],
Cell[2900214, 47321, 97, 3, 213, "Input"],
Cell[CellGroupData[{
Cell[2900336, 47328, 285, 7, 213, "Input"],
Cell[2900624, 47337, 4260, 100, 70, "Output"]
}, Open  ]],
Cell[2904899, 47440, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[2904954, 47444, 256, 6, 213, "Input"],
Cell[2905213, 47452, 22170, 426, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2927432, 47884, 39, 0, 197, "SubsubsectionIcon"],
Cell[2927474, 47886, 46, 0, 188, "Text"],
Cell[2927523, 47888, 251, 7, 213, "Input"],
Cell[2927777, 47897, 22, 0, 188, "Text"],
Cell[2927802, 47899, 173, 5, 213, "Input"],
Cell[2927978, 47906, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[2928030, 47910, 292, 6, 213, "Input"],
Cell[2928325, 47918, 5077, 110, 70, "Output"]
}, Open  ]],
Cell[2933417, 48031, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[2933472, 48035, 295, 6, 213, "Input"],
Cell[2933770, 48043, 24729, 486, 70, "Output"]
}, Open  ]],
Cell[2958514, 48532, 22, 0, 188, "Text"],
Cell[2958539, 48534, 174, 5, 213, "Input"],
Cell[2958716, 48541, 78, 0, 245, "Commentary"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[2958843, 48547, 32, 0, 32, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[2958900, 48551, 38, 0, 197, "SubsubsectionIcon"],
Cell[CellGroupData[{
Cell[2958963, 48555, 97, 2, 213, "Input"],
Cell[2959063, 48559, 1231, 33, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2960331, 48597, 411, 12, 213, "Input"],
Cell[2960745, 48611, 1885, 58, 70, "Output"]
}, Open  ]],
Cell[2962645, 48672, 183, 5, 213, "Input"],
Cell[2962831, 48679, 46, 0, 188, "Text"],
Cell[2962880, 48681, 363, 9, 213, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[2963280, 48695, 38, 0, 197, "SubsubsectionIcon"],
Cell[2963321, 48697, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[2963373, 48701, 253, 6, 213, "Input"],
Cell[2963629, 48709, 5002, 112, 70, "Output"]
}, Open  ]],
Cell[2968646, 48824, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[2968701, 48828, 256, 6, 213, "Input"],
Cell[2968960, 48836, 19458, 382, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[2988467, 49224, 38, 0, 197, "SubsubsectionIcon"],
Cell[2988508, 49226, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[2988560, 49230, 285, 7, 213, "Input"],
Cell[2988848, 49239, 5035, 112, 70, "Output"]
}, Open  ]],
Cell[2993898, 49354, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[2993953, 49358, 256, 6, 213, "Input"],
Cell[2994212, 49366, 21671, 418, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3015932, 49790, 39, 0, 197, "SubsubsectionIcon"],
Cell[3015974, 49792, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3016026, 49796, 292, 6, 213, "Input"],
Cell[3016321, 49804, 5308, 114, 70, "Output"]
}, Open  ]],
Cell[3021644, 49921, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3021699, 49925, 295, 6, 213, "Input"],
Cell[3021997, 49933, 25001, 489, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[3047059, 50429, 33, 0, 32, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[3047117, 50433, 38, 0, 197, "SubsubsectionIcon"],
Cell[3047158, 50435, 62, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3047245, 50439, 98, 2, 213, "Input"],
Cell[3047346, 50443, 1429, 40, 70, "Output"]
}, Open  ]],
Cell[3048790, 50486, 158, 3, 188, "Text"],
Cell[CellGroupData[{
Cell[3048973, 50493, 413, 12, 213, "Input"],
Cell[3049389, 50507, 2419, 76, 70, "Output"]
}, Open  ]],
Cell[3051823, 50586, 154, 3, 245, "Commentary"],
Cell[3051980, 50591, 183, 5, 213, "Input"],
Cell[3052166, 50598, 177, 5, 213, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[3052380, 50608, 38, 0, 197, "SubsubsectionIcon"],
Cell[3052421, 50610, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3052473, 50614, 253, 6, 213, "Input"],
Cell[3052729, 50622, 5017, 112, 70, "Output"]
}, Open  ]],
Cell[3057761, 50737, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3057816, 50741, 256, 6, 213, "Input"],
Cell[3058075, 50749, 18641, 368, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3076765, 51123, 38, 0, 197, "SubsubsectionIcon"],
Cell[3076806, 51125, 237, 7, 188, "Text",
 CellTags->"ICRP 78"],
Cell[3077046, 51134, 60, 0, 340, "MathCaption"],
Cell[3077109, 51136, 107, 3, 213, "Input"],
Cell[3077219, 51141, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3077271, 51145, 285, 7, 213, "Input"],
Cell[3077559, 51154, 5070, 112, 70, "Output"]
}, Open  ]],
Cell[3082644, 51269, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3082699, 51273, 256, 6, 213, "Input"],
Cell[3082958, 51281, 22981, 439, 70, "Output"]
}, Open  ]],
Cell[3105954, 51723, 61, 0, 340, "MathCaption"],
Cell[3106018, 51725, 108, 3, 213, "Input"],
Cell[3106129, 51730, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3106181, 51734, 285, 7, 213, "Input"],
Cell[3106469, 51743, 4869, 103, 70, "Output"]
}, Open  ]],
Cell[3111353, 51849, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3111408, 51853, 256, 6, 213, "Input"],
Cell[3111667, 51861, 24036, 457, 70, "Output"]
}, Open  ]],
Cell[3135718, 52321, 72, 0, 188, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[3135827, 52326, 39, 0, 197, "SubsubsectionIcon"],
Cell[3135869, 52328, 232, 6, 340, "MathCaption"],
Cell[3136104, 52336, 244, 6, 213, "Input"],
Cell[3136351, 52344, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3136403, 52348, 292, 6, 213, "Input"],
Cell[3136698, 52356, 6060, 114, 70, "Output"]
}, Open  ]],
Cell[3142773, 52473, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3142828, 52477, 295, 6, 213, "Input"],
Cell[3143126, 52485, 25308, 495, 70, "Output"]
}, Open  ]],
Cell[3168449, 52983, 72, 0, 188, "Text"],
Cell[3168524, 52985, 167, 3, 340, "MathCaption"],
Cell[3168694, 52990, 111, 3, 188, "Text"],
Cell[3168808, 52995, 684, 17, 383, "Input"],
Cell[3169495, 53014, 94, 2, 340, "MathCaption"],
Cell[CellGroupData[{
Cell[3169614, 53020, 253, 8, 213, "Input"],
Cell[3169870, 53030, 1271, 33, 70, "Output"]
}, Open  ]],
Cell[3171156, 53066, 155, 3, 340, "MathCaption"],
Cell[CellGroupData[{
Cell[3171336, 53073, 390, 11, 213, "Input"],
Cell[3171729, 53086, 2871, 48, 70, "Output"]
}, Open  ]],
Cell[3174615, 53137, 153, 3, 340, "MathCaption"],
Cell[CellGroupData[{
Cell[3174793, 53144, 532, 15, 213, "Input"],
Cell[3175328, 53161, 2986, 69, 70, "Output"]
}, Open  ]],
Cell[3178329, 53233, 157, 3, 188, "Text"],
Cell[CellGroupData[{
Cell[3178511, 53240, 484, 14, 213, "Input"],
Cell[3178998, 53256, 1375, 20, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3180410, 53281, 527, 15, 213, "Input"],
Cell[3180940, 53298, 1916, 44, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3182893, 53347, 484, 14, 213, "Input"],
Cell[3183380, 53363, 1345, 20, 70, "Output"]
}, Open  ]],
Cell[3184740, 53386, 270, 6, 213, "Input"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[3185059, 53398, 32, 0, 32, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[3185116, 53402, 38, 0, 197, "SubsubsectionIcon"],
Cell[3185157, 53404, 63, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3185245, 53408, 97, 2, 213, "Input"],
Cell[3185345, 53412, 1298, 36, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3186680, 53453, 412, 12, 213, "Input"],
Cell[3187095, 53467, 2148, 67, 70, "Output"]
}, Open  ]],
Cell[3189258, 53537, 34, 0, 188, "Text"],
Cell[3189295, 53539, 155, 4, 213, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[3189487, 53548, 38, 0, 197, "SubsubsectionIcon"],
Cell[3189528, 53550, 119, 3, 340, "MathCaption"],
Cell[3189650, 53555, 222, 7, 213, "Input"],
Cell[3189875, 53564, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3189927, 53568, 253, 6, 213, "Input"],
Cell[3190183, 53576, 5044, 112, 70, "Output"]
}, Open  ]],
Cell[3195242, 53691, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3195297, 53695, 256, 6, 213, "Input"],
Cell[3195556, 53703, 18075, 358, 70, "Output"]
}, Open  ]],
Cell[3213646, 54064, 72, 0, 188, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[3213755, 54069, 38, 0, 197, "SubsubsectionIcon"],
Cell[3213796, 54071, 65, 0, 340, "MathCaption"],
Cell[3213864, 54073, 222, 7, 213, "Input"],
Cell[3214089, 54082, 92, 2, 188, "Text"],
Cell[3214184, 54086, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3214236, 54090, 285, 7, 213, "Input"],
Cell[3214524, 54099, 5041, 112, 70, "Output"]
}, Open  ]],
Cell[3219580, 54214, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3219635, 54218, 256, 6, 213, "Input"],
Cell[3219894, 54226, 20571, 398, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3240514, 54630, 39, 0, 197, "SubsubsectionIcon"],
Cell[3240556, 54632, 56, 0, 188, "Text"],
Cell[3240615, 54634, 374, 11, 213, "Input"],
Cell[3240992, 54647, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3241044, 54651, 292, 6, 213, "Input"],
Cell[3241339, 54659, 6090, 114, 70, "Output"]
}, Open  ]],
Cell[3247444, 54776, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3247499, 54780, 295, 6, 213, "Input"],
Cell[3247797, 54788, 24273, 478, 70, "Output"]
}, Open  ]],
Cell[3272085, 55269, 72, 0, 188, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[3272206, 55275, 30, 0, 32, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[3272261, 55279, 34, 0, 197, "SubsubsectionIcon"],
Cell[CellGroupData[{
Cell[3272320, 55283, 95, 2, 213, "Input"],
Cell[3272418, 55287, 1522, 41, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[3273977, 55333, 410, 12, 213, "Input"],
Cell[3274390, 55347, 2483, 79, 70, "Output"]
}, Open  ]],
Cell[3276888, 55429, 183, 5, 213, "Input"],
Cell[3277074, 55436, 361, 9, 213, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[3277472, 55450, 38, 0, 197, "SubsubsectionIcon"],
Cell[3277513, 55452, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3277565, 55456, 253, 6, 213, "Input"],
Cell[3277821, 55464, 4990, 112, 70, "Output"]
}, Open  ]],
Cell[3282826, 55579, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3282881, 55583, 256, 6, 213, "Input"],
Cell[3283140, 55591, 15841, 323, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3299030, 55920, 38, 0, 197, "SubsubsectionIcon"],
Cell[3299071, 55922, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3299123, 55926, 285, 7, 213, "Input"],
Cell[3299411, 55935, 5002, 112, 70, "Output"]
}, Open  ]],
Cell[3304428, 56050, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3304483, 56054, 256, 6, 213, "Input"],
Cell[3304742, 56062, 18949, 373, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[3323740, 56441, 39, 0, 197, "SubsubsectionIcon"],
Cell[3323782, 56443, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3323834, 56447, 292, 6, 213, "Input"],
Cell[3324129, 56455, 5301, 114, 70, "Output"]
}, Open  ]],
Cell[3329445, 56572, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[3329500, 56576, 295, 6, 213, "Input"],
Cell[3329798, 56584, 22417, 448, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[3352288, 57040, 89, 2, 78, "Section"],
Cell[CellGroupData[{
Cell[3352402, 57046, 123, 3, 28, "SubsubsectionIcon"],
Cell[3352528, 57051, 59, 0, 188, "Text"],
Cell[3352590, 57053, 1618129, 19980, 2410, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[4970756, 77038, 35, 0, 32, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[4970816, 77042, 38, 0, 197, "SubsubsectionIcon"],
Cell[4970857, 77044, 62, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[4970944, 77048, 100, 2, 213, "Input"],
Cell[4971047, 77052, 1390, 40, 70, "Output"]
}, Open  ]],
Cell[4972452, 77095, 208, 4, 188, "Text"],
Cell[CellGroupData[{
Cell[4972685, 77103, 433, 12, 245, "Input"],
Cell[4973121, 77117, 2497, 79, 70, "Output"]
}, Open  ]],
Cell[4975633, 77199, 183, 5, 213, "Input"],
Cell[4975819, 77206, 180, 5, 213, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[4976036, 77216, 38, 0, 197, "SubsubsectionIcon"],
Cell[4976077, 77218, 176, 6, 233, "Input"],
Cell[4976256, 77226, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[4976308, 77230, 253, 6, 213, "Input"],
Cell[4976564, 77238, 4990, 112, 70, "Output"]
}, Open  ]],
Cell[4981569, 77353, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[4981624, 77357, 256, 6, 213, "Input"],
Cell[4981883, 77365, 17453, 349, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[4999385, 77720, 38, 0, 197, "SubsubsectionIcon"],
Cell[4999426, 77722, 155, 3, 188, "Text"],
Cell[4999584, 77727, 368, 14, 340, "MathCaption"],
Cell[4999955, 77743, 176, 6, 233, "Input"],
Cell[5000134, 77751, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5000186, 77755, 285, 7, 213, "Input"],
Cell[5000474, 77764, 5054, 112, 70, "Output"]
}, Open  ]],
Cell[5005543, 77879, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5005598, 77883, 256, 6, 213, "Input"],
Cell[5005857, 77891, 22588, 433, 70, "Output"]
}, Open  ]],
Cell[5028460, 78327, 97, 2, 188, "Text"],
Cell[5028560, 78331, 150, 5, 233, "Input"],
Cell[5028713, 78338, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5028765, 78342, 285, 7, 213, "Input"],
Cell[5029053, 78351, 4834, 103, 70, "Output"]
}, Open  ]],
Cell[5033902, 78457, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5033957, 78461, 256, 6, 213, "Input"],
Cell[5034216, 78469, 23945, 455, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5058210, 78930, 39, 0, 197, "SubsubsectionIcon"],
Cell[5058252, 78932, 63, 0, 188, "Text"],
Cell[5058318, 78934, 466, 14, 233, "Input"],
Cell[CellGroupData[{
Cell[5058809, 78952, 292, 6, 213, "Input"],
Cell[5059104, 78960, 6051, 114, 70, "Output"]
}, Open  ]],
Cell[5065170, 79077, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5065225, 79081, 295, 6, 213, "Input"],
Cell[5065523, 79089, 23849, 472, 70, "Output"]
}, Open  ]],
Cell[5089387, 79564, 73, 0, 188, "Text"],
Cell[5089463, 79566, 30, 0, 188, "Text"],
Cell[5089496, 79568, 276, 8, 233, "Input"],
Cell[CellGroupData[{
Cell[5089797, 79580, 292, 6, 213, "Input"],
Cell[5090092, 79588, 6036, 114, 70, "Output"]
}, Open  ]],
Cell[5096143, 79705, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5096198, 79709, 295, 6, 213, "Input"],
Cell[5096496, 79717, 23750, 470, 70, "Output"]
}, Open  ]],
Cell[5120261, 80190, 73, 0, 188, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[5120383, 80196, 44, 0, 32, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[5120452, 80200, 38, 0, 197, "SubsubsectionIcon"],
Cell[5120493, 80202, 249, 4, 188, "Text"],
Cell[5120745, 80208, 62, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5120832, 80212, 100, 2, 213, "Input"],
Cell[5120935, 80216, 1362, 39, 70, "Output"]
}, Open  ]],
Cell[5122312, 80258, 208, 4, 188, "Text"],
Cell[CellGroupData[{
Cell[5122545, 80266, 433, 12, 245, "Input"],
Cell[5122981, 80280, 2405, 77, 70, "Output"]
}, Open  ]],
Cell[5125401, 80360, 183, 5, 213, "Input"],
Cell[5125587, 80367, 439, 12, 233, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[5126063, 80384, 38, 0, 197, "SubsubsectionIcon"],
Cell[5126104, 80386, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5126156, 80390, 253, 6, 213, "Input"],
Cell[5126412, 80398, 4990, 112, 70, "Output"]
}, Open  ]],
Cell[5131417, 80513, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5131472, 80517, 256, 6, 213, "Input"],
Cell[5131731, 80525, 18140, 361, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5149920, 80892, 38, 0, 197, "SubsubsectionIcon"],
Cell[5149961, 80894, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5150013, 80898, 285, 7, 213, "Input"],
Cell[5150301, 80907, 5060, 112, 70, "Output"]
}, Open  ]],
Cell[5155376, 81022, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5155431, 81026, 256, 6, 213, "Input"],
Cell[5155690, 81034, 23407, 447, 70, "Output"]
}, Open  ]],
Cell[5179112, 81484, 72, 0, 188, "Text"]
}, Closed]],
Cell[CellGroupData[{
Cell[5179221, 81489, 39, 0, 197, "SubsubsectionIcon"],
Cell[5179263, 81491, 30, 0, 188, "Text"],
Cell[5179296, 81493, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5179348, 81497, 292, 6, 213, "Input"],
Cell[5179643, 81505, 6042, 114, 70, "Output"]
}, Open  ]],
Cell[5185700, 81622, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5185755, 81626, 295, 6, 213, "Input"],
Cell[5186053, 81634, 24534, 484, 70, "Output"]
}, Open  ]],
Cell[5210602, 82121, 73, 0, 188, "Text"]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[5210724, 82127, 33, 0, 32, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[5210782, 82131, 38, 0, 197, "SubsubsectionIcon"],
Cell[5210823, 82133, 62, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5210910, 82137, 98, 2, 213, "Input"],
Cell[5211011, 82141, 1414, 40, 70, "Output"]
}, Open  ]],
Cell[5212440, 82184, 50, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5212515, 82188, 413, 12, 213, "Input"],
Cell[5212931, 82202, 2430, 76, 70, "Output"]
}, Open  ]],
Cell[5215376, 82281, 183, 5, 213, "Input"],
Cell[5215562, 82288, 437, 12, 233, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[5216036, 82305, 38, 0, 197, "SubsubsectionIcon"],
Cell[5216077, 82307, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5216129, 82311, 253, 6, 213, "Input"],
Cell[5216385, 82319, 5003, 112, 70, "Output"]
}, Open  ]],
Cell[5221403, 82434, 38, 0, 188, "Text"],
Cell[5221444, 82436, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5221499, 82440, 256, 6, 213, "Input"],
Cell[5221758, 82448, 17003, 341, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5238810, 82795, 38, 0, 197, "SubsubsectionIcon"],
Cell[5238851, 82797, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5238903, 82801, 285, 7, 213, "Input"],
Cell[5239191, 82810, 5066, 112, 70, "Output"]
}, Open  ]],
Cell[5244272, 82925, 38, 0, 188, "Text"],
Cell[5244313, 82927, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5244368, 82931, 256, 6, 213, "Input"],
Cell[5244627, 82939, 23865, 454, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5268541, 83399, 39, 0, 197, "SubsubsectionIcon"],
Cell[5268583, 83401, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5268635, 83405, 292, 6, 213, "Input"],
Cell[5268930, 83413, 6065, 114, 70, "Output"]
}, Open  ]],
Cell[5275010, 83530, 38, 0, 188, "Text"],
Cell[5275051, 83532, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5275106, 83536, 295, 6, 213, "Input"],
Cell[5275404, 83544, 24774, 488, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[5300239, 84039, 35, 0, 32, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[5300299, 84043, 38, 0, 28, "SubsubsectionIcon"],
Cell[5300340, 84045, 62, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5300427, 84049, 100, 2, 213, "Input"],
Cell[5300530, 84053, 1388, 40, 70, "Output"]
}, Open  ]],
Cell[5301933, 84096, 50, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5302008, 84100, 415, 12, 213, "Input"],
Cell[5302426, 84114, 2408, 75, 70, "Output"]
}, Open  ]],
Cell[5304849, 84192, 183, 5, 213, "Input"],
Cell[5305035, 84199, 439, 12, 233, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[5305511, 84216, 38, 0, 22, "SubsubsectionIcon"],
Cell[5305552, 84218, 41, 0, 188, "Text"],
Cell[5305596, 84220, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5305648, 84224, 253, 6, 213, "Input"],
Cell[5305904, 84232, 4978, 112, 70, "Output"]
}, Open  ]],
Cell[5310897, 84347, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5310952, 84351, 256, 6, 213, "Input"],
Cell[5311211, 84359, 19100, 376, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5330360, 84741, 38, 0, 22, "SubsubsectionIcon"],
Cell[5330401, 84743, 40, 0, 188, "Text"],
Cell[5330444, 84745, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5330496, 84749, 285, 7, 213, "Input"],
Cell[5330784, 84758, 5060, 112, 70, "Output"]
}, Open  ]],
Cell[5335859, 84873, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5335914, 84877, 256, 6, 213, "Input"],
Cell[5336173, 84885, 24778, 469, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5361000, 85360, 39, 0, 22, "SubsubsectionIcon"],
Cell[5361042, 85362, 30, 0, 188, "Text"],
Cell[5361075, 85364, 42, 0, 188, "Text"],
Cell[5361120, 85366, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5361172, 85370, 292, 6, 213, "Input"],
Cell[5361467, 85378, 6038, 114, 70, "Output"]
}, Open  ]],
Cell[5367520, 85495, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5367575, 85499, 295, 6, 213, "Input"],
Cell[5367873, 85507, 24877, 489, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]],
Cell[CellGroupData[{
Cell[5392823, 86004, 50, 0, 78, "Section"],
Cell[CellGroupData[{
Cell[5392898, 86008, 33, 0, 46, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[5392956, 86012, 34, 0, 197, "SubsubsectionIcon"],
Cell[5392993, 86014, 85213, 1055, 2426, "Text"],
Cell[5478209, 87071, 73, 1, 188, "Text"],
Cell[CellGroupData[{
Cell[5478307, 87076, 98, 2, 213, "Input"],
Cell[5478408, 87080, 1255, 35, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5479700, 87120, 412, 12, 213, "Input"],
Cell[5480115, 87134, 1898, 58, 70, "Output"]
}, Open  ]],
Cell[5482028, 87195, 43, 0, 188, "Text"],
Cell[5482074, 87197, 223, 7, 213, "Input"],
Cell[5482300, 87206, 183, 5, 213, "Input"],
Cell[5482486, 87213, 424, 11, 213, "Input"]
}, Closed]],
Cell[CellGroupData[{
Cell[5482947, 87229, 38, 0, 197, "SubsubsectionIcon"],
Cell[5482988, 87231, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5483040, 87235, 253, 6, 213, "Input"],
Cell[5483296, 87243, 4430, 103, 70, "Output"]
}, Open  ]],
Cell[5487741, 87349, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5487796, 87353, 256, 6, 213, "Input"],
Cell[5488055, 87361, 26582, 499, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5514686, 87866, 38, 0, 197, "SubsubsectionIcon"],
Cell[5514727, 87868, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5514779, 87872, 285, 7, 213, "Input"],
Cell[5515067, 87881, 3744, 93, 70, "Output"]
}, Open  ]],
Cell[5518826, 87977, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5518881, 87981, 256, 6, 213, "Input"],
Cell[5519140, 87989, 28371, 528, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5547560, 88523, 39, 0, 197, "SubsubsectionIcon"],
Cell[5547602, 88525, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5547654, 88529, 292, 6, 213, "Input"],
Cell[5547949, 88537, 5312, 105, 70, "Output"]
}, Open  ]],
Cell[5553276, 88645, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5553331, 88649, 295, 6, 213, "Input"],
Cell[5553629, 88657, 39145, 723, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[5592835, 89387, 30, 0, 32, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[5592890, 89391, 34, 0, 197, "SubsubsectionIcon"],
Cell[5592927, 89393, 172, 3, 188, "Text"],
Cell[5593102, 89398, 7373, 123, 6750, "Graphics"],
Cell[CellGroupData[{
Cell[5600500, 89525, 95, 2, 213, "Input"],
Cell[5600598, 89529, 1350, 36, 70, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[5601985, 89570, 410, 12, 213, "Input"],
Cell[5602398, 89584, 2151, 68, 70, "Output"]
}, Open  ]],
Cell[5604564, 89655, 147, 4, 213, "Input"],
Cell[5604714, 89661, 183, 5, 213, "Input"],
Cell[5604900, 89668, 479, 13, 213, "Input"],
Cell[5605382, 89683, 320, 12, 356, "MathCaption"]
}, Closed]],
Cell[CellGroupData[{
Cell[5605739, 89700, 38, 0, 197, "SubsubsectionIcon"],
Cell[5605780, 89702, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5605832, 89706, 253, 6, 213, "Input"],
Cell[5606088, 89714, 5028, 112, 70, "Output"]
}, Open  ]],
Cell[5611131, 89829, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5611186, 89833, 256, 6, 213, "Input"],
Cell[5611445, 89841, 16278, 329, 70, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5627772, 90176, 38, 0, 197, "SubsubsectionIcon"],
Cell[5627813, 90178, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5627865, 90182, 285, 7, 213, "Input"],
Cell[5628153, 90191, 5016, 112, 70, "Output"]
}, Open  ]],
Cell[5633184, 90306, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5633239, 90310, 256, 6, 213, "Input"],
Cell[5633498, 90318, 21056, 408, 70, "Output"],
Cell[5654557, 90728, 208, 7, 210, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[5654814, 90741, 39, 0, 197, "SubsubsectionIcon"],
Cell[5654856, 90743, 27, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5654908, 90747, 292, 6, 213, "Input"],
Cell[5655203, 90755, 6040, 114, 70, "Output"]
}, Open  ]],
Cell[5661258, 90872, 30, 0, 188, "Text"],
Cell[CellGroupData[{
Cell[5661313, 90876, 295, 6, 213, "Input"],
Cell[5661611, 90884, 24925, 490, 70, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
