(* Content-type: application/mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 6.0' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       145,          7]
NotebookDataLength[    288434,       7375]
NotebookOptionsPosition[    275440,       6989]
NotebookOutlinePosition[    277390,       7052]
CellTagsIndexPosition[    277347,       7049]
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell["\<\

OPTIMAL DESIGN of EXPERIMENT (ODE)\
\>", "Chapter",
 CellChangeTimes->{{3.5920609279214954`*^9, 3.592060935017063*^9}, {
  3.592061512286994*^9, 3.5920615179912004`*^9}}],

Cell[TextData[{
 StyleBox["Author",
  FontWeight->"Bold"],
 ": Guillermo Sanchez:  ",
 ButtonBox[" http://diarium.usal.es/guillermo",
  BaseStyle->"Hyperlink",
  ButtonData->{" http://diarium.usal.es/guillermo", None}]
}], "Text",
 CellChangeTimes->{{3.3992809464453416`*^9, 3.3992809874687996`*^9}, {
  3.5920607540325823`*^9, 3.5920607970410223`*^9}}],

Cell["Last updated:  \t 2015-11-10", "Commentary",
 CellChangeTimes->{{3.39928025384801*^9, 3.399280259603493*^9}, {
  3.4228525171714554`*^9, 3.4228525382666454`*^9}, {3.422936332120079*^9, 
  3.422936340401223*^9}, {3.442218589593443*^9, 3.4422185944372244`*^9}, {
  3.479816247027495*^9, 3.4798162579804096`*^9}, {3.541915873948969*^9, 
  3.5419158891680107`*^9}, {3.592060800832576*^9, 3.5920608078831396`*^9}, {
  3.643616675381913*^9, 3.643616687522586*^9}, {3.65623571953561*^9, 
  3.65623572620757*^9}}],

Cell[CellGroupData[{

Cell[BoxData["$Version"], "Input",
 CellLabel->"In[1]:="],

Cell[BoxData["\<\"10.2.0 for Microsoft Windows (64-bit) (July 28, \
2015)\"\>"], "Output",
 CellChangeTimes->{
  3.3992752647824697`*^9, 3.422852547121887*^9, 3.4422186266093054`*^9, 
   3.4798162427619514`*^9, 3.479969368478038*^9, 3.5419158636362705`*^9, 
   3.541920101262663*^9, 3.592060814727437*^9, 3.6436166928350353`*^9, {
   3.6562357299575386`*^9, 3.6562357399263306`*^9}},
 CellLabel->"Out[1]="]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\

ODE TO STABLISH  A BIOASSAY PROGRAM FOR PARAMETER ESTIMATIONS\
\>", "Section",
 CellChangeTimes->{{3.5920609391761456`*^9, 3.5920609523196974`*^9}}],

Cell[TextData[{
 "Bioassays can be used to estimate the initial intake I for the case of an \
acute intake exposure for an individual worker.  To evaluate the effective \
dose, apart from I, we need to know other parameters such as Activity Median \
Aerodynamic Diameter (AMAD) or the fraction absorption (f1) in the blood from \
the GI tract, but in an accident situation these parameters are often \
unknown.  The bioassay measurement values can be used to estimate by fitting \
the parameters unknown. In this paper optimal designs for the estimation of \
the unknown parameters are developed. The goodness of the design will depend \
on the number of samples and the measurement accuracy. The method described \
applies D-optimality that maximizes the determinant of the Fisher information \
matrix to find the best moments where the bioassay measurements should be \
taken. It requires obtaining the analytical solution of the biokinetic model \
as a function of the parameters to be fitted. The method has been implemented \
as a ",
 StyleBox["Mathematica",
  FontSlant->"Italic"],
 " package called Optdesign as part of the BIOKMOD tool"
}], "Commentary"],

Cell["This section  be considered an addendum of the paper:  ", "Text",
 CellChangeTimes->{{3.592060838038052*^9, 3.5920608449711065`*^9}, {
  3.59206096135667*^9, 3.5920609731301117`*^9}}],

Cell["\<\
G.S\[AAcute]nchez; J.M.Rodr\[IAcute]guez-D\[IAcute]az.Optimal design and \
mathematical model applied to establish bioassay programs\
\[CloseCurlyDoubleQuote]:Radiation Protection \
Dosimetry.doi:10.1093/rpd/ncl499.2007. ISSN/ISBN:ISSN 1742-3406\
\>", "Reference"],

Cell[CellGroupData[{

Cell["Inicialization", "SubsectionIcon"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Needs", "[", "\"\<Biokmod`Biokdata`\>\"", "]"}]], "Input",
 CellLabel->"In[2]:="],

Cell[BoxData["\<\"Resptract 1.2  2005-05-16\"\>"], "Print",
 CellChangeTimes->{3.656235755129511*^9},
 CellLabel->"During evaluation of In[2]:="],

Cell[BoxData["\<\"SysModel, version 1.5.1   2013-11-12\"\>"], "Print",
 CellChangeTimes->{3.656235755129511*^9},
 CellLabel->"During evaluation of In[2]:="],

Cell[BoxData["\<\"Humorap 3.7 2015-06-15\"\>"], "Print",
 CellChangeTimes->{3.6562357551607714`*^9},
 CellLabel->"During evaluation of In[2]:="],

Cell[BoxData["\<\"Biokdata 1.2.2 2004-09-3\"\>"], "Print",
 CellChangeTimes->{3.6562357552076473`*^9},
 CellLabel->"During evaluation of In[2]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Biokmod`Optdesign`\>\"", "]"}], " "}]], "Input",
 CellLabel->"In[3]:="],

Cell[BoxData["\<\"Optdesign, 1.0   2007-04-09\"\>"], "Print",
 CellChangeTimes->{3.3990227596661005`*^9, 3.399022970101532*^9, 
  3.399024179679263*^9, 3.479969370684038*^9, 3.5419157952755833`*^9, 
  3.5419201029189453`*^9, 3.592060818183964*^9, 3.643616692960037*^9, 
  3.656235755270136*^9},
 CellLabel->"During evaluation of In[3]:="]
}, Open  ]],

Cell[TextData[{
 "Optdegn include the function ",
 StyleBox["Optdes", "Input"]
}], "Text"],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{
   RowBox[{"Optdes", "[", " ", 
    RowBox[{
     RowBox[{"R", "[", 
      RowBox[{"t", ",", 
       SubscriptBox["\[Beta]", "1"], ",", "...", ",", 
       SubscriptBox["\[Beta]", "p"]}], "]"}], ",", " ", "t", ",", " ", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["\[Beta]", "1"], ",", 
         SubscriptBox["\[Beta]", "10"]}], "}"}], ",", "...", ",", 
       RowBox[{"{", 
        RowBox[{
         SubscriptBox["\[Beta]", "p"], ",", 
         SubscriptBox["\[Beta]", "p0"]}], "}"}]}], "}"}], ",", " ", 
     SubscriptBox["t", "0"], ",", " ", "\[Rho]", ",", " ", "\[Sigma]", ",", 
     " ", "n", ",", " ", "opts"}], "]"}], " "}]]],
 "being  ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Beta]", "1"], ",", "...", ",", 
   SubscriptBox["\[Beta]", "p"]}]]],
 " the unknown parameters and   ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["\[Beta]", "10"], ",", "...", ",", 
   SubscriptBox["\[Beta]", 
    RowBox[{"p0", " "}]]}]]],
 "their the initial values,  ",
 Cell[BoxData[
  SubscriptBox["t", "0"]]],
 " is the point were is takes the first measured, \[Rho]",
 StyleBox[" (relationship between samples that decays exponential), ",
  FontSlant->"Italic"],
 StyleBox["usually will be used \[Rho]=1 (it is assumed that there not \
correlation between samples will be written \"NoCorrelation\");",
  FontVariations->{"CompatibilityType"->0}],
 Cell[BoxData[
  RowBox[{" ", "\[Sigma]"}]]],
 " is the standard deviation of the measures, n is the number of the point \
(additional at  ",
 Cell[BoxData[
  SubscriptBox["t", "0"]]],
 ") where we want to take measured; ",
 StyleBox[" ",
  FontWeight->"Bold"],
 StyleBox["opts",
  FontSlant->"Italic"],
 " is a option to close the maximization method (The are the same that used \
by NMaximize).The function will give the values for {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 ",..,  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ", ...  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "n"], TraditionalForm]]],
 "}. "
}], "DefinitionBox"]
}, Open  ]],

Cell[CellGroupData[{

Cell["D-optimal designs ", "SubsectionIcon"],

Cell[TextData[{
 "Be the function ",
 Cell[BoxData[
  FormBox[
   RowBox[{"r", "(", 
    RowBox[{"t", ",", " ", "\[Beta]"}], ")"}], TraditionalForm]]],
 "   where , where",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"\[Beta]", " ", "=", 
     RowBox[{"{", 
      RowBox[{
       SubscriptBox["\[Beta]", "1"], ",", "...", ",", 
       SubscriptBox["\[Beta]", "p"]}], " ", "}"}], " "}]}], TraditionalForm]]],
 " are parameters unknowns  to be fitted using experimental data . We wish \
chose the best moments {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 ",..,  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ", ...  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "n"], TraditionalForm]]],
 "} to take the experimental data. It will be assumed that all measured have \
more or less the same uncertainties, that is  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["\[Sigma]", "2"], "\[TildeEqual]", 
    SubsuperscriptBox["\[Sigma]", "i", "2"]}], TraditionalForm]]],
 ". ",
 StyleBox["The Fisher information matrix for a specific design ",
  FontVariations->{"CompatibilityType"->0}],
 "{",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "1"], TraditionalForm]]],
 ",..,  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ", ...  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "n"], TraditionalForm]]],
 "}",
 StyleBox["= (",
  FontVariations->{"CompatibilityType"->0}],
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 StyleBox[" is the time when the ",
  FontVariations->{"CompatibilityType"->0}],
 Cell[BoxData[
  FormBox["i", TraditionalForm]]],
 StyleBox["-th sample should be taken) will be used to compute the o",
  FontVariations->{"CompatibilityType"->0}],
 "ptimal design",
 StyleBox[". A ",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["D",
  FontSlant->"Italic"],
 "-optimal design will be a design that leads the determinant of the \
information matrix to a maximum. "
}], "Text"],

Cell[TextData[{
 "1.- It is defined a model  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"r", "(", 
     RowBox[{"t", ",", " ", "\[Beta]"}], ")"}], " "}], TraditionalForm]]],
 "where the unkown parameters are ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Beta]", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"inp", ",", "p"}], "}"}]}], TraditionalForm]]],
 "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"r", " ", "=", " ", 
  RowBox[{"inp", " ", 
   RowBox[{"(", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", " ", "2.0"}], " ", "t"}], "-", " ", 
       RowBox[{"0.09", " ", "p"}]}]], " ", "+", " ", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{
        RowBox[{"-", " ", "0.001"}], " ", "t"}], "-", " ", 
       RowBox[{"0.2", "p"}]}]]}], ")"}]}]}]], "Input",
 CellLabel->"In[4]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "0.09`"}], " ", "p"}], "-", 
      RowBox[{"2.`", " ", "t"}]}]], "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "0.2`"}], " ", "p"}], "-", 
      RowBox[{"0.001`", " ", "t"}]}]]}], ")"}], " ", "inp"}]], "Output",
 CellChangeTimes->{3.399022759681734*^9, 3.399024179741763*^9, 
  3.4799693707220383`*^9, 3.5419201029501953`*^9, 3.5920608184077315`*^9, 
  3.6436166929756603`*^9, 3.6562357552857604`*^9},
 CellLabel->"Out[4]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Beta]", "=", 
   RowBox[{"{", 
    RowBox[{"inp", ",", "p"}], "}"}]}], ";"}]], "Input",
 CellLabel->"In[5]:="],

Cell[TextData[{
 "2.-Now it is computed  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Del]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"r", "(", "t", ")"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"inp", ",", " ", "p"}], "}"}]}], ")"}]}], TraditionalForm]]],
 " = {",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"dr", "(", "t", ")"}], "dinp"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"dr", "(", "t", ")"}], "dp"], TraditionalForm]]],
 "},"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{"grad", "[", 
   RowBox[{"s_", ",", "vars_List"}], "]"}], " ", ":=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{"Function", "[", 
     RowBox[{
      RowBox[{"{", "v", "}"}], ",", " ", 
      RowBox[{"D", "[", 
       RowBox[{"s", ",", "v"}], "]"}]}], "]"}], ",", " ", "vars"}], 
   "]"}]}]], "Input",
 CellLabel->"In[6]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "[", "t_", "]"}], "=", 
  RowBox[{"grad", "[", 
   RowBox[{"r", ",", "\[Beta]"}], "]"}]}]], "Input",
 CellLabel->"In[7]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "0.09`"}], " ", "p"}], "-", 
      RowBox[{"2.`", " ", "t"}]}]], "+", 
    SuperscriptBox["\[ExponentialE]", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "0.2`"}], " ", "p"}], "-", 
      RowBox[{"0.001`", " ", "t"}]}]]}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{
       RowBox[{"-", "0.09`"}], " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.09`"}], " ", "p"}], "-", 
         RowBox[{"2.`", " ", "t"}]}]]}], "-", 
      RowBox[{"0.2`", " ", 
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{
          RowBox[{"-", "0.2`"}], " ", "p"}], "-", 
         RowBox[{"0.001`", " ", "t"}]}]]}]}], ")"}], " ", "inp"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.3990227597442713`*^9, 3.399024179835514*^9, 
  3.4799693707820377`*^9, 3.5419201029970713`*^9, 3.5920608187302575`*^9, 
  3.6436166930225353`*^9, 3.656235755301385*^9},
 CellLabel->"Out[7]="]
}, Open  ]],

Cell["\<\
3.- Here is defined the number of points to be used in the optimal design. We \
suppose a 2-points design. The first is defined by the user \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"n", " ", "=", " ", "1"}], ";", 
  RowBox[{"tt", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["t", "i"], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "0", ",", "n"}], "}"}]}], "]"}]}]}]], "Input",
 CellLabel->"In[8]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["t", "0"], ",", 
   SubscriptBox["t", "1"]}], "}"}]], "Output",
 CellChangeTimes->{3.3990227597755394`*^9, 3.399024179866764*^9, 
  3.479969370819038*^9, 3.541920103028322*^9, 3.5920608189552755`*^9, 
  3.6436166930381856`*^9, 3.656235755301385*^9},
 CellLabel->"Out[8]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["For computational purpose we have found more appropriate to use \
the distance ",
  FontVariations->{"CompatibilityType"->0}],
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "i"], TraditionalForm]]],
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->0}],
 "= ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["t", "i"], "-", 
    SubscriptBox["t", 
     RowBox[{"i", "-", "1"}]]}], TraditionalForm]]],
 ", ",
 StyleBox["instead of  ",
  FontVariations->{"CompatibilityType"->0}],
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ", then ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["\[Sum]", "i"], 
    SubscriptBox["d", "i"]}], TraditionalForm]]],
 " being ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["d", "0"], " ", "=", 
    SubscriptBox["t", "0"], " "}], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"dd", "=", 
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["d", "i"], ",", 
     RowBox[{"{", 
      RowBox[{"i", ",", "n"}], "}"}]}], "]"}]}], ";", " ", 
  RowBox[{"ddd", " ", "=", " ", 
   RowBox[{"FoldList", "[", 
    RowBox[{"Plus", ",", " ", 
     RowBox[{"Subscript", "[", 
      RowBox[{"d", ",", " ", "0"}], "]"}], ",", " ", "dd"}], 
    "]"}]}]}]], "Input",
 CellLabel->"In[9]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   SubscriptBox["d", "0"], ",", 
   RowBox[{
    SubscriptBox["d", "0"], "+", 
    SubscriptBox["d", "1"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.399022759806808*^9, 3.399024179898014*^9, 
  3.4799693708540382`*^9, 3.5419201030595727`*^9, 3.592060819186544*^9, 
  3.643616693069411*^9, 3.656235755301385*^9},
 CellLabel->"Out[9]="]
}, Open  ]],

Cell[TextData[{
 "5.- It is evaluated \[Del](r(t), \[Beta]) at points ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 ":{",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 ",..., ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "n"], TraditionalForm]]],
 "}, obtaining ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      FormBox[
       SubscriptBox["X", "1"],
       TraditionalForm], ",", "...", ",", " ", 
      FormBox[
       SubscriptBox["X", "p"],
       TraditionalForm]}], "}"}], " "}], TraditionalForm]]],
 "with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["X", "1"], TraditionalForm]]],
 " = {",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"dr", "(", 
      SubscriptBox["t", "0"], ")"}], 
     SubscriptBox["d\[Beta]", "1"]], ",", " ", "...", ",", 
    FractionBox[
     RowBox[{"dr", "(", 
      SubscriptBox["t", "n"], ")"}], 
     SubscriptBox["d\[Beta]", "1"]], " "}], TraditionalForm]]],
 "}, ..., ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["X", "p"], TraditionalForm]]],
 " = {",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"dr", "(", 
      SubscriptBox["t", "0"], ")"}], 
     SubscriptBox["d\[Beta]", "p"]], ",", " ", "...", ",", 
    FractionBox[
     RowBox[{"dr", "(", 
      SubscriptBox["t", "n"], ")"}], 
     SubscriptBox["d\[Beta]", "p"]], " "}], TraditionalForm]]],
 "}  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"X", " ", "=", 
  RowBox[{"g", "[", "ddd", "]"}]}]], "Input",
 CellLabel->"In[10]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "0.09`"}], " ", "p"}], "-", 
        RowBox[{"2.`", " ", 
         SubscriptBox["d", "0"]}]}]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "0.2`"}], " ", "p"}], "-", 
        RowBox[{"0.001`", " ", 
         SubscriptBox["d", "0"]}]}]]}], ",", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "0.09`"}], " ", "p"}], "-", 
        RowBox[{"2.`", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["d", "0"], "+", 
           SubscriptBox["d", "1"]}], ")"}]}]}]], "+", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "0.2`"}], " ", "p"}], "-", 
        RowBox[{"0.001`", " ", 
         RowBox[{"(", 
          RowBox[{
           SubscriptBox["d", "0"], "+", 
           SubscriptBox["d", "1"]}], ")"}]}]}]]}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "0.09`"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "0.09`"}], " ", "p"}], "-", 
           RowBox[{"2.`", " ", 
            SubscriptBox["d", "0"]}]}]]}], "-", 
        RowBox[{"0.2`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "0.2`"}], " ", "p"}], "-", 
           RowBox[{"0.001`", " ", 
            SubscriptBox["d", "0"]}]}]]}]}], ")"}], " ", "inp"}], ",", 
     RowBox[{
      RowBox[{"(", 
       RowBox[{
        RowBox[{
         RowBox[{"-", "0.09`"}], " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "0.09`"}], " ", "p"}], "-", 
           RowBox[{"2.`", " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["d", "0"], "+", 
              SubscriptBox["d", "1"]}], ")"}]}]}]]}], "-", 
        RowBox[{"0.2`", " ", 
         SuperscriptBox["\[ExponentialE]", 
          RowBox[{
           RowBox[{
            RowBox[{"-", "0.2`"}], " ", "p"}], "-", 
           RowBox[{"0.001`", " ", 
            RowBox[{"(", 
             RowBox[{
              SubscriptBox["d", "0"], "+", 
              SubscriptBox["d", "1"]}], ")"}]}]}]]}]}], ")"}], " ", "inp"}]}],
     "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.399022759822442*^9, 3.399024179929264*^9, 
  3.479969370889038*^9, 3.541920103090823*^9, 3.5920608194415646`*^9, 
  3.643616693085036*^9, 3.6562357553170104`*^9},
 CellLabel->"Out[10]="]
}, Open  ]],

Cell[TextData[{
 StyleBox["\[CapitalATilde]",
  FontFamily->"Times Greek",
  FontSize->9,
  FontSlant->"Italic"],
 StyleBox[" = (",
  FontSize->9],
 StyleBox["l",
  FontSize->9,
  FontSlant->"Italic"],
 StyleBox["ij",
  FontSize->9,
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox[") with ",
  FontSize->9],
 StyleBox["l",
  FontSize->9,
  FontSlant->"Italic"],
 StyleBox["ij",
  FontSize->9,
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox[" =exp(-",
  FontSize->9],
 StyleBox["\[NTilde]",
  FontFamily->"Times Greek",
  FontSize->9,
  FontSlant->"Italic"],
 StyleBox["|",
  FontSize->9],
 StyleBox["t",
  FontSize->9,
  FontSlant->"Italic"],
 StyleBox["j",
  FontSize->9,
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox["-",
  FontSize->9],
 StyleBox["t",
  FontSize->9,
  FontSlant->"Italic"],
 StyleBox["j",
  FontSize->9,
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox["|) , meaning that the relationship between samples decays \
exponentially with increasing time-distance between them",
  FontSize->9]
}], "Text"],

Cell[TextData[{
 "6.- A typical election for compute the covariance matrix is assumed that",
 "  that the relationship between samples decays exponentially with \
increasing time-distance between them, that is ",
 " ",
 Cell[BoxData[
  FormBox["\[CapitalGamma]", TraditionalForm]]],
 " = {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "ij"], TraditionalForm]]],
 "} with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "ij"], TraditionalForm]]],
 "= exp {\[Rho]|",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["t", "j"], " ", "-"}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "j"], TraditionalForm]]],
 "|}  \n\n ",
 Cell[BoxData[
  FormBox["\[CapitalGamma]", TraditionalForm]]],
 " where "
}], "Text"],

Cell[BoxData[
 RowBox[{"\[CapitalGamma]", "=", 
  RowBox[{"(", GridBox[{
     {"1", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[Rho]"}], "|", 
        RowBox[{
         SubscriptBox["t", "0"], "-", 
         SubscriptBox["t", "1"]}], "|"}]]},
     {
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[Rho]"}], " ", "|", 
        RowBox[{
         SubscriptBox["t", "0"], "-", 
         SubscriptBox["t", "1"]}], "|"}]], "1"}
    }], ")"}]}]], "Text"],

Cell["that is  ", "Text"],

Cell[BoxData[
 RowBox[{
  SubscriptBox["a", 
   RowBox[{"ij", " "}]], "=", " ", 
  RowBox[{
   RowBox[{"1", " ", "if", "  ", "i"}], " ", "=", " ", 
   RowBox[{
    RowBox[{"j", " ", "and", "  ", 
     SubscriptBox["a", 
      RowBox[{"ij", " "}]]}], " ", "=", " ", 
    RowBox[{
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{"-", "\[Rho]"}], "|", 
        RowBox[{
         SubscriptBox["t", "i"], "-", " ", 
         SubscriptBox["t", "j"]}], "|"}]], " ", "if", "  ", "i"}], 
     "\[NotEqual]", "j", " "}]}]}]}]], "Text"],

Cell[TextData[{
 "replacing (for computational purpose)  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 " for  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "i"], TraditionalForm]]],
 " "
}], "Text"],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"For", " ", "i"}], "<", "j"}], " ", "|", 
   RowBox[{
    SubscriptBox["t", "i"], "-", " ", 
    SubscriptBox["t", "j"]}], "|"}], "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["d", 
      RowBox[{"i", "+", "1"}]], " ", "+", " ", 
     SubscriptBox["d", 
      RowBox[{"i", "+", "2"}]], " ", "+"}], "..."}], "+", " ", 
   SubscriptBox["d", "j"]}]}], "\[IndentingNewLine]", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{"For", "  ", "i"}], ">", "j"}], " ", "|", 
   RowBox[{
    SubscriptBox["t", "i"], "-", " ", 
    SubscriptBox["t", "j"]}], "|"}], "=", " ", 
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["d", 
      RowBox[{"j", "+", "1"}]], " ", "+", " ", 
     SubscriptBox["d", 
      RowBox[{"j", "+", "2"}]], " ", "+"}], "..."}], "+", " ", 
   SubscriptBox["d", "i"]}]}]}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"ff", "[", 
    RowBox[{"i_", ",", "j_"}], "]"}], ":=", 
   RowBox[{"Which", "[", 
    RowBox[{
     RowBox[{"i", "\[Equal]", "j"}], ",", "1", ",", 
     RowBox[{"i", "<", "j"}], ",", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[Rho]"}], " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "i"}], 
         RowBox[{"j", "-", "1"}]], 
        SubscriptBox["d", "k"]}]}]], ",", 
     RowBox[{"i", ">", "j"}], ",", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[Rho]"}], " ", 
       RowBox[{
        UnderoverscriptBox["\[Sum]", 
         RowBox[{"k", "=", "j"}], 
         RowBox[{"i", "-", "1"}]], 
        SubscriptBox["d", "k"]}]}]]}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[11]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"\[CapitalGamma]", "=", 
  RowBox[{"Array", "[", 
   RowBox[{"ff", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"n", "+", "1"}], ",", 
      RowBox[{"n", "+", "1"}]}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[12]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[Rho]"}], " ", 
       SubscriptBox["d", "1"]}]]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     SuperscriptBox["\[ExponentialE]", 
      RowBox[{
       RowBox[{"-", "\[Rho]"}], " ", 
       SubscriptBox["d", "1"]}]], ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.3990227598693447`*^9, 3.399024179960515*^9, 
  3.479969370936038*^9, 3.541920103137699*^9, 3.592060819837846*^9, 
  3.643616693131911*^9, 3.656235755332636*^9},
 CellLabel->"Out[12]="]
}, Open  ]],

Cell[TextData[{
 "6.-  Now it is computed the convariance matrix \[CapitalSigma] = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Sigma]", "2"], TraditionalForm]]],
 "  ",
 Cell[BoxData[
  FormBox["\[CapitalGamma]", TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"\[CapitalSigma]", " ", "=", " ", 
    RowBox[{
     FormBox[
      SuperscriptBox["\[Sigma]", "2"],
      TraditionalForm], "*", "\[CapitalGamma]"}]}], ";"}]}]], "Input",
 CellLabel->"In[13]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"\[CapitalSigma]", "//", "MatrixForm"}]}]], "Input",
 CellLabel->"In[14]:="],

Cell[BoxData[
 TagBox[
  RowBox[{"(", "\[NoBreak]", GridBox[{
     {
      SuperscriptBox["\[Sigma]", "2"], 
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[Rho]"}], " ", 
         SubscriptBox["d", "1"]}]], " ", 
       SuperscriptBox["\[Sigma]", "2"]}]},
     {
      RowBox[{
       SuperscriptBox["\[ExponentialE]", 
        RowBox[{
         RowBox[{"-", "\[Rho]"}], " ", 
         SubscriptBox["d", "1"]}]], " ", 
       SuperscriptBox["\[Sigma]", "2"]}], 
      SuperscriptBox["\[Sigma]", "2"]}
    },
    GridBoxAlignment->{
     "Columns" -> {{Center}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
      "RowsIndexed" -> {}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[0.7]}, 
        Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}, "RowsIndexed" -> {}}], "\[NoBreak]", ")"}],
  Function[BoxForm`e$, 
   MatrixForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.3990227599006133`*^9, 3.39902418000739*^9, 
  3.479969370995038*^9, 3.5419201032627015`*^9, 3.5920608203153844`*^9, 
  3.6436166931631613`*^9, 3.656235755348261*^9},
 CellLabel->"Out[14]//MatrixForm="]
}, Open  ]],

Cell[TextData[{
 "We take \[Rho]=1. We will also  need give the initial values for the \
\[Beta] parameters and the standard deviation of the measures. The first \
measured should be take at ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 " > 0 as soon as possible. Here is taken  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 "= 0.5"
}], "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SubscriptBox["d", "0"], "=", 
   RowBox[{"t0", " ", "=", " ", "0.5"}]}], ";", " ", 
  RowBox[{"inp", " ", "=", " ", 
   RowBox[{"i0", " ", "=", " ", "100"}]}], ";", 
  RowBox[{"p", "=", "5"}], ";"}]], "Input",
 CellLabel->"In[15]:="],

Cell["7.- Then we can obtain the information matrix", "Text"],

Cell[TextData[{
 "M =  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["X", "T"], " ", 
    SuperscriptBox["\[CapitalSigma]", 
     RowBox[{"-", "1"}]], " ", "X", " "}], TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"m", " ", "=", 
    RowBox[{"X", " ", ".", " ", 
     RowBox[{"Inverse", "[", "\[CapitalSigma]", "]"}], ".", "  ", 
     RowBox[{"Transpose", "[", "X", "]"}]}]}], ";"}]}]], "Input",
 CellLabel->"In[16]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"\[Sigma]", " ", "=", " ", "2"}], ";", 
  RowBox[{"\[Rho]", "=", "1"}], ";"}]], "Input",
 CellLabel->"In[17]:="],

Cell["\<\
8.- A D-optimal design will be a design that leads the determinant of the \
information matrix det|M| to a maximum. It can be done as it follows\
\>", "Text"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"deter1", "[", "x_", "]"}], " ", ":=", " ", 
    RowBox[{"Det", "[", 
     RowBox[{"m", " ", "/.", " ", 
      RowBox[{"Thread", "[", 
       RowBox[{"dd", " ", "->", " ", "x"}], "]"}]}], "]"}]}], 
   ";"}]}]], "Input",
 CellLabel->"In[18]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", " ", 
  RowBox[{"Maximize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"deter1", "[", "dd", "]"}], ",", " ", 
      RowBox[{"Thread", "[", 
       RowBox[{"dd", " ", ">", " ", "1"}], "]"}]}], "}"}], ",", " ", "dd"}], 
   " ", "]"}]}]], "Input",
 CellLabel->"In[19]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.05581496056814773`", ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["d", "1"], "\[Rule]", "3.4573307238364683`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.3990227609950075`*^9, 3.3990241802105165`*^9, 
  3.479969371710038*^9, 3.541920104137718*^9, 3.5920608221680326`*^9, 
  3.6436166934287863`*^9, 3.656235755535761*^9},
 CellLabel->"Out[19]="]
}, Open  ]],

Cell["Finally", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ddd", "/.", 
  RowBox[{"sol", "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellLabel->"In[20]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.5`", ",", "3.9573307238364683`"}], "}"}]], "Output",
 CellChangeTimes->{3.3990227610731783`*^9, 3.3990241802417665`*^9, 
  3.479969371794038*^9, 3.5419201042002196`*^9, 3.5920608224318037`*^9, 
  3.6436166934444113`*^9, 3.656235755535761*^9},
 CellLabel->"Out[20]="]
}, Open  ]],

Cell["\<\
 Maximize try to find a global maximum using analytical method, in many case \
it will take a long time of computation. For this reason it can be convenient \
use  NMaximize. It can be made as follows\
\>", "Commentary"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{
    RowBox[{"deter", "[", 
     RowBox[{"x_", "?", 
      RowBox[{"(", 
       RowBox[{
        RowBox[{"VectorQ", "[", 
         RowBox[{"#", ",", "NumberQ"}], "]"}], "&"}], ")"}]}], "]"}], " ", ":=",
     " ", 
    RowBox[{"Det", "[", 
     RowBox[{"m", " ", "/.", " ", 
      RowBox[{"Thread", "[", 
       RowBox[{"dd", " ", "->", " ", "x"}], "]"}]}], "]"}]}], 
   ";"}]}]], "Input",
 CellLabel->"In[21]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"NMaximize", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"deter", "[", "dd", "]"}], ",", " ", 
      RowBox[{"Thread", "[", 
       RowBox[{"dd", " ", ">", " ", "1"}], "]"}]}], "}"}], ",", " ", "dd"}], 
   "]"}]}]], "Input",
 CellLabel->"In[22]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.05581496056814816`", ",", 
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["d", "1"], "\[Rule]", "3.457332299020126`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399022761307691*^9, 3.399024180429268*^9, 
  3.479969373194038*^9, 3.5419201051064873`*^9, 3.5920608244557157`*^9, 
  3.6436166938350363`*^9, 3.656235755926389*^9},
 CellLabel->"Out[22]="]
}, Open  ]],

Cell["\<\
It can be shown that the previous values it alredy a maximun \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"d", ",", 
       RowBox[{"Det", "[", 
        RowBox[{"m", "/.", "\[InvisibleSpace]", 
         RowBox[{"Thread", "[", 
          RowBox[{"dd", "\[Rule]", "d"}], "]"}]}], "]"}]}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"d", ",", "0.5`", ",", "10", ",", "0.02`"}], "}"}]}], "]"}], 
   ",", 
   RowBox[{"Joined", "\[Rule]", "True"}]}], "]"}]], "Input",
 CellLabel->"In[23]:="],

Cell[BoxData[
 GraphicsBox[{{}, {{}, {}, 
    {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.007333333333333334], 
     AbsoluteThickness[1.6], LineBox[CompressedData["
1:eJw92HlcTekfB/BKKu3d9v0umJihIYRR56MiEpWItKi0SKhEqURJC+332kKW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      "]]}}, {}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0.05417863573758073},
  DisplayFunction->Identity,
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{},
  PlotRange->{{0, 10.}, {0.05425655592980033, 0.055814959774192506`}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.399022762386451*^9, 3.3990241815230246`*^9, 
  3.4799693744790382`*^9, 3.54192010549712*^9, 3.592060826295863*^9, 
  3.6436166940694113`*^9, 3.6562357563014407`*^9},
 CellLabel->"Out[23]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{
  RowBox[{"Clear", "[", 
   RowBox[{
   "inp", ",", "t0", ",", " ", "p", ",", " ", "\[Sigma]", ",", 
    "\[CapitalSigma]", ",", "  ", "m", ",", " ", "deter", ",", " ", "bb", ",",
     " ", "dd", ",", " ", "ddd", ",", " ", "sol"}], "]"}], " "}]], "Input",
 CellLabel->"In[24]:="],

Cell[TextData[{
 "The same computation can be made directely using the package functions ",
 StyleBox["Optdes", "Input"]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Optdes", "[", "  ", 
  RowBox[{
   RowBox[{"inp", " ", 
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", " ", "2.0"}], " ", "t"}], "-", " ", 
        RowBox[{"0.09", " ", "p"}]}]], " ", "+", " ", 
      SuperscriptBox["\[ExponentialE]", 
       RowBox[{
        RowBox[{
         RowBox[{"-", " ", "0.001"}], " ", "t"}], "-", " ", 
        RowBox[{"0.2", "p"}]}]]}], ")"}]}], ",", " ", "t", ",", " ", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"inp", ",", "100"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"p", ",", " ", "5"}], "}"}]}], "}"}], " ", ",", "  ", "0.5", 
   ",", " ", "1", ",", " ", "2", ",", " ", "1"}], "]"}]], "Input",
 CellLabel->"In[25]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.055814960568147304`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["t", "0"], "\[Rule]", "0.5`"}], ",", 
     RowBox[{
      SubscriptBox["t", "1"], "\[Rule]", "3.957329271727824`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399022762620964*^9, 3.3990241818199015`*^9, 
  3.479969377351038*^9, 3.5419201062940097`*^9, 3.5920608280560036`*^9, 
  3.6436166944912877`*^9, 3.656235756738891*^9},
 CellLabel->"Out[25]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
 "Solving ICRP model as function of AMAD ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 " or a rate transfer factor ",
 Cell[BoxData[
  FormBox["k", TraditionalForm]]],
 "."
}], "SubsectionIcon"],

Cell[TextData[{
 StyleBox["In occasions after an accidental intake ",
  FontVariations->{"CompatibilityType"->0}],
 Cell[BoxData[
  FormBox["I", TraditionalForm]],
  FontVariations->{"CompatibilityType"->0}],
 StyleBox[" of radioactive particles we need to estimate some parameters of \
the particles intaken (AMAD, ",
  FontVariations->{"CompatibilityType"->0}],
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 StyleBox[", etc). It can be made taken bioassay measures. ",
  FontVariations->{"CompatibilityType"->0}],
 StyleBox["Optdesign",
  FontWeight->"Bold"],
 " can be applied to establish the best moments where the bioassay measures \
should be taken. We will need known  the ",
 StyleBox["R",
  FontSlant->"Italic"],
 StyleBox["m",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 Cell[BoxData[
  FormBox["I", TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "1"], TraditionalForm]]],
 ",..., ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "p"], TraditionalForm]]],
 " , ",
 StyleBox["t",
  FontSlant->"Italic"],
 ")  = ",
 Cell[BoxData[
  FormBox["I", TraditionalForm]]],
 "  ",
 StyleBox["r",
  FontSlant->"Italic"],
 StyleBox["m",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 Cell[BoxData[
  FormBox["I", TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "1"], TraditionalForm]]],
 ",..., ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "p"], TraditionalForm]]],
 " , ",
 StyleBox["t",
  FontSlant->"Italic"],
 ")  as function of the parameters unknown. In the practical situations the \
typical parameters unknown are ",
 Cell[BoxData[
  FormBox[
   RowBox[{"I", " "}], TraditionalForm]]],
 "and AMAD or ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 ". In this cases we will need find the analytical solutions of the ICRP \
models as function of this parameters."
}], "Text"],

Cell[TextData[{
 "The predicted value ",
 StyleBox["r",
  FontSlant->"Italic"],
 StyleBox["m",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["t",
  FontSlant->"Italic"],
 ")  of the retention function for a kind of bioassay ",
 Cell[BoxData[
  FormBox["m", TraditionalForm]]],
 " after an acute input ",
 StyleBox["I ",
  FontSlant->"Italic"],
 "= \[OpenCurlyDoubleQuote]1\[CloseCurlyDoubleQuote] at  ",
 StyleBox["t",
  FontSlant->"Italic"],
 " = 0 is obtained by the sum of the content of one or several compartments. \
It will also a sum of exponentials. It can be shown in the following examples "
}], "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 "ICRP model solution as function of ",
 "AMAD ",
 StyleBox["p",
  FontSlant->"Italic"],
 " "
}], "SubsubsectionIcon"],

Cell[TextData[{
 "To obtain the solution as function of AMAD ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 " we will use an approximation of the Initial Deposition Factor (IDF). The \
IDF",
 StyleBox["j",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ") may be either calculated following the procedure described in ICRP 66 \
(1994) or obtained from Annex F of ICRP 66 (1994). ICRP 66 already gives the \
procedure to obtain what we call the Initial Deposition Derivate Factor or ",
 StyleBox["IDDF",
  FontSlant->"Italic"],
 StyleBox["k",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 "). "
}], "MathCaption"],

Cell[TextData[StyleBox["Relation IDDF vs IDF  ",
 FontWeight->"Bold"]], "Text"],

Cell[TextData[{
 StyleBox["IDF",
  FontSlant->"Italic"],
 StyleBox["1",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")",
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox["=",
  FontSlant->"Italic"],
 StyleBox[" ",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "0.3 ",
 StyleBox["IDDF",
  FontSlant->"Italic"],
 StyleBox["AI",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ");\n",
 StyleBox["IDF",
  FontSlant->"Italic"],
 StyleBox["2",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox[" ",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")",
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "= 0.6 ",
 StyleBox["IDDF",
  FontSlant->"Italic"],
 StyleBox["AI",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")\n",
 StyleBox["IDF",
  FontSlant->"Italic"],
 StyleBox["3",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")",
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox[" ",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "= 0.1 ",
 StyleBox["IDDF",
  FontSlant->"Italic"],
 StyleBox["AI",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")\n",
 StyleBox["IDF",
  FontSlant->"Italic"],
 StyleBox["4 ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")",
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox["= ",
  FontSlant->"Italic"],
 "0.993 ",
 StyleBox["IDDF",
  FontSlant->"Italic"],
 StyleBox["bb(fast+sec)",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")",
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "- 0.007 ",
 StyleBox["IDDF",
  FontSlant->"Italic"],
 StyleBox["bb(slow)",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")\n",
 StyleBox["IDF",
  FontSlant->"Italic"],
 StyleBox["5 ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")",
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox["= IDDF",
  FontSlant->"Italic"],
 StyleBox["bb(slow)",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 " (",
 StyleBox["p",
  FontSlant->"Italic"],
 ")\n",
 StyleBox["IDF",
  FontSlant->"Italic"],
 StyleBox["6 ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")",
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox["=",
  FontSlant->"Italic"],
 " 0.007 ",
 StyleBox["IDDF",
  FontSlant->"Italic"],
 StyleBox["bb(fast+sec)",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")",
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "+ ",
 StyleBox["IDDF",
  FontSlant->"Italic"],
 StyleBox["bb(slow)",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")\n",
 StyleBox["IDF",
  FontSlant->"Italic"],
 StyleBox["7",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox[" ",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")",
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox["= ",
  FontSlant->"Italic"],
 "0.993 ",
 StyleBox["IDDF",
  FontSlant->"Italic"],
 StyleBox["BB(fast+sec)",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")",
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 " - 0.007 ",
 StyleBox["IDDF",
  FontSlant->"Italic"],
 StyleBox["BB(slow)",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")\n",
 StyleBox["IDF",
  FontSlant->"Italic"],
 StyleBox["8 ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")",
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox["= IDDF",
  FontSlant->"Italic"],
 StyleBox["BB(slow)",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")\n",
 StyleBox["IDF",
  FontSlant->"Italic"],
 StyleBox["9",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")",
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox[" ",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox["= ",
  FontSlant->"Italic"],
 "0.007 ",
 StyleBox["IDDF",
  FontSlant->"Italic"],
 StyleBox["BB(fast+sec)",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ") + ",
 StyleBox["IDDF",
  FontSlant->"Italic"],
 StyleBox["BB(slow)",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")\n",
 StyleBox["IDF",
  FontSlant->"Italic"],
 StyleBox["10 ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")",
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox["= ",
  FontSlant->"Italic"],
 "0.9995",
 StyleBox[" IDDF",
  FontSlant->"Italic"],
 StyleBox["ET2",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")\nET",
 StyleBox["seq",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox["IDF",
  FontSlant->"Italic"],
 StyleBox["11 ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")",
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox["= ",
  FontSlant->"Italic"],
 "0.0005",
 StyleBox[" IDDF",
  FontSlant->"Italic"],
 StyleBox["ET2",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")\n",
 StyleBox["IDF",
  FontSlant->"Italic"],
 StyleBox["12",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")",
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 StyleBox["= IDDF",
  FontSlant->"Italic"],
 StyleBox["ET1",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["p",
  FontSlant->"Italic"],
 ")\n"
}], "DefinitionBox"],

Cell[TextData[{
 "We have found that the ",
 StyleBox["IDDF",
  FontSlant->"Italic"],
 " parameters in the range of interest of AMAD ",
 StyleBox["p",
  FontSlant->"Italic"],
 ", [0.5 \[Micro]m, 20 \[Micro]m], for standard workers  may be fitted using \
least squared estimators. This approximation is used by ",
 StyleBox["AMADfit[p]", "Input"]
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     SubscriptBox["IDDF", "AI"], ",", 
     SubscriptBox["IDDF", "\"\<bb(fast+seq)\>\""], ",", 
     SubscriptBox["IDDF", "bbslow"], ",", " ", 
     SubscriptBox["IDDF", "\"\<BB(fast+seq)\>\""], " ", ",", " ", 
     SubscriptBox["IDDF", "BBslow"], ",", "  ", 
     SubscriptBox["IDDET", "2"], ",", " ", 
     SubscriptBox["IDDET", "1"]}], "}"}], " ", "=", 
   RowBox[{"AMADfit", "[", "p", "]"}]}], ";"}]], "Input",
 CellLabel->"In[26]:="],

Cell[CellGroupData[{

Cell[BoxData[
 SubscriptBox["IDDF", "AI"]], "Input",
 CellLabel->"In[27]:="],

Cell[BoxData[
 RowBox[{"0.12818684263349484`", " ", 
  SuperscriptBox["\[ExponentialE]", 
   RowBox[{
    RowBox[{"-", "0.17011061305604133`"}], " ", "p"}]]}]], "Output",
 CellChangeTimes->{3.399022762652232*^9, 3.3990241818511515`*^9, 
  3.479969378806038*^9, 3.54192010632526*^9, 3.59206082838728*^9, 
  3.643616694522538*^9, 3.65623575675453*^9},
 CellLabel->"Out[27]="]
}, Open  ]],

Cell[TextData[{
 "Here it is shown the lung retention for an Adult worker as function of ",
 StyleBox["I",
  FontSlant->"Italic"],
 " and the AMAD ",
 StyleBox["p ",
  FontSlant->"Italic"],
 "(type S and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", "R"], TraditionalForm]]],
 "\[Rule]0), after an acute intake ",
 StyleBox["I",
  FontSlant->"Italic"],
 " at ",
 StyleBox["t",
  FontSlant->"Italic"],
 "= 0. It will be used in example 1."
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"LungsRetention", "[", 
   RowBox[{"1", ",", 
    RowBox[{"AMADfit", "[", "p", "]"}], " ", ",", "S", ",", " ", "t", ",", 
    "0"}], "]"}], "//", "Chop"}]], "Input",
 CellLabel->"In[28]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "2.6744111608650476`*^-8"}], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4.353270952537328`"}], " ", "p"}], "-", 
     RowBox[{"110.1`", " ", "t"}]}]]}], "+", 
  RowBox[{"7.743249257250958`*^-8", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1.1114709327884795`"}], " ", "p"}], "-", 
     RowBox[{"110.1`", " ", "t"}]}]]}], "-", 
  RowBox[{"0.000017019528996169847`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.5667829354923091`"}], " ", "p"}], "-", 
     RowBox[{"110.1`", " ", "t"}]}]]}], "+", 
  RowBox[{"2.1179221904039762`*^-8", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.17011061305604133`"}], " ", "p"}], "-", 
     RowBox[{"110.1`", " ", "t"}]}]]}], "-", 
  RowBox[{"1.1572369185732363`*^-8", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.14724386061421538`"}], " ", "p"}], "-", 
     RowBox[{"110.1`", " ", "t"}]}]]}], "-", 
  RowBox[{"7.743249257250958`*^-8", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.1235776148578769`"}], " ", "p"}], "-", 
     RowBox[{"110.1`", " ", "t"}]}]]}], "-", 
  RowBox[{"2.495804722963974`*^-6", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.08789446045802779`"}], " ", "p"}], "-", 
     RowBox[{"110.1`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.000017019528996169847`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.05778349162703789`"}], " ", "p"}], "-", 
     RowBox[{"110.1`", " ", "t"}]}]]}], "-", 
  RowBox[{"1.8586651555154462`*^-7", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4.353270952537328`"}], " ", "p"}], "-", 
     RowBox[{"102.1`", " ", "t"}]}]]}], "-", 
  RowBox[{"5.333842485646511`*^-7", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.17011061305604133`"}], " ", "p"}], "-", 
     RowBox[{"102.1`", " ", "t"}]}]]}], "-", 
  RowBox[{"8.042577628677191`*^-8", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.14724386061421538`"}], " ", "p"}], "-", 
     RowBox[{"102.1`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.000012479023614819437`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.08789446045802779`"}], " ", "p"}], "-", 
     RowBox[{"102.1`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.00002130580490632139`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4.353270952537328`"}], " ", "p"}], "-", 
     RowBox[{"100.13`", " ", "t"}]}]]}], "-", 
  RowBox[{"0.000011061784653215376`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1.1114709327884795`"}], " ", "p"}], "-", 
     RowBox[{"100.13`", " ", "t"}]}]]}], "+", 
  RowBox[{"9.219174814358716`*^-6", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.14724386061421538`"}], " ", "p"}], "-", 
     RowBox[{"100.13`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.000011061784653215376`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.1235776148578769`"}], " ", "p"}], "-", 
     RowBox[{"100.13`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.00003884461434045666`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.17011061305604133`"}], " ", "p"}], "-", 
     RowBox[{"100.11999999999999`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.00007680459063545697`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.17011061305604133`"}], " ", "p"}], "-", 
     RowBox[{"100.101`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.000010661672038446077`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.17011061305604133`"}], " ", "p"}], "-", 
     RowBox[{"100.10012`", " ", "t"}]}]]}], "+", 
  RowBox[{"1.4869321244122486`*^-7", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4.353270952537328`"}], " ", "p"}], "-", 
     RowBox[{"100.1`", " ", "t"}]}]]}], "-", 
  RowBox[{"7.743249257249603`*^-8", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1.1114709327884795`"}], " ", "p"}], "-", 
     RowBox[{"100.1`", " ", "t"}]}]]}], "-", 
  RowBox[{"1.1997653874440298`*^-7", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.5667829354923091`"}], " ", "p"}], "-", 
     RowBox[{"100.1`", " ", "t"}]}]]}], "+", 
  RowBox[{"2.1321808811470416`*^-6", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.17011061305604133`"}], " ", "p"}], "-", 
     RowBox[{"100.1`", " ", "t"}]}]]}], "+", 
  RowBox[{"6.434062102942024`*^-8", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.14724386061421538`"}], " ", "p"}], "-", 
     RowBox[{"100.1`", " ", "t"}]}]]}], "+", 
  RowBox[{"7.743249257249603`*^-8", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.1235776148578769`"}], " ", "p"}], "-", 
     RowBox[{"100.1`", " ", "t"}]}]]}], "+", 
  RowBox[{"7.0375158351451`*^-8", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.08789446045802779`"}], " ", "p"}], "-", 
     RowBox[{"100.1`", " ", "t"}]}]]}], "+", 
  RowBox[{"1.1997653874440298`*^-7", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.05778349162703789`"}], " ", "p"}], "-", 
     RowBox[{"100.1`", " ", "t"}]}]]}], "-", 
  RowBox[{"0.000026770882491157064`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4.353270952537328`"}], " ", "p"}], "-", 
     RowBox[{"10.0001`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.00007751000257509473`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1.1114709327884795`"}], " ", "p"}], "-", 
     RowBox[{"10.0001`", " ", "t"}]}]]}], "-", 
  RowBox[{"0.017036565561733847`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.5667829354923091`"}], " ", "p"}], "-", 
     RowBox[{"10.0001`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.000021200422326368132`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.17011061305604133`"}], " ", "p"}], "-", 
     RowBox[{"10.0001`", " ", "t"}]}]]}], "-", 
  RowBox[{"0.000011583953138867045`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.14724386061421538`"}], " ", "p"}], "-", 
     RowBox[{"10.0001`", " ", "t"}]}]]}], "-", 
  RowBox[{"0.00007751000257509473`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.1235776148578769`"}], " ", "p"}], "-", 
     RowBox[{"10.0001`", " ", "t"}]}]]}], "-", 
  RowBox[{"0.002498303025990488`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.08789446045802779`"}], " ", "p"}], "-", 
     RowBox[{"10.0001`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.017036565561733847`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.05778349162703789`"}], " ", "p"}], "-", 
     RowBox[{"10.0001`", " ", "t"}]}]]}], "-", 
  RowBox[{"0.00018605256811968248`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4.353270952537328`"}], " ", "p"}], "-", 
     RowBox[{"2.0001`", " ", "t"}]}]]}], "-", 
  RowBox[{"0.000533918166731499`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.17011061305604133`"}], " ", "p"}], "-", 
     RowBox[{"2.0001`", " ", "t"}]}]]}], "-", 
  RowBox[{"0.0000805062825693618`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.14724386061421538`"}], " ", "p"}], "-", 
     RowBox[{"2.0001`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.01249151512995244`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.08789446045802779`"}], " ", "p"}], "-", 
     RowBox[{"2.0001`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.021327132038364522`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4.353270952537328`"}], " ", "p"}], "-", 
     RowBox[{"0.0301`", " ", "t"}]}]]}], "-", 
  RowBox[{"0.011072857510727818`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1.1114709327884795`"}], " ", "p"}], "-", 
     RowBox[{"0.0301`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.009228403217579801`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.14724386061421538`"}], " ", "p"}], "-", 
     RowBox[{"0.0301`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.011072857510727818`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.1235776148578769`"}], " ", "p"}], "-", 
     RowBox[{"0.0301`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.03888349783829052`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.17011061305604133`"}], " ", "p"}], "-", 
     RowBox[{"0.0201`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.07688147210756655`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.17011061305604133`"}], " ", "p"}], "-", 
     RowBox[{"0.0011`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.010672344382830311`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.17011061305604133`"}], " ", "p"}], "-", 
     RowBox[{"0.00022`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.000148842054495746`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4.353270952537328`"}], " ", "p"}], "-", 
     RowBox[{"0.0001`", " ", "t"}]}]]}], "-", 
  RowBox[{"0.00007751000257509473`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1.1114709327884795`"}], " ", "p"}], "-", 
     RowBox[{"0.0001`", " ", "t"}]}]]}], "-", 
  RowBox[{"0.0001200966353797955`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.5667829354923091`"}], " ", "p"}], "-", 
     RowBox[{"0.0001`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.0021343151963437667`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.17011061305604133`"}], " ", "p"}], "-", 
     RowBox[{"0.0001`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.00006440502605548944`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.14724386061421538`"}], " ", "p"}], "-", 
     RowBox[{"0.0001`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.00007751000257509473`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.1235776148578769`"}], " ", "p"}], "-", 
     RowBox[{"0.0001`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.00007044560395542161`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.08789446045802779`"}], " ", "p"}], "-", 
     RowBox[{"0.0001`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.0001200966353797955`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.05778349162703789`"}], " ", "p"}], "-", 
     RowBox[{"0.0001`", " ", "t"}]}]]}]}]], "Output",
 CellChangeTimes->{3.3990227630274534`*^9, 3.399024182523031*^9, 
  3.479969379280038*^9, 3.541920106512764*^9, 3.592060828926073*^9, 
  3.643616694678789*^9, 3.656235756863891*^9},
 CellLabel->"Out[28]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox["Biokinetic model for elements using ICRP 30 metabolic \
model structure",
 FormatType->StandardForm,
 FontFamily->"Times New Roman"]], "SubsubsectionIcon"],

Cell[TextData[{
 "We will need the analytical expression of ",
 StyleBox["R",
  FontSlant->"Italic"],
 StyleBox["m",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "(",
 StyleBox["I",
  FontSlant->"Italic"],
 ", ",
 StyleBox["k",
  FontSlant->"Italic"],
 ", ",
 StyleBox["t",
  FontSlant->"Italic"],
 "),  where ",
 StyleBox["k",
  FontSlant->"Italic"],
 " represents any parameter of the model, is only possible in particular \
cases. However they are many practical situations in which it is feasible, in \
particular it can be obtained for models that do not involve recycling. This \
condition is verified for many ICRP models (ICRP 2001), all of them where is \
still applicable the ICRP 30 (1981) metabolic model structure represented in \
fig. 1. \n"
}], "Text"],

Cell[GraphicsData["Metafile", "\<\
CF5dJ6E]HGAYHf4PEfU^I6mgLb15CDHPAVmbKF5d0@0008880@0006`0001@0000j@400<d1001S0`00
h`T00=4k0016>000FFT00215CDH00040288005L400060000000000000000000000@0000300100@00
l0000000000000000000003R1020Z@<0AP0002`0000P0000ADe6:`500@0L00004000004@`=/10000
H000060000160000G00005000015CDH[8T0400`0000000007T0100`000000000940100`000000000
8D0700`000000000<4020100000400000020?`A0000<0000000001P0000<0000000001T0000<0000
oooo01@0000<00003@000180000<00000P00024000080000500000`0000=0000<00000`0000?0020
AP0002P0000L0000AdA9@`80001A0000jP400<d1001O0`00000004H0000X0000700004M4BD<20000
/`0009H2003b0000d@80000000160000e0000<P00015CDH[:T0002@0000H00000020?`0000000000
0020?`000000000024000i00002400000A30f`d000000000081B@`309DB7Yd530<0UA000=4>Dl2Q4
000d@`3P;4@003A3K<l`A8NW@D<003A4081B@`00=4AiF6=3000dA000LD=/cc14001a@`3P;4@00753
U?0XA7UHHd<0`2E4081B@`309D@00`<30`<30`<30`>300005400P10000040000ooooob4000080000
HP0000`000010000900002@00000080m000000000000080m00000000000200009@0000`000000020
4`0000`000010000>`0000P0001E0000D000000000000000ooooooooool=000080eX:A<<J2Th2cDZ
>0/`:cP;;2`C3?P/80gh;2h>n2`83b`/20l`:`P?=BX^3VPY80eX:C`000080000?P0001P0002c0000
UP800?40003@0P004`0000`0000100009@0000`000000020900002@0000008110000000000000811
0000000000020000AP000600001D0000ADe6:`Q00@900000=000004@`=/00000GP0000000000080o
0P000080000200000000@@8000014<3K000000000?lE@000400000@000010000900002@00000080m
000000000000080m0000000000020000G`0003P000010000>0000000000h0000000000000@0@0000
000000000000000000000000000U000030000040000U0000300000D0081E0000D0000;80002E0P00
lP000=42000=000080eX:A<<J2Th2cDZ>0/`:cP;;2`C3?P/80gh;2h>n2`83b`/20l`:`P?=BX^3VPY
80eX:BD0000<00001`00P2D0000<00000000P2@0000T00000020@@00000000000020@@0000000000
0P0002P0000<00000@000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000
500000P00017A4U30`000240000800007P0001P000310000X@800>D000370P00DP00070100010000
kOooo`000000000000000;`20000000000008440LP1Y0640K0000000000000000000000000000000
0000000000000000000000000000000000000000000000004eX2<0X40001000078DC00D0003`1@X4
000009b54`1XQQ<0N000080000000000X5W_MiR54`010000W8DC0180003XdeT1W8DC0>fZ031`deT1
c8DC00`00038nET1b8hC02D000000000E01Q06P0K`1]0640n8<C00005E/l4AQKI8@C0=RRAP0PQ1<0
6EPEFb2TAP1/XTH0Y:9604RRAP0B0000U0000183002b0000l8@C01=D5E/004H0;e@EFhbVAP04Qa<0
B:960000000000400@020:QmkgMePnmgG`L:Se`0003<Q1<0L==I0K244`19mP0`I7H02000000U0000
30000040000U0000300000d0080U000030000040000B000030000040001D0000E0000<`0002R0P00
f@000;L200010000003j@@00nT7<0000XP800040001<00000000000000000000oooooooooom@0000
@P0000h0000U0000300000d0080R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000
000001h0000H00006P000140003/0`00;@800280000<0000oooooaP0000<0000000001T0000<0000
oooo02D0000<00000000P2D0000<00003@00P4H0000X0000700004M4BD<20000L0000?82002A0000
4@<0000000160000e0000<P00015CDH[:T0002@0000H00000020?`00000000000020?`0000000000
24020i00002400000A30f`d0000000000800@`30?4CDh>m20<0lA000hT9dGci4003R@P1P@4@00>92
S612A=CPkd8004A40800@`00A4BF3`U30014A00044><H494000@@`1P@4@00113M5lnA9H?2D<0`3a4
0800@`30?4@00`<30`<30`<30`>300005402P10000040000ooooob4000080000HP0000`000010000
900002@00000080m000000000000080m00000000000200009@0000`0000000204`0000`000010000
>`0000P0001E0000D000000000000000ooooooooool=000000PX;gL7:2l81i0_20L@<0P7TC1g1oP`
00Sh<8T8n33h294`n0P@<?P8T2n922P_00PX;c`000080000?P0001P0001`0000lP800900000@0`00
4`0000`0000100009@0000`000000020900002@00000081100000000000008110000000000020000
AP000600001D0000ADe6:`Q00`900000=000004@`=/00000GP0000000000080o0P00008000020000
0000@@8000014<3K000000000?lE@080400000@000030000900002@00000080m000000000000080m
0000000000020000G`0003P000020000>0000000000h0000000000000@0@00000000000000000000
00000000000U000030000080000U0000300000D0081E0000D00006l0003a0P00T@000143000=0000
00PX;gL7:2l81i0_20L@<0P7TC1g1oP`00Sh<8T8n33h294`n0P@<?P8T2n922P_00PX;bD0000<0000
1`00P2D0000<00000000P2@0000T00000020@@00000000000020@@00000000000P0002P0000<0000
0P000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000500000P00017A4U3
0`000240000800007P0001P0001i0000n@8008T0000;0`00DP00070100020000loooo`0000000000
000009010000000000000440LP1Y0640K00000000000000000000000000000000000000000000000
00000000000000000000000000000000000006Af00P00000TPD11`000000000000000;CO4`3@h1<0
N0000800003j1`00C9de<K3O4`010000_08000d0001L]ZX0]=lC0>fZ033T]JX0i=lC00`0003@h1<0
[>4C0000003coooo0000000000000000_080000000000000@@1b06T0H@1/00000000000000000000
000000000000000000000000000000000000000000000000000000H0000R000000000100000=0000
0`000:QmkgMePnmgR@D:35`0003TgQ<0K;FZ0<SN4`19mP0`I7H02000000U000030000080000U0000
300000d0080U000030000080000D0000300000d0000B000030000040001D0000E00007T0003i0P00
O`0000P300010000003j@@00nT5i0000n@800040001<00000000000000000000oooooooooom@0000
H@0000L0000U0000300000d0080R000030000?oooolQ0000200001T0000<0000oooo01P0000<0000
000001h0000H00006P000140003/0`00;@800280000<0000oooooaP0000<0000000001T0000<0000
oooo02D0000<00000000P2D0000<00003@00P4H0000X0000700004M4BD<20000``000?82003T0000
4@<0000000160000e0000<P00015CDH[:T0002@0000H00000020?`00000000000020?`0000000000
24040i00002400000A30f`d000000000081C@`30?4AZl4Y30<0lA000A4=dGci40014@`1P@4@004A3
S612A6[`BT<004A4081C@`00A4BF3ea30014A000Hd><H494001S@`1P@4@006=3M5lnA9H?G4<0`3a4
081C@`30?4@00`<30`<30`<30`>300005404P10000040000ooooob4000080000HP0000`000010000
900002@00000080m000000000000080m00000000000200009@0000`0000000204`0000`000010000
>`0000P0001E0000D000000000000000ooooooooool=0000<0dX;jL<:2lh390_>0`@<3P<TC2W3?P`
<0gh<;T=n30X3Y4`:0h@<2P>T2ni3BP_<0dX;c`000080000?P0001P000330000lP800><0000@0`00
4`0000`0000100009@0000`000000020900002@00000081100000000000008110000000000020000
AP000600001D0000ADe6:`Q01@900000=000004@`=/00000GP0000000000080o0P00008000020000
0000@@8000014<3K000000000?lE@0@0400000@000050000900002@00000080m000000000000080m
0000000000020000G`0003P000030000>0000000000h0000000000000@0@00000000000000000000
00000000000U0000300000<0000U0000300000D0081E0000D0000<80003a0P00i0000143000=0000
<0dX;jL<:2lh390_>0`@<3P<TC2W3?P`<0gh<;T=n30X3Y4`:0h@<2P>T2ni3BP_<0dX;bD0000<0000
1`00P2D0000<00000000P2@0000T00000020@@00000000000020@@00000000000P0002P0000<0000
0`000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000500000P00017A4U3
0`000240000800007P0001P0003<0000n@800=`0000;0`009@0000`0000200009@0000`0000=0020
9@0000`000020000500000`0000=00004P0000`000010000E00005@0003<0000n@800=8000080`00
0@000000nT400?Y1c0000?T200010000C00000000000000000000?ooooooooooD000068000070000
9@0000`0000=00208P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001X0000A0000k0<002d2000R000030000?oooolH000030000000000I000030000?ooo`0U0000
30000000080U0000300000d008160000:00001`00017A4U30P0001<1003b0P00=040014300000000
AP000=@000380000ADe6:bY0000T000060000000P3l0000000000000P3l00000000000Q01P>@0000
Q000004@`=/=000000000030TD<0`3a4=GR=@`30?4@008Y3M5lnA000RT<0H414002:@haP@T@eN8e3
0014A030TD<004A4b`NF@`00A4@0P9U3S612A020VD<0H414082I@gAO?TC;1iI30<0lA030TD<0`3a4
00<30`<30`<30`<3P`0001A01X0@000010000?oooolQ000020000680000<00000@0002@0000T0000
0020?@00000000000020?@00000000000P0002D0000<00000000P1<0000<00000@0003/000080000
E@0005000000000000000?oooooooooo3@00030B:2nW4BP_>16@;cPA430h4I4`Ya7h<30Bn32i4_P`
:1>A<2PC430X4i0_^A8X;c0B:2ll0000200003h0000H00004`400?82000c0@0040<001<0000<0000
0@0002D0000<00000000P2@0000T00000020@@00000000000020@@00000000000P0004H0001P0000
E00004E=AR/8@0L2@00003@000014<3K000005h0000000000020?`80000200000P00000004420000
0A30f`000000003o5D060100000400001`0002@0000T00000020?@00000000000020?@0000000000
0P0005l0000h00000`0003P000000000>00000000000004040000000000000000000000000000000
9@0000`0000300009@0000`000050020E@000500000B0@00l@8003@1000A0`003@00030B:2nW4BP_
>16@;cPA430h4I4`Ya7h<30Bn32i4_P`:1>A<2PC430X4i0_^A8X;c0B:2lU0000300000L0080U0000
30000000080T000090000000P440000000000000P440000000000080000X0000300000<0000R0000
30000?oooom60000700001000015CDH[140000`000000000AP0001@000080000AdA9@`<0000Q0000
200001h0000H000070400?T2000/0@002`<002D0000<00000P0002D0000<00003@00P2D0000<0000
0P0001@0000<00003@000180000<00000@0005@0001D000070400?T2000R0@0020<0004000000?Y1
003j@A`1003i0P000@0004`00000000000000000003ooooooooooe00001S00001`0002D0000<0000
3@00P280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@000>`3000]0P008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000000020
9@0000`0000=0020AP0002P0000L0000AdA9@`80001D0@008`<007X100170`00000004H0003D0000
b00004E=AR/Z@000900001P00000080o000000000000080o000000000008@0P3T00008@000014<3K
3@0000000000P;=30019A7N7[T<004U4082Z@aGWBT@0P:Y3041=A020ZT?[V4m4MhN^@`20DD@0P;=3
081AA8Uh^4<0P554082l@n^HCd@0P;a3041=A020_4<EidY4RGRh@`00BD@0P;=30019A0030`<30`<3
0`<30h<0000D@0R0400000@0003ooooo8@0000P0001R000030000040000T000090000000P3d00000
00000000P3d0000000000080000U000030000000080C000030000040000k0000200005D0001@0000
00000000003oooooooooo`d0001X5SPbbADh<TPE/S985DPcB1GO<lTEF3AX5UPd21MH=8PGgc>85dPc
R1Nb<PPG>39X5SPb?00000P0000n0000600005@1000S0`00N@4004H3000C000030000040000U0000
30000000080T000090000000P440000000000000P44000000000008000160000H00005@00015CDH[
24090T00000d00000A30f`00001N000000000000P3l200000P000080000000110P00004@`=/00000
0000oaE0200@0000100000T0000T000090000000P3d0000000000000P3d0000000000080001O0000
>00000<0000h0000000003P00000000000010100000000000000000000000000000002D0000<0000
0`0002D0000<00001@00P5D0001@0000D`400283001j0@00A`<000d0001X5SPbbADh<TPE/S985DPc
B1GO<lTEF3AX5UPd21MH=8PGgc>85dPcR1Nb<PPG>39X5SPb9@0000`0000700209@0000`000000020
900002@00000081100000000000008110000000000020000:00000`0000300008P0000`0003ooooo
AP0001`0000@0000ADe6:`A0000<0000000004H0000D0000200004M4BD<300008@0000P0000N0000
600005h1000Z0`00L@400443000U000030000080000U0000300000d0080U000030000080000D0000
300000d0000B000030000040001D0000F00005h1000Z0`00K@4003T300010000003j@@00nT5N0@00
:P<00080001<00000000000000000000oooooooooom@0000@P1<00T0000700009@0000`0000=0020
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A0000
k0<002d2000R000030000?oooolH000030000000000I000030000?ooo`0U000030000000080U0000
300000d008160000:00001`00017A4U30P000<00001V0P00hP0008L200000000AP000=@000380000
ADe6:bY0000T000060000000P3l0000000000000P3l00000000000Q02P>@0000Q000004@`=/=0000
00000000DD<0`1U4^2U8@`306D@004536g`KA000@D<0X1e40011@nG37dBh:DQ3080QA000DD<0P254
B=II@`208D@00653iL<OA000HD<0X1e4001Q@a]l6dA8eUU30<0IA000DD<0`1U400<30`<30`<30`<3
P`0001A02X0@000010000?oooolQ000020000680000<00000@0002@0000T00000020?@0000000000
0020?@00000000000P0002D0000<00000000P1<0000<00000@0003/000080000E@00050000000000
00000?oooooooooo3@0000P=J2Ik36PV20cG9PP<H2L83>TWN`aH:0P=F2RF3EPX20kY9`P>H2L83]LV
UPeX9PP=J2Hl0000200003h0000H0000`00006H2003Q0000QP8001<0000<00000@0002D0000<0000
0000P2@0000T00000020@@00000000000020@@00000000000P0004H0001P0000E00004E=AR/8@0/2
@00003@000014<3K000005h0000000000020?`80000200000P000000044200000A30f`000000003o
5D0:0100000400002`0002@0000T00000020?@00000000000020?@00000000000P0005l0000h0000
0`0003P000000000>000000000000040400000000000000000000000000000009@0000`000030000
9@0000`000050020E@000500002o0000I@800>8000270P003@0000P=J2Ik36PV20cG9PP<H2L83>TW
N`aH:0P=F2RF3EPX20kY9`P>H2L83]LVUPeX9PP=J2HU0000300000L0080U000030000000080T0000
90000000P440000000000000P440000000000080000X0000300000<0000R000030000?oooom60000
700001000015CDH[140000`000000000AP0001@000080000AdA9@`<0000Q0000200001h0000H0000
b@0006d2003J0000P@800580001`0@000`000?Goool0000000000000002@0@000000000002110780
J@1Q06`0000000000000000000000000000000000000000000000000000000000000000000000000
000007P0000005T1j@L00000000Z[K4`l0D:1000002LQA<0J8HC07P00020000000000:1IkgNHQA<0
0@0009b54`0;0000`;aI0Ib54`3]ZP0`B;aI0Lb54`0<0000E3?O0<R>4`0<0000000005@0H@1X06l0
K@1Q0?R34`0001EK?14HFfB44`3HXTH088@C01UH5E/PY4H0K:960:BRAP18XTH04P0009@0000B0`00
/P000?244`0CE1EK001602mD5E^<YTH018LC04RRAP000000000100400P2XONmgMH?_Mm/:2YAL0000
c8@C04RlF@6`Q1<0BOH0<6Af00P000009@0000`0000300009@0000`0000=00209@0000`000030000
500000`0000=00004P0000`000010000E000060000390000K@800=L0001j0P000@000000nT400?Y1
b@0006d200030000C00000000000000000000?ooooooooooE00005D0C01900001`0000H000020000
9@0000`0000=00208P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000
600001X0000A0000k0<002d2000R000030000?oooolH000030000000000I000030000?ooo`0U0000
30000000080U0000300000d008160000:00001`00017A4U30P000<00000c0P00hP0005@200000000
AP000=@000380000ADe6:bY0000T000060000000P3l0000000000000P3l00000000000Q030>@0000
Q000004@`=/=000000000000DD<000e4^2U8@`003D@004536k`>A000@D<0h1140011@nD34dBh:DQ3
0<0DA000DD<0`1A4B=II@`3054@00653i@<CA000HD<0h114001Q@a^l3TA8eUU3000=A000DD<000e4
00<30`<30`<30`<3P`0001A0380@000010000?oooolQ000020000680000<00000@0002@0000T0000
0020?@00000000000020?@00000000000P0002D0000<00000000P1<0000<00000@0003/000080000
E@0005000000000000000?oooooooooo3@0000P=>2=k33PS20bW8`P<<2@83;TTN``X9@P=:2FF3BPU
20ji90P><2@83ZLSUPdh8`P=>2<l0000200003h0000H0000`00003<2003Q0000D`8001<0000<0000
0@0002D0000<00000000P2@0000T00000020@@00000000000020@@00000000000P0004H0001P0000
E00004E=AR/8@0d2@00003@000014<3K000005h0000000000020?`80000200000P00000004420000
0A30f`000000003o5D0<0100000400003@0002@0000T00000020?@00000000000020?@0000000000
0P0005l0000h0000100003P000000000>00000000000004040000000000000000000000000000000
9@0000`0000400009@0000`000050020E@000500002o0000<P800>80001D0P003@0000P=>2=k33PS
20bW8`P<<2@83;TTN``X9@P=:2FF3BPU20ji90P><2@83ZLSUPdh8`P=>2<U0000300000L0080U0000
30000000080T000090000000P440000000000000P440000000000080000X0000300000@0000R0000
30000?oooom60000700001000015CDH[140000`000000000AP0001@000080000AdA9@`<0000Q0000
200001h0000H0000b@0003X2003J0000CP8002D0000<00000`0002D0000<00003@00P2D0000<0000
0`0001@0000<00003@000180000<00000@0005@0001P0000b@0003X2003F0000A`80004000000?Y1
003j@LT0000j0P000`0004`00000000000000000003ooooooooooe@0001<04`0B@0000H000060000
0P0002D0000<00003@00P280000<0000ooooob40000800006@0000`0003oool0600000`000000000
7P0001P0000J00004@000>`3000]0P008P0000`0003ooooo600000`0000000006@0000`0003oool0
9@0000`0000000209@0000`0000=0020AP0002P0000L0000AdA9@`80002l0000jP400>H0000@0P00
000004H0003D0000b00004E=AR/Z@000900001P00000080o000000000000080o000000000008@0h3
T00008@000014<3K3@00000000000553083e@bKdAD<0P?E3000m@gN7nD<003e3083n@`00?D=4_054
9_A5@`300d@005530<03A=X;G4<0`0=4001U@dBl0D@006E3083n@`00ID=gQoU3fP]L@`20mD<00553
083e@`030`<30`<30`<30h<0000D@0j0400000@0003MgMgo8@0000P0001R000030000040000T0000
90000000P3d0000000000000P3d0000000000080000W0000600000@000000000gMgM0000000U0000
300000@0000C000030000040000k0000200005D0001@000000000000003oooooooooo`d000083JPN
F0bX7/P;:Ao82lPOb0]X85P<j2083NPP^@gX84P>J2183/POB0hY7kT=Z1h83JPN?00000P0000n0000
60000;`0003Z0@00i@0000l2000C000030000040000U000030000000080T000090000000P4400000
00000000P44000000000008000160000H00005@00015CDH[240?0T00000d00000A30f`00001N0000
00000000P3l200000P000080000000110P00004@`=/000000000oaE03P0@0000100000l0000T0000
90000000P3d0000000000000P3d0000000000080001O0000>00000D0000h0000000003P000000000
00010100000000000000000000000000000002D0000<00001@0002D0000<00001@00P5D0001@0000
^`000>T1003V0000408000d000083JPNF0bX7/P;:Ao82lPOb0]X85P<j2083NPP^@gX84P>J2183/PO
B0hY7kT=Z1h83JPN9@0000`0000700209@0000`000000020900002@0000008110000000000000811
0000000000020000:00000`0000500008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000
000004H0000D0000200004M4BD<300008@0000P0000N000060000<H0003b0@00g@0000T2000U0000
300000<0000U0000300000d0080U0000300000<0000D0000300000d0000B000030000040001D0000
H0000<H0003b0@00f0000?l100010000003j@@00nT760000lP4000<0001<00000000000000000000
oooooooooomD0000AP1504<0000600001P0000L0000U0000300000d0080R000030000?oooolQ0000
200001T0000<0000oooo01P0000<0000000001h0000H00006P000140003/0`00;@800280000<0000
oooooaP0000<0000000001T0000<0000oooo02D0000<00000000P2D0000<00003@00P4H0000X0000
700004M4BD<20000N`000;<2002e0000m@8000000016000020400?`00015CDH[:T0002@0000H0000
0020?`00000000000020?`0000000000240@0Y`0002@00000A30f`00001N400000000000P3l20000
o`000080000000110P0005P000014<3K0000004000020000EUEE@00000000000000000008440080o
0000000000000000000001`000014<3K0`00001P00020?co00000?koo?l00H400A30f`000000003o
240A0bP0000L00000A30f`<00000@000]02d0X40]0:10?<2004101E04@0@000010000100000X0000
300000@0000Q000020000680000<00000@0002@0000T00000020?@00000000000020?@0000000000
0P0005l0000h0000100003P000000000>000000000004P4040000000000000000000000000000000
9@0000`0000400009`0001P00005000000000000000000009@0000`0000500004`0000`000020000
>`0000P0000K0000400003P;0010:`00F@0002P00000000000000?oooooooooo0`0000P8@2/@23P[
40Sc;UP0000d000000000000003oooooooooo`H0000@2?P^3@Sk;PP8nbh42?/^00Sh;P08lbhf0000
40000008000h:`00F00002P00000000000000?oooooooooo0`000008=2/4230[20P`:cH0000@0000
>0/0030[001H0000=000000000000000ooooooooool60000?@/`:d0;=2]02cP[@0/m:cd;@2/h2d0[
?@0000P0000K0000400004P8002X;P00F@0002@00000000000000?oooooooooo0P0000P8:2o81jP^
?@0000P0000l0000200003l0000H0000N`000;42002f0000m08001<0000<00000@0002D0000<0000
0000P2D0000<00001`00P2@0000T00000020@@00000000000020@@00000000000P0002P0000<0000
10000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000500000P00017A4U3
0`0004H0000X0000700004M4BD<20000cP000<l2003J0000m@8000000016000010400?P00015CDH[
:T0002@0000H00000020?`00000000000020?`0000000000240B0Y`0002@00000A30f`00001N4000
00000000P3l20000o`000080000000110P0005P000014<3K0000004000020000EUEE@00000000000
000000008440080o0000000000000000000001`000014<3K0`00001P00020?co00000?koo?l00H40
0A30f`000000003o240C0b@0000H00000A30f`800000@000d`3@0]@0l`800@005D0C010000040000
4P00024000080000HP0000`000010000900002@00000080m000000000000080m0000000000020000
G`0003P000040000>0000000000h00000000000B0@0@0000000000000000000000000000000U0000
300000@0000U0000300000D0000C000030000080000k0000200001/0000@0000<0d00?P/000f0000
400003l=003c;P00F00003@00000000000000?oooooooooo1P0003l=mbhl3O/^=`gk;S<=nbh_3OP^
;`gc;SH0000@000080d00?T/001H0000=000000000000000ooooooooool6000080gd;2@=lB`X3O0/
;@g`;30=m2``3OP/?@0000P0000K0000400007D=002W;P00F@0002@00000000000000?oooooooooo
0P0003P=:2oe3:X^?@0000P0000l0000200003l0000H0000c@000<d2003I0000m08001<0000<0000
0@0002D0000<00000000P2D0000<00001`00P2@0000T00000020@@00000000000020@@0000000000
0P0002P0000<000010000280000<0000ooooodH0000L0000400004E=AR/4@0003000000000160000
500000P00017A4U30`0004H0000X0000700004M4BD<20000k`000;@2000Y0@00mP80000000160000
20400?`00015CDH[:T0002@0000H00000020?`00000000000020?`0000000000240D0Y`0002@0000
0A30f`00001N400000000000P3l20000o`000080000000110P0005P000014<3K0000004000020000
EUEE@00000000000000000008440080o0000000000000000000001`000014<3K0`00001P00020?co
00000?koo?l00H400A30f`000000003o240E0bP0000L00000A30f`<00000@000l02e0R<1]@8S0O@2
004101E05@0@0000100001@0000Q000020000680000<00000@0002@0000T00000020?@0000000000
0020?@00000000000P0005l0000h0000100003P000000000>000000000004P404000000000000000
00000000000000009@0000`0000400009@0000`0000500004`0000`000020000>`0000P0000K0000
40000?P>0010:`00=P000100000X4P00@2/005P0000X000000000000003oooooooooo`<0000]4T0[
<194:c0BB2/f00004000030B0003;`00F00003@00000000000000?oooooooooo1P00030B22l]4P/_
:18;;b@B2blP4PP_8183;eT0000X000000000000003oooooooooo`<0000P4TP[:19@:oP>D2]H0000
=000000000000000ooooooooool60000m0i@:o0>CB_`3TP[l0i4:o@>@2_h3T0[?@0000P0000K0000
400006PB002h;P00F@0002@00000000000000?oooooooooo0P0002PB>2oX4KP^?@0000P0000l0000
200003l0000H0000k@000;82000X0@00m@8001<0000<00000@0002D0000<00000000P2D0000<0000
1`00P2@0000T00000020@@00000000000020@@00000000000P0002P0000<000010000280000<0000
ooooodH0000L0000400004E=AR/4@0003000000000160000500000P00017A4U30`0004H0000X0000
700004M4BD<20000M@0007h200380000nP80000000160000704001010015CDH[:T0002@0000H0000
0020?`00000000000020?`0000000000240F0Y`0002@00000A30f`00001N400000000000P3l20000
o`000080000000110P0005P000014<3K0000004000020000EUEE@00000000000000000008440080o
0000000000000000000001`000014<3K0`00001P00020?co00000?koo?l00H400A30f`000000003o
240G0c`0000`00000A30f`@000000000003/@P10?T@00>a2;D0PA000@T<]@2140012@`0084@00@41
5D0G0100000400005P00024000080000HP0000`000010000900002@00000080m000000000000080m
0000000000020000G`0003P000040000>0000000000h00000000000B0@0@00000000000000000000
00000000000U0000300000@0000U0000300000D0000C000030000080000k0000200001/0000@0000
D0L008P_000f0000400005070009:000F00002P00000000000000?oooooooooo0`00050712QD1`4X
F0L1:3H0000@0000i@/00?hW001H0000=000000000000000ooooooooool60000j@_n9nd;0BS]2`HX
k@/::>T;3RSU2`hXF@0002P00000000000000?oooooooooo0`0005P74BQP1`TXH0N8;eP0000d0000
00000000003oooooooooo`H0001P1hd_G@N@;eP7T2mD1i0_D0N=;e07R2lm0000200001/0000@0000
S@/00=/W001I00009000000000000000ooooooooool2000060ch9jd;EbPm0000200003`000080000
?`0001P0001c0000O0800<<0003k0P004`0000`0000100009@0000`0000000209@0000`000070020
900002@00000081100000000000008110000000000020000:00000`0000400008P0000`0003ooooo
AP0001`0000@0000ADe6:`A0000<0000000004H0000D0000200004M4BD<30000AP0002P0000L0000
AdA9@`80002Q0000O`800<`000030`00000004H0000X0@00704004E=AR/Z@000900001P00000080o
000000000000080o000000000008@1P2W000090000014<3K000005h@000000000020?`80003o0000
0P00000004420000F000004@`=/000000@000080001FEEE00000000000000000000P@@00P3l00000
00000000000000007000004@`=/3000006000080o?l00000o_olo`01P@014<3K000000000?l8@1T3
B00003`000014<3K1@000000000004A30810A0008T<0P414000R@c2094@004I3<80TA000AT<0@214
00410@40000E@1T0400000@0000H00008@0000P0001R000030000040000T000090000000P3d00000
00000000P3d0000000000080001O0000>00000@0000h0000000003P0000000000181010000000000
0000000000000000000002D0000<0000100002D0000<00001@0001<0000<00000P0003/000080000
6`000100000h3000830003H0000@000060X0020`001H0000:000000000000000ooooooooool30000
50XP<10:7C0@2QP`=P000100000@2P006BT005P0000X000000000000003oooooooooo`<0000@2Q@Y
50XA:AP:4BUI0000:000000000000000ooooooooool30000F0`A:E0<6BU@33hXF00003@000000000
00000?oooooooooo1P00050<>BQD33HXF0`f:5d<=RQP33TXH0`n:3H0000@0000H0`001TY001H0000
:000000000000000ooooooooool30000H0`M:Ed<8BUH324YF@0003000000000000000?oooooooooo
1@0001P:8BTP2QTY80XH<1P:430h310`F00003@00000000000000?oooooooooo1P0003d<431031@`
@0`H<40<7C0m320`>0`P<3d0000800006`000100000H3000R2P005T0000T000000000000003ooooo
ooooo`80001H30PXV0b8:3d000080000?00000P0000o0000600009l0001o0P00b`0000@3000C0000
30000040000U000030000000080U0000300000L0080T000090000000P440000000000000P4400000
00000080000X0000300000@0000R000030000?oooom60000700001000015CDH[140000`000000000
AP0001@000080000AdA9@`<000160000:00001`00017A4U30P000=l0001a0P00;`400?P200000000
AP0000P1003l0000ADe6:bY0000T000060000000P3l0000000000000P3l00000000000Q06P:L0000
T000004@`=/00000GQ0000000000080o0P000?l0000200000000@@80001H00000A30f`0000010000
0P0005IEED00000000000000000002110020?`000000000000000000000L00000A30f`<00000H000
0P3lo`00003nooco0061004@`=/000000000o`Q06`<X00007000004@`=/30000040002h1m`8^0GL2
h@1g0P010@0E@1/0400000@0000J00008@0000P0001R000030000040000T000090000000P3d00000
00000000P3d0000000000080001O0000>00000@0000h0000000003P0000000000181010000000000
0000000000000000000002D0000<0000100002D0000<00001@0001<0000<00000P0003/000080000
6`000100003@4P00J2l005T0000X000000000000003oooooooooo`<0003@4VPWf19`9ch>L2MH0000
=000000000000000ooooooooool60000>@i`9cH>KBLf3VPW=PiT9cT>H2Ln3V0W=P000100003H4P00
H2L005P0000X000000000000003oooooooooo`<0003M4V0Wh19T9n0BJ2Lf000040000>0B001X;`00
F00003@00000000000000?oooooooooo1P000>0BKBoM4W0_f19`;m@BL2o@4Vd_d19X;cd000080000
6`00010000283P00Z2L005T0000T000000000000003oooooooooo`8000083VPWR0hX9cd000080000
?00000P0000o000060000=l0001a0P00<0400?T2000C000030000040000U000030000000080U0000
300000L0080T000090000000P440000000000000P440000000000080000X0000300000@0000R0000
30000?oooom60000700001000015CDH[140000`000000000AP0001@000080000AdA9@`<000160000
:00001`00017A4U30P000</0001A0P00e`0006P200000000AP0000@1003h0000ADe6:bY0000T0000
60000000P3l0000000000000P3l00000000000Q070:L0000T000004@`=/00000GQ0000000000080o
0P000?l0000200000000@@80001H00000A30f`00000100000P0005IEED0000000000000000000211
0020?`000000000000000000000L00000A30f`<00000H0000P3lo`00003nooco0061004@`=/00000
0000o`Q07@<T00006000004@`=/2000004000=40I`;A05<2004001E07@0@0000100001`0000Q0000
20000680000<00000@0002@0000T00000020?@00000000000020?@00000000000P0005l0000h0000
100003P000000000>000000000004P40400000000000000000000000000000009@0000`000040000
9@0000`0000500004`0000`000020000>`0000P0000K00004000000=001X9P00=P00010000003@00
GRD005P0000d000000000000003oooooooooo`H000003ETU10eF9@P=ERD=3EHU40eI9A0=GRDf0000
4000010=001X9P00F00003@00000000000000?oooooooooo1P00010=KBH=3G0V20e`9P@=L2H03FdV
00eX9Sd0000800006`00010000383000Z2D005T0000T000000000000003oooooooooo`8000083BPU
B0fX9Cd000080000?00000P0000o000060000</0001A0P00eP0006T2000C000030000040000U0000
30000000080U0000300000L0080T000090000000P440000000000000P440000000000080000X0000
300000@0000R000030000?oooom60000700001000015CDH[140000`000000000AP0001@000080000
AdA9@`<000160000:00001`00017A4U30P000</0000=0P00e`0003D200000000AP0000@1003h0000
ADe6:bY0000T000060000000P3l0000000000000P3l00000000000Q07P:L0000T000004@`=/00000
GQ0000000000080o0P000?l0000200000000@@80001H00000A30f`00000100000P0005IEED000000
00000000000002110020?`000000000000000000000L00000A30f`<00000H0000P3lo`00003nooco
0061004@`=/000000000o`Q07`<T00006000004@`=/2000004000=40=0;A00l2004001E07`0@0000
100001h0000Q000020000680000<00000@0002@0000T00000020?@00000000000020?@0000000000
0P0005l0000h0000100003P000000000>000000000004P4040000000000000000000000000000000
9@0000`0000400009@0000`0000500004`0000`000020000>`0000P0000K00004000000=000h8`00
=P00010000003@007R4005P0000d000000000000003oooooooooo`H000003ATQ10dF8@P=5R4=3AHQ
40dI8A0=7R4f00004000010=000h8`00F00003@00000000000000?oooooooooo1P00010=?B<=3D0S
20e08`@=@2<03CdS00dh8cd0000800006`00010000383000J24005T0000T000000000000003ooooo
ooooo`8000083NPPB0eX8Cd000080000?00000P0000o000060000</0000=0P00eP0003H2000C0000
30000040000U000030000000080U0000300000L0080T000090000000P440000000000000P4400000
00000080000X0000300000@0000R000030000?oooom60000700001000015CDH[140000`000000000
AP0001@000080000AdA9@`<000160000:00001`00017A4U30P000800000?0`00H04005l300000000
AP0001`1000@0@00ADe6:bY0000T000060000000P3l0000000000000P3l00000000000Q080:L0000
T000004@`=/00000GQ0000000000080o0P000?l0000200000000@@80001H00000A30f`0000010000
0P0005IEED00000000000000000002110020?`000000000000000000000L00000A30f`<00000H000
0P3lo`00003nooco0061004@`=/000000000o`Q08@<l0000<000004@`=/40000000000000D<004A4
0001@`b0Ed@00:e3381GA000[D<0@51400410AE08@0@000010000200000Q000020000680000<0000
0@0002@0000T00000020?@00000000000020?@00000000000P0005l0000h0000100003P000000000
>000000000004P40400000000000000000000000000000009@0000`0000400009@0000`000050000
4`0000`000020000>`0000P0000K000040000108003h<000F@0003000000000000000?oooooooooo
1@000108f3D82=0eV1G@=I0Ef3F@5ChdF00003@00000000000000?oooooooooo1P00090E>CBD5CHd
V1Df=9dE=SBP5CTdX1Dn=3H0000@0000X1D00=Pe001H0000:000000000000000ooooooooool30000
X1GM=IdEh3FH5N0e=P00010000082000h3D005P0000X000000000000003oooooooooo`<000042>0e
00SM=@08f3Df000040000008003h<000F00003@00000000000000?oooooooooo1P000008m3042?0`
20S`<0d8l30@2?@`40Sh<3d0000800006`000100001H5@00R3@005T0000T000000000000003ooooo
ooooo`80002H5@Pdf1F8=3d000080000?00000P0000o0000600007h0000=0`00G`400603000C0000
30000040000U000030000000080U0000300000L0080T000090000000P440000000000000P4400000
00000080000X0000300000@0000R000030000?oooom60000700001000015CDH[140000`000000000
AP0001@000080000AdA9@`<000160000:00001`00017A4U30P000=<0000?0`00E`4003/300000000
AP0000P1003l0000ADe6:bY0000T000060000000P3l0000000000000P3l00000000000Q08P:L0000
T000004@`=/00000GQ0000000000080o0P000?l0000200000000@@80001H00000A30f`0000010000
0P0005IEED00000000000000000002110020?`000000000000000000000L00000A30f`<00000H000
0P3lo`00003nooco0061004@`=/000000000o`Q08`<X00007000004@`=/3000004000=@040?D03D3
E@4e0`010@0E@2<0400000@0000R00008@0000P0001R000030000040000T000090000000P3d00000
00000000P3d0000000000080001O0000>00000@0000h0000000003P0000000000181010000000000
0000000000000000000002D0000<0000100002D0000<00001@0001<0000<00000P0003/000080000
6`00010000103@00n30005T0000X000000000000003oooooooooo`<000103DPc>0e0<a<E@3=H0000
=000000000000000ooooooooool6000061E0<a/EA3<K5DPc6aE=<aPED3<C5E0c=P000100000h3@00
D3<005P0000X000000000000003oooooooooo`<0000d3E0c<0e=<c0=B3<f00004000030=003h<000
F00003@00000000000000?oooooooooo1P00030=m30d3O0`>0g`<3d=l3103O@`@0gh<3d000080000
6`0001000038500023<005T0000T000000000000003oooooooooo`8000185DPcb1B8<cd000080000
?00000P0000o000060000=40000=0`00EP4003X3000C000030000040000U000030000000080U0000
300000L0080T000090000000P440000000000000P440000000000080000X0000300000@0000R0000
30000?oooom60000700001000015CDH[140000`000000000AP0001@000080000AdA9@`<000160000
:00001`00017A4U30P0002<1000?0`00H04002/300000000AP0000`100000@00ADe6:bY0000T0000
60000000P3l0000000000000P3l00000000000Q090:L0000T000004@`=/00000GQ0000000000080o
0P000?l0000200000000@@80001H00000A30f`00000100000P0005IEED0000000000000000000211
0020?`000000000000000000000L00000A30f`<00000H0000P3lo`00003nooco0061004@`=/00000
0000o`Q09@</00008000004@`=/40000040002@140<T0AX3FP4J0eX1:@<00@415D0U010000040000
9000024000080000HP0000`000010000900002@00000080m000000000000080m0000000000020000
G`0003P000040000>0000000000h00000000000B0@0@0000000000000000000000000000000U0000
300000@0000U0000300000D0000C000030000080000k0000200001/0000@0000@1800?P`001I0000
:000000000000000ooooooooool30000@1:H<CPBT36H5I0aF00002P00000000000000?oooooooooo
0`0009dET36P5I@aX1FH<CH0000@0000X1D005<b001H0000=000000000000000ooooooooool60000
X1EH<YdEFc:H5E/bU1EK<Y0EF3:@5E<bF@0002P00000000000000?oooooooooo0`00090EV36H5J0a
>1:P<EP0000X000000000000003oooooooooo`<0000d4Z0a<1:M<C0BV34f00004000030B003h<000
F00003@00000000000000?oooooooooo1P00030Bm30d4_0`>1;`<3dBl3104_@`@1;h<3d000080000
6`000100003H5@00238005T0000T000000000000003oooooooooo`80002H5HPbF1D8<Sd000080000
?00000P0000o000060000241000=0`00G`4002X3000C000030000040000U000030000000080U0000
300000L0080T000090000000P440000000000000P440000000000080000X0000300000@0000R0000
30000?oooom60000700001000015CDH[140000`000000000AP0001@000080000AdA9@`<000160000
:00001`00017A4U30P000>L0001n0P00K@4002H300000000AP0001`1000@0@00ADe6:bY0000T0000
60000000P3l0000000000000P3l00000000000Q09P:L0000T000004@`=/00000GQ0000000000080o
0P000?l0000200000000@@80001H00000A30f`00000100000P0005IEED0000000000000000000211
0020?`000000000000000000000L00000A30f`<00000H0000P3lo`00003nooco0061004@`=/00000
0000o`Q09`<l0000<000004@`=/4000000000000J4<0`2M4001X@ono7d@0P;=3oklOA020/d<004U4
00410AE09`0@0000100002H0000Q000020000680000<00000@0002@0000T00000020?@0000000000
0020?@00000000000P0005l0000h0000100003P000000000>000000000004P404000000000000000
00000000000000009@0000`0000400009@0000`0000500004`0000`000020000>`0000P0000K0000
4000070>003X:@00=P000100001`3P00j2L005P0000X000000000000003oooooooooo`<0001`3^@W
M0kP9gP>h2Lf0000400006PF003P9`00F00002P00000000000000?oooooooooo0`0006dFh2M`5^@W
L1KX9cH0000@0000L1H000<b001H0000=000000000000000ooooooooool60000L1H8<VdF2c9X5P/b
I1H;<V0F239P5P<bF@0003000000000000000?oooooooooo1@00060Fj2MX5_0WN0k`9h0>j2N03^PY
F00003@00000000000000?oooooooooo1P00080>kBUm3_0YN0k`:G@>l2U`3^dYL0kX:Cd000080000
6`000100002X5P00^34005T0000T000000000000003oooooooooo`80001X5SPb:1Jh<Cd000080000
?00000P0000o000060000>D0001l0P00K04002D3000C000030000040000U000030000000080U0000
300000L0080T000090000000P440000000000000P440000000000080000X0000300000@0000R0000
30000?oooom60000700001000015CDH[140000`000000000AP0001@000080000AdA9@`<000160000
:00001`00017A4U30P000:P1000T0`00c@4004P300000000AP000=@000380000ADe6:bY0000T0000
60000000P3l0000000000000P3l00000000000Q0:0>@0000Q000004@`=/=000000000010gD<0@4U4
dF[H@`10BD@0P=A35BM;A020e4<0P4e4083D@n_HCdCAJ]Q30<1AA010gD<0`554;aGR@`30DD@00>I3
jmQ?A000iT<0P4e4003V@aDWBd@_5N930419A010gD<0@4U400<30`<30`<30`<3P`0001A0:80@0000
10000=gMgOlX0000300000D0000Q000020000680000<00000@0002@0000T00000020?@0000000000
0020?@00000000000P0002L0000H00001@000000003MgMd0000002D0000<00001@0001<0000<0000
0@0003/000080000E@0005000000000000000?oooooooooo3@000:0KB3866dPbR1[2<XPJF3>86^lc
1Q]X=:0KJ3@k76Pd^1c_<kPLF3>h7<8b>aa8<Z0KB38l0000200003h0000H0000Z04002@3003<0@00
A`<001<0000<00000@0002D0000<00000000P2@0000T00000020@@00000000000020@@0000000000
0P0004H0001P0000E00004E=AR/8@2T2@00003@000014<3K000005h0000000000020?`8000020000
0P000000044200000A30f`000000003o5D0X010000040000:@0002@0000T00000020?@0000000000
0020?@00000000000P0005l0000h0000100003P000000000>0000000000000404000000000000000
00000000000000009@0000`0000400009@0000`000050020E@000500002W0@008`<00<d100180`00
3@000:0KB3866dPbR1[2<XPJF3>86^lc1Q]X=:0KJ3@k76Pd^1c_<kPLF3>h7<8b>aa8<Z0KB38U0000
300000L0080U000030000000080T000090000000P440000000000000P440000000000080000X0000
300000@0000R000030000?oooom60000700001000015CDH[140000`000000000AP0001@000080000
AdA9@`<0000Q0000200001h0000H0000/@4002/300350@00@P<002D0000<00000`0002D0000<0000
3@00P2D0000<00000`0001@0000<00003@000180000<00000@0005@0001P0000/@4002/300300@00
>0<0004000000?Y1003j@K41000[0`000`0004`00000000000000000003ooooooooooe@0001E0580
B@0000L0000700000P0002D0000<00003@00P280000<0000ooooob40000800006@0000`0003oool0
600000`0000000007P0001P0000J00004@000>`3000]0P008P0000`0003ooooo600000`000000000
6@0000`0003oool09@0000`0000000209@0000`0000=0020AP0002P0000L0000AdA9@`80001h0@00
;P<00:/1000j0`00000004H000040@00n00004E=AR/Z@000900001P00000080o000000000000080o
000000000008@2X2W000090000014<3K000005h@000000000020?`80003o00000P00000004420000
F000004@`=/000000@000080001FEEE00000000000000000000P@@00P3l000000000000000000000
7000004@`=/3000006000080o?l00000o_olo`01P@014<3K000000000?l8@2/3900001P000014<3K
0P000010001i0CD3Z@4d0`01000E@2/0400000@0000Z0000:00000`0000500008@0000P0001R0000
30000040000T000090000000P3d0000000000000P3d0000000000080001O0000>00000D0000h0000
000003P00000000001810100000000000000000000000000000002D0000<00001@0002L0000H0000
1000000000000000000002D0000<0000100001<0000<00000P0003/0000800006`00010000285`00
@3<003H0000@0000DaX0038c001H0000=000000000000000ooooooooool60000EaXa<e/J=C=K6STc
FaXn<ePJ@C=C6T8c=P00010000295`00D3<005P0000d000000000000003oooooooooo`H000245e4c
PAM=<h0GBC>05d@cQ1M1<hPG@3<m0000200001/0000@00001aX00?/b001I00009000000000000000
ooooooooool20000R1Xh<`XJNc<m0000200003`000080000?`0001P0001f0@00;P<00:X1000j0`00
4`0000`0000100009@0000`0000000209@0000`000070020900002@0000008110000000000000811
0000000000020000:00000`0000500008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000
000004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80003<0000Q0800=H0002H0P00
000004H0000<0@00004004E=AR/Z@000900001P00000080o000000000000080o000000000008@2`2
Y00009P000014<3K000003`@00000000ZjZZ?ol0000200000000@@80001T00000A30f`0000010000
0P0000000400000000000000000002110020?`000000000000000000000X00000A30f`<000008000
ZjZZ?j^Z:/00000000000:^ZZ[n[ZR[00061004@`=/000000000o`Q0;@<T00006000004@`=/20000
04000=40U`;A08H2004001E0;@0@0000100002`0000Q000020000680000<00000@0002@0000T0000
0020?@00000000000020?@00000000000P0005l0000h00001@0003P000000000>000000000004P40
400000000000000000000000000000009@0000`0000500009@0000`0000400004`0000`000020000
F`000<@0003<0000Q0800=D0002H0P001`000280000500001@0000D0000500001@0000D000040000
oPaX:Oh<DbTC3E<Y4`eX:Oh<J2Wn33hYoP`X:A<=:2TC3ChYoP`n:Oh<4bWn3?hX4`gn:1<=4bWn31<Y
oPcX:?h<dbPC3M<X4`gX:?h<j2Sn3;hXoPbX:1<=Z2PC3KhXoPbn:?h<TbSn38<X4`f3:1<=TbSn39<X
gPb^:0P=F2Pc3JhXgPb^:1<0000<00000@0002D0000<00000000P2D0000<00001`00P2@0000T0000
0020@@00000000000020@@00000000000P0002P0000<00001@000280000<0000ooooodH0000L0000
400004E=AR/4@0003000000000160000500000P00017A4U30`0004H0000X0000700004M4BD<20000
TP0005D2002d0000MP80000000160000e0000<P00015CDH[:T0002@0000H00000020?`0000000000
0020?`0000000000240^0i00002400000A30f`d000000000000S@`205DBh:AY3080EA0004d<K?1M4
000C@`1P6D@001=3iH<KA;PY6T<0@1e4000S@`107DA8eR]3040MA000<d?UPa]4000c@`1P6D@003=3
6c`GA4SF:d<0P1E4000S@`205D@00`<30`<30`<30`>30000540^P10000040000ooooobP0000<0000
1000024000080000HP0000`000010000900002@00000080m000000000000080m0000000000020000
9`0001P00004000000000?ooo`0000009@0000`0000400004`0000`000010000>`0000P0001E0000
D000000000000000ooooooooool=0000:0YH9I/9F2DX2LLU:0U@9RP9fBJK2DPW:0Y89kH:B2LX2mTV
:0]@9RP;abFf2UPU:0YH9C`000080000?P0001P0002B0000E@800;<0001e0P004`0000`000010000
9@0000`000000020900002@00000081100000000000008110000000000020000AP000600001D0000
ADe6:`Q0;`900000=000004@`=/00000GP0000000000080o0P000080000200000000@@8000014<3K
000000000?lE@2h0400000@0000_0000900002@00000080m000000000000080m0000000000020000
G`0003P000050000>0000000000h0000000000000@0@0000000000000000000000000000000U0000
300000D0000U0000300000D0081E0000D0000940001D0P00]00007H2000=0000:0YH9I/9F2DX2LLU
:0U@9RP9fBJK2DPW:0Y89kH:B2LX2mTV:0]@9RP;abFf2UPU:0YH9BD0000<00001`00P2D0000<0000
0000P2@0000T00000020@@00000000000020@@00000000000P0002P0000<00001@000280000<0000
ooooodH0000L0000400004E=AR/4@0003000000000160000500000P00017A4U30`00024000080000
7P0001P0002K0000G0800:`0001`0P009@0000`0000300009@0000`0000=00209@0000`000030000
500000`0000=00004P0000`000010000E00005P0002K0000G0800:<0001Y0P000@000000nT400?Y1
V`0005`200020000C00000000000000000000?ooooooooooD00005<0B@0700000P0002D0000<0000
3@00P280000<0000ooooob40000800006@0000`0003oool0600000`0000000007P0001P0000J0000
4@000>`3000]0P008P0000`0003ooooo600000`0000000006@0000`0003oool09@0000`000000020
9@0000`0000=0020AP0002P0000L0000AdA9@`80001A0000E08007<0001e0P00000004H0003D0000
b00004E=AR/Z@000900001P00000080o000000000000080o000000000008@303T00008@000014<3K
3@00000000000<A2040EA71C/T80@1E4002T@Q_l5T@00:A2020IA000Y4;U@a]4L5>b@P007D@00<A2
000MA92/eD8001e4003T@^E36d@00>A2020IA000i48Ko1I4T:cE@P105D@00<A2040EA0030`<30`<3
0`<30h<0000D@320400000@0003ooooo8@0000P0001R000030000040000T000090000000P3d00000
00000000P3d0000000000080000U0000300000@0000C000030000040000k0000200005D0001@0000
00000000003oooooooooo`d0000H1TPUR`E89AP5]bDH1D0V60G99X/5>2LH1SPWYPHh9aP7bBHH1d0V
60Ng9JH6B2DH1TPU?00000P0000n000060000540001D0P00LP0007@2000C000030000040000U0000
30000000080T000090000000P440000000000000P44000000000008000160000H00005@00015CDH[
240a0T00000d00000A30f`00001N000000000000P3l200000P000080000000110P00004@`=/00000
0000oaE0<00@000010000340000T000090000000P3d0000000000000P3d0000000000080001O0000
>00000D0000h0000000003P00000000000010100000000000000000000000000000002D0000<0000
1@0002D0000<00001@00P5D0001@0000D00005<2001c0000M@8000d0000H1TPUR`E89AP5]bDH1D0V
60G99X/5>2LH1SPWYPHh9aP7bBHH1d0V60Ng9JH6B2DH1TPU9@0000`0000700209@0000`000000020
900002@00000081100000000000008110000000000020000:00000`0000500008P0000`0003ooooo
AP0001`0000@0000ADe6:`A0000<0000000004H0000D0000200004M4BD<300008@0000P0000N0000
600005X0001K0P00J`0006l2000U0000300000<0000U0000300000d0080U0000300000<0000D0000
300000d0000B000030000040001D0000F00005X0001K0P00IP0006P200010000003j@@00nT5J0000
F`800080001<00000000000000000000oooooooooom@0000D`1D00L0000600009@0000`0000=0020
8P0000`0003ooooo8@0000P0000I000030000?ooo`0H000030000000000N0000600001X0000A0000
k0<002d2000R000030000?oooolH000030000000000I000030000?ooo`0U000030000000080U0000
300000d008160000:00001`00017A4U30P000740001P0P00U@0006`200000000AP0000@1003h0000
ADe6:bY0000T000060000000P3l0000000000000P3l00000000000Q0<P:L0000T000004@`=/00000
GQ0000000000080o0P000?l0000200000000@@80001H00000A30f`00000100000P0005IEED000000
00000000000002110020?`000000000000000000000L00000A30f`<00000H0000P3lo`00003nooco
0061004@`=/000000000o`Q0<`<T00006000004@`=/2000004000780I@:C06H2004001E0<`0@0000
10000380000X0000300000@0000Q000020000680000<00000@0002@0000T00000020?@0000000000
0020?@00000000000P0005l0000h0000100003P000000000>000000000004P404000000000000000
00000000000000009@0000`0000400009`0001P00005000000000000000000009@0000`000050000
4`0000`000020000>`0000P0000K0000400001T700109P00=P000100003c2000CbH005P0000d0000
00000000003oooooooooo`H0003h24lVn`QC9_/8EbKk25`Vm`QO9_<8GbHf0000400001P7001@9P00
F00003@00000000000000?oooooooooo1P0001@7D2H@1ddV40M89Q47A2HD1d0V6@M09Sd000080000
6`000100002Z20005BH005T0000T000000000000003oooooooooo`80000X2EPVY`RE9Sd000080000
?00000P0000o0000600006l0001O0P00U00006/2000C000030000040000U000030000000080U0000
300000L0080T000090000000P440000000000000P440000000000080000X0000300000@0000R0000
30000?oooom60000700001000015CDH[140000`000000000AP0001@000080000AdA9@`<000160000
:00001`00017A4U30P000;80001U0P00aP0007`200000000AP0000@1003h0000ADe6:bY0000T0000
60000000P3l0000000000000P3l00000000000Q0=0:L0000T000004@`=/00000GQ0000000000080o
0P000?l0000200000000@@80001H00000A30f`00000100000P0005IEED0000000000000000000211
0020?`000000000000000000000L00000A30f`<00000H0000P3lo`00003nooco0061004@`=/00000
0000o`Q0=@<T00006000004@`=/2000004000;<0IP;107L2004001E0=@0@0000100003@0000Q0000
20000680000<00000@0002@0000T00000020?@00000000000020?@00000000000P0005l0000h0000
100003P000000000>000000000004P40400000000000000000000000000000009@0000`000040000
9@0000`0000500004`0000`000020000>`0000P0000K0000400002l;001C9P00=P000100003]2`00
>RL005P0000d000000000000003oooooooooo`H0003`2chWk`]39n`;ABOX2dPWh`]89n0;A2Lf0000
4000028;001N9P00F00003@00000000000000?oooooooooo1P0001l;FRHP2eDV8`]B9RL;CbH/2e0V
;`]C9Sd0000800006`000100003Y2`00gBH005T0000T000000000000003oooooooooo`80000836PW
QP/^9cd000080000?00000P0000o000060000;00001S0P00`P0007P2000C000030000040000U0000
30000000080U0000300000L0080T000090000000P440000000000000P440000000000080000X0000
300000@0000R000030000?oooom60000700001000015CDH[140000`000000000AP0001@000080000
AdA9@`<000160000:00001`00017A4U30P000:80001d0P00^P000:`200000000AP0001`1000@0@00
ADe6:bY0000T000060000000P3l0000000000000P3l00000000000Q0=P:L0000T000004@`=/00000
GQ0000000000080o0P000?l0000200000000@@80001H00000A30f`00000100000P0005IEED000000
00000000000002110020?`000000000000000000000L00000A30f`<00000H0000P3lo`00003nooco
0061004@`=/000000000o`Q0=`<l0000<000004@`=/40000000000008d<0@1e4000S@oNo8d@003A3
mklSA000=4<0P2Y400410AE0=`0@0000100003H0000Q000020000680000<00000@0002@0000T0000
0020?@00000000000020?@00000000000P0005l0000h0000100003P000000000>000000000004P40
400000000000000000000000000000009@0000`0000400009@0000`0000500004`0000`000020000
>`0000P0000K00004000030:00189`00F@0002P00000000000000?oooooooooo0`00030:j2PX2^0X
>0_P:5P0000X000000000000003oooooooooo`<0000m2n0X@0_T:40;j2Pf00004000040;001S:P00
F00003@00000000000000?oooooooooo1P00040;J2Xm2f/Z>0][:S@;JbX`2fPZ<0]S:UT0000X0000
00000000003oooooooooo`<0000`2nPX>0_`:2P:l2QH0000:000000000000000ooooooooool30000
90[`:20:kBPP2^PX=P000100000P2P00B2L005P0000d000000000000003oooooooooo`H0000P2T@W
90Y09bP:@2L]2T0W<0Y49c0:B2Lm0000200001/0000@0000N0/001PZ001I00009000000000000000
ooooooooool20000>0^H:_P:62Xm0000200003`000080000?`0001P0002P0000LP800;T0002[0P00
4`0000`0000100009@0000`0000000209@0000`000070020900002@0000008110000000000000811
0000000000020000:00000`0000400008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000
000004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80001K0000@08006L0001F0P00
000004H0002L0000T00004E=AR/Z@000900001P00000080o000000000000080o000000000008@3P3
F00004`000014<3K1`00000000000;Y20=0CA000_T80d1=4002n@P1044@00<I2040@A000aT80d1=4
003:@P3@4d@00<92000EA0010@410H40540hP10000040000ooooobP0000<00001@00024000080000
HP0000`000010000900002@00000080m000000000000080m00000000000200009`0001P000050000
00000?ooo`0000009@0000`0000500004`0000`0000100009@0000`000080020EP0003P0001L0000
@08006D0001D0P001`000<P5k2CX1N`Tj0D892P622@X1^`TB0K/90P6>2DU0000300000L0080C0000
30000040000U000030000000080T000090000000P440000000000000P44000000000008000160000
H00005@00015CDH[240i0T00000d00000A30f`00001N000000000000P3l200000P00008000000011
0P00004@`=/000000000oaE0>00@0000100003T0000T000090000000P3d0000000000000P3d00000
00000080001O0000>00000@0000h0000000003P00000000000010100000000000000000000000000
000002D0000<0000100002D0000<00001@00P5H0000h0000F`0003l2001V0000E@8000L000381N`T
j0G/9>P522@X1PPT:0K/94P6k2@81SPU9@0000`0000700209@0000`000000020900002@000000811
00000000000008110000000000020000:00000`0000400008P0000`0003oooooAP0001`0000@0000
ADe6:`A0000<0000000004H0000D0000200004M4BD<30000AP0002P0000L0000AdA9@`80002]0000
bP800<H0003[0P00000004H0002L0000T00004E=AR/Z@000900001P00000080o000000000000080o
000000000008@3X3F00004`000014<3K1`000000003?^SY3>?PcA0T1?D<XFcA4?Z/^@mjP>DBb=c=3
_fHjA7j=@D<:8CE4^==3@o^3=DB73TA3<_`bA0010@410H40540jP10000040000ooooob4000080000
HP0000`000010000900002@00000080m000000000000080m00000000000200009@0000`000050000
4`0000`0000100009@0000`000080020EP0003P0002^0000b`800<@0003Z0P001`000:@;mbc92`l]
h`YQ;R`;TRhA344]=PaI;CT<^2`U0000300000L0080C000030000040000U000030000000080T0000
90000000P440000000000000P44000000000008000160000H00005@00015CDH[240k0T00000d0000
0A30f`00001N000000000000P3l200000P000080000000110P00004@`=/000000000oaE0>P0@0000
100003/0000T000090000000P3d0000000000000P3d0000000000080001O0000>00000@0000h0000
000003P00000000000010100000000000000000000000000000002D0000<0000100002D0000<0000
1@00P5H0000h0000[0000<X200360000j`8000L0002T2oL/b@/?;N<:HBh/2i8^4@a1;CH<FBdi3;P/
9@0000`0000700209@0000`000000020900002@00000081100000000000008110000000000020000
:00000`0000400008P0000`0003oooooAP0001`0000@0000ADe6:`A0000<0000000004H0000D0000
200004M4BD<30000AP0001@000080000AdA9@`<0000H000030000000000I000030000?ooo`0U0000
30000000080U0000300000d0080R000030000?oooom60000=00002P00015CDH[:T0002@0000H0000
0020?`00080000200020?`00080000208@0000P0001R000030000040001<0000I0000540003Z0@00
c04006<3001A0000jP4007`1001j0@00:@2Z0000000000000020?`00000000000020?`0000000000
000000000000000000000000000000008P0000`0003oooooAP0001`0000@0000ADe6:`90000<0000
000000h0000D000000000100000D0000
\>"], "Text",
 ImageSize->{336.625, 330.438},
 ImageMargins->{{0, 0}, {0, 0}},
 ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[StyleBox["Fig 1 represents a diagram flow where are included \
all ICRP 30 elements. All elements have compartments B, LLI, ULI, BL and URI \
however the number of systemic compartments change (the maximum is three: a, \
b and c) depending on the element . The same happen of the flow. ",
 FormatType->StandardForm]], "Text"],

Cell[TextData[{
 "Compartments numbers: Blood (1), ",
 StyleBox["a",
  FontWeight->"Bold"],
 " or SysA (2), ",
 StyleBox["b",
  FontWeight->"Bold"],
 " or  SysB (3), ",
 StyleBox["c",
  FontWeight->"Bold"],
 " or SysC (4), Bladder (5), URI (6), ULI (7), LLI(8) and FEC(9).  If a \
element has only 2 systemic compartments the numbers (since bladder) will \
decrease in minus 1"
}], "Text"],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "u"], TraditionalForm]]],
 " = fraction from Sys i to BL\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "f"], TraditionalForm]]],
 " = fraction from Sys i to ULI \n",
 Cell[BoxData[
  RowBox[{
   StyleBox[
    SubscriptBox["T", "i"],
    FormatType->StandardForm,
    FontFamily->"Times New Roman"], 
   StyleBox["=",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"], 
   StyleBox[" ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"], 
   RowBox[{
    StyleBox["{",
     FormatType->StandardForm,
     FontFamily->"Times New Roman"], 
    RowBox[{
     FormBox[
      SubscriptBox["T", "a"],
      TraditionalForm], 
     StyleBox[",",
      FormatType->StandardForm,
      FontFamily->"Times New Roman"], 
     StyleBox[" ",
      FormatType->StandardForm,
      FontFamily->"Times New Roman"], 
     FormBox[
      SubscriptBox["T", "b"],
      TraditionalForm], 
     StyleBox[",",
      FormatType->StandardForm,
      FontFamily->"Times New Roman"], 
     StyleBox[" ",
      FormatType->StandardForm,
      FontFamily->"Times New Roman"], 
     FormBox[
      SubscriptBox["T", "c"],
      TraditionalForm]}], 
    StyleBox["}",
     FormatType->StandardForm,
     FontFamily->"Times New Roman"]}], 
   StyleBox[" ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"]}]]],
 "where ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "i"], TraditionalForm]]],
 "= Log(2)/",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "i"], TraditionalForm]]],
 " with ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]]],
 " = {SysA, SysB, SysC}\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "i"], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  RowBox[{
   StyleBox[" ",
    FormatType->StandardForm,
    FontFamily->"Times New Roman"], 
   RowBox[{
    StyleBox["{",
     FormatType->StandardForm,
     FontFamily->"Times New Roman"], 
    RowBox[{
     SubscriptBox["f", "SYA"], 
     StyleBox[",",
      FormatType->StandardForm,
      FontFamily->"Times New Roman"], 
     StyleBox[" ",
      FormatType->StandardForm,
      FontFamily->"Times New Roman"], 
     SubscriptBox["f", "SYB"], 
     StyleBox[",",
      FormatType->StandardForm,
      FontFamily->"Times New Roman"], 
     StyleBox[" ",
      FormatType->StandardForm,
      FontFamily->"Times New Roman"], 
     SubscriptBox["f", "SYC"]}], 
    StyleBox["}",
     FormatType->StandardForm,
     FontFamily->"Times New Roman"]}]}]]],
 " fraction from compartment B to compartment ",
 Cell[BoxData[
  FormBox["i", TraditionalForm]]],
 " . \n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "R"], TraditionalForm]]],
 " = fraction from compartment B .It must be verified ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "R"], TraditionalForm]]],
 " + ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Sum]", 
    SubscriptBox["f", "i"]}], TraditionalForm]]],
 " = 1 \[Rule]  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "R"], TraditionalForm]]],
 "= 1 -  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Sum]", 
    SubscriptBox["f", "i"]}], TraditionalForm]]],
 "  (for same elements ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "R"], TraditionalForm]]],
 "=0)\n",
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "B"], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"Log", "[", "2", "]"}], "/", 
   SubscriptBox["k", "B"]}]]],
 "where ",
 Cell[BoxData[
  SubscriptBox["k", "B"]]],
 " = total rate transfer from B."
}], "Text"],

Cell[TextData[{
 StyleBox["The information of {",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "u"], TraditionalForm]]],
 StyleBox[", ",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"],
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "f"], TraditionalForm]]],
 StyleBox[",", "Input",
  FormatType->StandardForm,
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "i"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "i"], TraditionalForm]]],
 ", ",
 StyleBox["and ", "Input",
  FormatType->StandardForm,
  FontFamily->"Times New Roman",
  FontWeight->"Plain",
  FontVariations->{"CompatibilityType"->0}],
 Cell[BoxData[
  FormBox[
   SubscriptBox["T", "B"], TraditionalForm]]],
 StyleBox[" }", "Input",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"],
 StyleBox[" are summarized in Potter CA, Health Phys 83:775-779  (table E3).; \
2002. \"Metabolic parameters for elements using ICRP 30 metabolic model \
structure\". Not always these match with ICRP 78 (i.e Cf-252).\n",
  FormatType->StandardForm,
  FontFamily->"Times New Roman"],
 "The examples 2 and 3 shown the solution for cobalt",
 StyleBox["\:f35f",
  FormatType->StandardForm]
}], "Text"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Examples", "SubsectionIcon"],

Cell["\<\
These examples, including the information about the method of the \
measurements (minimum detectable activity, precision, etc)  are based in the \
report:  Direct Method for Measuring Radionuclides in the Human Body.  IAEA \
Safety Series No. 114. Vienna 1996.\
\>", "Text"],

Cell[CellGroupData[{

Cell[TextData[{
 "EXAMPLE 1 .- Lung counter applied to estimate the uranium intake ",
 StyleBox["I",
  FontSlant->"Italic"],
 " by inhalation (being  ",
 StyleBox["I",
  FontSlant->"Italic"],
 " and the AMAD ",
 StyleBox["p",
  FontSlant->"Italic"],
 " unknown)"
}], "SubsubsectionIcon"],

Cell[TextData[{
 "A worker has accidentally intaken by inhalation an unknown ",
 StyleBox["I",
  FontSlant->"Italic"],
 " quantity of UO",
 StyleBox["2",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 " enriched 4.4 % ",
 StyleBox["235",
  FontVariations->{"CompatibilityType"->"Superscript"}],
 "U being the AMAD  ",
 StyleBox["p",
  FontSlant->"Italic"],
 " also unknown. We wish to estimate ",
 StyleBox["I",
  FontSlant->"Italic"],
 " measuring the uranium lung content using a lung body counter. It will be \
assumed that the worker has not previously been exposed to significant \
uranium intakes.  "
}], "Text"],

Cell[TextData[{
 "Note.- The enriched uranium is composed  of  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "234"], TraditionalForm]]],
 "U , ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["", "235"], "U"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["", "238"], "U"}], TraditionalForm]]],
 ". The lung counters usually measure only the ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["", "235"], "U"}], TraditionalForm]]],
 " content. However, given that the isotopic composition is usually known \
then ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["", "234"], "U"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["", "238"], "U"}], TraditionalForm]]],
 " can be derivated from the  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["", "235"], "U"}], TraditionalForm]]],
 " measured. So for the enriched 4.4 % ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["", "235"], "U"}], TraditionalForm]]],
 ", the activity for ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["", "235"], "U"}], TraditionalForm]]],
 " is 3.5%  this means that if it 3.5 Bq of  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["", "235"], "U"}], TraditionalForm]]],
 " is measured with the lung counter then the uranium content will be 100 Bq. \
 Also, the disintegration constants can be assumed \[OpenCurlyDoubleQuote]0\
\[CloseCurlyDoubleQuote]  for all uranium isotopes because their half-live \
are too long ",
 StyleBox[" ",
  FontFamily->"Courier"]
}], "Commentary"],

Cell[TextData[{
 "The minimum detectable activity (MDA), according IAEA 1996 (VIII-5) of  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "235"], TraditionalForm]]],
 "U is 7 \[Dash] 14 Bq with phoswich detector and 4 \[Dash] 6 Bq with array \
germanium detectors. Based in MDA = 3.3 \[Sigma] , therefore that is  \
\[Sigma]: 1.2 \[Dash] 1.8 Bq . We will assumed   ",
 Cell[BoxData[
  FormBox["\[Sigma]", TraditionalForm]]],
 " = 2."
}], "Text"],

Cell[TextData[{
 "To define the optimal design the first step to obtain the lung retention \
function ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    FormBox[
     SubscriptBox["R", "Lung"],
     TraditionalForm], 
    RowBox[{"(", 
     StyleBox[
      RowBox[{"I", ",", "p", ",", "t"}],
      FontSlant->"Italic"], ")"}]}], "=", 
   RowBox[{
    FormBox["I",
     TraditionalForm], " ", 
    FormBox[
     SubscriptBox["r", 
      RowBox[{"Lung", " "}]],
     TraditionalForm], 
    RowBox[{"(", 
     StyleBox[
      RowBox[{"t", ",", " ", "p"}],
      FontSlant->"Italic"], ")"}], " "}]}]]],
 " for these kind of radioactive aerosols. The terms negligable are dropped. "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"rlung", "[", 
   RowBox[{"t_", ",", "p_"}], "]"}], "=", 
  RowBox[{
   RowBox[{"Drop", "[", 
    RowBox[{
     RowBox[{"LungsRetention", "[", 
      RowBox[{"1", ",", 
       RowBox[{"AMADfit", "[", "p", "]"}], " ", ",", "S", ",", " ", "t", ",", 
       "0"}], "]"}], ",", " ", "42"}], "]"}], "//", "Chop"}]}]], "Input",
 CellLabel->"In[29]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"-", "0.00018605256811968248`"}], " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4.353270952537328`"}], " ", "p"}], "-", 
     RowBox[{"2.0001`", " ", "t"}]}]]}], "-", 
  RowBox[{"0.000533918166731499`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.17011061305604133`"}], " ", "p"}], "-", 
     RowBox[{"2.0001`", " ", "t"}]}]]}], "-", 
  RowBox[{"0.0000805062825693618`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.14724386061421538`"}], " ", "p"}], "-", 
     RowBox[{"2.0001`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.01249151512995244`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.08789446045802779`"}], " ", "p"}], "-", 
     RowBox[{"2.0001`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.021327132038364522`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4.353270952537328`"}], " ", "p"}], "-", 
     RowBox[{"0.0301`", " ", "t"}]}]]}], "-", 
  RowBox[{"0.011072857510727818`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1.1114709327884795`"}], " ", "p"}], "-", 
     RowBox[{"0.0301`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.009228403217579801`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.14724386061421538`"}], " ", "p"}], "-", 
     RowBox[{"0.0301`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.011072857510727818`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.1235776148578769`"}], " ", "p"}], "-", 
     RowBox[{"0.0301`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.03888349783829052`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.17011061305604133`"}], " ", "p"}], "-", 
     RowBox[{"0.0201`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.07688147210756655`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.17011061305604133`"}], " ", "p"}], "-", 
     RowBox[{"0.0011`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.010672344382830311`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.17011061305604133`"}], " ", "p"}], "-", 
     RowBox[{"0.00022`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.000148842054495746`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "4.353270952537328`"}], " ", "p"}], "-", 
     RowBox[{"0.0001`", " ", "t"}]}]]}], "-", 
  RowBox[{"0.00007751000257509473`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "1.1114709327884795`"}], " ", "p"}], "-", 
     RowBox[{"0.0001`", " ", "t"}]}]]}], "-", 
  RowBox[{"0.0001200966353797955`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.5667829354923091`"}], " ", "p"}], "-", 
     RowBox[{"0.0001`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.0021343151963437667`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.17011061305604133`"}], " ", "p"}], "-", 
     RowBox[{"0.0001`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.00006440502605548944`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.14724386061421538`"}], " ", "p"}], "-", 
     RowBox[{"0.0001`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.00007751000257509473`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.1235776148578769`"}], " ", "p"}], "-", 
     RowBox[{"0.0001`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.00007044560395542161`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.08789446045802779`"}], " ", "p"}], "-", 
     RowBox[{"0.0001`", " ", "t"}]}]]}], "+", 
  RowBox[{"0.0001200966353797955`", " ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{
      RowBox[{"-", "0.05778349162703789`"}], " ", "p"}], "-", 
     RowBox[{"0.0001`", " ", "t"}]}]]}]}]], "Output",
 CellChangeTimes->{3.39902276338704*^9, 3.3990230854696426`*^9, 
  3.399024183148035*^9, 3.479969379776038*^9, 3.541920106700268*^9, 
  3.5920608294686165`*^9, 3.6436166947881627`*^9, 3.6562357570045176`*^9},
 CellLabel->"Out[29]="]
}, Open  ]],

Cell[TextData[{
 Cell[BoxData["Optdes"], "Input"],
 " is used the define a n-point design taken as initial values ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 "=0.5, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "o"], TraditionalForm]]],
 "= 1000; ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["p", "0"], TraditionalForm]]],
 " = 5 , \[Rho] = 1"
}], "MathCaption"],

Cell["\<\
Here it is computed the design for different n-points  using \[Rho] =1.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opdEj1", " ", "=", " ", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{"Optdes", "[", 
        RowBox[{
         RowBox[{"inp", " ", 
          RowBox[{"rlung", "[", 
           RowBox[{"t", ",", "p"}], "]"}]}], ",", " ", "t", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"inp", ",", "1000"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"p", ",", " ", "5"}], "}"}]}], "}"}], " ", ",", "  ", 
         "0.5", ",", " ", "1", ",", " ", "2", ",", " ", "n"}], "]"}]}], "}"}],
      ",", " ", 
     RowBox[{"{", 
      RowBox[{"n", ",", " ", "1", ",", " ", "3"}], "}"}]}], "]"}], "//", 
   "TableForm"}]}]], "Input",
 CellLabel->"In[30]:="],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"1", GridBox[{
       {"0.00003343701331241558`", "\<\"\"\>"},
       {
        RowBox[{
         SubscriptBox["t", "0"], "\[Rule]", "0.5`"}], 
        RowBox[{
         SubscriptBox["t", "1"], "\[Rule]", "70.22984338183775`"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"2", GridBox[{
       {"0.00006680912480883052`", "\<\"\"\>", "\<\"\"\>"},
       {
        RowBox[{
         SubscriptBox["t", "0"], "\[Rule]", "0.5`"}], 
        RowBox[{
         SubscriptBox["t", "1"], "\[Rule]", "66.17797592273358`"}], 
        RowBox[{
         SubscriptBox["t", "2"], "\[Rule]", "74.78569994274648`"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"3", GridBox[{
       {"0.00009909762852654326`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
       {
        RowBox[{
         SubscriptBox["t", "0"], "\[Rule]", "0.5`"}], 
        RowBox[{
         SubscriptBox["t", "1"], "\[Rule]", "5.474209679855997`"}], 
        RowBox[{
         SubscriptBox["t", "2"], "\[Rule]", "76.73143268473505`"}], 
        RowBox[{
         SubscriptBox["t", "3"], "\[Rule]", "85.3860920359406`"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{
    1, {0.00003343701331241558, {
      Subscript[$CellContext`t, 0] -> 0.5, Subscript[$CellContext`t, 1] -> 
       70.22984338183775}}}, {
    2, {0.00006680912480883052, {
      Subscript[$CellContext`t, 0] -> 0.5, Subscript[$CellContext`t, 1] -> 
       66.17797592273358, Subscript[$CellContext`t, 2] -> 
       74.78569994274648}}}, {
    3, {0.00009909762852654326, {
      Subscript[$CellContext`t, 0] -> 0.5, Subscript[$CellContext`t, 1] -> 
       5.474209679855997, Subscript[$CellContext`t, 2] -> 76.73143268473505, 
       Subscript[$CellContext`t, 3] -> 85.3860920359406}}}}]]], "Output",
 CellChangeTimes->{3.3990227782395296`*^9, 3.3990230976597166`*^9, 
  3.3990241983825073`*^9, 3.479969411626038*^9, 3.5419201235287156`*^9, 
  3.592060860117318*^9, 3.6436167006162972`*^9, 3.656235761504549*^9},
 CellLabel->"Out[30]//TableForm="]
}, Open  ]],

Cell["\<\
Here it is assumed that there are not corretations  between samples.\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"n", ",", 
       RowBox[{"Optdes", "[", 
        RowBox[{
         RowBox[{"inp", " ", 
          RowBox[{"rlung", "[", 
           RowBox[{"t", ",", "p"}], "]"}]}], ",", " ", "t", ",", " ", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"{", 
            RowBox[{"inp", ",", "1000"}], "}"}], ",", 
           RowBox[{"{", 
            RowBox[{"p", ",", " ", "5"}], "}"}]}], "}"}], " ", ",", "  ", 
         "0.5", ",", " ", "\"\<NoCorrelation\>\"", ",", " ", "2", ",", " ", 
         "n"}], "]"}]}], "}"}], ",", " ", 
     RowBox[{"{", 
      RowBox[{"n", ",", " ", "1", ",", " ", "3"}], "}"}]}], "]"}], "//", 
   "TableForm"}]}]], "Input",
 CellLabel->"In[31]:="],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"1", GridBox[{
       {"0.00003343701331241309`", "\<\"\"\>"},
       {
        RowBox[{
         SubscriptBox["t", "0"], "\[Rule]", "0.5`"}], 
        RowBox[{
         SubscriptBox["t", "1"], "\[Rule]", "70.22986557819955`"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"2", GridBox[{
       {"0.00006687328766286916`", "\<\"\"\>", "\<\"\"\>"},
       {
        RowBox[{
         SubscriptBox["t", "0"], "\[Rule]", "0.5`"}], 
        RowBox[{
         SubscriptBox["t", "1"], "\[Rule]", "69.74882240641223`"}], 
        RowBox[{
         SubscriptBox["t", "2"], "\[Rule]", "70.76516662642273`"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"3", GridBox[{
       {"0.00010030763692175109`", "\<\"\"\>", "\<\"\"\>", "\<\"\"\>"},
       {
        RowBox[{
         SubscriptBox["t", "0"], "\[Rule]", "0.5`"}], 
        RowBox[{
         SubscriptBox["t", "1"], "\[Rule]", "68.82807381566799`"}], 
        RowBox[{
         SubscriptBox["t", "2"], "\[Rule]", "69.82875786957165`"}], 
        RowBox[{
         SubscriptBox["t", "3"], "\[Rule]", "70.82875787326246`"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{
    1, {0.00003343701331241309, {
      Subscript[$CellContext`t, 0] -> 0.5, Subscript[$CellContext`t, 1] -> 
       70.22986557819955}}}, {
    2, {0.00006687328766286916, {
      Subscript[$CellContext`t, 0] -> 0.5, Subscript[$CellContext`t, 1] -> 
       69.74882240641223, Subscript[$CellContext`t, 2] -> 
       70.76516662642273}}}, {
    3, {0.00010030763692175109`, {
      Subscript[$CellContext`t, 0] -> 0.5, Subscript[$CellContext`t, 1] -> 
       68.82807381566799, Subscript[$CellContext`t, 2] -> 69.82875786957165, 
       Subscript[$CellContext`t, 3] -> 70.82875787326246}}}}]]], "Output",
 CellChangeTimes->{3.3990227885268335`*^9, 3.3990231078798523`*^9, 
  3.399024208773199*^9, 3.479969423836038*^9, 3.541920132185132*^9, 
  3.5920608711607018`*^9, 3.6436167025694246`*^9, 3.6562357643014355`*^9},
 CellLabel->"Out[31]//TableForm="]
}, Open  ]],

Cell[TextData[StyleBox["Simulation and fitting data",
 FontWeight->"Bold"]], "Text"],

Cell[TextData[{
 "We simulate the lung measured in the moment predicted by the optimal design \
assuming an \"unknown\" intake of 850 Bq of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "235"], TraditionalForm]]],
 "U  with AMAD 7 \[Mu]m in ",
 Cell[BoxData[
  FormBox[
   RowBox[{"t", " ", "=", " ", "0"}], TraditionalForm]]],
 " (a random noise N(\[Mu]=0, \[Sigma]=2)  is included ). "
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"uraniumLungRet", "[", 
    RowBox[{"t_", ",", "int_", ",", " ", "p_"}], "]"}], ":=", 
   RowBox[{
    StyleBox["LungsRetention", "Input"], "[", 
    RowBox[{"int", ",", 
     RowBox[{"AMADAdultW", "[", "p", "]"}], ",", "S", ",", " ", "t", ",", 
     "0"}], "]"}]}], ";"}]], "Input",
 CellLabel->"In[32]:="],

Cell[BoxData[
 RowBox[{"SeedRandom", "[", "110", "]"}]], "Input",
 CellLabel->"In[33]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"daymeasured", " ", "=", " ", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      SubscriptBox["t", "i"], ",", " ", 
      RowBox[{"{", 
       RowBox[{"i", ",", " ", "0", ",", " ", "3"}], "}"}]}], "]"}], "/.", 
    RowBox[{"opdEj1", "[", 
     RowBox[{"[", 
      RowBox[{"1", ",", "3", ",", "2", ",", "2"}], "]"}], "]"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{
  3.399023228029704*^9, {3.3990232778147774`*^9, 3.399023278736723*^9}, {
   3.3990233354129505`*^9, 3.3990233392101173`*^9}},
 CellLabel->"In[34]:="],

Cell["\<\
 Here is simulated the uncertainty of the measured system (it only simulates \
the uncertainties of the measured system)\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sampleLung", " ", "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"#", ",", 
       RowBox[{
        RowBox[{"uraniumLungRet", "[", 
         RowBox[{"#", ",", "850", ",", " ", "7"}], "]"}], "+", 
        RowBox[{"Random", "[", 
         RowBox[{"NormalDistribution", "[", 
          RowBox[{"0", ",", " ", "2"}], "]"}], "]"}]}]}], "}"}], "&"}], ",", 
    "daymeasured"}], "]"}]}]], "Input",
 CellLabel->"In[35]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.5`", ",", "40.52996258649016`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5.474209679855997`", ",", "37.66671862108089`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"76.73143268473505`", ",", "21.89859672879357`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"85.3860920359406`", ",", "24.321094238848953`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399022790825061*^9, 3.3990233461481495`*^9, 
  3.399023689455632*^9, 3.3990242088982*^9, 3.479969425213038*^9, 
  3.54192013232576*^9, 3.5920608716694927`*^9, 3.64361670264755*^9, 
  3.6562357643639235`*^9},
 CellLabel->"Out[35]="]
}, Open  ]],

Cell["The best fit parameters are", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"inputAcute", ",", " ", "pp"}], "}"}], "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"int", ",", " ", "p"}], "}"}], "/.", 
   RowBox[{"FindFit", "[", 
    RowBox[{"sampleLung", ",", 
     RowBox[{"int", " ", 
      RowBox[{"rlung", "[", 
       RowBox[{"t", ",", "p"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"int", ",", "500", ",", "1000"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"p", ",", "3", ",", "10"}], "}"}]}], "}"}], ",", "t"}], 
    "]"}]}]}]], "Input",
 CellLabel->"In[36]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"891.7816519199913`", ",", "7.465315153472123`"}], "}"}]], "Output",
 CellChangeTimes->{3.3990227912628183`*^9, 3.399023358680362*^9, 
  3.3990236925494413`*^9, 3.399024208945075*^9, 3.4799694259400377`*^9, 
  3.541920132388261*^9, 3.592060871915762*^9, 3.6436167026788006`*^9, 
  3.6562357643951864`*^9},
 CellLabel->"Out[36]="]
}, Open  ]],

Cell["\<\
The agree between experimental and the fitted function is  good\
\>", "MathCaption",
 CellChangeTimes->{3.3990237115810566`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"Evaluate", "[", 
    RowBox[{"uraniumLungRet", "[", 
     RowBox[{"t", ",", "inputAcute", ",", " ", "pp"}], "]"}], "]"}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", " ", "100"}], "}"}], ",", " ", "\n", "  ", 
   RowBox[{"Epilog", " ", "->", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Hue", "[", "0.", "]"}], ",", " ", 
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", " ", 
      RowBox[{"Map", "[", 
       RowBox[{"Point", ",", "sampleLung"}], " ", "]"}]}], "}"}]}], ",", " ", 
   RowBox[{"PlotRange", " ", "->", 
    RowBox[{"{", 
     RowBox[{"20", ",", "50"}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[37]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwd1HlUjXsXB/AmbjQK1SVXKW9db9KR51Qqv2/Pc1IXKQ16QqS6iuYkXUOS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     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 20.},
  DisplayFunction->Identity,
  Epilog->{
    Hue[0.], 
    PointSize[0.02], {
     PointBox[{0.5, 40.52996258649016}], 
     PointBox[{5.474209679855997, 37.66671862108089}], 
     PointBox[{76.73143268473505, 21.89859672879357}], 
     PointBox[{85.3860920359406, 24.321094238848953`}]}},
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0., 99.99999795918367}, {20, 50}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {0, 0}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.399022791481697*^9, 3.399023702784013*^9, 
  3.3990242092732024`*^9, 3.4799694264390383`*^9, 3.5419201326226406`*^9, 
  3.592060872489558*^9, 3.6436167027569275`*^9, 3.6562357644576883`*^9},
 CellLabel->"Out[37]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "EXAMPLE 2 .- Whole body counter applied to estimation of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "60"], TraditionalForm]]],
 "Co intake by ingestion (being ",
 StyleBox["I",
  FontSlant->"Italic"],
 " and the ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 " unknown)"
}], "SubsubsectionIcon"],

Cell[TextData[{
 "An adult male has been exposed to a simple accidental intake by ingestion \
of  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "60"], TraditionalForm]]],
 "Co being both ",
 StyleBox["I",
  FontSlant->"Italic"],
 " and the fractional absorption  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 " unknown. The aim is to estimate ",
 StyleBox["I",
  FontSlant->"Italic"],
 " using a whole body counter. It will be assumed that the individual has not \
been previously exposed to a negligible ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "60"], TraditionalForm]]],
 "Co intake.  "
}], "Text"],

Cell[TextData[{
 "The minimum detectable activity (MDA), according IAEA 1996 (Table V-1) of  ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "60"], TraditionalForm]]],
 "Co is 28 Bq. Based in MDA = 3.3 \[Sigma] , therefore that is  \[Sigma] = \
8.5 Bq . We will assumed   ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Sigma]", "2"], TraditionalForm]]],
 " = 72."
}], "Text"],

Cell[TextData[StyleBox["Obtaining the whole body retention function",
 FontWeight->"Bold"]], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"CompartNumbers", "[", "cobalt", "]"}]], "Input",
 CellLabel->"In[38]:="],

Cell[BoxData[
 TagBox[GridBox[{
    {"1", "\<\"Blood\"\>"},
    {"2", "\<\"Systemic A\"\>"},
    {"3", "\<\"Systemic B\"\>"},
    {"4", "\<\"Systemic C\"\>"},
    {"5", "\<\"Bladder\"\>"},
    {"6", "\<\"Urine\"\>"},
    {"7", "\<\"ULI\"\>"},
    {"8", "\<\"LLI\"\>"},
    {"9", "\<\"FEC\"\>"}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output",
 CellChangeTimes->{3.3990227915755024`*^9, 3.3990242092888274`*^9, 
  3.4799694265240383`*^9, 3.5419201326382656`*^9, 3.5920608727083254`*^9, 
  3.643616702788175*^9, 3.6562357644576883`*^9},
 CellLabel->"Out[38]//TableForm="]
}, Open  ]],

Cell["The GI compartments much be added ", "Text"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"Bladder (n-4) to urine(n-3)\"\>", "\<\"k[n-4,n-3]->\"\>", "12"},
    {"\<\"ULI (n-2) to LLI(n-1)\"\>", "\<\"k[n-2,n-1]->\"\>", 
     SubscriptBox["k", "ULI"]},
    {"\<\"LLI (n-1) to FEC(n)\"\>", "\<\"k[n-1,n]->\"\>", 
     SubscriptBox["k", "LLI"]},
    {"\<\"SI (n+1) to ULI(n-2)\"\>", "\<\"k[n+1,n-2]->\"\>", 
     SubscriptBox["k", "SI"]},
    {"\<\"ST (n+2) to SI (n+1)\"\>", "\<\"k[n+2,n+1]->\"\>", 
     SubscriptBox["k", "ST"]},
    {"\<\"SI (n+1) to B(1)\"\>", "\<\"k[n+1,1]->\"\>", 
     RowBox[{
      SubscriptBox["f", "B"], " ", 
      SubscriptBox["k", "SI"]}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  Function[BoxForm`e$, 
   TableForm[BoxForm`e$]]]], "Output"],

Cell["Then the cobalt compartmental matrix is ", "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{"cobaltextended", " ", "=", 
   RowBox[{
    RowBox[{"Join", "[", " ", 
     RowBox[{
      RowBox[{"icrp30Model", "[", 
       RowBox[{
        RowBox[{"6", "/", "7"}], ",", 
        RowBox[{"1", "/", "7"}], ",", 
        RowBox[{"{", 
         RowBox[{"6", ",", " ", "60", 
          StyleBox[" ",
           FormatType->StandardForm,
           FontFamily->"Times New Roman"], 
          StyleBox[",",
           FormatType->StandardForm,
           FontFamily->"Times New Roman"], 
          StyleBox[" ",
           FormatType->StandardForm,
           FontFamily->"Times New Roman"], 
          StyleBox["800",
           FormatType->StandardForm,
           FontFamily->"Times New Roman"]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"3", "/", "10"}], ",", 
          RowBox[{"1", "/", "10"}], ",", 
          RowBox[{"1", "/", "10"}]}], "}"}], ",", 
        RowBox[{"1", "/", "2"}]}], "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"11", ",", "10", ",", 
          SubscriptBox["k", "ST"]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"10", ",", "1", ",", 
          RowBox[{
           SubscriptBox["f", "B"], " ", 
           SubscriptBox["k", "SI"]}]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"10", ",", "7", ",", " ", 
          SubscriptBox["k", "SI"]}], "}"}]}], "}"}]}], "]"}], "/.", 
    RowBox[{"Rationalize", "[", 
     RowBox[{"Options", "[", "qGI", "]"}], "]"}]}]}], ";"}]], "Input",
 CellLabel->"In[39]:="],

Cell[TextData[{
 "The content in each compartment, for ",
 StyleBox["I",
  FontSlant->"Italic"],
 " = 1, is given by  "
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["q", "1"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "2"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "3"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "4"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "5"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "6"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "7"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "8"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "9"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "10"], "[", "t_", "]"}], ",", 
     RowBox[{
      SubscriptBox["q", "11"], "[", "t_", "]"}]}], "}"}], "=", 
   RowBox[{
    RowBox[{"MatrixExp", "[", 
     RowBox[{
      RowBox[{"CompartMatrix", "[", 
       RowBox[{"11", ",", "cobaltextended"}], "]"}], " ", "t"}], "]"}], ".", 
    RowBox[{"{", 
     RowBox[{
     "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", "0", ",", 
      "0", ",", "0", ",", " ", "0", ",", "1"}], "}"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.3990238438802385`*^9, 3.3990238444583673`*^9}},
 CellLabel->"In[40]:="],

Cell[TextData[{
 "The whole body content as function of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 "and ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 " is (note are obtained sum all compartment content except compartment 6 \
(urine) and 9 (fecal)"
}], "MathCaption"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"rWBCo", "[", 
    RowBox[{"t_", ",", "fn1_"}], "]"}], "=", 
   RowBox[{"Block", "[", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"f1", "=", " ", "fn1"}], "}"}], ",", 
     RowBox[{"Plus", "@@", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{
         SubscriptBox["q", "1"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["q", "2"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["q", "3"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["q", "4"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["q", "5"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["q", "7"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["q", "8"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["q", "10"], "[", "t", "]"}], ",", 
        RowBox[{
         SubscriptBox["q", "11"], "[", "t", "]"}]}], "}"}]}]}], "]"}]}], 
  ";"}]], "Input",
 CellLabel->"In[41]:="],

Cell[TextData[{
 Cell[BoxData[
  RowBox[{"Optdes", "[", 
   RowBox[{
    RowBox[{"{", 
     FormBox[
      RowBox[{
       RowBox[{"I", " ", 
        RowBox[{
         SubscriptBox["r", "wb"], "(", 
         RowBox[{"t", ",", 
          SubscriptBox["f", "1"]}], ")"}]}], ",", " ", "I", ",", " ", 
       SubscriptBox["f", "1"], ",", " ", "t"}],
      TraditionalForm], "}"}], " ", ",", "  ", 
    FormBox[
     SubscriptBox["I", "o"],
     TraditionalForm], ",", " ", 
    FormBox[
     SubscriptBox[
      SubscriptBox["f", "1"], "0"],
     TraditionalForm], ",", " ", 
    FormBox[
     SubscriptBox["t", "0"],
     TraditionalForm], ",", "\[Rho]", ",", 
    FormBox[
     SuperscriptBox["\[Sigma]", "2"],
     TraditionalForm], ",", 
    RowBox[{"n", "-", "1"}]}], "]"}]]],
 " is used the define a n-point design taken as initial values ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 "=0.5, ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["I", "o"], TraditionalForm]]],
 "= 10000 (this parameter can be modified an the solution will be the same); ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 " = 0.1 , \[Rho] = 1, and ",
 Cell[BoxData[
  FormBox["\[Sigma]", TraditionalForm]]],
 " = 10 . It has been account that for ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "60"], TraditionalForm]]],
 "Co ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["\[Lambda]", "R"], TraditionalForm]]],
 "= Log[2]/(5.27*365.24).  "
}], "MathCaption"],

Cell[TextData[{
 "The 3-point D-optimal designs for values of  ",
 StyleBox["f",
  FontSlant->"Italic"],
 StyleBox["1",
  FontSlant->"Italic",
  FontVariations->{"CompatibilityType"->"Subscript"}],
 "= {0.05, 0.1, 0.15, 0.2} are obtained proving that the optimal designs are \
very robust respect to the election of the initial value for parameter ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SubscriptBox["f", "1"]}], TraditionalForm]]]
}], "Text"],

Cell["\<\
Here it is computed 3-point D-optimal designs. The solution is very robust \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"opdEj2", "=", 
   RowBox[{
    RowBox[{"Table", "[", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"f1", ",", " ", 
        RowBox[{"Optdes", "[", 
         RowBox[{
          RowBox[{"inp", " ", 
           RowBox[{"rWBCo", "[", 
            RowBox[{"t", ",", "fn1"}], "]"}], " ", 
           RowBox[{"Exp", "[", 
            RowBox[{
             RowBox[{
              RowBox[{"-", " ", 
               RowBox[{"Log", "[", "2", "]"}]}], "/", 
              RowBox[{"(", 
               RowBox[{"5.27", "*", "365.24"}], ")"}]}], " ", "t"}], "]"}]}], 
          ",", "t", ",", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"{", " ", 
             RowBox[{"inp", ",", "10000"}], "}"}], ",", 
            RowBox[{"{", " ", 
             RowBox[{"fn1", ",", " ", "f1"}], "}"}]}], "}"}], ",", "0.5", ",",
           "1", ",", "10", ",", "2"}], "]"}]}], "}"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"f1", ",", " ", "0.05", ",", " ", "0.2", ",", " ", "0.05"}], 
       "}"}]}], "]"}], "//", "TableForm"}]}]}]], "Input",
 CellLabel->"In[42]:="],

Cell[BoxData[
 InterpretationBox[GridBox[{
    {"0.05`", GridBox[{
       {"2114.172112168042`", "\<\"\"\>", "\<\"\"\>"},
       {
        RowBox[{
         SubscriptBox["t", "0"], "\[Rule]", "0.5`"}], 
        RowBox[{
         SubscriptBox["t", "1"], "\[Rule]", "3.9961036964917147`"}], 
        RowBox[{
         SubscriptBox["t", "2"], "\[Rule]", "7.042116758544967`"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"0.1`", GridBox[{
       {"2117.739241237183`", "\<\"\"\>", "\<\"\"\>"},
       {
        RowBox[{
         SubscriptBox["t", "0"], "\[Rule]", "0.5`"}], 
        RowBox[{
         SubscriptBox["t", "1"], "\[Rule]", "3.968861427662317`"}], 
        RowBox[{
         SubscriptBox["t", "2"], "\[Rule]", "7.014325631868996`"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"0.15000000000000002`", GridBox[{
       {"2122.1426682438264`", "\<\"\"\>", "\<\"\"\>"},
       {
        RowBox[{
         SubscriptBox["t", "0"], "\[Rule]", "0.5`"}], 
        RowBox[{
         SubscriptBox["t", "1"], "\[Rule]", "3.9415344052882264`"}], 
        RowBox[{
         SubscriptBox["t", "2"], "\[Rule]", "6.98644321746167`"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]},
    {"0.2`", GridBox[{
       {"2127.4084614650083`", "\<\"\"\>", "\<\"\"\>"},
       {
        RowBox[{
         SubscriptBox["t", "0"], "\[Rule]", "0.5`"}], 
        RowBox[{
         SubscriptBox["t", "1"], "\[Rule]", "3.9141556698172324`"}], 
        RowBox[{
         SubscriptBox["t", "2"], "\[Rule]", "6.958503723522652`"}]}
      },
      GridBoxAlignment->{
       "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
        "RowsIndexed" -> {}},
      GridBoxSpacings->{"Columns" -> {
          Offset[0.27999999999999997`], {
           Offset[0.7]}, 
          Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
          Offset[0.2], {
           Offset[0.1]}, 
          Offset[0.2]}, "RowsIndexed" -> {}}]}
   },
   GridBoxAlignment->{
    "Columns" -> {{Left}}, "ColumnsIndexed" -> {}, "Rows" -> {{Baseline}}, 
     "RowsIndexed" -> {}},
   GridBoxSpacings->{"Columns" -> {
       Offset[0.27999999999999997`], {
        Offset[2.0999999999999996`]}, 
       Offset[0.27999999999999997`]}, "ColumnsIndexed" -> {}, "Rows" -> {
       Offset[0.2], {
        Offset[0.4]}, 
       Offset[0.2]}, "RowsIndexed" -> {}}],
  TableForm[{{
    0.05, {2114.172112168042, {
      Subscript[$CellContext`t, 0] -> 0.5, Subscript[$CellContext`t, 1] -> 
       3.9961036964917147`, Subscript[$CellContext`t, 2] -> 
       7.042116758544967}}}, {
    0.1, {2117.739241237183, {
      Subscript[$CellContext`t, 0] -> 0.5, Subscript[$CellContext`t, 1] -> 
       3.968861427662317, Subscript[$CellContext`t, 2] -> 
       7.014325631868996}}}, {
    0.15000000000000002`, {
     2122.1426682438264`, {
      Subscript[$CellContext`t, 0] -> 0.5, Subscript[$CellContext`t, 1] -> 
       3.9415344052882264`, Subscript[$CellContext`t, 2] -> 
       6.98644321746167}}}, {
    0.2, {2127.4084614650083`, {
      Subscript[$CellContext`t, 0] -> 0.5, Subscript[$CellContext`t, 1] -> 
       3.9141556698172324`, Subscript[$CellContext`t, 2] -> 
       6.958503723522652}}}}]]], "Output",
 CellChangeTimes->{3.399022792810604*^9, 3.3990239370839605`*^9, 
  3.3990242628204203`*^9, 3.479969470611038*^9, 3.5419201637013617`*^9, 
  3.592060922916095*^9, 3.6436167088038096`*^9, 3.656235774613979*^9},
 CellLabel->"Out[42]//TableForm="]
}, Open  ]],

Cell[TextData[StyleBox["Fitting data",
 FontWeight->"Bold"]], "Text"],

Cell[BoxData[
 RowBox[{"Clear", "[", 
  RowBox[{
  "daymeasured", ",", "sampleWB", ",", "inputAcute", ",", " ", "ff1"}], 
  "]"}]], "Input",
 CellLabel->"In[43]:="],

Cell[TextData[{
 "We simulate the whole body measured in the moment predicted by the optimal \
design assuming an \"unknown\" intake of 25000 Bq of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "60"], TraditionalForm]]],
 "Co  in t = 0 with ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["f", "1"], "=", " ", "0.15"}], TraditionalForm]]],
 "  (a random noise N(\[Mu]=0, \[Sigma] = 10)  is included ). "
}], "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"opdEj2", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", "4", ",", "2", ",", "2"}], "]"}], "]"}]], "Input",
 CellLabel->"In[44]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["t", "0"], "\[Rule]", "0.5`"}], ",", 
   RowBox[{
    SubscriptBox["t", "1"], "\[Rule]", "3.9141556698172324`"}], ",", 
   RowBox[{
    SubscriptBox["t", "2"], "\[Rule]", "6.958503723522652`"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399023964099758*^9, 3.3990242628516703`*^9, 
  3.479969471426038*^9, 3.5419201637951136`*^9, 3.5920609232111187`*^9, 
  3.6436167088506837`*^9, 3.6562357746608553`*^9},
 CellLabel->"Out[44]="]
}, Open  ]],

Cell[BoxData[
 RowBox[{"SeedRandom", "[", "110", "]"}]], "Input",
 CellLabel->"In[45]:="],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"daymeasured", " ", "=", " ", 
  RowBox[{
   RowBox[{"Table", "[", 
    RowBox[{
     SubscriptBox["t", "i"], ",", " ", 
     RowBox[{"{", 
      RowBox[{"i", ",", " ", "0", ",", " ", "2"}], "}"}]}], "]"}], "/.", 
   RowBox[{"opdEj2", "[", 
    RowBox[{"[", 
     RowBox[{"1", ",", "4", ",", "2", ",", "2"}], "]"}], "]"}]}]}]], "Input",
 CellLabel->"In[46]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.5`", ",", "3.9141556698172324`", ",", "6.958503723522652`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.3990227928731413`*^9, 3.3990239708810515`*^9, 
  3.3990242628672953`*^9, 3.479969473180038*^9, 3.541920163857615*^9, 
  3.5920609234273863`*^9, 3.643616708881934*^9, 3.6562357746608553`*^9},
 CellLabel->"Out[46]="]
}, Open  ]],

Cell[" Here is simulated the uncertainty of the measured system", \
"MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sampleWB", " ", "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"#", ",", 
       RowBox[{
        RowBox[{"25000", " ", 
         RowBox[{"rWBCo", "[", 
          RowBox[{"#", ",", "0.15"}], "]"}]}], "+", 
        RowBox[{"Random", "[", 
         RowBox[{"NormalDistribution", "[", 
          RowBox[{"0", ",", " ", "10"}], "]"}], "]"}]}]}], "}"}], "&"}], ",", 
    "daymeasured"}], "]"}]}]], "Input",
 CellLabel->"In[47]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.5`", ",", "22926.508141496208`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3.9141556698172324`", ",", "2738.269009644751`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6.958503723522652`", ",", "1353.9435211681455`"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399022792951312*^9, 3.3990239760060844`*^9, 
  3.3990242628985453`*^9, 3.4799694733620377`*^9, 3.5419201639044905`*^9, 
  3.5920609236411533`*^9, 3.64361670889756*^9, 3.656235774676467*^9},
 CellLabel->"Out[47]="]
}, Open  ]],

Cell["\<\
Hear is made the simulation rounds the days where the measuremnts are made, \
excep 0.5 d, also is taken an error = 2 \[Sigma]\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sampleWB", " ", "=", 
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{
     RowBox[{"{", 
      RowBox[{"#", ",", 
       RowBox[{
        RowBox[{"25000", " ", 
         RowBox[{"rWBCo", "[", 
          RowBox[{"#", ",", "0.15"}], "]"}]}], "+", " ", 
        RowBox[{"Random", "[", 
         RowBox[{"NormalDistribution", "[", 
          RowBox[{"0", ",", " ", "20"}], "]"}], "]"}]}]}], "}"}], "&"}], ",", 
    " ", 
    RowBox[{"{", 
     RowBox[{"0.5", ",", "4", ",", "6", ",", "9"}], "}"}]}], "]"}]}]], "Input",
 CellLabel->"In[48]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"0.5`", ",", "22940.341448680527`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "2637.7510363916517`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"6", ",", "1541.0423067209836`"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"9", ",", "1189.5183418872768`"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.39902279298258*^9, 3.3990239860842743`*^9, 
  3.3990242629297953`*^9, 3.479969473793038*^9, 3.5419201639357414`*^9, 
  3.592060923862421*^9, 3.6436167089288225`*^9, 3.6562357746920924`*^9},
 CellLabel->"Out[48]="]
}, Open  ]],

Cell["The best fit parameters are", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"inputAcute", ",", " ", "ff1"}], "}"}], "=", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"int", ",", " ", "f1"}], "}"}], "/.", 
   RowBox[{"FindFit", "[", 
    RowBox[{"sampleWB", ",", 
     RowBox[{"int", " ", 
      RowBox[{"rWBCo", "[", 
       RowBox[{"t", ",", "f1"}], "]"}]}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"int", ",", "1000", ",", "5000"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"f1", ",", "0.05", ",", "0.2"}], "}"}]}], "}"}], ",", "t"}], 
    "]"}]}]}]], "Input",
 CellLabel->"In[49]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"25013.854949950524`", ",", "0.15085036996241719`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.399022793107654*^9, 3.3990239898030477`*^9, 
  3.399024263023546*^9, 3.479969474594038*^9, 3.5419201640138683`*^9, 
  3.592060924174946*^9, 3.6436167089913096`*^9, 3.656235774754593*^9},
 CellLabel->"Out[49]="]
}, Open  ]],

Cell["\<\
The agree between experimental and the fitted function is very good\
\>", "MathCaption"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Plot", "[", 
  RowBox[{
   RowBox[{"inputAcute", " ", 
    RowBox[{"rWBCo", "[", 
     RowBox[{"t", ",", "ff1"}], "]"}]}], ",", " ", 
   RowBox[{"{", 
    RowBox[{"t", ",", "0", ",", " ", "10"}], "}"}], ",", " ", "\n", "  ", 
   RowBox[{"Epilog", " ", "->", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Hue", "[", "0.", "]"}], ",", " ", 
      RowBox[{"PointSize", "[", "0.02", "]"}], ",", " ", 
      RowBox[{"Map", "[", 
       RowBox[{"Point", ",", "sampleWB"}], "]"}]}], "}"}]}]}], "]"}]], "Input",
 CellLabel->"In[50]:="],

Cell[BoxData[
 GraphicsBox[{{}, {}, 
   {RGBColor[0.368417, 0.506779, 0.709798], AbsoluteThickness[1.6], Opacity[
    1.], LineBox[CompressedData["
1:eJwV0mk01XsXB3DVNY+HCJmP5CrNhIbf94Y8Eg0aiDKGUhSKIpIyR8dJEwmF
IkOmS0mnDElIGc7fVNQVyTxliuf0Yq+9Puu7X+y91la2d99/fDEXF9cHTv3p
9/3tedY7RmzftBDw7/nTFBKO9OsdVjpBbGRaCv+4xTTcQ0npAnlhuifzjzds
/vBQgLpCSNqya3/sbWQpwq0URipn6pb/ccnhbz4LztHkbMqs/jmOF+UXjsyx
Y4jFFrdKT45VS2bVZmZjiWNukMNZjneWw/qX4l2yxsmk8TTHLjXXGOP68WSe
znzvwnFEY3XliPMDYmvYNmnH8eFBXv9fhkmkp2jTgsWfeY906Ul2MjEuEAg3
5fjC5O688ROPCPWsRZdwHH5xyHRsNoU0KzVlaXIcP8/oHbmeRlxMLoVIc5x5
ZVPQsOITsjhWzW7hFIVSHrb80LN0YmDuSXVxXB9+oWhA/ymZ3/s67BXHXSJy
5v1NmeTj7wjaHY5HY0oH+pyzyVqdciFXjq9ErCsf98sh3lEKMjoch9cG0sYN
nxHv1xZN864UmKINx8ZEcslOQ++uUo7j96k+HWXnkuRTs5+9OX7EPDc9kphH
0Cl+9m+OM5sqd46cyCe146ytDScpFC6Tvjm8oYBEuSz+4cVxqeWJrqFZjnn6
FUQ4fhv3fM1QeSHhelgelnCCs3+HoN/g9X+JYLssewXHXXZZUgOKxcQhwLht
mQuFvocLDv29xWRAVns60JlzT/feZz+fPSdSh9rfdjlR+OvkmEmffgkpqvps
G3icgtBTg7s/hF6SSBvTVJYjBcnB2O+9TS8JSz0uZtyBgpqHTmCP8ytivC3j
rK49BelWA2dPaRb5dJc5ZmxHQc53QHjMj0VmpuL0zGw5//Byu9Wo4WuyNFNv
3/pjFNSP9SzySH9NxHytykSPUtBciH48IvKGdF1IIF1WFLT/6ZoYZr8hePY7
39qSgt7XsPgzW8tIalKnPY8Fhe1BG/SHE8tI707rq8mHKBhVBN0YOlFO9mxS
ePjMnMJup9Wb3evKiVfI7HHV/RT28jZ1DG6oIBZNwSvD9lKwMFZbNThbQdal
rzZSN6Vg3Vf38bRtJbHxol+0N6FgF+HtM1BeSRbHOB+MMqZwsraqov/6W5Jw
qvT1c0MKvvtcbX8qviNmf3lOOm6jMB+kLfMl8h15WrrBcEaPwuXCRZ8+Tb8j
UdU8u/x1KFxdfkf/eUM1SeASPrZ/I4Wo7nK1sJAasvnTTRcNdQpi0je++I3X
EIfBdAmtFRRidlndOWNXS0LaOt3XqFC4nT3Cb7GljnwbdT84sJxC4gWFAbWh
D2TMrPVDvAgFWvP4fuE19WTDQsO4vCCF/e5H1oY41hNIpslH8VJoSlrRe/Fj
PQmpiinawkWhlafE0j7jI/HqtZmoHWbjW33v1vU2DaT0h45iZx0bqifNZDJi
G8ihZ52OR6rZcFqSP6Fa00Ceph2cK69go1crIEtat5G4S+0LdS1ho/+epBKX
RBNRCxhc4HrCxqTjjiUfKpvJzP6CxuMBbPBPx707taaV2KhUkm5lNnRCWi7u
smslmRc10wXl2HCRXLZa/WYr4e2fvbNSio3K9TFR36ZbyUy4hzME2Lh6MtT8
SEUbKdjJDJgaaQZXu1eHkXUHkRGX0r7zqhm+X1J9aIadZFVYoww50IyzbwIi
+z2+Ed7ONOZKlyasecT8mJ/1g6Ryh8WOOjWg28xF7ovOMIlIJEFaqh9xWzZY
Psl2jIjOMDtqN9ZB16Moe0nNJNn1unvle/lqlLHj9rqvnCHxistXZIdUYn3k
/HZp499EU2jtRE9sGYy+631Zd5gLW28YJR78yEKPZqHheP8iZGpzT5lrvYTv
XNjGkotLwKOl1+jqXwxeWu+JAxrc+FV/zWZwaSEmQ6wNH6zjhqOmwzIz/kJ8
n69X6tPmhsNfc5EFvwtQ2V/MDtDnxtHO4Adx3wsQXBVhmGHNjVVSFt1lRQXg
ubxWeXE0N3Snu8UDj3E8dJ7KHuPGWkbkpujsfHDXchsJvuQBa+bQdn7nPAid
jnfoKOOBgZw+cbDOw1LhjZezq3mw2uS5ZMW+PKia2habUzygTZ9dk7g1Dwa1
z1fFj/HAbSzhUp54Hq7UuotpavAiV1lLdBcrF1x1LS1mt3mRWrHaSkI5F7N1
madizvLhjUaR9qKpHCh8tIsz8OHDFImw3T+Ugx0NktWT/nwYL7zf8+R7DsLZ
l1ZaRfJhxTDfnGtTDqQ7Tb/S0/jQPbiufEteDrRHBg4XtPNh7MwiQZ4zOTgj
sUafMuKHWuxv5z3t2eg+nCWjoCAAp3W5vWd/ZSLV4vcba1UB3LE2LJ3+kQkX
y92n4jQEsPzksi/h7ZnoO9JXKr1ZAAcVan5Uvc7E8FE1R4m9ArB0vOydF5mJ
OYeELL4rAkgttVXcppoJiTNR+mPdAmjdwpsxZfkU/4S6na7KFERXrmv7+8/p
kM39cjgqXxA+l4IEgz6lY7xt744DLwRhksrlrV+ZjtS1G5d1Vgmiz6Oz50tm
OoTYv1i/vglCrVnRM/hSOppXBC5dKSuEQddVplcV0uFaxnxxLVgIv2WKO5Y6
P0HsfBG/vo0wVHQXv1hBewyhlRVusceFQYiiQSrvY1zd87Ghx1UYtzdWX9Cc
T4NH4o/7kT7C4HaeYu/5mQazHbIbmhmcXCu5/VtFGniCfY+cKBeGjavBlIFf
GnyEt2dE/y2C/HqjuPcDqbCSK9vdPiYCbwXCP/E1BX2nR0YLZkTgk8prbN6a
Ap9XinejF4liE/YtK/qYglv2ft07REVxw0nYJJaVgk+PtfyfaIhi0bZLgfcT
UrBL63H2eTtRyP2XU9VplQI9s+vitA+ioMnNu4m1PYIQa1W/ykExfA/59lPo
50N8vbuvKsBCDOXRO1YL/PcQ/3p6P2q3EsNnr5EEoY6HsF9ZZn3LXgwqXusF
lT9w8qgjtfxnxLArJSA6JI+THw3LGg4Xw5Gls5+MLj1E0cz3M6UsMVQGS+lc
XPoQx7WSJyxX07Cn5oESe28ywqMkRS+tpeHzFJF2NklGVk+oeuIGGk4e2PRu
xjAZk3fdrb7r0NC9dMduzS3JCJ3f+trDkAY75vmI0hXJSH/Ljow4RoNsS8Sd
6NkkDFoKq768QYPtnb2JLU+S4O3vs19pgoYDXI6tl8WSoN7vJxQyRcM9K99t
oYJJoCwDKwdmaehlMQyZPEnQ0QrXe7FYHEEaarr5c4mY+hmnckhMHOe8zY8q
/0jERctXoxGrxGFQrCGX+iYR/pt4mL/sxJE//XnK0CcR1/qYDXV14ij+W/fU
zdYH2K0h+ljongS6GnXCB2gJuJ6pzdpttxTy6U6CrNh4VJs/nPPSlUSlzo7g
2s1xYNW6R65eIoVJebfXJcr3kHsyEDUdUuC35nNrUrwLBROi45a/DEIRQ2ea
dt6B/oJ10AM/aSwenDwlfPs2HJtfjRYdlIE8/4VA++Fb2B54pcBOSRbejJar
55xvIcZ95IVQjyxu0SqE3gzF4uvllO8PSpcjf8r1tJtvLH4eL3Z8EyKH404K
c6EysRg+Lc5baycP7hsvBCWLbyLL+P2ck6YCTAevGaQ43cR3l3XaSyYUUELX
0G1bfhOyGa3MkFpFMPlVtp2rZyLI1iO51kQJoTsXf82IYuLXnMx1k2Il8D5O
WZNiwoT6i9t3q1WV8c7fayhSmAkth4o9tDBlyI2ZT/o3x4AVLyldM6GMg6u+
2ofej4E6SzLczEoFJb7bE++fjIEpd7/8p1IViLzcK3FLLwbDbf+VvdOgIzJD
a+4YXwzc469LhEXTITHKPa3QxkDNItWhXQw6DFgTOhatDGg4P68WYtKhODBz
k9HCwH/rewJv3KJj4pJM0l8UAxZvMXz7Ph3Puc/z9TcysGN0rCY1g46Wx1sE
WHUMSP3vSHD5Wzoc1CVu+L1hwDNz2C74HR057Uu2F79moF48ZNv/3tOhM1PM
M8liIKIjb/x9HR33zpn1ur9igMtT2KGhiQ7fVYt/OpYw0HefRb5+o8PYZ6bb
vJABoyWHlz/qpqPOM2lLTAEDj1wGJo/30HFe52xGfT4DNhtls3700VE15Nhi
msdAY5Wn3MgIHUM2zNPGOQysXyMwlTtGx5uS88zQbAaimIkNXhN0zG/d3PA2
iwHjY7XhU1N0rLDQSNyZyUBqmYPT8xk69ljv0gx+ysBff8/84zdHh9UhlcaK
DAbsom7Ib5+no03wyU1ujkvH1KYXFuhYbdzkZpjOwP8BJ6oxZA==
     "]]}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{True, True},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Epilog->{
    Hue[0.], 
    PointSize[0.02], {
     PointBox[{0.5, 22940.341448680527`}], 
     PointBox[{4, 2637.7510363916517`}], 
     PointBox[{6, 1541.0423067209836`}], 
     PointBox[{9, 1189.5183418872768`}]}},
  Frame->{{False, False}, {False, False}},
  FrameLabel->{{None, None}, {None, None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  Method->{
   "DefaultBoundaryStyle" -> Automatic, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "ScalingFunctions" -> None},
  PlotRange->{{0, 10}, {0., 25013.85494995043}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.05], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{3.3990227931389227`*^9, 3.399023994178076*^9, 
  3.399024264257929*^9, 3.479969477537038*^9, 3.5419201646857557`*^9, 
  3.59206092560756*^9, 3.6436167094288225`*^9, 3.6562357751608458`*^9},
 CellLabel->"Out[50]="]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "EXAMPLE 3 .- Whole body counter applied to estimation of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "60"], TraditionalForm]]],
 "Co intake by inhalation (being ",
 StyleBox["I",
  FontSlant->"Italic"],
 " and the AMAD ",
 StyleBox["p",
  FontSlant->"Italic"],
 " unknown)"
}], "SubsubsectionIcon"],

Cell[TextData[{
 "An operator has been exposed to an simple accidental intake by inhalation \
of ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["", "60"], TraditionalForm]]],
 "Co, we wish estimate the intake ",
 Cell[BoxData[
  FormBox["I", TraditionalForm]]],
 " and the AMAD ",
 Cell[BoxData[
  FormBox["p", TraditionalForm]]],
 ", it is take ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["f", "1"], TraditionalForm]]],
 " = 0.1.  A program of in-vivo monitoring using an whole body counter must \
be defined "
}], "Text"],

Cell[TextData[{
 "The first step is get the whole body retention for ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SuperscriptBox["", "60"]}], TraditionalForm]]],
 "Co, it can be done as it follows "
}], "MathCaption",
 CellChangeTimes->{{3.3990240586628637`*^9, 3.3990240589128647`*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"cobaltwb", "[", "t_", "]"}], "=", "  ", 
   RowBox[{
    RowBox[{"qWholebody", "[", "t", "]"}], "/.", 
    RowBox[{"BiokdataReport", "[", " ", 
     RowBox[{
     "cobalt", ",", "\"\<Inhalation\>\"", ",", " ", "\"\<Acute\>\"", ",", 
      "\"\<Automatic\>\"", ",", "1", ",", "  ", 
      RowBox[{"{", 
       RowBox[{"AI", ",", 
        SubscriptBox["bb", 
         RowBox[{"fast", "+", "seq"}]], ",", 
        SubscriptBox["bb", "slow"], ",", " ", 
        SubscriptBox["BB", 
         RowBox[{"fast", "+", "seq"}]], " ", ",", " ", 
        SubscriptBox["BB", "slow"], ",", "  ", 
        SubscriptBox["ET", "2"], ",", " ", 
        SubscriptBox["ET", "1"]}], "}"}], ",", "S", ",", " ", "0.1", ",", "t",
       ",", 
      RowBox[{
       RowBox[{"Log", "[", "2", "]"}], "/", 
       RowBox[{"(", 
        RowBox[{"5.27", "*", "365.24"}], ")"}]}]}], "]"}]}]}], ";"}]], "Input",
 CellLabel->"In[51]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"{", 
    RowBox[{"AI", ",", 
     SubscriptBox["bb", 
      RowBox[{"fast", "+", "seq"}]], ",", 
     SubscriptBox["bb", "slow"], ",", 
     SubscriptBox["BB", 
      RowBox[{"fast", "+", "seq"}]], ",", 
     SubscriptBox["BB", "slow"], ",", 
     SubscriptBox["ET", "2"], ",", 
     SubscriptBox["ET", "1"]}], "}"}], " ", "=", " ", 
   RowBox[{"AMADfit", "[", "p", "]"}]}], ";"}]], "Input",
 CellLabel->"In[52]:="],

Cell["\<\
To avoid a too long time of computation negligable terms are eliminated\
\>", "Text"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"coWB", "[", 
    RowBox[{"t_", ",", "p_"}], "]"}], "=", 
   RowBox[{
    RowBox[{"Drop", "[", " ", 
     RowBox[{
      RowBox[{"ExpandAll", "[", 
       RowBox[{"cobaltwb", "[", "t", "]"}], "]"}], ",", " ", "86"}], "]"}], "//",
     "Chop"}]}], ";"}]], "Input",
 CellLabel->"In[53]:="],

Cell[TextData[{
 "Here it is to obtain a 4-points design. The first measure is taken at",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{"t", "=", " ", "0.5", " "}]}], TraditionalForm]]],
 "and ",
 Cell[BoxData[
  FormBox["\[Sigma]", TraditionalForm]]],
 " = 10 Bq . "
}], "Text",
 CellChangeTimes->{3.479969533390038*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{"Optdes", "[", 
   RowBox[{
    RowBox[{"inp", " ", 
     RowBox[{"coWB", "[", 
      RowBox[{"t", ",", "p"}], "]"}]}], ",", " ", "t", ",", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"inp", ",", " ", "1000"}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"p", ",", "  ", "5"}], "}"}]}], "}"}], ",", "  ", "0.5", ",", 
    " ", "1", ",", "10", ",", " ", "3"}], "]"}]}]], "Input",
 CellLabel->"In[54]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0.012059168376557843`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["t", "0"], "\[Rule]", "0.5`"}], ",", 
     RowBox[{
      SubscriptBox["t", "1"], "\[Rule]", "4.511942562638393`"}], ",", 
     RowBox[{
      SubscriptBox["t", "2"], "\[Rule]", "8.699129712746348`"}], ",", 
     RowBox[{
      SubscriptBox["t", "3"], "\[Rule]", "13.566900274547283`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.3990228614379625`*^9, 3.3990240661941614`*^9, 
  3.3990243366646423`*^9, 3.479969526924038*^9, 3.5419158456515503`*^9, 
  3.5419202023427286`*^9, 3.592060975930336*^9, 3.6436167214288282`*^9, 
  3.656235788567163*^9},
 CellLabel->"Out[54]="]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Optimal design solving numerically the the diffential equations of the model\
\>", "Section",
 CellChangeTimes->{{3.544849372578843*^9, 3.544849375464848*^9}, {
  3.591678659777142*^9, 3.5916786677956963`*^9}, {3.592060619059969*^9, 
  3.5920607342597504`*^9}}],

Cell[BoxData[
 RowBox[{"Quit", "[", "]"}]], "Input",
 CellChangeTimes->{{3.5920612053786936`*^9, 3.5920612082814255`*^9}},
 CellLabel->"In[1]:="],

Cell["This section  is based on:   ", "Text",
 CellChangeTimes->{{3.592060838038052*^9, 3.5920608449711065`*^9}, {
  3.59206096135667*^9, 3.5920609731301117`*^9}, {3.6562358761457005`*^9, 
  3.6562358849581895`*^9}}],

Cell["\<\
Juan M. Rodr\[IAcute]guez-D\[IAcute]az; G. S\[AAcute]nchez-Le\[OAcute]n:\
\[CloseCurlyDoubleQuote]Design optimality for models defined by a system of \
ordinary differential equations\[CloseCurlyDoubleQuote] Biometrical Journal \
56 (5), pag 886\[Dash]900, September 2014\
\>", "Reference",
 CellChangeTimes->{3.656235872130063*^9}],

Cell[TextData[{
 "The following differential equations result from the model  ofA. \
S\[AAcute]nchez-Navarro, C. Casquero, and M. Weiss, 'Distribution of \
Ciprofloxacin and Ofloxacin in the Isolated Hindlimb of the Rat', ",
 StyleBox["Pharmaceutical Research", "PI"],
 ", 16: 587-591 (1999): "
}], "Text",
 CellChangeTimes->{{3.5447728018047495`*^9, 3.5447728316483145`*^9}, {
  3.5447731156040096`*^9, 3.544773174058708*^9}, {3.544773285133238*^9, 
  3.5447732995635147`*^9}, {3.544793641662468*^9, 3.5447936501176834`*^9}, {
  3.544849431250546*^9, 3.544849456928191*^9}}],

Cell[BoxData[{
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["c", "out"], "'"}], "[", "t", "]"}], "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox["Q", 
       SubscriptBox["V", "p"]], "+", " ", 
      FractionBox["PS", 
       SubscriptBox["V", "p"]]}], ")"}], 
    RowBox[{
     SubscriptBox["c", "out"], "[", "t", "]"}]}], " ", "-", 
   RowBox[{
    FractionBox["PS", 
     SubscriptBox["V", "p"]], " ", 
    RowBox[{
     SubscriptBox["c", "Tu"], "[", "t", "]"}]}]}], "=", 
  RowBox[{
   FractionBox["Q", 
    SubscriptBox["V", "p"]], " ", 
   RowBox[{
    SubscriptBox["c", "in"], "[", "t", "]"}]}]}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["c", "Tu"], "'"}], 
    RowBox[{"[", "t", "]"}]}], " ", "+", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      FractionBox["PS", 
       SubscriptBox["V", "Tu"]], " ", "+", 
      SubscriptBox["k", "on"]}], " ", ")"}], 
    RowBox[{
     SubscriptBox["c", "Tu"], "[", "t", "]"}]}], "-", 
   RowBox[{
    FractionBox["PS", 
     SubscriptBox["V", "Tu"]], 
    RowBox[{
     SubscriptBox["c", "out"], "[", "t", "]"}]}], "-", 
   RowBox[{
    SubscriptBox["k", "off"], 
    FractionBox[
     SubscriptBox["V", "Tb"], 
     SubscriptBox["V", "Tu"]], 
    RowBox[{
     SubscriptBox["C", "Tb"], "[", "t", "]"}]}]}], "=", " ", "0"}], "\n", 
 RowBox[{
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["c", "Tb"], "'"}], 
    RowBox[{"[", "t", "]"}]}], "+", 
   RowBox[{
    SubscriptBox["k", "off"], 
    RowBox[{
     SubscriptBox["c", "Tb"], "[", "t", "]"}]}], "-", " ", 
   RowBox[{
    SubscriptBox["k", "on"], 
    FractionBox[
     SubscriptBox["V", "Tu"], 
     SubscriptBox["V", "Tb"]], 
    RowBox[{
     SubscriptBox["c", "Tu"], "[", "t", "]"}]}]}], "=", 
  "0"}]}], "NumberedEquation",
 CellChangeTimes->{{3.544773367986431*^9, 3.544773383446328*^9}, {
  3.544788085372505*^9, 3.544788155510228*^9}, {3.5447934250180874`*^9, 
  3.5447934516785345`*^9}, {3.5447955954879*^9, 3.5447955994035068`*^9}, {
  3.5447959516521254`*^9, 3.5447959523229265`*^9}}],

Cell[TextData[{
 "Initial conditions: ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{
     SubscriptBox["c", "out"], "[", "0", "]"}], "=", " ", "0"}], ",", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "Tu"], "[", "0", "]"}], "=", "0"}], ",", " ", 
   RowBox[{
    RowBox[{
     SubscriptBox["c", "Tb"], "[", "0", "]"}], "=", "0"}]}]]]
}], "Text",
 CellChangeTimes->{{3.5447734988417473`*^9, 3.5447735511495533`*^9}, {
   3.544773613425951*^9, 3.5447736757491493`*^9}, {3.544773774748653*^9, 
   3.5447737929854035`*^9}, 3.5447738264948483`*^9, 3.5447738827339296`*^9, {
   3.5447951532271233`*^9, 3.544795296482175*^9}}],

Cell[TextData[{
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "i"], TraditionalForm]]],
 "(t)",
 StyleBox[" , with ",
  FontFamily->"New York"],
 StyleBox["i",
  FontFamily->"New York",
  FontSlant->"Italic"],
 StyleBox[" = {out, Tu, Tb}, represents the concentration of a sustance in \
differentes part of the models. We consider the case where ",
  FontFamily->"New York"],
 "with Q =  3 mL ",
 Cell[BoxData[
  SuperscriptBox["min", 
   RowBox[{"-", "1"}]]]],
 StyleBox[", ",
  FontFamily->"New York"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["V", "Tu"], "=", "6.411"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "p"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox["0.973", TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["V", "Tb"], "=", "1"}], TraditionalForm]]],
 ",  and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"P", " ", "S"}], "=", "2.714"}], TraditionalForm]]],
 ", then replacing ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "Tu"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "p"], TraditionalForm]]],
 ",  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["V", "Tb"], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{"P", " ", "S"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox["Q", TraditionalForm]]],
 " for their values where for convenients we call  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "1"], "(", "t", ")"}], TraditionalForm]]],
 ", ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "2"], "(", "t", ")"}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "3"], "(", "t", ")"}], TraditionalForm]]],
 " intead of ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "out"], 
   RowBox[{"(", "t", ")"}]}]],
  CellChangeTimes->{{3.544773367986431*^9, 3.544773383446328*^9}, {
   3.544788085372505*^9, 3.544788155510228*^9}, {3.5447934250180874`*^9, 
   3.5447934516785345`*^9}, {3.5447955954879*^9, 3.5447955994035068`*^9}}],
 ", ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "Tu"], 
   RowBox[{"(", "t", ")"}]}]]],
 "and ",
 Cell[BoxData[
  RowBox[{
   SubscriptBox["c", "Tb"], 
   RowBox[{"(", "t", ")"}]}]]]
}], "Text",
 CellChangeTimes->{{3.5447734988417473`*^9, 3.5447735511495533`*^9}, {
   3.544773613425951*^9, 3.5447736757491493`*^9}, {3.544773774748653*^9, 
   3.5447737929854035`*^9}, 3.5447738264948483`*^9, 3.5447738827339296`*^9, {
   3.5447951532271233`*^9, 3.5447953086813965`*^9}, 3.5447953497406683`*^9, {
   3.5447954146367826`*^9, 3.5447954210639935`*^9}, 3.544795515412959*^9, {
   3.544795646094389*^9, 3.544795820362295*^9}}],

Cell[TextData[{
 "We use  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["c", "in"], TraditionalForm]]],
 "(t) = ",
 Cell[BoxData[
  RowBox[{"13610.10776942386`", " ", "t", "  ", 
   SuperscriptBox["\[ExponentialE]", 
    RowBox[{
     RowBox[{"-", "11.215992508521028`"}], " ", "t"}]], " "}]],
  CellChangeTimes->{3.3981392434339075`*^9, 3.398139459337884*^9, 
   3.398161699477437*^9, 3.39816194679152*^9, 3.480338254634055*^9, 
   3.480340936881855*^9, 3.4803415031356544`*^9, 3.4803427480030546`*^9, 
   3.518536642061124*^9, 3.53969785078972*^9, 3.539698038902707*^9}],
 " (According to G. Sanchez Biokmod: A Mathematica toolbox for modeling \
Biokinetic Systems\[CloseCurlyDoubleQuote]. ",
 StyleBox["Mathematica in Education and Research",
  FontSlant->"Italic"],
 ": 10 (2) 2005. ISSN/ISBN: 1096-3324  using the experimental data obtained \
by of A. S\[AAcute]nchez-Navarro et al. )"
}], "Text",
 CellChangeTimes->{{3.5447962678958807`*^9, 3.544796340311208*^9}, {
   3.5447963889208937`*^9, 3.5447964567810125`*^9}, 3.5447966713905897`*^9}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Needs", "[", "\"\<Biokmod`SysModel`\>\"", "]"}], 
  " "}]], "InputOnly",
 CellChangeTimes->{{3.54540633530774*^9, 3.54540633532334*^9}, {
   3.5705135838193464`*^9, 3.570513599357109*^9}, 3.5705136941123343`*^9, {
   3.570540240407283*^9, 3.570540244057683*^9}},
 CellLabel->"In[1]:="],

Cell[BoxData["\<\"SysModel, version 1.5.1   2013-11-12\"\>"], "Print",
 CellChangeTimes->{3.592061276366872*^9, 3.643616808116459*^9, 
  3.656235507091464*^9},
 CellLabel->"During evaluation of In[1]:="]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"modelmatrix", "=", " ", 
  RowBox[{
   RowBox[{"CoefMatrix", "[", 
    RowBox[{"3", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{"1", ",", "1", ",", " ", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["Q", 
             SubscriptBox["V", "p"]], "+", " ", 
            FractionBox["PS", 
             SubscriptBox["V", "p"]]}], ")"}]}]}], " ", "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2", ",", " ", 
         FractionBox["PS", 
          SubscriptBox["V", "p"]]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1", ",", " ", 
         FractionBox["PS", 
          SubscriptBox["V", "Tu"]]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2", ",", " ", 
         RowBox[{"-", 
          RowBox[{"(", 
           RowBox[{
            FractionBox["PS", 
             SubscriptBox["V", "Tu"]], " ", "+", 
            SubscriptBox["k", "on"]}], " ", ")"}]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3", ",", 
         RowBox[{
          SubscriptBox["k", "off"], " ", 
          FractionBox[
           SubscriptBox["V", "Tb"], 
           SubscriptBox["V", "Tu"]]}]}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{"3", ",", "2", ",", " ", 
         RowBox[{
          SubscriptBox["k", "on"], 
          FractionBox[
           SubscriptBox["V", "Tu"], 
           SubscriptBox["V", "Tb"]]}]}], "}"}], " ", ",", "  ", 
       RowBox[{"{", 
        RowBox[{"3", ",", "3", ",", " ", 
         RowBox[{"-", 
          SubscriptBox["k", "off"]}]}], "}"}]}], "}"}]}], "]"}], " ", "/.", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{
      SubscriptBox["V", "Tu"], "\[Rule]", "6.411"}], ",", 
     RowBox[{"Q", " ", "\[Rule]", "3"}], ",", 
     RowBox[{
      SubscriptBox["V", "p"], "\[Rule]", "0.973"}], ",", 
     RowBox[{
      SubscriptBox["V", "Tb"], "\[Rule]", "1"}], ",", 
     RowBox[{"PS", "\[Rule]", "2.714"}], ",", 
     RowBox[{"Q", " ", "\[Rule]", "3"}], ",", 
     RowBox[{
      SubscriptBox["V", "Tb"], "\[Rule]", "1"}], ",", " ", 
     RowBox[{
      SubscriptBox["k", "on"], "\[Rule]", "kon"}], ",", " ", 
     RowBox[{
      SubscriptBox["k", "off"], "\[Rule]", "koff"}]}], " ", 
    "}"}]}]}]], "InputOnly",
 CellChangeTimes->{
  3.5448466396786485`*^9, 3.544856787996955*^9, 3.5705402571150002`*^9, 
   3.570540308626665*^9, {3.591679271533326*^9, 3.591679275894762*^9}, 
   3.591679581361871*^9, {3.591679619732707*^9, 3.5916796482405577`*^9}},
 CellLabel->"In[2]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"-", "5.872559095580678`"}], ",", "2.789311408016444`", ",", 
     "0"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.42333489315239436`", ",", 
     RowBox[{
      RowBox[{"-", "0.42333489315239436`"}], "-", "kon"}], ",", 
     RowBox[{"0.15598190609889254`", " ", "koff"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0", ",", 
     RowBox[{"6.411`", " ", "kon"}], ",", 
     RowBox[{"-", "koff"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.5705402577702065`*^9, 3.5916792861127834`*^9, 
  3.591679608088543*^9, 3.591679648869621*^9, 3.5916799418937798`*^9, 
  3.5920609760003414`*^9, 3.592061276535636*^9, 3.6436168081477118`*^9, 
  3.656235507107088*^9},
 CellLabel->"Out[2]="]
}, Open  ]],

Cell["The initial condtion are ", "Text",
 CellChangeTimes->{{3.5916798378065124`*^9, 3.5916798592846603`*^9}}],

Cell[TextData[{
 StyleBox["x",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", "0", ")"}], " "}], TraditionalForm]]],
 " = ",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{
        FormBox[
         SubscriptBox["x", "1"],
         TraditionalForm], "(", "0", ")"}], ",", " ", 
       RowBox[{
        FormBox[
         SubscriptBox["x", "2"],
         TraditionalForm], "(", "0", ")"}], ",", " ", 
       RowBox[{
        FormBox[
         SubscriptBox["x", "3"],
         TraditionalForm], "(", "0", ")"}]}], "}"}], 
     FormBox[
      SuperscriptBox["", "T"],
      TraditionalForm]}]}], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.544796118634819*^9, 3.544796135092848*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"initialcondition", " ", "=", 
   RowBox[{"{", 
    RowBox[{"0", ",", " ", "0", ",", " ", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5916798691496463`*^9, 3.5916798874894805`*^9}},
 CellLabel->"In[3]:="],

Cell["The input is given by", "Text",
 CellChangeTimes->{{3.5916796674264765`*^9, 3.591679686020335*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"b1", "=", 
   RowBox[{
    RowBox[{
     FractionBox["Q", 
      SubscriptBox["V", "p"]], " ", 
     SubscriptBox["c", "in"]}], "/.", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Q", " ", "\[Rule]", "3"}], ",", 
      RowBox[{
       SubscriptBox["V", "p"], "\[Rule]", "0.973"}], ",", 
      RowBox[{
       SubscriptBox["c", "in"], "->", 
       RowBox[{"13610.10", " ", "t", "  ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "11.216"}], " ", "t"}]]}]}]}], "}"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.591679524923165*^9, 3.5916795528566494`*^9}, {
  3.5916795864103756`*^9, 3.5916795933890734`*^9}, {3.59167965336407*^9, 
  3.5916796632080545`*^9}, {3.591679757606493*^9, 3.591679810166749*^9}, {
  3.59167991038977*^9, 3.591679914840215*^9}},
 CellLabel->"In[4]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"binput", "=", " ", 
   RowBox[{"{", 
    RowBox[{"b1", ",", " ", "0", ",", " ", "0"}], "}"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.5916798929810295`*^9, 3.591679930583789*^9}},
 CellLabel->"In[5]:="],

Cell[TextData[{
 StyleBox["b",
  FontWeight->"Bold"],
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"(", "t", ")"}], " ", "=", " ", 
    SuperscriptBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"41963.340825`", "t", "  ", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "11.215992508521028`"}], " ", "t"}]]}], " ", ",", " ", 
       "0", ",", " ", "0"}], "}"}], "T"], " "}], TraditionalForm]]],
 " "
}], "Text",
 CellChangeTimes->{{3.5447959748649664`*^9, 3.544796035611473*^9}, {
  3.544796643731741*^9, 3.5447966534193583`*^9}}],

Cell[TextData[{
 "We want to estimate the values of ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "on"], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "off"], TraditionalForm]]],
 " making an experiment that consist on in measure the concentration of a \
compount at ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox[
     OverscriptBox["x", "^"], "1"], "(", "t", ")"}], TraditionalForm]]],
 "  for ",
 StyleBox["t ",
  FontSlant->"Italic"],
 ":{",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 ",..,  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ", ...  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "n"], TraditionalForm]]],
 "} an then estimate",
 Cell[BoxData[
  FormBox[
   RowBox[{" ", 
    SubscriptBox["k", "on"]}], TraditionalForm]]],
 " and ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["k", "off"], TraditionalForm]]],
 " by fitting  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "1"], "(", 
    RowBox[{"t", ",", "  ", 
     FormBox[
      SubscriptBox["k", "on"],
      TraditionalForm], ",", 
     FormBox[
      SubscriptBox["k", "off"],
      TraditionalForm]}], ")"}], TraditionalForm]]],
 " . "
}], "Text",
 CellChangeTimes->{{3.5447728018047495`*^9, 3.5447728316327143`*^9}, 
   3.5447737503341837`*^9, {3.5447739355877457`*^9, 3.544773947787181*^9}, {
   3.544849639354912*^9, 3.544849875929327*^9}, {3.5448499116221895`*^9, 
   3.5448499740222993`*^9}, {3.5448500082487593`*^9, 3.54485001434837*^9}, {
   3.5448500858900957`*^9, 3.5448500858900957`*^9}, {3.5448501176205516`*^9, 
   3.544850143407397*^9}, {3.544850177368656*^9, 3.544850244916775*^9}, {
   3.5448508214157877`*^9, 3.544850840447821*^9}}],

Cell[TextData[{
 "We wish  find  ",
 StyleBox["t ",
  FontSlant->"Italic"],
 ":{",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 ",..,  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ", ...  ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "n"], TraditionalForm]]],
 "} of the model given by eq. (1).   using ",
 StyleBox["D",
  FontSlant->"Italic"],
 "-optimal design when the analitycal expresion of ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "1"], "(", 
    RowBox[{"t", ",", "  ", 
     FormBox[
      SubscriptBox["k", "on"],
      TraditionalForm], ",", 
     FormBox[
      SubscriptBox["k", "off"],
      TraditionalForm]}], ")"}], TraditionalForm]]],
 " can not be found. [f(t, \[Beta]) =",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["x", "1"], "(", 
    RowBox[{"t", ",", "  ", 
     FormBox[
      SubscriptBox["k", "on"],
      TraditionalForm], ",", 
     FormBox[
      SubscriptBox["k", "off"],
      TraditionalForm]}], ")"}], TraditionalForm]]],
 "]. We procedure as follow"
}], "Text",
 CellChangeTimes->{{3.5448512851792884`*^9, 3.544851305552924*^9}, {
  3.5448513409337864`*^9, 3.5448514828784356`*^9}, {3.5448515275101137`*^9, 
  3.5448517021212206`*^9}, {3.544851749826104*^9, 3.5448518977455645`*^9}, {
  3.5448519286492186`*^9, 3.5448519318628244`*^9}, {3.54485204897223*^9, 
  3.5448520868646965`*^9}, {3.544959592609887*^9, 3.5449596156043277`*^9}, {
  3.5916800095404406`*^9, 3.591680013944543*^9}, {3.5920601155141926`*^9, 
  3.5920601280004406`*^9}}],

Cell[TextData[{
 "1.- It is defined a model  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    RowBox[{"f", "(", 
     RowBox[{"t", ",", " ", "\[Beta]"}], ")"}], " "}], TraditionalForm]]],
 "using the new function ",
 Cell[BoxData[
  FormBox[
   StyleBox["ParametricSystemNDSolve", "Input"], TraditionalForm]]],
 " (included in the SysModel package) where the numerical solution is given \
as function ot the unkown parameters are ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Beta]", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], TraditionalForm]]],
 "."
}], "Text",
 CellChangeTimes->{{3.539847488487944*^9, 3.5398474998291645`*^9}, {
  3.592060142232864*^9, 3.5920602455971994`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", "=", " ", 
  RowBox[{"ParametricSystemNDSolve", "[", 
   RowBox[{"modelmatrix", ",", 
    RowBox[{"{", 
     RowBox[{"0", ",", "0", ",", "0"}], "}"}], ",", "binput", ",", 
    RowBox[{"{", 
     RowBox[{"t", ",", "0", ",", "100"}], "}"}], ",", "x", ",", " ", 
    RowBox[{"{", 
     RowBox[{"kon", ",", " ", "koff"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.586750420365636*^9, 3.5867504224716897`*^9}, {
   3.5867507084738226`*^9, 3.586750745852381*^9}, {3.586757974200929*^9, 
   3.58675797447094*^9}, {3.5867582011688876`*^9, 3.5867582048315344`*^9}, 
   3.5867583019868555`*^9, {3.5867583742011075`*^9, 3.5867583778672013`*^9}, {
   3.5867603837275996`*^9, 3.5867604738856144`*^9}, {3.5867607907470446`*^9, 
   3.586760837439042*^9}, 3.586761180691944*^9, 3.586765531897671*^9, {
   3.5916793242055926`*^9, 3.591679351754347*^9}, 3.5916799575537825`*^9, {
   3.5916800838426347`*^9, 3.591680113236236*^9}, 3.5916801527718983`*^9},
 CellLabel->"In[6]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    SubscriptBox["x", "1"], "\[Rule]", 
    TagBox[
     TemplateBox[{RowBox[{
         StyleBox[
          TagBox["ParametricFunction", "SummaryHead"], 
          "NonInterpretableSummary"], 
         StyleBox["[", "NonInterpretableSummary"], 
         DynamicModuleBox[{Typeset`open$$ = False}, 
          PanelBox[
           PaneSelectorBox[{False -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{}, {}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090884856*^-8}, {
                    0.0874367476365131, 0.08197166587636243}, {
                    0.18222810297558026`, 0.1358255024317191}, {
                    0.27073779576926765`, 0.13315455086535802`}, {
                    0.3575112797365835, 0.08143316377978886}, {
                    0.4516394623155443, -0.007347854733426912}, {
                    0.5394859823491253, -0.08816932746972758}, {
                    0.6346872009943513, -0.13787329990112937`}, {
                    0.7281522108132057, -0.12816574147938434`}, {
                    0.8153355580866803, -0.07001063326902106}, {
                    0.9098736039718, 0.02121659675083076}, {
                    0.9999999090909091, 0.10024804094746914`}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090880112*^-8}, {
                    0.0874367476365131, 0.08090369567458766}, {
                    0.18222810297558026`, 0.12746559200130417`}, {
                    0.27073779576926765`, 0.1116266937044405}, {
                    0.3575112797365835, 0.046963725126600256`}, {
                    0.4516394623155443, -0.04509050859182233}, {
                    0.5394859823491253, -0.11115559892361665`}, {
                    0.6346872009943513, -0.12642564594664163`}, {
                    0.7281522108132057, -0.07740196037964171}, {
                    0.8153355580866803, 0.004179083230780074}, {
                    0.9098736039718, 0.08937493944143977}, {
                    0.9999999090909091, 0.12834702174618903`}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090875369*^-8}, {
                    0.0874367476365131, 0.07984396759533968}, {
                    0.18222810297558026`, 0.11939549826670079`}, {
                    0.27073779576926765`, 0.09184904274707059}, {
                    0.3575112797365835, 0.017913117173780694`}, {
                    0.4516394623155443, -0.07109962300031061}, {
                    0.5394859823491253, -0.11717052830989395`}, {
                    0.6346872009943513, -0.09879571259704382}, {
                    0.7281522108132057, -0.022693471356141894`}, {
                    0.8153355580866803, 0.06128703302641453}, {
                    0.9098736039718, 0.11605625481609519`}, {
                    0.9999999090909091, 0.10415981267620744`}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090870287*^-8}, {
                    0.0874367476365131, 0.07879243663407876}, {
                    0.18222810297558026`, 0.1116081822210312}, {
                    0.27073779576926765`, 0.07372482040530459}, {
                    0.3575112797365835, -0.006267252216927747}, {
                    0.4516394623155443, -0.08743897872291118}, {
                    0.5394859823491253, -0.11109134853087661`}, {
                    0.6346872009943513, -0.06371549528296311}, {
                    0.7281522108132057, 0.02544576624054603}, {
                    0.8153355580866803, 0.09464282937855747}, {
                    0.9098736039718, 0.10731931496853601`}, {
                    0.9999999090909091, 0.0516787429232188}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    LineBox[{{9.09090909090909*^-8, 9.090909090865543*^-8}, {
                    0.0874367476365131, 0.07774905743802465}, {
                    0.18222810297558026`, 0.10409673959866513`}, {
                    0.27073779576926765`, 0.05716133039337165}, {
                    0.3575112797365835, -0.026084496726167965`}, {
                    0.4516394623155443, -0.09591154799603378}, {
                    0.5394859823491253, -0.09685594593277226}, {
                    0.6346872009943513, -0.02730376120671303}, {
                    0.7281522108132057, 0.061646715198529656`}, {
                    0.8153355580866803, 0.1046634148537508}, {0.9098736039718,
                     0.07509702498429204}, {
                    0.9999999090909091, -0.006536873471333553}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.0909090908608*^-8}, {
                    0.0874367476365131, 0.07671378556951527}, {
                    0.18222810297558026`, 0.09685439581479163}, {
                    0.27073779576926765`, 0.042069810325321415`}, {
                    0.3575112797365835, -0.042006785469922474`}, {
                    0.4516394623155443, -0.09808544986431629}, {
                    0.5394859823491253, -0.07760167026270944}, {
                    0.6346872009943513, 0.0063643674428021085`}, {
                    0.7281522108132057, 0.08405712128907425}, {
                    0.8153355580866803, 0.09555213349985489}, {
                    0.9098736039718, 0.03202960165577907}, {
                    0.9999999090909091, -0.054402034659985464`}}]}}, 
                  AspectRatio -> 1, Axes -> {False, False}, 
                  AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Background -> 
                  GrayLevel[0.93], BaseStyle -> {FontFamily -> "Arial"}, 
                  DisplayFunction -> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Thickness[Tiny], 
                    GrayLevel[0.7]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> {Automatic, 
                    Dynamic[
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, LabelStyle -> {FontFamily -> "Arial"}, 
                  Method -> {"ScalingFunctions" -> None}, 
                  PlotRange -> {All, All}, PlotRangeClipping -> True, 
                  PlotRangePadding -> {Automatic, Automatic}, 
                  Ticks -> {Automatic, Automatic}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Expression: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    TagBox[
                    SubscriptBox["x", "1"], HoldForm], "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Parameters: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"kon", ",", "koff"}], "}"}], "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}], True -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{}, {}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090884856*^-8}, {
                    0.0874367476365131, 0.08197166587636243}, {
                    0.18222810297558026`, 0.1358255024317191}, {
                    0.27073779576926765`, 0.13315455086535802`}, {
                    0.3575112797365835, 0.08143316377978886}, {
                    0.4516394623155443, -0.007347854733426912}, {
                    0.5394859823491253, -0.08816932746972758}, {
                    0.6346872009943513, -0.13787329990112937`}, {
                    0.7281522108132057, -0.12816574147938434`}, {
                    0.8153355580866803, -0.07001063326902106}, {
                    0.9098736039718, 0.02121659675083076}, {
                    0.9999999090909091, 0.10024804094746914`}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090880112*^-8}, {
                    0.0874367476365131, 0.08090369567458766}, {
                    0.18222810297558026`, 0.12746559200130417`}, {
                    0.27073779576926765`, 0.1116266937044405}, {
                    0.3575112797365835, 0.046963725126600256`}, {
                    0.4516394623155443, -0.04509050859182233}, {
                    0.5394859823491253, -0.11115559892361665`}, {
                    0.6346872009943513, -0.12642564594664163`}, {
                    0.7281522108132057, -0.07740196037964171}, {
                    0.8153355580866803, 0.004179083230780074}, {
                    0.9098736039718, 0.08937493944143977}, {
                    0.9999999090909091, 0.12834702174618903`}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090875369*^-8}, {
                    0.0874367476365131, 0.07984396759533968}, {
                    0.18222810297558026`, 0.11939549826670079`}, {
                    0.27073779576926765`, 0.09184904274707059}, {
                    0.3575112797365835, 0.017913117173780694`}, {
                    0.4516394623155443, -0.07109962300031061}, {
                    0.5394859823491253, -0.11717052830989395`}, {
                    0.6346872009943513, -0.09879571259704382}, {
                    0.7281522108132057, -0.022693471356141894`}, {
                    0.8153355580866803, 0.06128703302641453}, {
                    0.9098736039718, 0.11605625481609519`}, {
                    0.9999999090909091, 0.10415981267620744`}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090870287*^-8}, {
                    0.0874367476365131, 0.07879243663407876}, {
                    0.18222810297558026`, 0.1116081822210312}, {
                    0.27073779576926765`, 0.07372482040530459}, {
                    0.3575112797365835, -0.006267252216927747}, {
                    0.4516394623155443, -0.08743897872291118}, {
                    0.5394859823491253, -0.11109134853087661`}, {
                    0.6346872009943513, -0.06371549528296311}, {
                    0.7281522108132057, 0.02544576624054603}, {
                    0.8153355580866803, 0.09464282937855747}, {
                    0.9098736039718, 0.10731931496853601`}, {
                    0.9999999090909091, 0.0516787429232188}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090865543*^-8}, {
                    0.0874367476365131, 0.07774905743802465}, {
                    0.18222810297558026`, 0.10409673959866513`}, {
                    0.27073779576926765`, 0.05716133039337165}, {
                    0.3575112797365835, -0.026084496726167965`}, {
                    0.4516394623155443, -0.09591154799603378}, {
                    0.5394859823491253, -0.09685594593277226}, {
                    0.6346872009943513, -0.02730376120671303}, {
                    0.7281522108132057, 0.061646715198529656`}, {
                    0.8153355580866803, 0.1046634148537508}, {0.9098736039718,
                     0.07509702498429204}, {
                    0.9999999090909091, -0.006536873471333553}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.0909090908608*^-8}, {
                    0.0874367476365131, 0.07671378556951527}, {
                    0.18222810297558026`, 0.09685439581479163}, {
                    0.27073779576926765`, 0.042069810325321415`}, {
                    0.3575112797365835, -0.042006785469922474`}, {
                    0.4516394623155443, -0.09808544986431629}, {
                    0.5394859823491253, -0.07760167026270944}, {
                    0.6346872009943513, 0.0063643674428021085`}, {
                    0.7281522108132057, 0.08405712128907425}, {
                    0.8153355580866803, 0.09555213349985489}, {
                    0.9098736039718, 0.03202960165577907}, {
                    0.9999999090909091, -0.054402034659985464`}}]}}, 
                  AspectRatio -> 1, Axes -> {False, False}, 
                  AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Background -> 
                  GrayLevel[0.93], BaseStyle -> {FontFamily -> "Arial"}, 
                  DisplayFunction -> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Thickness[Tiny], 
                    GrayLevel[0.7]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> {Automatic, 
                    Dynamic[
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, LabelStyle -> {FontFamily -> "Arial"}, 
                  Method -> {"ScalingFunctions" -> None}, 
                  PlotRange -> {All, All}, PlotRangeClipping -> True, 
                  PlotRangePadding -> {Automatic, Automatic}, 
                  Ticks -> {Automatic, Automatic}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Expression: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    TagBox[
                    SubscriptBox["x", "1"], HoldForm], "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Parameters: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"kon", ",", "koff"}], "}"}], "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Generator: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["ParametricNDSolve", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox[
                    "\"Dependent variables: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    
                    RowBox[{
                    "TemporaryVariable$422", ",", "TemporaryVariable$423", 
                    ",", "TemporaryVariable$424"}], "}"}], "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox[
                    "\"Independent variables: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", "t", "}"}], "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}]}, 
            Dynamic[Typeset`open$$], ImageSize -> Automatic], 
           BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
         StyleBox["]", "NonInterpretableSummary"]}]},
      "CopyTag",
      DisplayFunction->(#& ),
      InterpretationFunction->("ParametricFunction[<>]"& )],
     False,
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], ",", 
   RowBox[{
    SubscriptBox["x", "2"], "\[Rule]", 
    TagBox[
     TemplateBox[{RowBox[{
         StyleBox[
          TagBox["ParametricFunction", "SummaryHead"], 
          "NonInterpretableSummary"], 
         StyleBox["[", "NonInterpretableSummary"], 
         DynamicModuleBox[{Typeset`open$$ = False}, 
          PanelBox[
           PaneSelectorBox[{False -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{}, {}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090884856*^-8}, {
                    0.0874367476365131, 0.08197166587636243}, {
                    0.18222810297558026`, 0.1358255024317191}, {
                    0.27073779576926765`, 0.13315455086535802`}, {
                    0.3575112797365835, 0.08143316377978886}, {
                    0.4516394623155443, -0.007347854733426912}, {
                    0.5394859823491253, -0.08816932746972758}, {
                    0.6346872009943513, -0.13787329990112937`}, {
                    0.7281522108132057, -0.12816574147938434`}, {
                    0.8153355580866803, -0.07001063326902106}, {
                    0.9098736039718, 0.02121659675083076}, {
                    0.9999999090909091, 0.10024804094746914`}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090880112*^-8}, {
                    0.0874367476365131, 0.08090369567458766}, {
                    0.18222810297558026`, 0.12746559200130417`}, {
                    0.27073779576926765`, 0.1116266937044405}, {
                    0.3575112797365835, 0.046963725126600256`}, {
                    0.4516394623155443, -0.04509050859182233}, {
                    0.5394859823491253, -0.11115559892361665`}, {
                    0.6346872009943513, -0.12642564594664163`}, {
                    0.7281522108132057, -0.07740196037964171}, {
                    0.8153355580866803, 0.004179083230780074}, {
                    0.9098736039718, 0.08937493944143977}, {
                    0.9999999090909091, 0.12834702174618903`}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090875369*^-8}, {
                    0.0874367476365131, 0.07984396759533968}, {
                    0.18222810297558026`, 0.11939549826670079`}, {
                    0.27073779576926765`, 0.09184904274707059}, {
                    0.3575112797365835, 0.017913117173780694`}, {
                    0.4516394623155443, -0.07109962300031061}, {
                    0.5394859823491253, -0.11717052830989395`}, {
                    0.6346872009943513, -0.09879571259704382}, {
                    0.7281522108132057, -0.022693471356141894`}, {
                    0.8153355580866803, 0.06128703302641453}, {
                    0.9098736039718, 0.11605625481609519`}, {
                    0.9999999090909091, 0.10415981267620744`}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090870287*^-8}, {
                    0.0874367476365131, 0.07879243663407876}, {
                    0.18222810297558026`, 0.1116081822210312}, {
                    0.27073779576926765`, 0.07372482040530459}, {
                    0.3575112797365835, -0.006267252216927747}, {
                    0.4516394623155443, -0.08743897872291118}, {
                    0.5394859823491253, -0.11109134853087661`}, {
                    0.6346872009943513, -0.06371549528296311}, {
                    0.7281522108132057, 0.02544576624054603}, {
                    0.8153355580866803, 0.09464282937855747}, {
                    0.9098736039718, 0.10731931496853601`}, {
                    0.9999999090909091, 0.0516787429232188}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090865543*^-8}, {
                    0.0874367476365131, 0.07774905743802465}, {
                    0.18222810297558026`, 0.10409673959866513`}, {
                    0.27073779576926765`, 0.05716133039337165}, {
                    0.3575112797365835, -0.026084496726167965`}, {
                    0.4516394623155443, -0.09591154799603378}, {
                    0.5394859823491253, -0.09685594593277226}, {
                    0.6346872009943513, -0.02730376120671303}, {
                    0.7281522108132057, 0.061646715198529656`}, {
                    0.8153355580866803, 0.1046634148537508}, {0.9098736039718,
                     0.07509702498429204}, {
                    0.9999999090909091, -0.006536873471333553}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.0909090908608*^-8}, {
                    0.0874367476365131, 0.07671378556951527}, {
                    0.18222810297558026`, 0.09685439581479163}, {
                    0.27073779576926765`, 0.042069810325321415`}, {
                    0.3575112797365835, -0.042006785469922474`}, {
                    0.4516394623155443, -0.09808544986431629}, {
                    0.5394859823491253, -0.07760167026270944}, {
                    0.6346872009943513, 0.0063643674428021085`}, {
                    0.7281522108132057, 0.08405712128907425}, {
                    0.8153355580866803, 0.09555213349985489}, {
                    0.9098736039718, 0.03202960165577907}, {
                    0.9999999090909091, -0.054402034659985464`}}]}}, 
                  AspectRatio -> 1, Axes -> {False, False}, 
                  AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Background -> 
                  GrayLevel[0.93], BaseStyle -> {FontFamily -> "Arial"}, 
                  DisplayFunction -> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Thickness[Tiny], 
                    GrayLevel[0.7]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> {Automatic, 
                    Dynamic[
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, LabelStyle -> {FontFamily -> "Arial"}, 
                  Method -> {"ScalingFunctions" -> None}, 
                  PlotRange -> {All, All}, PlotRangeClipping -> True, 
                  PlotRangePadding -> {Automatic, Automatic}, 
                  Ticks -> {Automatic, Automatic}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Expression: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    TagBox[
                    SubscriptBox["x", "2"], HoldForm], "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Parameters: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"kon", ",", "koff"}], "}"}], "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}], True -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{}, {}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090884856*^-8}, {
                    0.0874367476365131, 0.08197166587636243}, {
                    0.18222810297558026`, 0.1358255024317191}, {
                    0.27073779576926765`, 0.13315455086535802`}, {
                    0.3575112797365835, 0.08143316377978886}, {
                    0.4516394623155443, -0.007347854733426912}, {
                    0.5394859823491253, -0.08816932746972758}, {
                    0.6346872009943513, -0.13787329990112937`}, {
                    0.7281522108132057, -0.12816574147938434`}, {
                    0.8153355580866803, -0.07001063326902106}, {
                    0.9098736039718, 0.02121659675083076}, {
                    0.9999999090909091, 0.10024804094746914`}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090880112*^-8}, {
                    0.0874367476365131, 0.08090369567458766}, {
                    0.18222810297558026`, 0.12746559200130417`}, {
                    0.27073779576926765`, 0.1116266937044405}, {
                    0.3575112797365835, 0.046963725126600256`}, {
                    0.4516394623155443, -0.04509050859182233}, {
                    0.5394859823491253, -0.11115559892361665`}, {
                    0.6346872009943513, -0.12642564594664163`}, {
                    0.7281522108132057, -0.07740196037964171}, {
                    0.8153355580866803, 0.004179083230780074}, {
                    0.9098736039718, 0.08937493944143977}, {
                    0.9999999090909091, 0.12834702174618903`}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090875369*^-8}, {
                    0.0874367476365131, 0.07984396759533968}, {
                    0.18222810297558026`, 0.11939549826670079`}, {
                    0.27073779576926765`, 0.09184904274707059}, {
                    0.3575112797365835, 0.017913117173780694`}, {
                    0.4516394623155443, -0.07109962300031061}, {
                    0.5394859823491253, -0.11717052830989395`}, {
                    0.6346872009943513, -0.09879571259704382}, {
                    0.7281522108132057, -0.022693471356141894`}, {
                    0.8153355580866803, 0.06128703302641453}, {
                    0.9098736039718, 0.11605625481609519`}, {
                    0.9999999090909091, 0.10415981267620744`}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090870287*^-8}, {
                    0.0874367476365131, 0.07879243663407876}, {
                    0.18222810297558026`, 0.1116081822210312}, {
                    0.27073779576926765`, 0.07372482040530459}, {
                    0.3575112797365835, -0.006267252216927747}, {
                    0.4516394623155443, -0.08743897872291118}, {
                    0.5394859823491253, -0.11109134853087661`}, {
                    0.6346872009943513, -0.06371549528296311}, {
                    0.7281522108132057, 0.02544576624054603}, {
                    0.8153355580866803, 0.09464282937855747}, {
                    0.9098736039718, 0.10731931496853601`}, {
                    0.9999999090909091, 0.0516787429232188}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090865543*^-8}, {
                    0.0874367476365131, 0.07774905743802465}, {
                    0.18222810297558026`, 0.10409673959866513`}, {
                    0.27073779576926765`, 0.05716133039337165}, {
                    0.3575112797365835, -0.026084496726167965`}, {
                    0.4516394623155443, -0.09591154799603378}, {
                    0.5394859823491253, -0.09685594593277226}, {
                    0.6346872009943513, -0.02730376120671303}, {
                    0.7281522108132057, 0.061646715198529656`}, {
                    0.8153355580866803, 0.1046634148537508}, {0.9098736039718,
                     0.07509702498429204}, {
                    0.9999999090909091, -0.006536873471333553}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.0909090908608*^-8}, {
                    0.0874367476365131, 0.07671378556951527}, {
                    0.18222810297558026`, 0.09685439581479163}, {
                    0.27073779576926765`, 0.042069810325321415`}, {
                    0.3575112797365835, -0.042006785469922474`}, {
                    0.4516394623155443, -0.09808544986431629}, {
                    0.5394859823491253, -0.07760167026270944}, {
                    0.6346872009943513, 0.0063643674428021085`}, {
                    0.7281522108132057, 0.08405712128907425}, {
                    0.8153355580866803, 0.09555213349985489}, {
                    0.9098736039718, 0.03202960165577907}, {
                    0.9999999090909091, -0.054402034659985464`}}]}}, 
                  AspectRatio -> 1, Axes -> {False, False}, 
                  AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Background -> 
                  GrayLevel[0.93], BaseStyle -> {FontFamily -> "Arial"}, 
                  DisplayFunction -> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Thickness[Tiny], 
                    GrayLevel[0.7]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> {Automatic, 
                    Dynamic[
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, LabelStyle -> {FontFamily -> "Arial"}, 
                  Method -> {"ScalingFunctions" -> None}, 
                  PlotRange -> {All, All}, PlotRangeClipping -> True, 
                  PlotRangePadding -> {Automatic, Automatic}, 
                  Ticks -> {Automatic, Automatic}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Expression: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    TagBox[
                    SubscriptBox["x", "2"], HoldForm], "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Parameters: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"kon", ",", "koff"}], "}"}], "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Generator: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["ParametricNDSolve", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox[
                    "\"Dependent variables: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    
                    RowBox[{
                    "TemporaryVariable$422", ",", "TemporaryVariable$423", 
                    ",", "TemporaryVariable$424"}], "}"}], "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox[
                    "\"Independent variables: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", "t", "}"}], "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}]}, 
            Dynamic[Typeset`open$$], ImageSize -> Automatic], 
           BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
         StyleBox["]", "NonInterpretableSummary"]}]},
      "CopyTag",
      DisplayFunction->(#& ),
      InterpretationFunction->("ParametricFunction[<>]"& )],
     False,
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}], ",", 
   RowBox[{
    SubscriptBox["x", "3"], "\[Rule]", 
    TagBox[
     TemplateBox[{RowBox[{
         StyleBox[
          TagBox["ParametricFunction", "SummaryHead"], 
          "NonInterpretableSummary"], 
         StyleBox["[", "NonInterpretableSummary"], 
         DynamicModuleBox[{Typeset`open$$ = False}, 
          PanelBox[
           PaneSelectorBox[{False -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquarePlusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = True), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{}, {}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090884856*^-8}, {
                    0.0874367476365131, 0.08197166587636243}, {
                    0.18222810297558026`, 0.1358255024317191}, {
                    0.27073779576926765`, 0.13315455086535802`}, {
                    0.3575112797365835, 0.08143316377978886}, {
                    0.4516394623155443, -0.007347854733426912}, {
                    0.5394859823491253, -0.08816932746972758}, {
                    0.6346872009943513, -0.13787329990112937`}, {
                    0.7281522108132057, -0.12816574147938434`}, {
                    0.8153355580866803, -0.07001063326902106}, {
                    0.9098736039718, 0.02121659675083076}, {
                    0.9999999090909091, 0.10024804094746914`}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090880112*^-8}, {
                    0.0874367476365131, 0.08090369567458766}, {
                    0.18222810297558026`, 0.12746559200130417`}, {
                    0.27073779576926765`, 0.1116266937044405}, {
                    0.3575112797365835, 0.046963725126600256`}, {
                    0.4516394623155443, -0.04509050859182233}, {
                    0.5394859823491253, -0.11115559892361665`}, {
                    0.6346872009943513, -0.12642564594664163`}, {
                    0.7281522108132057, -0.07740196037964171}, {
                    0.8153355580866803, 0.004179083230780074}, {
                    0.9098736039718, 0.08937493944143977}, {
                    0.9999999090909091, 0.12834702174618903`}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090875369*^-8}, {
                    0.0874367476365131, 0.07984396759533968}, {
                    0.18222810297558026`, 0.11939549826670079`}, {
                    0.27073779576926765`, 0.09184904274707059}, {
                    0.3575112797365835, 0.017913117173780694`}, {
                    0.4516394623155443, -0.07109962300031061}, {
                    0.5394859823491253, -0.11717052830989395`}, {
                    0.6346872009943513, -0.09879571259704382}, {
                    0.7281522108132057, -0.022693471356141894`}, {
                    0.8153355580866803, 0.06128703302641453}, {
                    0.9098736039718, 0.11605625481609519`}, {
                    0.9999999090909091, 0.10415981267620744`}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090870287*^-8}, {
                    0.0874367476365131, 0.07879243663407876}, {
                    0.18222810297558026`, 0.1116081822210312}, {
                    0.27073779576926765`, 0.07372482040530459}, {
                    0.3575112797365835, -0.006267252216927747}, {
                    0.4516394623155443, -0.08743897872291118}, {
                    0.5394859823491253, -0.11109134853087661`}, {
                    0.6346872009943513, -0.06371549528296311}, {
                    0.7281522108132057, 0.02544576624054603}, {
                    0.8153355580866803, 0.09464282937855747}, {
                    0.9098736039718, 0.10731931496853601`}, {
                    0.9999999090909091, 0.0516787429232188}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090865543*^-8}, {
                    0.0874367476365131, 0.07774905743802465}, {
                    0.18222810297558026`, 0.10409673959866513`}, {
                    0.27073779576926765`, 0.05716133039337165}, {
                    0.3575112797365835, -0.026084496726167965`}, {
                    0.4516394623155443, -0.09591154799603378}, {
                    0.5394859823491253, -0.09685594593277226}, {
                    0.6346872009943513, -0.02730376120671303}, {
                    0.7281522108132057, 0.061646715198529656`}, {
                    0.8153355580866803, 0.1046634148537508}, {0.9098736039718,
                     0.07509702498429204}, {
                    0.9999999090909091, -0.006536873471333553}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.0909090908608*^-8}, {
                    0.0874367476365131, 0.07671378556951527}, {
                    0.18222810297558026`, 0.09685439581479163}, {
                    0.27073779576926765`, 0.042069810325321415`}, {
                    0.3575112797365835, -0.042006785469922474`}, {
                    0.4516394623155443, -0.09808544986431629}, {
                    0.5394859823491253, -0.07760167026270944}, {
                    0.6346872009943513, 0.0063643674428021085`}, {
                    0.7281522108132057, 0.08405712128907425}, {
                    0.8153355580866803, 0.09555213349985489}, {
                    0.9098736039718, 0.03202960165577907}, {
                    0.9999999090909091, -0.054402034659985464`}}]}}, 
                  AspectRatio -> 1, Axes -> {False, False}, 
                  AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Background -> 
                  GrayLevel[0.93], BaseStyle -> {FontFamily -> "Arial"}, 
                  DisplayFunction -> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Thickness[Tiny], 
                    GrayLevel[0.7]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> {Automatic, 
                    Dynamic[
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, LabelStyle -> {FontFamily -> "Arial"}, 
                  Method -> {"ScalingFunctions" -> None}, 
                  PlotRange -> {All, All}, PlotRangeClipping -> True, 
                  PlotRangePadding -> {Automatic, Automatic}, 
                  Ticks -> {Automatic, Automatic}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Expression: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    TagBox[
                    SubscriptBox["x", "3"], HoldForm], "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Parameters: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"kon", ",", "koff"}], "}"}], "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}], True -> GridBox[{{
                 PaneBox[
                  ButtonBox[
                   DynamicBox[
                    FEPrivate`FrontEndResource[
                    "FEBitmaps", "SquareMinusIconMedium"]], 
                   ButtonFunction :> (Typeset`open$$ = False), Appearance -> 
                   None, Evaluator -> Automatic, Method -> "Preemptive"], 
                  Alignment -> {Center, Center}, ImageSize -> 
                  Dynamic[{
                    Automatic, 3.5 CurrentValue["FontCapHeight"]/
                    AbsoluteCurrentValue[Magnification]}]], 
                 GraphicsBox[{{}, {}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090884856*^-8}, {
                    0.0874367476365131, 0.08197166587636243}, {
                    0.18222810297558026`, 0.1358255024317191}, {
                    0.27073779576926765`, 0.13315455086535802`}, {
                    0.3575112797365835, 0.08143316377978886}, {
                    0.4516394623155443, -0.007347854733426912}, {
                    0.5394859823491253, -0.08816932746972758}, {
                    0.6346872009943513, -0.13787329990112937`}, {
                    0.7281522108132057, -0.12816574147938434`}, {
                    0.8153355580866803, -0.07001063326902106}, {
                    0.9098736039718, 0.02121659675083076}, {
                    0.9999999090909091, 0.10024804094746914`}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090880112*^-8}, {
                    0.0874367476365131, 0.08090369567458766}, {
                    0.18222810297558026`, 0.12746559200130417`}, {
                    0.27073779576926765`, 0.1116266937044405}, {
                    0.3575112797365835, 0.046963725126600256`}, {
                    0.4516394623155443, -0.04509050859182233}, {
                    0.5394859823491253, -0.11115559892361665`}, {
                    0.6346872009943513, -0.12642564594664163`}, {
                    0.7281522108132057, -0.07740196037964171}, {
                    0.8153355580866803, 0.004179083230780074}, {
                    0.9098736039718, 0.08937493944143977}, {
                    0.9999999090909091, 0.12834702174618903`}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090875369*^-8}, {
                    0.0874367476365131, 0.07984396759533968}, {
                    0.18222810297558026`, 0.11939549826670079`}, {
                    0.27073779576926765`, 0.09184904274707059}, {
                    0.3575112797365835, 0.017913117173780694`}, {
                    0.4516394623155443, -0.07109962300031061}, {
                    0.5394859823491253, -0.11717052830989395`}, {
                    0.6346872009943513, -0.09879571259704382}, {
                    0.7281522108132057, -0.022693471356141894`}, {
                    0.8153355580866803, 0.06128703302641453}, {
                    0.9098736039718, 0.11605625481609519`}, {
                    0.9999999090909091, 0.10415981267620744`}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090870287*^-8}, {
                    0.0874367476365131, 0.07879243663407876}, {
                    0.18222810297558026`, 0.1116081822210312}, {
                    0.27073779576926765`, 0.07372482040530459}, {
                    0.3575112797365835, -0.006267252216927747}, {
                    0.4516394623155443, -0.08743897872291118}, {
                    0.5394859823491253, -0.11109134853087661`}, {
                    0.6346872009943513, -0.06371549528296311}, {
                    0.7281522108132057, 0.02544576624054603}, {
                    0.8153355580866803, 0.09464282937855747}, {
                    0.9098736039718, 0.10731931496853601`}, {
                    0.9999999090909091, 0.0516787429232188}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.090909090865543*^-8}, {
                    0.0874367476365131, 0.07774905743802465}, {
                    0.18222810297558026`, 0.10409673959866513`}, {
                    0.27073779576926765`, 0.05716133039337165}, {
                    0.3575112797365835, -0.026084496726167965`}, {
                    0.4516394623155443, -0.09591154799603378}, {
                    0.5394859823491253, -0.09685594593277226}, {
                    0.6346872009943513, -0.02730376120671303}, {
                    0.7281522108132057, 0.061646715198529656`}, {
                    0.8153355580866803, 0.1046634148537508}, {0.9098736039718,
                     0.07509702498429204}, {
                    0.9999999090909091, -0.006536873471333553}}]}, {
                    GrayLevel[0.55], 
                    AbsoluteThickness[1.5], 
                    Opacity[1.], 
                    
                    LineBox[{{9.09090909090909*^-8, 9.0909090908608*^-8}, {
                    0.0874367476365131, 0.07671378556951527}, {
                    0.18222810297558026`, 0.09685439581479163}, {
                    0.27073779576926765`, 0.042069810325321415`}, {
                    0.3575112797365835, -0.042006785469922474`}, {
                    0.4516394623155443, -0.09808544986431629}, {
                    0.5394859823491253, -0.07760167026270944}, {
                    0.6346872009943513, 0.0063643674428021085`}, {
                    0.7281522108132057, 0.08405712128907425}, {
                    0.8153355580866803, 0.09555213349985489}, {
                    0.9098736039718, 0.03202960165577907}, {
                    0.9999999090909091, -0.054402034659985464`}}]}}, 
                  AspectRatio -> 1, Axes -> {False, False}, 
                  AxesLabel -> {None, None}, AxesOrigin -> {0, 0}, Background -> 
                  GrayLevel[0.93], BaseStyle -> {FontFamily -> "Arial"}, 
                  DisplayFunction -> Identity, 
                  Frame -> {{True, True}, {True, True}}, 
                  FrameLabel -> {{None, None}, {None, None}}, FrameStyle -> 
                  Directive[
                    Thickness[Tiny], 
                    GrayLevel[0.7]], 
                  FrameTicks -> {{None, None}, {None, None}}, 
                  GridLines -> {None, None}, GridLinesStyle -> Directive[
                    GrayLevel[0.5, 0.4]], ImageSize -> {Automatic, 
                    Dynamic[
                    3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                    Magnification])]}, LabelStyle -> {FontFamily -> "Arial"}, 
                  Method -> {"ScalingFunctions" -> None}, 
                  PlotRange -> {All, All}, PlotRangeClipping -> True, 
                  PlotRangePadding -> {Automatic, Automatic}, 
                  Ticks -> {Automatic, Automatic}], 
                 GridBox[{{
                    RowBox[{
                    TagBox["\"Expression: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    TagBox[
                    SubscriptBox["x", "3"], HoldForm], "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Parameters: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    RowBox[{"kon", ",", "koff"}], "}"}], "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox["\"Generator: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox["ParametricNDSolve", "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox[
                    "\"Dependent variables: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", 
                    
                    RowBox[{
                    "TemporaryVariable$422", ",", "TemporaryVariable$423", 
                    ",", "TemporaryVariable$424"}], "}"}], "SummaryItem"]}]}, {
                    RowBox[{
                    TagBox[
                    "\"Independent variables: \"", "SummaryItemAnnotation"], 
                    "\[InvisibleSpace]", 
                    TagBox[
                    RowBox[{"{", "t", "}"}], "SummaryItem"]}]}}, 
                  GridBoxAlignment -> {
                   "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
                  AutoDelete -> False, 
                  GridBoxItemSize -> {
                   "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
                  GridBoxSpacings -> {
                   "Columns" -> {{2}}, "Rows" -> {{Automatic}}}, 
                  BaseStyle -> {
                   ShowStringCharacters -> False, NumberMarks -> False, 
                    PrintPrecision -> 3, ShowSyntaxStyles -> False}]}}, 
               GridBoxAlignment -> {"Rows" -> {{Top}}}, AutoDelete -> False, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               BaselinePosition -> {1, 1}]}, 
            Dynamic[Typeset`open$$], ImageSize -> Automatic], 
           BaselinePosition -> Baseline], DynamicModuleValues :> {}], 
         StyleBox["]", "NonInterpretableSummary"]}]},
      "CopyTag",
      DisplayFunction->(#& ),
      InterpretationFunction->("ParametricFunction[<>]"& )],
     False,
     Editable->False,
     SelectWithContents->True,
     Selectable->False]}]}], "}"}]], "Output",
 CellChangeTimes->{{3.5916800844064293`*^9, 3.591680113773779*^9}, 
   3.591680153490706*^9, 3.5920609761391025`*^9, 3.592061276680647*^9, 
   3.6436168082414594`*^9, 3.656235507372716*^9},
 CellLabel->"Out[6]="]
}, Open  ]],

Cell[TextData[{
 "2.-Now it is computed  ",
 Cell[BoxData[
  FormBox[
   RowBox[{"\[Del]", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"f", "(", "t", ")"}], ",", " ", 
      RowBox[{"{", 
       RowBox[{"a", ",", " ", "b"}], "}"}]}], ")"}]}], TraditionalForm]]],
 " = {",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"df", "(", "t", ")"}], "da"], TraditionalForm]]],
 ",",
 Cell[BoxData[
  FormBox[
   FractionBox[
    RowBox[{"df", "(", "t", ")"}], "db"], TraditionalForm]]],
 "}. We need build a numerical method for computing the derivatives"
}], "Text",
 CellChangeTimes->{{3.539847585192514*^9, 3.5398476212441773`*^9}, {
  3.5920602595185914`*^9, 3.592060296930332*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"fa", "[", 
   RowBox[{
    RowBox[{"a1_", "?", "NumberQ"}], ",", " ", 
    RowBox[{"b_", "?", "NumberQ"}], ",", " ", 
    RowBox[{"t_", "?", "NumberQ"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["x", "1"], "[", 
        RowBox[{"a", ",", "b"}], "]"}], ",", "a"}], "]"}], "[", "t", "]"}], "/.", 
    RowBox[{"a", "\[Rule]", "a1"}]}], "/.", "sol"}]}]], "Input",
 CellChangeTimes->{{3.5454970322092934`*^9, 3.545497039822107*^9}, {
   3.545497075249769*^9, 3.545497169832735*^9}, {3.5454974210711765`*^9, 
   3.545497486310491*^9}, {3.5454978827227874`*^9, 3.5454978853435917`*^9}, {
   3.5455723871899233`*^9, 3.5455724137879705`*^9}, {3.5455724820068903`*^9, 
   3.545572492302908*^9}, {3.545572597665493*^9, 3.545572625963943*^9}, {
   3.545572657990799*^9, 3.545572665603613*^9}, {3.545572717083703*^9, 
   3.5455727340253325`*^9}, {3.545572839497118*^9, 3.545572935827287*^9}, {
   3.569512543787388*^9, 3.5695125686392317`*^9}, 3.5695129461452947`*^9, 
   3.5695131845449133`*^9, {3.586442124927493*^9, 3.5864421278135*^9}, 
   3.586442592808028*^9, {3.5864426424634037`*^9, 3.586442644663031*^9}, {
   3.5865219147340097`*^9, 3.5865219168868947`*^9}, {3.5865223715356126`*^9, 
   3.5865223770736446`*^9}, {3.586611792967874*^9, 3.586611793279882*^9}, {
   3.586619614257415*^9, 3.5866196501661215`*^9}, {3.5866197260707116`*^9, 
   3.5866197306531696`*^9}, 3.5866207291903534`*^9, 3.586660164246765*^9, {
   3.5866602354248824`*^9, 3.586660255283868*^9}, {3.586669184681472*^9, 
   3.586669186437647*^9}, {3.5916801818729763`*^9, 3.591680185779539*^9}},
 CellLabel->"In[7]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"fb", "[", 
   RowBox[{
    RowBox[{"a_", "?", "NumberQ"}], ",", " ", 
    RowBox[{"b1_", "?", "NumberQ"}], ",", " ", 
    RowBox[{"t_", "?", "NumberQ"}]}], "]"}], ":=", 
  RowBox[{
   RowBox[{
    RowBox[{
     RowBox[{"D", "[", 
      RowBox[{
       RowBox[{
        SubscriptBox["x", "2"], "[", 
        RowBox[{"a", ",", "b"}], "]"}], ",", "b"}], "]"}], "[", "t", "]"}], "/.", 
    RowBox[{"b", "\[Rule]", "b1"}]}], "/.", "sol"}]}]], "Input",
 CellChangeTimes->{{3.5454970322092934`*^9, 3.545497039822107*^9}, {
   3.545497075249769*^9, 3.545497169832735*^9}, {3.5454974210711765`*^9, 
   3.545497486310491*^9}, {3.5454978827227874`*^9, 3.5454978853435917`*^9}, {
   3.5455723871899233`*^9, 3.5455724137879705`*^9}, {3.5455724820068903`*^9, 
   3.545572492302908*^9}, {3.545572597665493*^9, 3.545572625963943*^9}, {
   3.545572657990799*^9, 3.545572665603613*^9}, {3.545572717083703*^9, 
   3.5455727340253325`*^9}, {3.545572839497118*^9, 3.545572935827287*^9}, {
   3.569512543787388*^9, 3.5695125686392317`*^9}, 3.5695129461452947`*^9, 
   3.5695131845449133`*^9, {3.586442124927493*^9, 3.5864421278135*^9}, 
   3.586442592808028*^9, {3.5864426424634037`*^9, 3.586442644663031*^9}, {
   3.5865219147340097`*^9, 3.5865219168868947`*^9}, {3.5865223715356126`*^9, 
   3.5865223770736446`*^9}, {3.586611792967874*^9, 3.586611793279882*^9}, {
   3.586619614257415*^9, 3.5866196501661215`*^9}, {3.5866197260707116`*^9, 
   3.5866197306531696`*^9}, 3.5866207291903534`*^9, 3.586660164246765*^9, {
   3.5866602354248824`*^9, 3.586660255283868*^9}, {3.5866604529066286`*^9, 
   3.586660471963534*^9}, {3.5866612994287105`*^9, 3.5866613133910685`*^9}, {
   3.586669189339937*^9, 3.5866691906320667`*^9}, {3.591680189068552*^9, 
   3.5916801906136756`*^9}},
 CellLabel->"In[8]:="],

Cell[TextData[{
 "3.- It is build a function to evaluate \[Del](f(t), \[Beta]) at points ",
 Cell[BoxData[
  FormBox["t", TraditionalForm]]],
 ":{",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "0"], TraditionalForm]]],
 ",..., ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "n"], TraditionalForm]]],
 "}: ",
 Cell[BoxData[
  FormBox[
   RowBox[{"X", " ", "=", " ", 
    RowBox[{"{", 
     RowBox[{
      FormBox[
       SubscriptBox["X", "1"],
       TraditionalForm], ",", "...", ",", " ", 
      FormBox[
       SubscriptBox["X", "p"],
       TraditionalForm]}], "}"}], " "}], TraditionalForm]]],
 "with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["X", "1"], TraditionalForm]]],
 " = {",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"df", "(", 
      SubscriptBox["t", "0"], ")"}], 
     SubscriptBox["d\[Beta]", "1"]], ",", " ", "...", ",", 
    FractionBox[
     RowBox[{"df", "(", 
      SubscriptBox["t", "n"], ")"}], 
     SubscriptBox["d\[Beta]", "1"]], " "}], TraditionalForm]]],
 "}, ..., ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["X", "p"], TraditionalForm]]],
 " = {",
 Cell[BoxData[
  FormBox[
   RowBox[{
    FractionBox[
     RowBox[{"df", "(", 
      SubscriptBox["t", "0"], ")"}], 
     SubscriptBox["d\[Beta]", "p"]], ",", " ", "...", ",", 
    FractionBox[
     RowBox[{"df", "(", 
      SubscriptBox["t", "n"], ")"}], 
     SubscriptBox["d\[Beta]", "p"]], " "}], TraditionalForm]]],
 "}  "
}], "Text",
 CellChangeTimes->{{3.5398482299416466`*^9, 3.5398482465244756`*^9}, {
  3.540126025609722*^9, 3.540126025609722*^9}, {3.540624755880291*^9, 
  3.5406247594214973`*^9}, {3.5406253882274017`*^9, 3.540625389023003*^9}, {
  3.592060322870926*^9, 3.592060404792138*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{"X1", "[", 
   RowBox[{"a_", ",", "b_", ",", " ", "ti_"}], "]"}], ":=", 
  RowBox[{"{", " ", 
   RowBox[{
    RowBox[{"fa", "[", 
     RowBox[{"a", ",", "b", ",", " ", "ti"}], "]"}], ",", " ", 
    RowBox[{"fb", "[", 
     RowBox[{"a", ",", "b", ",", " ", "ti"}], "]"}]}], "}"}]}]], "Input",
 CellChangeTimes->CompressedData["
1:eJxTTMoPSmViYGAQBWIQHedY9tsh4ZVjqcrXPyD6yhtVRkcg/WGvEheIDtPT
4gfR82xtBUA0QyyXGIj+9GiJJIhu0NRRBdF8RZvB9JuQw4kgukfBOQlEJyWa
zgHRGoFT54Lovo4ZS0G00DSFlSCajeX6RhB9r+YFmLZbNXm/SeIrx2UWXUdB
dFPQq3sgepP9wUcg+stO3b4Dma8cTXn4JoJotV1vzx8C0mZ5hjdB9K5Hc1IP
A2mlE3fB9IR2rcUus4DmcsUuAdGrl5rsBdExeXvA9Ftz9scg+ljwXzCduuSr
kweQftO20RVER7zRbtu/A6i+62QXiFZhzVwCogW8c5aD6CVswufeA2n/ihlg
GgDQ2qhO
  "],
 CellLabel->"In[9]:="],

Cell[TextData[{
 "4.- A typical election for compute the covariance matrix is assumed that  \
that the relationship between samples decays exponentially with increasing \
time-distance between them, that is  ",
 Cell[BoxData[
  FormBox["\[CapitalGamma]", TraditionalForm]]],
 " = {",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "ij"], TraditionalForm]]],
 "} with ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["l", "ij"], TraditionalForm]]],
 "= exp {\[Rho]|",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["t", "j"], " ", "-"}], TraditionalForm]]],
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "j"], TraditionalForm]]],
 "|}.",
 StyleBox["For computational purpose we have found more appropriate to use \
the distance ",
  FontVariations->{"CompatibilityType"->0}],
 Cell[BoxData[
  FormBox[
   SubscriptBox["d", "i"], TraditionalForm]]],
 StyleBox[" ",
  FontVariations->{"CompatibilityType"->0}],
 "= ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["t", "i"], "-", 
    SubscriptBox["t", 
     RowBox[{"i", "-", "1"}]]}], TraditionalForm]]],
 ", ",
 StyleBox["instead of  ",
  FontVariations->{"CompatibilityType"->0}],
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 ", then ",
 Cell[BoxData[
  FormBox[
   SubscriptBox["t", "i"], TraditionalForm]]],
 "= ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    UnderscriptBox["\[Sum]", "i"], 
    SubscriptBox["d", "i"]}], TraditionalForm]]],
 " being ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SubscriptBox["d", "0"], " ", "=", 
    SubscriptBox["t", "0"], " "}], TraditionalForm]]],
 ". That is for a two points design . We suppose a 3-points design. The first \
is defined by the user \n\n ",
 Cell[BoxData[
  FormBox["\[CapitalGamma]", TraditionalForm]]],
 " where "
}], "Text",
 CellChangeTimes->{{3.540625406183033*^9, 3.5406254109722414`*^9}, {
  3.5451304552347426`*^9, 3.5451304744383764`*^9}, {3.5920604202633753`*^9, 
  3.59206042082592*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"\[CapitalGamma]", "=", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"1", ",", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[Rho]"}], " ", "d1"}]], ",", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[Rho]"}], " ", 
          RowBox[{"(", 
           RowBox[{"d1", "+", "d2"}], ")"}]}]]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[Rho]"}], " ", "d1"}]], ",", "1", ",", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[Rho]"}], " ", "d2"}]]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[Rho]"}], " ", 
          RowBox[{"(", 
           RowBox[{"d1", "+", "d2"}], ")"}]}]], ",", 
        SuperscriptBox["\[ExponentialE]", 
         RowBox[{
          RowBox[{"-", "\[Rho]"}], " ", "d2"}]], ",", "1"}], "}"}]}], "}"}]}],
    ";"}], ";"}]], "Input",
 CellChangeTimes->{
  3.540625252787964*^9, {3.5406254244350653`*^9, 3.540625431891878*^9}, 
   3.5451111354347157`*^9, 3.5451304391355143`*^9, 3.5451305206924577`*^9, 
   3.570973146430005*^9},
 CellLabel->"In[10]:="],

Cell[TextData[{
 "6.-  Now it is computed the convariance matrix \[CapitalSigma] = ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["\[Sigma]", "2"], TraditionalForm]]],
 "  ",
 Cell[BoxData[
  FormBox["\[CapitalGamma]", TraditionalForm]]]
}], "Text"],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"\[CapitalSigma]", " ", "=", " ", 
    RowBox[{
     FormBox[
      SuperscriptBox["\[Sigma]", "2"],
      TraditionalForm], "*", "\[CapitalGamma]"}]}], ";"}]}]], "Input",
 CellLabel->"In[11]:="],

Cell["We take:", "Text",
 CellChangeTimes->{{3.543644917601961*^9, 3.543644926561973*^9}}],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"d0", "=", "0"}], ";", 
   RowBox[{"\[Rho]", "=", "1"}], ";", 
   RowBox[{"\[Sigma]", " ", "=", "1"}], ";"}], " "}]], "Input",
 CellChangeTimes->{{3.5401260979494495`*^9, 3.5401261152186794`*^9}, {
  3.540625474339553*^9, 3.5406254961483912`*^9}, {3.54062563813984*^9, 
  3.5406256421646476`*^9}, {3.5406256729591017`*^9, 3.540625686000725*^9}, {
  3.544972054071789*^9, 3.544972054539789*^9}},
 CellLabel->"In[12]:="],

Cell["\<\
We will also  need give the initial values for the \[Beta] parameters and the \
standard deviation of the measures. kon= 0.7, koff=0.11\
\>", "Text",
 CellChangeTimes->{{3.540625487303176*^9, 3.540625491327983*^9}, 
   3.5436447801117687`*^9, 3.5436448765019035`*^9, {3.543644996322071*^9, 
   3.5436450167921*^9}, {3.5449611717455993`*^9, 3.5449611776499367`*^9}, {
   3.5449612360022745`*^9, 3.5449612482409744`*^9}, 3.5916802683673954`*^9}],

Cell["7.- Then we can obtain the information matrix", "Text",
 CellChangeTimes->{{3.5406256750183053`*^9, 3.540625677093109*^9}, 
   3.5436441346508646`*^9}],

Cell[TextData[{
 "M =  ",
 Cell[BoxData[
  FormBox[
   RowBox[{
    SuperscriptBox["X", "T"], " ", 
    SuperscriptBox["\[CapitalSigma]", 
     RowBox[{"-", "1"}]], " ", "X", " "}], TraditionalForm]]]
}], "Text"],

Cell[" m := X . Inverse[\[CapitalSigma]].  Transpose[X];", "Text",
 CellChangeTimes->{3.5401265957751226`*^9, 3.540127525209155*^9}],

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"m1", "[", "ti_", "]"}], " ", ":=", 
   RowBox[{
    RowBox[{"Transpose", "[", 
     RowBox[{"Map", "[", 
      RowBox[{
       RowBox[{
        RowBox[{"X1", "[", 
         RowBox[{"0.7", ",", " ", "0.11", ",", " ", "#"}], "]"}], "&"}], ",", 
       "ti"}], "]"}], " ", "]"}], ".", " ", 
    RowBox[{"Inverse", "[", "\[CapitalSigma]", "]"}], ".", 
    RowBox[{"Map", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"X1", "[", 
        RowBox[{"0.7", ",", " ", "0.11", ",", " ", "#"}], "]"}], "&"}], ",", 
      "ti"}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{
  3.5401265957751226`*^9, {3.540127179340948*^9, 3.5401272427706594`*^9}, {
   3.5401273167771893`*^9, 3.540127317697591*^9}, {3.540393197485012*^9, 
   3.5403932003554173`*^9}, {3.5403935426668186`*^9, 
   3.5403935450848227`*^9}, {3.5403935904809027`*^9, 3.5403937458727756`*^9}, 
   3.5407341091509185`*^9, 3.5436450896722016`*^9, {3.543645189872342*^9, 
   3.5436451932623467`*^9}, {3.5436458896933217`*^9, 3.543645893233327*^9}, {
   3.5436459248133707`*^9, 3.54364593122338*^9}, {3.543646082853592*^9, 
   3.5436460897736015`*^9}, {3.545110745902032*^9, 3.545110752906444*^9}, 
   3.5451118269839306`*^9, {3.545119548714531*^9, 3.545119574844577*^9}, {
   3.5864963768445544`*^9, 3.586496382211092*^9}, {3.586501939572788*^9, 
   3.5865019626060905`*^9}, {3.5866692905810604`*^9, 3.5866693038113832`*^9}},
 CellLabel->"In[13]:="],

Cell[BoxData[
 RowBox[{
  RowBox[{"obj", "[", 
   RowBox[{
    RowBox[{"d0_", "?", "NumericQ"}], ",", 
    RowBox[{"d1_", "?", "NumericQ"}], ",", 
    RowBox[{"d2_", "?", "NumericQ"}]}], "]"}], ":=", 
  RowBox[{"Det", "[", 
   RowBox[{"m1", "[", 
    RowBox[{"{", 
     RowBox[{"d0", ",", 
      RowBox[{"d1", "+", "d0"}], ",", 
      RowBox[{"d0", "+", "d1", "+", "d2"}]}], "}"}], "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.570890730462919*^9, 3.570890749312152*^9}, {
   3.5708909540580053`*^9, 3.570890954633597*^9}, {3.5708911881635303`*^9, 
   3.5708912130578814`*^9}, 3.578373348839544*^9},
 CellLabel->"In[14]:="],

Cell["Now we evaluate the maximun ", "Text",
 CellChangeTimes->{{3.5706256479541006`*^9, 3.5706256662373323`*^9}, {
  3.570626197030265*^9, 3.570626210212288*^9}, {3.5709016953909874`*^9, 
  3.57090175591745*^9}, {3.5709734734654355`*^9, 3.5709734757057276`*^9}, {
  3.5916788879003286`*^9, 3.5916789109107714`*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"sol", " ", "=", 
  RowBox[{"NMaximize", "[", " ", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"obj", "[", 
       RowBox[{"d0", ",", "d1", ",", "d2"}], "]"}], ",", 
      RowBox[{"0.02", "<", "d1", "<", "10"}], ",", " ", 
      RowBox[{"0.02", "<", "d2", "<", "10"}]}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"d1", ",", "d2"}], "}"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.5708905800367517`*^9, 3.570890592937711*^9}, {
   3.570890817948639*^9, 3.5708908252008953`*^9}, {3.570891363297112*^9, 
   3.570891368543685*^9}, 3.5709008712128477`*^9, {3.5709014284147177`*^9, 
   3.570901432140931*^9}, 3.591678935902452*^9, {3.592061124768495*^9, 
   3.592061127317449*^9}, 3.592061254636384*^9},
 CellLabel->"In[15]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"2541.0496067197582`", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"d1", "\[Rule]", "1.5250101528550015`"}], ",", 
     RowBox[{"d2", "\[Rule]", "4.462031468644734`"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{3.578572636189087*^9, 3.578572686294981*^9, 
  3.586669342164218*^9, 3.5916802262990303`*^9, 3.592060981145753*^9, 
  3.5920612814810314`*^9, 3.643616809475837*^9, 3.656235508857096*^9},
 CellLabel->"Out[15]="]
}, Open  ]],

Cell["That is : the best moments to take the samples are", "Text",
 CellChangeTimes->{{3.5920610461347017`*^9, 3.5920610479335957`*^9}, {
  3.5920610844290185`*^9, 3.59206110769588*^9}}],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"d0", ",", " ", 
    RowBox[{"d0", "+", "d1"}], ",", " ", 
    RowBox[{"d0", "+", "d1", "+", "d2"}]}], "}"}], "/.", 
  RowBox[{"sol", "[", 
   RowBox[{"[", "2", "]"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.592061154135844*^9, 3.592061183671957*^9}, {
  3.5920612927631836`*^9, 3.5920613172476425`*^9}},
 CellLabel->"In[16]:="],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"0", ",", "1.5250101528550015`", ",", "5.987041621499736`"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.592061320899184*^9, 3.643616809553974*^9, 
  3.6562355089820957`*^9},
 CellLabel->"Out[16]="]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Section"],

Cell["\<\
1.\tInternational Commission on Radiological Protection. ICRP Database of \
Dose Coefficients: Workers and Members of the Public. Version 2.0.1 (CD-ROM), \
Oxford: Pergamon Press; (ICRP); 2001.
2.\tInternational Commission on Radiological Protection. Human respiratory \
tract model for radiological protection. Oxford: Pergamon Press; ICRP \
Publication 66; 1994.
3.\tInternational Commission on Radiological Protection. 30. Limits for \
intake of radionuclides by workers. Oxford: Pergamon Press; ICRP Publication \
30; 1981.
4.\tInternational Commission on Radiological Protection. Individual \
monitoring for internal exposure of workers. Oxford: Pergamon Press; (ICRP) \
Publication 78; 1997.
5.\tSanchez G, Lopez-Fidalgo J. Mathematical techniques for solving \
analytically large compartmental systems. Health Phys 85:184-193; 2003.
6.\tSanchez G., BIOKMOD: A Mathematica toolbox for modeling Biokinetic \
Systems. Mathematica and Research Vol.10 No.2; 2005
7.\tS\[AAcute]nchez G.; J.M.Rodr\[IAcute]guez-D\[IAcute]az.Optimal design and \
mathematical model applied to establish bioassay programs\
\[CloseCurlyDoubleQuote]:Radiation Protection \
Dosimetry.doi:10.1093/rpd/ncl499.2007. ISSN/ISBN:ISSN 1742-3406
8.\tL\[OAcute]pez-Fidalgo J, Rodr\[IAcute]guez-D\[IAcute]az J.M., \
S\[AAcute]nchez G. and Santos-Mart\[IAcute]n M.T. Optimal Designs for \
Compartmental Models with Correlated Observations. Journal of Applied \
Statistics Vol. 32, No. 10, 1075\[Dash]1088; 2005.
9.\tHill, P. D. H., 1980, D-optimal designs for partially nonlinear \
regression models. Technometrics 22:275\[Dash]276.
10.\tCressie, N., Statistics for Spatial Data, Wiley, New York 1993.
11.\tInternational Atomic Energy Agency. Direct Methoc for Measuring \
Radionuclides in the Human Body.  IAEA Safety Series No. 114. Vienna 1996.
12.\tSkrable KW, Chabot GE, French CS, La Bone TR. Intake retention functions \
and their applications to bioassay and the estimation of internal radiation \
doses. Health Phys 55:933-950; 1988.
13.  \tRodr\[IAcute]guez-D\[IAcute]az J.M., S\[AAcute]nchez G, Santos-Mart\
\[IAcute]n M.T. Optimal designs for compartmental models with \
unknown/non-constant transfer coefficients. MODA 2013.Lag\[OAcute]w Lubuski. \
Poland
14.\tJuan M. Rodr\[IAcute]guez-D\[IAcute]az; G. S\[AAcute]nchez-Le\[OAcute]n:\
\[CloseCurlyDoubleQuote]Design optimality for models defined by a system of \
ordinary differential equations\[CloseCurlyDoubleQuote] Biometrical Journal \
56 (5), pag 886\[Dash]900, September 2014\
\>", "SmallText",
 CellChangeTimes->{{3.5920605671413746`*^9, 3.5920606044105043`*^9}, {
  3.656235595591895*^9, 3.6562356005137334`*^9}, {3.65623566322288*^9, 
  3.656235695598065*^9}}]
}, Closed]]
}, Open  ]]
},
AutoGeneratedPackage->Automatic,
ScreenStyleEnvironment->"Brackets",
WindowToolbars->"EditBar",
WindowSize->{1134, 896},
WindowMargins->{{0, Automatic}, {Automatic, 0}},
DockedCells->(FrontEndExecute[{
   FrontEnd`NotebookApply[
    FrontEnd`InputNotebook[], #, Placeholder]}]& ),
PrintingStartingPageNumber->1,
PageHeaders->{{
   Cell[
    TextData[
     StyleBox[
      CounterBox["Page"], "PageNumber"]], "Header", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, 
   Cell[
    TextData[
     StyleBox[
      RowBox[{"Printed", " ", "from", " ", "the", " ", 
        StyleBox["Mathematica", FontSlant -> "Italic"], " ", "Help", " ", 
        "Browser"}], "PageHeader"]], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}, {
   Cell[
    TextData["Biokmod"], "Header", 
    CellMargins -> {{0, Inherited}, {Inherited, Inherited}}], None, 
   Cell[
    TextData[
     StyleBox[
      CounterBox["Page"], "PageNumber"]], "Header", 
    CellMargins -> {{Inherited, 0}, {Inherited, Inherited}}]}},
PageFooters->{{None, 
   Cell[
    TextData[
     StyleBox[
      RowBox[{
       "\[Copyright]", " ", "2013", " ", "Guillermo", " ", "S\[AAcute]nchez", 
        " ", "and", " ", "ENUSA", ".", " ", "All", " ", "rights", " ", 
        "reserved", "."}], "PageFooter"]], "Footer"], None}, {None, 
   Cell[
    TextData[{
     "http", ":", "//", "diarium", ".", "usal", ".", "es", "/", "guillermo"}],
     "Footer"], None}},
PageHeaderLines->{True, True},
PageFooterLines->{True, True},
PrintingOptions->{"FacingPages"->True,
"FirstPageFace"->Right,
"FirstPageFooter"->True,
"FirstPageHeader"->True},
ShowSelection->True,
Magnification->1.25,
FrontEndVersion->"10.2 for Microsoft Windows (64-bit) (July 29, 2015)",
StyleDefinitions->"HelpBrowser.nb"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{}
*)
(*CellTagsIndex
CellTagsIndex->{}
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[567, 22, 181, 5, 145, "Chapter"],
Cell[751, 29, 353, 9, 28, "Text"],
Cell[1107, 40, 511, 7, 34, "Commentary"],
Cell[CellGroupData[{
Cell[1643, 51, 57, 1, 30, "Input"],
Cell[1703, 54, 406, 7, 29, "Output"]
}, Open  ]],
Cell[CellGroupData[{
Cell[2146, 66, 159, 4, 110, "Section"],
Cell[2308, 72, 1162, 18, 159, "Commentary"],
Cell[3473, 92, 189, 2, 27, "Text"],
Cell[3665, 96, 274, 5, 46, "Reference"],
Cell[CellGroupData[{
Cell[3964, 105, 40, 0, 46, "SubsectionIcon"],
Cell[CellGroupData[{
Cell[4029, 109, 105, 2, 30, "Input"],
Cell[4137, 113, 145, 2, 24, "Print"],
Cell[4285, 117, 156, 2, 24, "Print"],
Cell[4444, 121, 144, 2, 24, "Print"],
Cell[4591, 125, 146, 2, 24, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[4774, 132, 124, 3, 30, "Input"],
Cell[4901, 137, 338, 5, 24, "Print"]
}, Open  ]],
Cell[5254, 145, 90, 3, 28, "Text"],
Cell[5347, 150, 2144, 66, 126, "DefinitionBox"]
}, Open  ]],
Cell[CellGroupData[{
Cell[7528, 221, 44, 0, 46, "SubsectionIcon"],
Cell[7575, 223, 2044, 69, 86, "Text"],
Cell[9622, 294, 380, 14, 27, "Text"],
Cell[CellGroupData[{
Cell[10027, 312, 488, 15, 32, "Input"],
Cell[10518, 329, 612, 17, 29, "Output"]
}, Open  ]],
Cell[11145, 349, 147, 5, 30, "Input"],
Cell[11295, 356, 510, 21, 39, "Text"],
Cell[11808, 379, 363, 12, 30, "Input"],
Cell[CellGroupData[{
Cell[12196, 395, 162, 5, 30, "Input"],
Cell[12361, 402, 1104, 34, 29, "Output"]
}, Open  ]],
Cell[13480, 439, 164, 3, 27, "Text"],
Cell[CellGroupData[{
Cell[13669, 446, 275, 9, 30, "Input"],
Cell[13947, 457, 328, 8, 29, "Output"]
}, Open  ]],
Cell[14290, 468, 963, 38, 27, "Text"],
Cell[CellGroupData[{
Cell[15278, 510, 433, 14, 30, "Input"],
Cell[15714, 526, 375, 10, 29, "Output"]
}, Open  ]],
Cell[16104, 539, 1445, 57, 46, "Text"],
Cell[CellGroupData[{
Cell[17574, 600, 108, 3, 30, "Input"],
Cell[17685, 605, 2760, 85, 52, "Output"]
}, Open  ]],
Cell[20460, 693, 1181, 50, 32, "Text"],
Cell[21644, 745, 742, 27, 100, "Text"],
Cell[22389, 774, 518, 17, 48, "Text"],
Cell[22910, 793, 25, 0, 27, "Text"],
Cell[22938, 795, 564, 18, 31, "Text"],
Cell[23505, 815, 233, 10, 27, "Text"],
Cell[23741, 827, 875, 30, 52, "Text"],
Cell[24619, 859, 834, 26, 39, "Input"],
Cell[CellGroupData[{
Cell[25478, 889, 249, 8, 30, "Input"],
Cell[25730, 899, 623, 18, 29, "Output"]
}, Open  ]],
Cell[26368, 920, 249, 8, 29, "Text"],
Cell[26620, 930, 246, 8, 32, "Input"],
Cell[CellGroupData[{
Cell[26891, 942, 115, 3, 30, "Input"],
Cell[27009, 947, 1266, 35, 67, "Output"]
}, Open  ]],
Cell[28290, 985, 406, 12, 46, "Text"],
Cell[28699, 999, 271, 8, 30, "Input"],
Cell[28973, 1009, 61, 0, 27, "Text"],
Cell[29037, 1011, 212, 8, 29, "Text"],
Cell[29252, 1021, 256, 7, 30, "Input"],
Cell[29511, 1030, 146, 4, 30, "Input"],
Cell[29660, 1036, 168, 3, 27, "Text"],
Cell[29831, 1041, 307, 10, 30, "Input"],
Cell[CellGroupData[{
Cell[30163, 1055, 324, 10, 30, "Input"],
Cell[30490, 1067, 405, 10, 29, "Output"]
}, Open  ]],
Cell[30910, 1080, 23, 0, 27, "Text"],
Cell[CellGroupData[{
Cell[30958, 1084, 130, 4, 30, "Input"],
Cell[31091, 1090, 308, 6, 29, "Output"]
}, Open  ]],
Cell[31414, 1099, 230, 4, 55, "Commentary"],
Cell[31647, 1105, 463, 16, 30, "Input"],
Cell[CellGroupData[{
Cell[32135, 1125, 307, 10, 30, "Input"],
Cell[32445, 1137, 402, 10, 29, "Output"]
}, Open  ]],
Cell[32862, 1150, 85, 2, 27, "Text"],
Cell[CellGroupData[{
Cell[32972, 1156, 506, 15, 30, "Input"],
Cell[33481, 1173, 6603, 119, 291, "Output"]
}, Open  ]],
Cell[40099, 1295, 303, 7, 30, "Input"],
Cell[40405, 1304, 132, 3, 28, "Text"],
Cell[CellGroupData[{
Cell[40562, 1311, 787, 23, 32, "Input"],
Cell[41352, 1336, 493, 13, 29, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[41894, 1355, 218, 8, 32, "SubsectionIcon"],
Cell[42115, 1365, 1974, 71, 102, "Text"],
Cell[44092, 1438, 661, 21, 56, "Text"],
Cell[CellGroupData[{
Cell[44778, 1463, 134, 6, 28, "SubsubsectionIcon"],
Cell[44915, 1471, 774, 24, 104, "MathCaption"],
Cell[45692, 1497, 79, 1, 27, "Text"],
Cell[45774, 1500, 6727, 298, 387, "DefinitionBox"],
Cell[52504, 1800, 364, 10, 70, "MathCaption"],
Cell[52871, 1812, 503, 13, 30, "Input"],
Cell[CellGroupData[{
Cell[53399, 1829, 76, 2, 30, "Input"],
Cell[53478, 1833, 373, 8, 29, "Output"]
}, Open  ]],
Cell[53866, 1844, 469, 18, 66, "MathCaption"],
Cell[CellGroupData[{
Cell[54360, 1866, 223, 6, 30, "Input"],
Cell[54586, 1874, 11964, 330, 404, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[66599, 2210, 179, 3, 27, "SubsubsectionIcon"],
Cell[66781, 2215, 801, 25, 100, "Text"],
Cell[67585, 2242, 45133, 560, 424, "Text"],
Cell[112721, 2804, 339, 4, 46, "Text"],
Cell[113063, 2810, 389, 13, 47, "Text"],
Cell[113455, 2825, 3511, 139, 161, "Text"],
Cell[116969, 2966, 1362, 45, 75, "Text"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[118380, 3017, 34, 0, 32, "SubsectionIcon"],
Cell[118417, 3019, 284, 5, 46, "Text"],
Cell[CellGroupData[{
Cell[118726, 3028, 287, 11, 28, "SubsubsectionIcon"],
Cell[119016, 3041, 627, 19, 56, "Text"],
Cell[119646, 3062, 1623, 57, 104, "Commentary"],
Cell[121272, 3121, 448, 11, 48, "Text"],
Cell[121723, 3134, 690, 25, 68, "MathCaption"],
Cell[CellGroupData[{
Cell[122438, 3163, 379, 11, 30, "Input"],
Cell[122820, 3176, 4387, 120, 140, "Output"]
}, Open  ]],
Cell[127222, 3299, 399, 15, 48, "MathCaption"],
Cell[127624, 3316, 102, 2, 47, "MathCaption"],
Cell[CellGroupData[{
Cell[127751, 3322, 789, 23, 30, "Input"],
Cell[128543, 3347, 3591, 88, 124, "Output"]
}, Open  ]],
Cell[132149, 3438, 99, 2, 47, "MathCaption"],
Cell[CellGroupData[{
Cell[132273, 3444, 793, 23, 53, "Input"],
Cell[133069, 3469, 3594, 88, 124, "Output"]
}, Open  ]],
Cell[136678, 3560, 84, 1, 27, "Text"],
Cell[136765, 3563, 411, 11, 68, "MathCaption"],
Cell[137179, 3576, 353, 10, 30, "Input"],
Cell[137535, 3588, 89, 2, 30, "Input"],
Cell[137627, 3592, 560, 16, 30, "Input"],
Cell[138190, 3610, 151, 3, 47, "MathCaption"],
Cell[CellGroupData[{
Cell[138366, 3617, 478, 14, 30, "Input"],
Cell[138847, 3633, 667, 16, 29, "Output"]
}, Open  ]],
Cell[139529, 3652, 50, 0, 47, "MathCaption"],
Cell[CellGroupData[{
Cell[139604, 3656, 596, 19, 30, "Input"],
Cell[140203, 3677, 368, 7, 29, "Output"]
}, Open  ]],
Cell[140586, 3687, 138, 3, 47, "MathCaption"],
Cell[CellGroupData[{
Cell[140749, 3694, 707, 18, 53, "Input"],
Cell[141459, 3714, 4176, 81, 312, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[145684, 3801, 351, 13, 30, "SubsubsectionIcon"],
Cell[146038, 3816, 646, 22, 50, "Text"],
Cell[146687, 3840, 381, 11, 50, "Text"],
Cell[147071, 3853, 100, 1, 27, "Text"],
Cell[CellGroupData[{
Cell[147196, 3858, 96, 2, 30, "Input"],
Cell[147295, 3862, 992, 27, 191, "Output"]
}, Open  ]],
Cell[148302, 3892, 50, 0, 27, "Text"],
Cell[148355, 3894, 1089, 27, 117, "Output"],
Cell[149447, 3923, 63, 0, 47, "MathCaption"],
Cell[149513, 3925, 1553, 45, 53, "Input"],
Cell[151069, 3972, 138, 5, 47, "MathCaption"],
Cell[151210, 3979, 1273, 37, 53, "Input"],
Cell[152486, 4018, 308, 10, 47, "MathCaption"],
Cell[152797, 4030, 999, 31, 30, "Input"],
Cell[153799, 4063, 1494, 52, 68, "MathCaption"],
Cell[155296, 4117, 454, 13, 56, "Text"],
Cell[155753, 4132, 99, 2, 27, "Text"],
Cell[CellGroupData[{
Cell[155877, 4138, 1109, 31, 75, "Input"],
Cell[156989, 4171, 4592, 114, 157, "Output"]
}, Open  ]],
Cell[161596, 4288, 69, 1, 27, "Text"],
Cell[161668, 4291, 164, 5, 30, "Input"],
Cell[161835, 4298, 437, 12, 68, "MathCaption"],
Cell[CellGroupData[{
Cell[162297, 4314, 150, 4, 30, "Input"],
Cell[162450, 4320, 500, 13, 29, "Output"]
}, Open  ]],
Cell[162965, 4336, 89, 2, 30, "Input"],
Cell[CellGroupData[{
Cell[163079, 4342, 383, 11, 30, "Input"],
Cell[163465, 4355, 360, 7, 29, "Output"]
}, Open  ]],
Cell[163840, 4365, 82, 1, 47, "MathCaption"],
Cell[CellGroupData[{
Cell[163947, 4370, 489, 15, 30, "Input"],
Cell[164439, 4387, 559, 13, 29, "Output"]
}, Open  ]],
Cell[165013, 4403, 150, 3, 27, "Text"],
Cell[CellGroupData[{
Cell[165188, 4410, 562, 17, 30, "Input"],
Cell[165753, 4429, 599, 14, 29, "Output"]
}, Open  ]],
Cell[166367, 4446, 50, 0, 47, "MathCaption"],
Cell[CellGroupData[{
Cell[166442, 4450, 603, 19, 30, "Input"],
Cell[167048, 4471, 345, 7, 29, "Output"]
}, Open  ]],
Cell[167408, 4481, 98, 2, 47, "MathCaption"],
Cell[CellGroupData[{
Cell[167531, 4487, 558, 15, 53, "Input"],
Cell[168092, 4504, 5688, 108, 280, "Output"]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[173829, 4618, 323, 12, 30, "SubsubsectionIcon"],
Cell[174155, 4632, 524, 18, 48, "Text"],
Cell[174682, 4652, 292, 8, 49, "MathCaption"],
Cell[174977, 4662, 949, 25, 53, "Input"],
Cell[175929, 4689, 462, 14, 30, "Input"],
Cell[176394, 4705, 95, 2, 27, "Text"],
Cell[176492, 4709, 333, 11, 30, "Input"],
Cell[176828, 4722, 330, 11, 27, "Text"],
Cell[CellGroupData[{
Cell[177183, 4737, 469, 14, 30, "Input"],
Cell[177655, 4753, 715, 18, 29, "Output"]
}, Open  ]]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[CellGroupData[{
Cell[178443, 4779, 271, 5, 45, "Section"],
Cell[178717, 4786, 145, 3, 30, "Input"],
Cell[178865, 4791, 216, 3, 27, "Text"],
Cell[179084, 4796, 342, 6, 46, "Reference"],
Cell[179429, 4804, 575, 10, 46, "Text"],
Cell[180007, 4816, 2077, 72, 140, "NumberedEquation"],
Cell[182087, 4890, 630, 17, 27, "Text"],
Cell[182720, 4909, 2694, 98, 66, "Text"],
Cell[185417, 5009, 1047, 23, 46, "Text"],
Cell[CellGroupData[{
Cell[186489, 5036, 320, 7, 37, "InputOnly"],
Cell[186812, 5045, 203, 3, 24, "Print"]
}, Open  ]],
Cell[CellGroupData[{
Cell[187052, 5053, 2556, 72, 124, "InputOnly"],
Cell[189611, 5127, 774, 20, 29, "Output"]
}, Open  ]],
Cell[190400, 5150, 111, 1, 27, "Text"],
Cell[190514, 5153, 783, 31, 29, "Text"],
Cell[191300, 5186, 249, 6, 30, "Input"],
Cell[191552, 5194, 105, 1, 27, "Text"],
Cell[191660, 5197, 855, 24, 52, "Input"],
Cell[192518, 5223, 238, 6, 30, "Input"],
Cell[192759, 5231, 579, 18, 33, "Text"],
Cell[193341, 5251, 1748, 60, 46, "Text"],
Cell[195092, 5313, 1571, 51, 46, "Text"],
Cell[196666, 5366, 705, 21, 47, "Text"],
Cell[CellGroupData[{
Cell[197396, 5391, 997, 18, 30, "Input"],
Cell[198396, 5411, 57677, 1052, 165, "Output"]
}, Open  ]],
Cell[256088, 6466, 688, 23, 37, "Text"],
Cell[256779, 6491, 1702, 32, 30, "Input"],
Cell[258484, 6525, 1810, 34, 30, "Input"],
Cell[260297, 6561, 1721, 61, 46, "Text"],
Cell[262021, 6624, 766, 19, 30, "Input"],
Cell[262790, 6645, 1947, 68, 118, "Text"],
Cell[264740, 6715, 1343, 39, 32, "Input"],
Cell[266086, 6756, 249, 8, 29, "Text"],
Cell[266338, 6766, 246, 8, 32, "Input"],
Cell[266587, 6776, 90, 1, 27, "Text"],
Cell[266680, 6779, 464, 10, 30, "Input"],
Cell[267147, 6791, 453, 7, 27, "Text"],
Cell[267603, 6800, 157, 2, 27, "Text"],
Cell[267763, 6804, 212, 8, 29, "Text"],
Cell[267978, 6814, 132, 1, 27, "Text"],
Cell[268113, 6817, 1451, 31, 30, "Input"],
Cell[269567, 6850, 625, 16, 30, "Input"],
Cell[270195, 6868, 316, 4, 27, "Text"],
Cell[CellGroupData[{
Cell[270536, 6876, 763, 17, 30, "Input"],
Cell[271302, 6895, 474, 11, 29, "Output"]
}, Open  ]],
Cell[271791, 6909, 186, 2, 27, "Text"],
Cell[CellGroupData[{
Cell[272002, 6915, 380, 10, 30, "Input"],
Cell[272385, 6927, 236, 6, 29, "Output"]
}, Open  ]]
}, Closed]],
Cell[CellGroupData[{
Cell[272670, 6939, 29, 0, 45, "Section"],
Cell[272702, 6941, 2710, 44, 400, "SmallText"]
}, Closed]]
}, Open  ]]
}
]
*)

(* End of internal cache information *)
